colors = {
"100 Mph":0xc93f38,
"18th Century Green":0xa59344,
"1975 Earth Red":0x7b463b,
"1989 Miami Hotline":0xdd3366,
"20000 Leagues Under the Sea":0x191970,
"24 Karat":0xab7f46,
"3AM in Shibuya":0x225577,
"3am Latte":0xc0a98e,
"400XT Film":0xd2d2c0,
"5-Masted Preußen":0x9bafad,
"8 Bit Eggplant":0x990066,
"90% Cocoa":0x3d1c02,
"A Brand New Day":0xffaabb,
"A Certain Shade Of Green":0xd1edee,
"A Dime a Dozen":0xd3dde4,
"A Hint of Incremental Blue":0x456789,
"A La Mode":0xf6ecde,
"A Lot of Love":0xffbcc5,
"A Pair of Brown Eyes":0xbfaf92,
"A Smell of Bakery":0xf3e9d9,
"A State of Mint":0x88ffcc,
"Aare River":0x00b89f,
"Aare River Brienz":0x05a3ad,
"Aarhusian Sky":0x1150af,
"Abaddon Black":0x231f20,
"Abaidh White":0xf2f1e6,
"Abalone":0xf8f3f6,
"Abalone Shell":0xe1ded9,
"Abandoned Mansion":0x94877e,
"Abbey":0x4c4f56,
"Abbey Road":0xa79f92,
"Abbey Stone":0xaba798,
"Abbey White":0xece6d0,
"Abbot":0x4d3c2d,
"Abduction":0x166461,
"Âbi Blue":0x5ba8ff,
"Abilene Lace":0xeae3d2,
"Ablaze":0xc04641,
"Abomination":0x77aa77,
"Abra Cadabra":0x966165,
"Abra Goldenrod":0xeec400,
"Absence of Light":0x15151c,
"Absinthe Green":0x76b583,
"Absinthe Turquoise":0x008a60,
"Absolute Apricot":0xff9944,
"Absolute Zero":0x0048ba,
"Abstract":0xe4cb97,
"Abstract White":0xede9dd,
"Abundance":0x629763,
"Abura Green":0xa19361,
"Abyss":0x8f9e9d,
"Abyssal Anchorfish Blue":0x1b2632,
"Abyssal Blue":0x00035b,
"Abyssal Depths":0x10246a,
"Abyssal Waters":0x005765,
"Abysse":0x3d5758,
"Abyssopelagic Water":0x000033,
"Acacia":0xdacd65,
"Acacia Green":0x486241,
"Acacia Haze":0x969c92,
"Academic Blue":0x2c3e56,
"Academy Purple":0x525367,
"Acadia":0x35312c,
"Acadia Bloom":0xe5b7be,
"Acai":0x46295a,
"Acai Berry":0x42314b,
"Acai Juice":0x942193,
"Acajou":0x4c2f27,
"Acanthus":0x9899a7,
"Acanthus Leaf":0x90977a,
"Acapulco":0x75aa94,
"Acapulco Cliffs":0x4e9aa8,
"Acapulco Dive":0x65a7dd,
"Acapulco Sun":0xeb8a44,
"Accent Green Blue":0x208468,
"Accent Orange":0xe56d00,
"Accessible Beige":0xd2c7b7,
"Accolade":0x7c94b2,
"Accursed Black":0x090807,
"Ace":0xc7cce7,
"Aceituna Picante":0x727a5f,
"Aceto Balsamico":0x4e4f48,
"Acid":0x00ff22,
"Acid Blond":0xefedd7,
"Acid Candy":0xa8c74d,
"Acid Drop":0x11ff22,
"Acid Green":0x8ffe09,
"Acid Lime":0xbadf30,
"Acid Pool":0x00ee22,
"Acid Pops":0x33ee66,
"Acid Sleazebag":0x4fc172,
"Acier":0x9e9991,
"Acini di Pepe":0xffd8b1,
"Acorn":0x7e5e52,
"Acorn Spice":0xb87439,
"Acorn Squash":0xeda740,
"Acoustic White":0xefece1,
"Across the Bay":0xb3e1e8,
"Actinic Light":0xff44ee,
"Action Green":0x00504b,
"Active Green":0x00a67e,
"Active Turquoise":0x006f72,
"Active Volcano":0xbb1133,
"Actor's Star":0xa7a6a3,
"Adamite Green":0x3b845e,
"Adana Kebabı":0x661111,
"Adaptive Shade":0x867e70,
"Addo Skin":0x585d58,
"Adeline":0xccb0b5,
"Adept":0x293947,
"Adeptus Battlegrey":0x7c8286,
"Adhesion":0x9e9cab,
"Adirondack":0xb0b9c1,
"Adirondack Blue":0x74858f,
"Admiral Blue":0x50647f,
"Admiralty":0x404e61,
"Admiration":0xf6f3d3,
"Adobe":0xbd6c48,
"Adobe Avenue":0xfb9587,
"Adobe Beige":0xdcbfa6,
"Adobe Rose":0xba9f99,
"Adobe Sand":0xe8dec5,
"Adobe South":0xe5c1a7,
"Adobe Straw":0xc3a998,
"Adobe White":0xe6dbc4,
"Adonis":0x64b5bf,
"Adonis Rose Yellow":0xefbf4d,
"Adorable":0xe3beb0,
"Adriatic Blue":0x5c899b,
"Adriatic Haze":0x96c6cd,
"Adriatic Mist":0xd3ece4,
"Adriatic Sea":0x016081,
"Adrift":0x4b9099,
"Advantageous":0x20726a,
"Adventure":0x34788c,
"Adventure Island Pink":0xf87858,
"Adventure Isle":0x6f9fb9,
"Adventure Orange":0xeda367,
"Adventurer":0x72664f,
"Advertisement Green":0xd8cb4b,
"Advertising Blue":0x0081a8,
"Advertising Green":0x53a079,
"Aebleskiver":0xe6d3b6,
"Aegean Blue":0x4e6e81,
"Aegean Green":0x4c8c72,
"Aegean Mist":0x9cbbe2,
"Aegean Sea":0x508fa2,
"Aegean Sky":0xe48b59,
"Aegean Splendor":0x9ba0a4,
"Aerial View":0xa0b2c8,
"Aero":0x7cb9e8,
"Aero Blue":0xc0e8d5,
"Aerobic Fix":0xa2c348,
"Aeronautic":0x2b3448,
"Aerospace Orange":0xff4f00,
"Aerostatics":0x355376,
"Aesthetic White":0xe3ddd3,
"Affair":0x745085,
"Affen Turquoise":0xaaffff,
"Affinity":0xfed2a5,
"Afghan Carpet":0x905e26,
"Afghan Hound":0xe2d7b5,
"Afghan Sand":0xd3a95c,
"Afloat":0x78a3c2,
"African Ambush":0x8e603c,
"African Bubinga":0xc7927a,
"African Gray":0x939899,
"African Mahogany":0xcd4a4a,
"African Mud":0x826c68,
"African Plain":0x86714a,
"African Queen":0x645e42,
"African Safari":0xb16b40,
"African Sand":0xccaa88,
"African Violet":0xb085b7,
"After Burn":0xfd8b60,
"After Dark":0x3c3535,
"After Dinner Mint":0xe3f5e5,
"After Eight Filling":0xd6eae8,
"After Midnight":0x38393f,
"After Rain":0xc1dbea,
"After Shock":0xfec65f,
"After the Rain":0x8bc4d1,
"After the Storm":0x33616a,
"After Work Blue":0x24246d,
"After-Party Pink":0xc95efb,
"Aftercare":0x85c0cd,
"Afterglow":0xf3e6c9,
"Afterlife":0xd91fff,
"Afternoon":0xfbcb78,
"Afternoon Sky":0x87ceeb,
"Afternoon Stroll":0xd9c5a1,
"Afternoon Tea":0x594e40,
"Agapanthus":0xbbc5de,
"Agate Brown":0x956a60,
"Agate Green":0x599f99,
"Agate Grey":0xb1b09f,
"Agate Violet":0x5a5b74,
"Agave":0x879d99,
"Agave Frond":0x5a6e6a,
"Agave Green":0x6b7169,
"Agave Plant":0x879c67,
"Aged Beige":0xd7cfc0,
"Aged Brandy":0x87413f,
"Aged Chocolate":0x5f4947,
"Aged Cotton":0xe0dcda,
"Aged Eucalyptus":0x898253,
"Aged Gouda":0xdd9944,
"Aged Jade":0x6c6956,
"Aged Merlot":0x73343a,
"Aged Mustard Green":0x6e6e30,
"Aged Olive":0x7e7666,
"Aged Parchment":0xe9ddca,
"Aged Pewter":0x889999,
"Aged Pink":0xc99f99,
"Aged Plastic Casing":0xfffa86,
"Aged Purple":0xa442a0,
"Aged Teak":0x7a4134,
"Aged to Perfection":0xa58ea9,
"Aged Whisky":0x9d7147,
"Aged White":0xe8decd,
"Aged Wine":0x895460,
"Ageless":0xececdf,
"Ageless Beauty":0xe7a995,
"Agent Orange":0xee6633,
"Aggressive Baby Blue":0x6fffff,
"Aggressive Salmon":0xff7799,
"Aging Barrel":0x6a5b4e,
"Agrax Earthshade":0x393121,
"Agreeable Gray":0xd1cbc1,
"Agrellan Badland":0xffb347,
"Agrellan Earth":0xa17c59,
"Agressive Aqua":0x00fbff,
"Agrodolce":0xf0e2d3,
"Agua Fría":0x9fc5cc,
"Ahaetulla Prasina":0x00fa92,
"Ahmar Red":0xc22147,
"Ahoy":0x2a3149,
"Ahriman Blue":0x199ebd,
"Ai Indigo":0x274447,
"Aida":0xb4c8b6,
"Aijiro White":0xecf7f7,
"Aimee":0xeee5e1,
"Aimiru Brown":0x2e372e,
"Air Blue":0x77acc7,
"Air Castle":0xd7d1e9,
"Air Force Blue":0x5d8aa8,
"Air of Mint":0xd8f2ee,
"Air Superiority Blue":0x72a0c1,
"Airborne":0xa2c2d0,
"Airbrushed Copper":0xaa6c51,
"Aircraft Blue":0x354f58,
"Aircraft Exterior Grey":0x939498,
"Aircraft Green":0x2a2c1f,
"Aircraft White":0xedf2f8,
"Airflow":0xd9e5e4,
"Airforce":0x364d70,
"Airline Green":0x8c9632,
"Airy":0xdae6e9,
"Airy Blue":0x88ccee,
"Airy Green":0xdbe0c4,
"Ajo Lily":0xfaecd9,
"Ajwain Green":0xd3de7b,
"Akabeni":0xc3272b,
"Akai Red":0xbc012e,
"Akakō Red":0xf07f5e,
"Akaroa":0xbeb29a,
"Ake Blood":0xcf3a24,
"Akebi Purple":0x983fb2,
"Akebono Dawn":0xfa7b62,
"Akhdhar Green":0xb0e313,
"Akihabara Arcade":0x601ef9,
"Akira Red":0xe12120,
"Akuma's Fury":0x871646,
"Alabama Crimson":0xa32638,
"Alabaster":0xf3e7db,
"Alabaster Beauty":0xe9e3d2,
"Alabaster Gleam":0xf0debd,
"Alabaster White":0xdfd4bf,
"Aladdin's Feather":0x5500ff,
"Alaea":0x81585b,
"Alaitoc Blue":0x8e8c97,
"Alajuela Toad":0xffae52,
"Alameda Ochre":0xca9234,
"Alamosa Green":0x939b71,
"Alarm":0xec0003,
"Alarming Slime":0x2ce335,
"Alaskan Blue":0x6da9d2,
"Alaskan Cruise":0x34466c,
"Alaskan Grey":0xbcbebc,
"Alaskan Ice":0x7e9ec2,
"Alaskan Mist":0xecf0e5,
"Alaskan Moss":0x05472a,
"Alaskan Skies":0xcddced,
"Alaskan Wind":0xbae3eb,
"Albanian Red":0xcc0001,
"Albeit":0x38546e,
"Albert Green":0x4f5845,
"Albescent White":0xe1dacb,
"Albino":0xfbeee5,
"Albuquerque":0xcca47e,
"Alchemy":0xe7cf8c,
"Aldabra":0xaaa492,
"Alden Till":0x7a4b49,
"Alert Tan":0x954e2c,
"Alesan":0xf1ceb3,
"Aleutian":0x9a9eb3,
"Alexandra Peach":0xdb9785,
"Alexandria":0xff8f73,
"Alexandria's Lighthouse":0xfcefc1,
"Alexandrian Sky":0xbcd9dc,
"Alexandrite":0x598c74,
"Alexandrite Green":0x767853,
"Alexis Blue":0x416082,
"Alfalfa":0xb7b59f,
"Alfalfa Extract":0x546940,
"Alga Moss":0x8da98d,
"Algae":0x54ac68,
"Algae Green":0x93dfb8,
"Algae Red":0x983d53,
"Algal Fuel":0x21c36f,
"Algen Gerne":0x479784,
"Algerian Coral":0xfc5a50,
"Algiers Blue":0x00859c,
"Algodon Azul":0xc1dbec,
"Alhambra":0x008778,
"Alhambra Cream":0xf7f2e1,
"Alhambra Green":0x00a465,
"Alibi":0xd4cbc4,
"Alice Blue":0xf0f8ff,
"Alice White":0xc2ced2,
"Alien":0x415764,
"Alien Abduction":0x0cff0c,
"Alien Armpit":0x84de02,
"Alien Breed":0xb9cc81,
"Alien Parasite":0x55ff33,
"Alien Purple":0x490648,
"Alienator Grey":0x9790a4,
"Align":0x00728d,
"Alizarin":0xe34636,
"Alizarin Crimson":0xe32636,
"All About Olive":0x676c58,
"All Dressed Up":0xe6999d,
"All Made Up":0xefd7e7,
"All Nighter":0x455454,
"All's Ace":0xc68886,
"Allegiance":0x5a6a8c,
"Allegory":0xb4b2a9,
"Allegro":0xb28959,
"Alley":0xb8c4d9,
"Alley Cat":0x656874,
"Alliance":0x2b655f,
"Alligator":0x886600,
"Alligator Egg":0xeaeed7,
"Alligator Gladiator":0x444411,
"Alligator Skin":0x646048,
"Allison Lace":0xf1ead4,
"Allium":0x9569a3,
"Alloy":0x98979a,
"Alloy Orange":0xc46210,
"Allports":0x1f6a7d,
"Allspice":0xf8cdaa,
"Allura Red":0xed2e38,
"Allure":0x7291b4,
"Alluring Blue":0x9ec4cd,
"Alluring Gesture":0xf8dbc2,
"Alluring Light":0xfff7d8,
"Alluring Umber":0x977b4d,
"Alluring White":0xefe1d2,
"Alluvial Inca":0xbb934b,
"Allyson":0xcb738b,
"Almeja":0xf5e0c9,
"Almendra Tostada":0xe8d6bd,
"Almond":0xeddcc8,
"Almond Beige":0xdfd5ca,
"Almond Biscuit":0xe9c9a9,
"Almond Blossom":0xf5bec7,
"Almond Blossom Pink":0xe0d2d1,
"Almond Brittle":0xe5d3b9,
"Almond Buff":0xccb390,
"Almond Butter":0xd8c6a8,
"Almond Cookie":0xeec87c,
"Almond Cream":0xf4c29f,
"Almond Frost":0x9a8678,
"Almond Green":0x595e4c,
"Almond Icing":0xefe3d9,
"Almond Kiss":0xf6e3d4,
"Almond Latte":0xd6c0a4,
"Almond Milk":0xd6cebe,
"Almond Oil":0xf4efc1,
"Almond Paste":0xe5dbc5,
"Almond Roca":0xf0e8e0,
"Almond Rose":0xcc8888,
"Almond Silk":0xe1cfb2,
"Almond Toast":0xbf9e77,
"Almond Truffle":0x7d665b,
"Almond Willow":0xe6c9bc,
"Almond Wisp":0xd6cab9,
"Almondine":0xfedebc,
"Almost Aloe":0xbfe5b1,
"Almost Apricot":0xe5b39b,
"Almost Aqua":0x98ddc5,
"Almost Famous":0x3a5457,
"Almost Mauve":0xe7dcd9,
"Almost Pink":0xf0e3da,
"Aloe":0x817a60,
"Aloe Blossom":0xc97863,
"Aloe Cream":0xdbe5b9,
"Aloe Essence":0xecf1e2,
"Aloe Leaf":0x61643f,
"Aloe Mist":0xdcf2e3,
"Aloe Nectar":0xdfe2c9,
"Aloe Plant":0xb8ba87,
"Aloe Thorn":0x888b73,
"Aloe Vera":0x678779,
"Aloe Vera Green":0x7e9b39,
"Aloe Vera Tea":0x848b71,
"Aloe Wash":0xd0d3b7,
"Aloeswood":0x6a432d,
"Aloha":0x1db394,
"Aloha Sunset":0xe9aa91,
"Alone in the Dark":0x000066,
"Aloof":0xd4e2e6,
"Aloof Gray":0xc9c9c0,
"Aloof Lama":0xd6c5a0,
"Alpaca":0xf7e5da,
"Alpaca Blanket":0xded7c5,
"Alpaca Wool":0xf9ede2,
"Alpenglow":0xf0beb8,
"Alpha Blue":0x588bb4,
"Alpha Centauri":0x4d5778,
"Alpha Gold":0xae8e5f,
"Alpha Male":0x715a45,
"Alpha Tango":0x628fb0,
"Alphabet Blue":0xabcdef,
"Alpine":0xad8a3b,
"Alpine Air":0xa9b4a9,
"Alpine Alabaster":0xbadbe6,
"Alpine Berry Yellow":0xf7e0ba,
"Alpine Blue":0xdbe4e5,
"Alpine Duck Grey":0x40464d,
"Alpine Expedition":0x99eeff,
"Alpine Frost":0xe0ded2,
"Alpine Goat":0xf1f2f8,
"Alpine Green":0x005f56,
"Alpine Haze":0xabbec0,
"Alpine Herbs":0x449955,
"Alpine Lake Green":0x4f603e,
"Alpine Landing":0x117b87,
"Alpine Moon":0xded3e6,
"Alpine Morning Blue":0xa6ccd8,
"Alpine Race":0x234162,
"Alpine Salamander":0x051009,
"Alpine Summer":0xa5a99a,
"Alpine Trail":0x515a52,
"Alsike Clover Red":0xb1575f,
"Alsot Olive":0xdfd5b1,
"Altar of Heaven":0x4d4c80,
"Altdorf Guard Blue":0x1f56a7,
"Altdorf Sky Blue":0x00a1ac,
"Alter Ego":0x69656d,
"Altered Pink":0xefc7be,
"Alto":0xcdc6c5,
"Alu Gobi":0xddbb00,
"Alucard's Night":0x000055,
"Aluminium":0x848789,
"Aluminium Powder":0xa9a0a9,
"Aluminium Snow":0xaeafb4,
"Aluminum":0x9f9586,
"Aluminum Foil":0xd2d9db,
"Aluminum Silver":0x8c8d91,
"Aluminum Sky":0xadafaf,
"Alverda":0xa5c970,
"Always Almond":0xebe5d2,
"Always Apple":0xa0a667,
"Always Blue":0xa2bacb,
"Always Green Grass":0x11aa00,
"Always Indigo":0x66778c,
"Always Neutral":0xdfd7cb,
"Always Rosey":0xe79db3,
"Alyssa":0xf4e2d6,
"Alyssum":0xf2d5d7,
"Amalfi":0x016e85,
"Amalfi Coast":0x297cbf,
"Amalfitan Azure":0x033b9a,
"Amaranth":0xe86ead,
"Amaranth Blossom":0x7b2331,
"Amaranth Deep Purple":0x9f2b68,
"Amaranth Pink":0xf19cbb,
"Amaranth Purple":0x6a397b,
"Amaranth Red":0xd3212d,
"Amarantha Red":0xcc3311,
"Amaranthine":0x5f4053,
"Amaretto":0xab6f60,
"Amaretto Sour":0xc09856,
"Amarillo Bebito":0xfff1d4,
"Amarillo Yellow":0xfbf1c3,
"Amarklor Violet":0x551199,
"Amaryllis":0xb85045,
"Amaya":0xf2c1cb,
"Amazing Amethyst":0x806568,
"Amazing Boulder":0xa9a797,
"Amazing Gray":0xbeb5a9,
"Amazing Smoke":0x6680bb,
"Amazon":0x387b54,
"Amazon Breeze":0xebebd6,
"Amazon Depths":0x505338,
"Amazon Foliage":0x606553,
"Amazon Green":0x786a4a,
"Amazon Jungle":0x686747,
"Amazon Mist":0xececdc,
"Amazon Moss":0x7e8c7a,
"Amazon Queen":0x948f54,
"Amazon River":0x777462,
"Amazon River Dolphin":0xe6b2b8,
"Amazon Stone":0x7e7873,
"Amazon Vine":0xabaa97,
"Amazonian":0xaa6644,
"Amazonian Orchid":0xa7819d,
"Amazonite":0x00c4b0,
"Ambassador Blue":0x0d2f5a,
"Amber":0xffbf00,
"Amber Autumn":0xc69c6a,
"Amber Brew":0xd7a361,
"Amber Brown":0xa66646,
"Amber Dawn":0xf6bc77,
"Amber Glass":0xc79958,
"Amber Glow":0xf29a39,
"Amber Gold":0xc19552,
"Amber Green":0x9a803a,
"Amber Grey":0xd0a592,
"Amber Leaf":0xba9971,
"Amber Moon":0xeed1a5,
"Amber Romance":0xb18140,
"Amber Sun":0xff9988,
"Amber Tide":0xffafa3,
"Amber Wave":0xd78b55,
"Amber Yellow":0xfab75a,
"Amberglow":0xdc793e,
"Amberlight":0xe2bea2,
"Ambience White":0xe7e7e6,
"Ambient Glow":0xf8ede0,
"Ambit":0x97653f,
"Ambitious Amber":0xf0cb97,
"Ambitious Rose":0xe9687e,
"Ambrosia":0xd2e7ca,
"Ambrosia Coffee Cake":0xeee9d3,
"Ambrosia Ivory":0xfff4eb,
"Ambrosia Salad":0xf4ded3,
"Ameixa":0x6a5acd,
"Amelia":0xbeccc2,
"Amélie's Tutu":0xfea7bd,
"America's Cup":0x34546d,
"American Anthem":0x7595ab,
"American Beauty":0xa73340,
"American Blue":0x3b3b6d,
"American Bronze":0x391802,
"American Brown":0x804040,
"American Gold":0xd3af37,
"American Green":0x34b334,
"American Mahogany":0x52352f,
"American Milking Devon":0x63403a,
"American Orange":0xff8b00,
"American Pink":0xff9899,
"American Purple":0x431c53,
"American Red":0xb32134,
"American River":0x626e71,
"American Roast":0x995544,
"American Rose":0xff033e,
"American Silver":0xcfcfcf,
"American Violet":0x551b8c,
"American Yellow":0xf2b400,
"American Yorkshire":0xefdcd4,
"Americana":0x0477b4,
"Americano":0x463732,
"Amethyst":0x9966cc,
"Amethyst Cream":0xeceaec,
"Amethyst Dark Violet":0x4f3c52,
"Amethyst Ganzstar":0x8f00ff,
"Amethyst Gem":0x776985,
"Amethyst Grey":0x9085c4,
"Amethyst Grey Violet":0x9c89a1,
"Amethyst Haze":0xa0a0aa,
"Amethyst Ice":0xd0c9c6,
"Amethyst Light Violet":0xcfc2d1,
"Amethyst Orchid":0x926aa6,
"Amethyst Paint":0x9c8aa4,
"Amethyst Phlox":0x9b91a1,
"Amethyst Purple":0x562f7e,
"Amethyst Show":0xbd97cf,
"Amethyst Smoke":0x95879c,
"Ametrine Quartz":0xded1e0,
"Amiable Orange":0xdf965b,
"Amish Bread":0xe6ddbe,
"Amish Green":0x3a5f4e,
"Amnesia Blue":0x1560bd,
"Amok":0xddcc22,
"Amor":0xee3377,
"Amora Purple":0xbb22aa,
"Amore":0xae2f48,
"Amorphous Rose":0xb1a7b7,
"Amour":0xee5851,
"Amour Frais":0xf5e6ea,
"Amourette":0xc8c5d7,
"Amourette Eternelle":0xe0dfe8,
"Amparo Blue":0x4960a8,
"Amphibian":0x264c47,
"Amphitrite":0x384e47,
"Amphora":0x9f8672,
"Amphystine":0x3f425a,
"Amulet":0x7d9d72,
"Amulet Gem":0x01748e,
"Amygdala Purple":0x69045f,
"Àn Zǐ Purple":0x94568c,
"Anaheim Pepper":0x00bb44,
"Anakiwa":0x8cceea,
"Analytical Gray":0xbfb6a7,
"Anarchist":0xdb304a,
"Anarchy":0xde0300,
"Ancestral":0xd0c1c3,
"Ancestral Gold":0xddcda6,
"Ancestral Water":0xd0d0d0,
"Ancestry Violet":0x9e90a7,
"Ancho Pepper":0x7a5145,
"Anchor Grey":0x596062,
"Anchor Point":0x435d8b,
"Anchorman":0x2c3641,
"Anchors Away":0x9ebbcd,
"Anchors Aweigh":0x2b3441,
"Anchovy":0x756f6b,
"Ancient Bamboo":0xda6304,
"Ancient Brandy":0xaa6611,
"Ancient Bronze":0x9c5221,
"Ancient Chest":0x99522b,
"Ancient Copper":0x9f543e,
"Ancient Doeskin":0xdcc9a8,
"Ancient Earth":0x746550,
"Ancient Ice":0x73fdff,
"Ancient Ivory":0xf1e6d1,
"Ancient Kingdom":0xd6d8cd,
"Ancient Lavastone":0x483c32,
"Ancient Magenta":0x953d55,
"Ancient Marble":0xd1ccb9,
"Ancient Maze":0x959651,
"Ancient Murasaki Purple":0x895b8a,
"Ancient Olive":0x6a5536,
"Ancient Pages":0xddd4ce,
"Ancient Pewter":0x898d91,
"Ancient Planks":0x774411,
"Ancient Pottery":0xa37d5e,
"Ancient Prunus":0x5a3d3f,
"Ancient Red":0x922a31,
"Ancient Root":0x70553d,
"Ancient Royal Banner":0x843f5b,
"Ancient Ruins":0xe0cac0,
"Ancient Scroll":0xf5e6de,
"Ancient Shelter":0x83696e,
"Ancient Stone":0xded8d4,
"Ancient Yellow":0xeecd00,
"Andean Opal Green":0xafcdc7,
"Andean Slate":0x90b19d,
"Andes Ash":0xc1a097,
"Andes Sky":0x78d8d9,
"Andiron":0x424036,
"Andorra":0x603535,
"Andouille":0xb58338,
"Andover Cream":0xfaf0d3,
"Andrea Blue":0x4477dd,
"Android Green":0xa4c639,
"Andromeda Blue":0xabcdee,
"Anemone":0x842c48,
"Anemone White":0xf9efe4,
"Anew Gray":0xbeb6ab,
"Angel Aura":0xafa8ae,
"Angel Blue":0x83c5cd,
"Angel Blush":0xf7e3da,
"Angel Breath":0xdcaf9f,
"Angel Face Rose":0xfe83cc,
"Angel Falls":0xa3bdd3,
"Angel Feather":0xf4efee,
"Angel Finger":0xb8acb4,
"Angel Food":0xf0e8d9,
"Angel Food Cake":0xd7a14f,
"Angel Green":0x004225,
"Angel Hair Silver":0xd2d6db,
"Angel Heart":0xa17791,
"Angel in Blue Jeans":0xbbc6d9,
"Angel Kiss":0xcec7dc,
"Angel of Death Victorious":0xc6f0e7,
"Angel Shark":0xe19640,
"Angel Wing":0xf3dfd7,
"Angel's Face":0xeed4c8,
"Angel's Feather":0xf3f1e6,
"Angel's Whisper":0xdbdfd4,
"Angela Bay":0xa9c1e5,
"Angela Canyon":0xc99997,
"Angelic":0xf2dcd7,
"Angelic Blue":0xbbc6d6,
"Angelic Choir":0xe9d9dc,
"Angelic Descent":0xeecc33,
"Angelic Eyes":0xbbd1e8,
"Angelic Sent":0xe3dfea,
"Angelic Starlet":0xebe9d8,
"Angelic White":0xf4ede4,
"Angelico":0xeacfc2,
"Angélique Grey":0xd8dee7,
"Anger":0xdd0055,
"Angora":0xdfd1bb,
"Angora Blue":0xb9c6d8,
"Angora Goat":0xede7de,
"Angora Pink":0xebdfea,
"Angraecum Orchid":0xf4f6ec,
"Angry Flamingo":0xf04e45,
"Angry Gargoyle":0x9799a6,
"Angry Ghost":0xeebbbb,
"Angry Gremlin":0x37503d,
"Angry Hornet":0xee9911,
"Angry Ocean":0x4e6665,
"Angry Pasta":0xffcc55,
"Aniline Mauve":0xb9abad,
"Animal Blood":0xa41313,
"Animal Cracker":0xf4e6ce,
"Animal Kingdom":0xbcc09e,
"Animated Coral":0xed9080,
"Animation":0x1d5c83,
"Anime":0xccc14d,
"Anise Biscotti":0xc0baaf,
"Anise Flower":0xf4e3b5,
"Anise Grey Yellow":0xb0ac98,
"Aniseed Leaf Green":0x8cb684,
"Anita":0x91a0b7,
"Anjou Pear":0xcdca9f,
"Annabel":0xf7efcf,
"Annapolis Blue":0x384a66,
"Annis":0x6b475d,
"Annular":0xe17861,
"Anode":0x89a4cd,
"Anon":0xbdbfc8,
"Anonymous":0xdadcd3,
"Another One Bites the Dust":0xc7bba4,
"Ant Red":0xb05d4a,
"Antarctic Blue":0x2b3f5c,
"Antarctic Circle":0x0000bb,
"Antarctic Deep":0x35383f,
"Antarctica":0xc6c5c6,
"Antarctica Lake":0xbfd2d0,
"Antelope":0xb19664,
"Anthill":0x7f684e,
"Anthracite":0x28282d,
"Anthracite Blue":0x3d475e,
"Anthracite Grey":0x373f42,
"Anthracite Red":0x73293b,
"Anti Rainbow Grey":0xbebdbc,
"Anti-Flash White":0xf2f3f4,
"Antigua":0x256d73,
"Antigua Blue":0x06b1c4,
"Antigua Sand":0x83c2cd,
"Antigua Sunrise":0xffe7c8,
"Antilles Blue":0x3b5e8d,
"Antilles Garden":0x8aa277,
"Antimony":0xc7c8c1,
"Antiquarian Brown":0x946644,
"Antiquarian Gold":0xba8a45,
"Antiquate":0x8d8aa0,
"Antique":0x8b846d,
"Antique Bear":0x9c867b,
"Antique Bourbon":0x926b43,
"Antique Brass":0x6c461f,
"Antique Bronze":0x704a07,
"Antique Brown":0x553f2d,
"Antique Cameo":0xf0baa4,
"Antique Candle Light":0xf4e1d6,
"Antique Chest":0xa7856d,
"Antique China":0xfdf6e7,
"Antique Coin":0xb5b8a8,
"Antique Copper":0x9e6649,
"Antique Coral":0xffc7b0,
"Antique Earth":0x7e6c5f,
"Antique Fuchsia":0x915c83,
"Antique Garnet":0x8e5e5e,
"Antique Gold":0xb59e5f,
"Antique Green":0x29675c,
"Antique Grey":0x69576d,
"Antique Heather":0xcdbacb,
"Antique Honey":0xb39355,
"Antique Hot Pink":0xb07f9e,
"Antique Ivory":0xf9ecd3,
"Antique Lace":0xfdf2db,
"Antique Leather":0x9e8e7e,
"Antique Linen":0xfaeedb,
"Antique Marble":0xf1e9d7,
"Antique Mauve":0xbbb0b1,
"Antique Moss":0x7a973b,
"Antique Paper":0xf4f0e8,
"Antique Parchment":0xead8c1,
"Antique Pearl":0xebd7cb,
"Antique Penny":0x957747,
"Antique Petal":0xe8e3e3,
"Antique Pink":0xc27a74,
"Antique Red":0x7d4f51,
"Antique Rose":0x997165,
"Antique Rosewood":0x72393f,
"Antique Ruby":0x841b2d,
"Antique Silver":0x918e8c,
"Antique Tin":0x6e7173,
"Antique Treasure":0xbb9973,
"Antique Turquoise":0x004e4e,
"Antique Viola":0x928ba6,
"Antique White":0xece6d5,
"Antique Wicker Basket":0xf3d3a1,
"Antique Windmill":0xb6a38d,
"Antiqued Aqua":0xbdccc1,
"Antiquities":0x8a6c57,
"Antiquity":0xc1a87c,
"Antler":0x957a76,
"Antler Moth":0x864f3e,
"Antler Velvet":0xc0ad96,
"Antoinette":0xb09391,
"Antoinette Pink":0xe7c2b4,
"Anubis Black":0x312231,
"Anzac":0xc68e3f,
"Ao":0x00800c,
"Aoife's Green":0x27b692,
"Aotake Bamboo":0x006442,
"Apatite Blue":0x31827b,
"Apatite Crystal Green":0xbbff99,
"Apeland":0x8a843b,
"Aphrodite's Pearls":0xeeffff,
"Aphroditean Fuschia":0xdd14ab,
"Apium":0xb5d0a2,
"Apnea Dive":0x284fbd,
"Apocalyptic Orange":0xf4711e,
"Apocyan":0x99ccff,
"Apollo Bay":0x748697,
"Apollo Landing":0xe5e5e1,
"Apollo's White":0xddffff,
"Appalachian Forest":0x848b80,
"Appalachian Trail":0xcfb989,
"Appaloosa Spots":0x876e52,
"Apparition":0xc2bca9,
"Appetite":0xb1e5aa,
"Appetizing Asparagus":0x66aa00,
"Applause Please":0x858c9b,
"Apple Blossom":0xddbca0,
"Apple Bob":0xd5e69d,
"Apple Brown Betty":0x9c6757,
"Apple Butter":0x844b4d,
"Apple Cherry":0xf81404,
"Apple Cider":0xda995f,
"Apple Cinnamon":0xb0885a,
"Apple Core":0xf4eed8,
"Apple Cream":0xb8d7a6,
"Apple Crisp":0xe19c55,
"Apple Crunch":0xfee5c9,
"Apple Cucumber":0xdbdbbc,
"Apple Custard":0xfddfae,
"Apple Day":0x7e976d,
"Apple Flower":0xedf4eb,
"Apple Green":0x76cd26,
"Apple Herb Black":0x4b4247,
"Apple Hill":0xa69f8d,
"Apple Ice":0xbdd0b1,
"Apple II Beige":0xbfca87,
"Apple II Blue":0x93d6bf,
"Apple II Chocolate":0xda680e,
"Apple II Green":0x04650d,
"Apple II Lime":0x25c40d,
"Apple II Magenta":0xdc41f1,
"Apple II Rose":0xac667b,
"Apple Infusion":0xddaabb,
"Apple Jack":0x8b974e,
"Apple Martini":0xf9fdd9,
"Apple Orchard":0x93c96a,
"Apple Pie":0xcaab94,
"Apple Polish":0x883e3f,
"Apple Sauce":0xf4ebd2,
"Apple Seed":0xa77c53,
"Apple Slice":0xf1f0bf,
"Apple Turnover":0xe8c194,
"Apple Valley":0xea8386,
"Apple Wine":0xb59f62,
"Apple-A-Day":0x903f45,
"Appleblossom":0xdab5b4,
"Applegate":0x8ac479,
"Applegate Park":0xaead93,
"Applemint":0xcdeacd,
"Applemint Soda":0xf3f5e9,
"Applesauce":0xf6d699,
"Applesauce Cake":0xc2a377,
"Appletini":0x929637,
"Appleton":0x6eb478,
"Approaching Dusk":0x8b97a5,
"Approval Green":0x039487,
"Apricot":0xffb16d,
"Apricot Appeal":0xfec382,
"Apricot Blush":0xfeaea5,
"Apricot Brandy":0xc26a5a,
"Apricot Brown":0xcc7e5b,
"Apricot Buff":0xcd7e4d,
"Apricot Chicken":0xda8923,
"Apricot Cream":0xf1bd89,
"Apricot Flower":0xffbb80,
"Apricot Foam":0xeeded8,
"Apricot Fool":0xffd2a0,
"Apricot Freeze":0xf3cfb7,
"Apricot Gelato":0xf5d7af,
"Apricot Glazed Chicken":0xeeaa22,
"Apricot Glow":0xffce79,
"Apricot Ice":0xfff6e9,
"Apricot Ice Cream":0xf8cc9c,
"Apricot Iced Tea":0xfbbe99,
"Apricot Illusion":0xe2c4a6,
"Apricot Jam":0xeea771,
"Apricot Light":0xffca95,
"Apricot Lily":0xfecfb5,
"Apricot Mix":0xb47756,
"Apricot Mousse":0xfcdfaf,
"Apricot Nectar":0xecaa79,
"Apricot Obsession":0xf8c4b4,
"Apricot Orange":0xc86b3c,
"Apricot Preserves":0xeeb192,
"Apricot Red":0xe8917d,
"Apricot Sherbet":0xfacd9e,
"Apricot Sorbet":0xe8a760,
"Apricot Spring":0xf1b393,
"Apricot Tan":0xdd9760,
"Apricot Wash":0xfbac82,
"Apricot White":0xf7f0db,
"Apricot Yellow":0xf7bd81,
"Apricotta":0xd8a48f,
"April Blush":0xf6d0d8,
"April Fool's Red":0x1fb57a,
"April Green":0xa9b062,
"April Love":0x8b3d2f,
"April Mist":0xccd9c9,
"April Showers":0xdadeb5,
"April Sunshine":0xfbe198,
"April Tears":0xb4cbd4,
"April Wedding":0xc5cfb1,
"April Winds":0xd5e2e5,
"Aqua":0x00ffff,
"Aqua Bay":0xb5dfc9,
"Aqua Belt":0x7acad0,
"Aqua Bloom":0x96d3d8,
"Aqua Blue":0x79b6bc,
"Aqua Breeze":0xd8e8e4,
"Aqua Clear":0x8bd0dd,
"Aqua Cyan":0x01f1f1,
"Aqua Deep":0x014b43,
"Aqua Eden":0x85c7a6,
"Aqua Experience":0x038e85,
"Aqua Fiesta":0x8cc3c3,
"Aqua Foam":0xadc3b4,
"Aqua Forest":0x5fa777,
"Aqua Fresco":0x4a9fa3,
"Aqua Frost":0xa9d1d7,
"Aqua Glass":0xd2e8e0,
"Aqua Green":0x12e193,
"Aqua Grey":0x889fa5,
"Aqua Haze":0xd9ddd5,
"Aqua Island":0xa1dad7,
"Aqua Lake":0x30949d,
"Aqua Mist":0xa0c9cb,
"Aqua Nation":0x08787f,
"Aqua Oasis":0xbce8dd,
"Aqua Obscura":0x05696b,
"Aqua Pura":0xddf2ee,
"Aqua Rapids":0x63a39c,
"Aqua Revival":0x539f91,
"Aqua Sea":0x6baaae,
"Aqua Sky":0x7bc4c4,
"Aqua Smoke":0x8c9fa0,
"Aqua Sparkle":0xd3e4e6,
"Aqua Splash":0x85ced1,
"Aqua Spray":0xa5dddb,
"Aqua Spring":0xe8f3e8,
"Aqua Squeeze":0xdbe4dc,
"Aqua Tint":0xe5f1ee,
"Aqua Velvet":0x00a29e,
"Aqua Verde":0x56b3c3,
"Aqua Vitale":0x7bbdc7,
"Aqua Waters":0x00937d,
"Aqua Whisper":0xbfdfdf,
"Aqua Wish":0xa0e3d1,
"Aqua Zing":0x7cd8d6,
"Aqua-Sphere":0x9cb0b3,
"Aquacade":0xe1f0ea,
"Aquadazzle":0x006f49,
"Aquadulce":0x7b9f82,
"Aqualogic":0x57b7c5,
"Aquamarine":0x2ee8bb,
"Aquamarine Blue":0x71d9e2,
"Aquamarine Dream":0xb3c4ba,
"Aquamarine Ocean":0x82cdad,
"Aquamentus Green":0x00a800,
"Aquarelle":0x61aab1,
"Aquarelle Beige":0xe8e0d5,
"Aquarelle Blue":0xbfe0e4,
"Aquarelle Green":0xe2f4e4,
"Aquarelle Lilac":0xedc8ff,
"Aquarelle Mint":0xdbf4d8,
"Aquarelle Orange":0xfbe8e0,
"Aquarelle Pink":0xfbe9de,
"Aquarelle Purple":0xd8e1f1,
"Aquarelle Red":0xfedddd,
"Aquarelle Sky":0xbce4eb,
"Aquarelle Yellow":0xf4eeda,
"Aquarium":0x356b6f,
"Aquarium Blue":0x66cdaa,
"Aquarium Diver":0x0a98ac,
"Aquarius":0x3cadd4,
"Aquarius Reef Base":0x559999,
"Aquastone":0x89c6b7,
"Aquatic":0x99c1cc,
"Aquatic Cool":0x41a0b4,
"Aquatic Green":0x49999a,
"Aquatint":0xb8e7de,
"Aquatone":0xa6b5a9,
"Aquaverde":0xa3c0bd,
"Aqueduct":0x60b3bc,
"Aquella":0x59b6d9,
"Aqueous":0x388d95,
"Aquifer":0xe2eced,
"Aquitaine":0x88abb4,
"Arabella":0x82acc4,
"Arabesque":0xd16f52,
"Arabian Bake":0xcd9945,
"Arabian Red":0xa14c3f,
"Arabian Sands":0xddc6b1,
"Arabian Silk":0x786e97,
"Arabian Spice":0x884332,
"Arabian Veil":0xc9fffa,
"Arabic Coffee":0x6f4d3f,
"Arabica Mint":0xc0ffee,
"Arable Brown":0x7a552e,
"Aragon":0xb06455,
"Aragon Green":0x47ba87,
"Aragonite":0xe4e0d4,
"Aragonite Blue":0x6a95b1,
"Aragonite Grey":0x948e96,
"Aragonite White":0xf3f1f3,
"Araigaki Orange":0xec8254,
"Arame Seaweed Green":0x3f4635,
"Arapawa":0x274a5d,
"Arathi Highlands":0x93a344,
"Araucana Egg":0xadd8e1,
"Arava":0xa18d71,
"Arbol De Tamarindo":0xcda182,
"Arbor Hollow":0xc1c2b4,
"Arbor Vitae":0xbbc3ad,
"Arboretum":0x70ba9f,
"Arc Light":0xccddff,
"Arcade Fire":0xee3311,
"Arcade Glow":0x0022cc,
"Arcade White":0xedebe2,
"Arcadia":0x00a28a,
"Arcadian Green":0xa3c893,
"Arcala Green":0x3b6c3f,
"Arcane":0x98687e,
"Arcavia Red":0x6a0002,
"Archaeological Site":0x8e785c,
"Archeology":0x6e6a5e,
"Architecture Blue":0x7195a6,
"Architecture Grey":0x6b6a69,
"Archivist":0x9f8c73,
"Arctic":0x648589,
"Arctic Blue":0x95d6dc,
"Arctic Cotton":0xe6e3df,
"Arctic Daisy":0xebe4be,
"Arctic Dawn":0xe3e5e8,
"Arctic Dusk":0x735b6a,
"Arctic Feelings":0xafbec1,
"Arctic Flow":0xdaeae4,
"Arctic Fox":0xe7e7e2,
"Arctic Glow":0xc9d1e9,
"Arctic Green":0x45bcb3,
"Arctic Grey":0xbbccdd,
"Arctic Ice":0xbfc7d6,
"Arctic Lichen Green":0x6f7872,
"Arctic Lime":0xd0ff14,
"Arctic Nights":0x345c61,
"Arctic Ocean":0x66c3d0,
"Arctic Paradise":0xb8dff8,
"Arctic Rose":0xb7abb0,
"Arctic Shadow":0xd9e5eb,
"Arctic Water":0x00fcfc,
"Arctic White":0xe9eae7,
"Ardcoat":0xe2dedf,
"Ardent Coral":0xe5756a,
"Ardósia":0x232f2c,
"Ares Red":0xdd2200,
"Ares Shadow":0x62584c,
"Argan Oil":0x8b593e,
"Argent":0x888888,
"Argos":0xbdbdb7,
"Argyle":0x348a5d,
"Argyle Purple":0x895c79,
"Argyle Rose":0xc48677,
"Aria":0xe3e4e2,
"Aria Ivory":0xf9e8d8,
"Arid Landscape":0xdcd6c6,
"Arid Plains":0xb6b4a9,
"Ariel":0xaed7ea,
"Ariel's Delight":0xb2a5d3,
"Aristocrat Ivory":0xfaf0df,
"Aristocrat Peach":0xecceb9,
"Aristocratic Pink":0xddaacc,
"Arizona":0xeeb377,
"Arizona Clay":0xad735a,
"Arizona Stone":0x00655a,
"Arizona Sunrise":0xebbcb9,
"Arizona Tan":0xe5bc82,
"Arizona Tree Frog":0x669264,
"Armada":0x536762,
"Armadillo":0x484a46,
"Armadillo Egg":0x7d4638,
"Armageddon Dunes":0x926a25,
"Armageddon Dust":0xd3a907,
"Armagnac":0xad916c,
"Armor":0x74857f,
"Armor Wash":0x030303,
"Armored Steel":0x747769,
"Armory":0x6a6b65,
"Army Canvas":0x5b6f61,
"Army Green":0x4b5320,
"Army Issue":0x8a806b,
"Army Issue Green":0x838254,
"Arnica":0xbf8f37,
"Arnica Yellow":0xe59b00,
"Aroma":0xd3c1c5,
"Aroma Blue":0x96d2d6,
"Aroma Garden":0xa1c4a8,
"Aromatic":0x706986,
"Aromatic Breeze":0xffcecb,
"Arona":0x879ba3,
"Arousing Alligator":0x776600,
"Arraign":0x5c546e,
"Arresting Auburn":0x5a3532,
"Arrow Creek":0x927257,
"Arrow Quiver":0xc7a998,
"Arrow Rock":0xa28440,
"Arrow Shaft":0x5c503a,
"Arrowhead":0x514b40,
"Arrowhead Lake":0x58728a,
"Arrowhead White":0xf9eaeb,
"Arrowroot":0xf8decf,
"Arrowroote":0xe4decf,
"Arrowtown":0x827a67,
"Arrowwood":0xbc8d1f,
"Arsenic":0x3b444b,
"Art and Craft":0x896956,
"Art Deco Pink":0xcdaca0,
"Art Deco Red":0x623745,
"Art District":0x94897c,
"Art House Pink":0xc06f70,
"Art Nouveau Glass":0xa29aa0,
"Art Nouveau Green":0x9c932f,
"Art Nouveau Violet":0xa08994,
"Artemis":0xd2a96e,
"Artemis Silver":0xddddee,
"Artemisia":0xe3ebea,
"Arterial Blood Red":0x711518,
"Artesian Pool":0xa6bee1,
"Artesian Water":0x007db6,
"Artesian Well":0x5eb2aa,
"Artful Aqua":0x91b4b3,
"Artful Magenta":0x80505d,
"Artichoke":0x8f9779,
"Artichoke Dip":0xa19676,
"Artichoke Green":0x4b6d41,
"Artichoke Mauve":0xc19aa5,
"Artifact":0xca9d8d,
"Artificial Strawberry":0xff43a4,
"Artificial Turf":0x41b45c,
"Artillery":0x746f67,
"Artisan":0x8f5c45,
"Artisan Crafts":0xb99779,
"Artisan Tan":0xb09879,
"Artisan Tea":0xdac2af,
"Artisan Tile":0x845e40,
"Artisans Gold":0xf2ab46,
"Artist Blue":0x01343a,
"Artist's Canvas":0xeee4d2,
"Artist's Shadow":0xa1969b,
"Artiste":0x987387,
"Artistic License":0x434053,
"Artistic Stone":0x5c6b65,
"Artistic Taupe":0xc3b1ac,
"Artistic Violet":0xd0d2e9,
"Arts & Crafts Gold":0xf5c68b,
"Arts and Crafts":0x7d6549,
"Aruba Aqua":0xd1ded3,
"Aruba Blue":0x81d7d3,
"Aruba Green":0x54b490,
"Arugula":0x75ad5b,
"Arylide Yellow":0xe9d66b,
"Asagi Blue":0x48929b,
"Asagi Koi":0x455559,
"Asagi Yellow":0xf7bb7d,
"Asfar Yellow":0xfcef01,
"Ash":0xbebaa7,
"Ash Blonde":0xd7bea5,
"Ash Blue":0xc0c6c9,
"Ash Brown":0x98623c,
"Ash Cherry Blossom":0xe8d3d1,
"Ash Gold":0x8c6f54,
"Ash Grey":0xc1b5a9,
"Ash Grove":0xb9b3bf,
"Ash Hollow":0xa88e8b,
"Ash in the Air":0xd9dde5,
"Ash Mauve":0x737486,
"Ash Pink":0x998e91,
"Ash Plum":0xe8d3c7,
"Ash Rose":0xb5817d,
"Ash to Ash":0x4e4e4c,
"Ash Tree":0xaabb99,
"Ash Tree Bark":0xcecfd6,
"Ash Violet":0x9695a4,
"Ash White":0xe9e4d4,
"Ash Yellow":0xf0bd7e,
"Ashberry":0xb495a4,
"Ashen":0xc9bfb2,
"Ashen Brown":0x994444,
"Ashen Plum":0x9b9092,
"Ashen Tan":0xd3cabf,
"Ashen Wind":0x94a9b7,
"Ashenvale Nights":0x104071,
"Asher Benjamin":0x45575e,
"Ashes":0xb8b5ad,
"Ashes to Ashes":0xbbb3a2,
"Ashley Blue":0x8699ab,
"Ashlite":0xa7a49f,
"Ashton Blue":0x4a79ba,
"Ashton Skies":0x7b8eb0,
"Ashwood":0xbcc4bd,
"Asian Fusion":0xece0cd,
"Asian Ivory":0xe8e0cd,
"Asian Jute":0xd4b78f,
"Asian Pear":0xae9156,
"Asian Violet":0x8b818c,
"Āsmānī Sky":0x88ddbb,
"Aspara":0x70b2cc,
"Asparagus":0x77ab56,
"Asparagus Cream":0x96af54,
"Asparagus Fern":0xb9cb5a,
"Asparagus Green":0xd2cdb4,
"Asparagus Sprig":0x576f44,
"Asparagus Yellow":0xdac98e,
"Aspen Aura":0x83a494,
"Aspen Branch":0xc6bcad,
"Aspen Gold":0xffd662,
"Aspen Green":0x7e9b76,
"Aspen Hush":0x6a8d88,
"Aspen Mist":0xcfd7cb,
"Aspen Snow":0xf0f0e7,
"Aspen Valley":0x687f7a,
"Aspen Whisper":0xedf1e3,
"Aspen Yellow":0xf6df9f,
"Asphalt":0x130a06,
"Asphalt Blue":0x474c55,
"Asphalt Grey":0x5e5e5d,
"Aspiring Blue":0xa2c1c0,
"Assassin":0x2d4f83,
"Assassin's Red":0xf60206,
"Assateague Sand":0xe1d0b2,
"Assault":0x1c4374,
"Aster":0x867ba9,
"Aster Flower Blue":0x9bacd8,
"Aster Petal":0xd4dae2,
"Aster Purple":0x7d74a8,
"Aster Violetta":0x8f629a,
"Astilbe":0xf091a9,
"Astorath Red":0xdd482b,
"Astra":0xedd5a6,
"Astral":0x376f89,
"Astral Aura":0x363151,
"Astral Spirit":0x8ec2e7,
"Astro Arcade Green":0x77ff77,
"Astro Bound":0x899fb9,
"Astro Nautico":0x5383c3,
"Astro Purple":0x6d5acf,
"Astro Sunset":0x937874,
"Astro Zinger":0x797eb5,
"Astrogranite":0x757679,
"Astrogranite Debris":0x3b424c,
"Astrolabe Reef":0x2d96ce,
"Astronaut":0x445172,
"Astronaut Blue":0x214559,
"Astronomer":0xe8f2eb,
"Astronomical":0x474b4a,
"Astronomicon Grey":0x6b7c85,
"Astroscopus Grey":0xafb4b6,
"Astroturf":0x67a159,
"Asurmen Blue Wash":0x273e51,
"Aswad Black":0x17181c,
"At Ease":0xe7eee1,
"At Ease Soldier":0x9e9985,
"At The Beach":0xe7d9b9,
"Atelier":0xa3abb8,
"Ateneo Blue":0x003a6c,
"Athena Blue":0x66ddff,
"Athenian Green":0x92a18a,
"Athens Grey":0xdcdddd,
"Athonian Camoshade":0x6d8e44,
"Aths Special":0xd5cbb2,
"Atlantic Blue":0x008997,
"Atlantic Breeze":0xcbe1ee,
"Atlantic Charter":0x2b2f41,
"Atlantic Deep":0x274e55,
"Atlantic Depths":0x001166,
"Atlantic Fig Snail":0xd7ceb9,
"Atlantic Gull":0x4b8eb0,
"Atlantic Mystique":0x00629a,
"Atlantic Ocean":0xa7d8e4,
"Atlantic Sand":0xdcd5d2,
"Atlantic Shoreline":0x708189,
"Atlantic Tide":0x3e586e,
"Atlantic Tulip":0xb598c3,
"Atlantic Wave":0x3d797c,
"Atlantic Waves":0x264243,
"Atlantis":0x336172,
"Atlantis Myth":0x006477,
"Atlas Cedar Green":0x667a6e,
"Atlas Red":0x82193a,
"Atlas White":0xede5cf,
"Atmosphere":0x0099dd,
"Atmospheric":0x899697,
"Atmospheric Pressure":0xc2d0e1,
"Atmospheric Soft Blue":0xace1f0,
"Atoll":0x2b797a,
"Atoll Sand":0xffcf9e,
"Atom Blue":0x8f9cac,
"Atomic":0x3d4b52,
"Atomic Lime":0xb9ff03,
"Atomic Pink":0xfb7efd,
"Atomic Tangerine":0xff9966,
"Atrium White":0xf1eee4,
"Attar of Rose":0x994240,
"Attica":0xa1bca9,
"Attitude":0xa48884,
"Attitude Gray":0x7c7d75,
"Attorney":0x3f4258,
"Au Chico":0x9e6759,
"Au Gratin":0xff9d45,
"Au Natural":0xe5e1ce,
"Au Naturel":0xe8cac0,
"Auberge":0x3f3130,
"Aubergine":0x372528,
"Aubergine Flesh":0xf2e4dd,
"Aubergine Green":0x8b762c,
"Aubergine Grey":0x6e5861,
"Aubergine Mauve":0x3b2741,
"Aubergine Perl":0x5500aa,
"Auburn":0x712f2c,
"Auburn Glaze":0xb58271,
"Auburn Lights":0x78342f,
"Auburn Wave":0xd8a394,
"Audition":0xb5acb7,
"Audrey's Blush":0xae8087,
"Auger Shell":0x9f9292,
"August Moon":0xe6e1d6,
"August Morning":0xffd79d,
"Aumbry":0x7c7469,
"Aunt Violet":0x7c0087,
"Aura":0xb2a8a1,
"Aura Orange":0xb4262a,
"Aura White":0xdee2e4,
"Aureolin":0xfdee00,
"Auric":0xc48919,
"Auric Armour Gold":0xe8bc6d,
"Auricula Purple":0x533552,
"AuroMetalSaurus":0x6e7f80,
"Aurora":0xeddd59,
"Aurora Brown":0x6a4238,
"Aurora Green":0x6adc99,
"Aurora Grey":0xd3c5c4,
"Aurora Magenta":0x963b60,
"Aurora Orange":0xec7042,
"Aurora Pink":0xe881a6,
"Aurora Red":0xb93a32,
"Aurora Splendor":0x595682,
"Austere":0x726848,
"Austere Gray":0xbebfb2,
"Australian Jade":0x84a194,
"Australian Mint":0xeff8aa,
"Australien":0xcc9911,
"Austrian Ice":0xdee6e7,
"Authentic Brown":0x6b5446,
"Authentic Tan":0xeaddc6,
"Autonomous":0xc6c7c5,
"Autumn Air":0xd2a888,
"Autumn Apple Yellow":0xcda449,
"Autumn Arrival":0xf9986f,
"Autumn Ashes":0x816b68,
"Autumn Avenue":0xe3ad59,
"Autumn Bark":0x9d6f46,
"Autumn Blaze":0xd9922e,
"Autumn Blonde":0xeed0ae,
"Autumn Bloom":0xffe0cb,
"Autumn Blush":0xe4d1c0,
"Autumn Child":0xfbe6c1,
"Autumn Crocodile":0x447744,
"Autumn Fall":0x67423b,
"Autumn Fern":0x507b49,
"Autumn Fest":0xbe7d33,
"Autumn Festival":0xa28b36,
"Autumn Glaze":0xb3573f,
"Autumn Glory":0xff8812,
"Autumn Glow":0xe5c382,
"Autumn Gold":0x7d623c,
"Autumn Gourd":0xe6ae76,
"Autumn Grey":0xb2aba7,
"Autumn Haze":0xd4c2b1,
"Autumn Hills":0x784f50,
"Autumn Laurel":0x9d8d66,
"Autumn Leaf":0xb56a4c,
"Autumn Leaf Brown":0x7a560e,
"Autumn Leaf Orange":0xd07a04,
"Autumn Leaf Red":0x623836,
"Autumn Leaves":0x6e4440,
"Autumn Malt":0xcea48e,
"Autumn Maple":0xc46215,
"Autumn Meadow":0xacb78e,
"Autumn Mist":0xf7b486,
"Autumn Night":0x3b5861,
"Autumn Orange":0xee9950,
"Autumn Orchid":0x9d9093,
"Autumn Pine Green":0x158078,
"Autumn Red":0x99451f,
"Autumn Ridge":0x9b423f,
"Autumn Robin":0xc2452d,
"Autumn Russet":0xa4746e,
"Autumn Sage":0xaea26e,
"Autumn Sunset":0xf38554,
"Autumn Umber":0xae704f,
"Autumn White":0xfae2cf,
"Autumn Wind":0xfbd1b6,
"Autumn Wisteria":0xc9a0dc,
"Autumn Yellow":0xe99700,
"Autumn's Hill":0xba7a61,
"Autumnal":0xa15325,
"Avagddu Green":0x106b21,
"Avalon":0x799b96,
"Avant-Garde Pink":0xff77ee,
"Aventurine":0x576e6a,
"Avenue Tan":0xd2c2b0,
"Averland Sunset":0xffaa1d,
"Aviary Blue":0xc6e3e8,
"Avid Apricot":0xf4c69f,
"Aviva":0xc5b47f,
"Avocado":0x568203,
"Avocado Cream":0xb7bf6b,
"Avocado Dark Green":0x3e4826,
"Avocado Green":0x87a922,
"Avocado Pear":0x555337,
"Avocado Peel":0x39373b,
"Avocado Toast":0x90b134,
"Avocado Whip":0xcdd6b1,
"Awaken":0xa7a3bb,
"Awakened":0xe3dae9,
"Awakening":0xbb9e9b,
"Award Blue":0x315886,
"Award Night":0x54617d,
"Award Winning White":0xfef0de,
"Awareness":0xe3ebb1,
"Awesome Aura":0xccc1da,
"Awesome Violet":0xa7b2d4,
"Awkward Purple":0xd208cc,
"Awning Red":0x90413e,
"Axe Handle":0x6b4730,
"Axinite":0x756050,
"Axis":0xbab6cb,
"Axolotl":0xfff0df,
"Ayahuasca Vine":0x665500,
"Ayame Iris":0x763568,
"Ayrshire":0xa07254,
"Azalea":0xd42e5b,
"Azalea Flower":0xefc0cb,
"Azalea Leaf":0x4a6871,
"Azalea Pink":0xf9c0c4,
"Azeitona":0xa5b546,
"Azores Blue":0x0085a7,
"Azraq Blue":0x4c6cb3,
"Azshara Vein":0xb13916,
"Aztec":0x293432,
"Aztec Aura":0xffefbc,
"Aztec Brick":0x9e8352,
"Aztec Glimmer":0xe7b347,
"Aztec Gold":0xc39953,
"Aztec Jade":0x33bb88,
"Aztec Sky":0x4db5d7,
"Aztec Temple":0x84705b,
"Aztec Turquoise":0x00d6e2,
"Aztec Warrior":0xbb0066,
"Azuki Bean":0x96514d,
"Azuki Red":0x672422,
"Azul":0x1d5dec,
"Azul Caribe":0x0089c4,
"Azul Cielito Lindo":0xc9e3eb,
"Azul Pavo Real":0x537faf,
"Azul Petróleo":0x36454f,
"Azul Primavera":0xe2eff2,
"Azul Tequila":0xc0cfc7,
"Azul Turquesa":0x6abac4,
"Azure":0x007fff,
"Azure Blue":0x4d91c6,
"Azure Dragon":0x053976,
"Azure Green Blue":0x006c81,
"Azure Hint":0xdddce1,
"Azure Lake":0x7bbbc8,
"Azure Mist":0xf0fff1,
"Azure Radiance":0x007f1f,
"Azure Sky":0xb0e0f6,
"Azure Tide":0x2b9890,
"Azurean":0x59bad9,
"Azureish White":0xdbe9f4,
"Azuremyst Isle":0xcc81f0,
"Azurite Water Green":0x497f73,
"B'dazzled Blue":0x2e5894,
"Baal Red Wash":0x610023,
"Baba Ganoush":0xeebb88,
"Babbling Brook":0xbecfcd,
"Babbling Creek":0xa7bad3,
"Babe":0xdc7b7c,
"Babiana":0x876fa3,
"Baby Aqua":0xabccc3,
"Baby Artichoke":0xe9e3ce,
"Baby Barn Owl":0xc3c3b8,
"Baby Bear":0x6f5944,
"Baby Berries":0x9c4a62,
"Baby Blossom":0xfaefe9,
"Baby Blue":0xa2cffe,
"Baby Blue Eyes":0xa1caf1,
"Baby Bok Choy":0xbbb98a,
"Baby Breath":0xf0d0b0,
"Baby Bunting":0xabcaea,
"Baby Burro":0x8c665c,
"Baby Cake":0x87bea3,
"Baby Chick":0xffeda2,
"Baby Fish Mouth":0xf3acb9,
"Baby Frog":0xc8ba63,
"Baby Girl":0xffdfe8,
"Baby Grass":0x8abd7b,
"Baby Green":0x8cff9e,
"Baby Jane":0xd0a7a8,
"Baby Melon":0xffa468,
"Baby Motive":0x8fcbdc,
"Baby Pink":0xffb7ce,
"Baby Powder":0xfefefa,
"Baby Purple":0xca9bf7,
"Baby Seal":0xa1a5a8,
"Baby Shoes":0x005784,
"Baby Spinach":0x89a882,
"Baby Sprout":0xa78b81,
"Baby Steps":0xf5c9da,
"Baby Tears":0x66b9d6,
"Baby Tone":0xdcc2cb,
"Baby Tooth":0xeeffdd,
"Baby Vegetable":0x5d6942,
"Baby's Blanket":0xffaec1,
"Baby's Booties":0xe8c1c2,
"Baby's Breath":0xd8e4e8,
"Babyccino":0xeeccbb,
"Baca Berry":0x945759,
"Bacchanalia Red":0x8a3a3c,
"Bachelor Blue":0x8faaca,
"Bachelor Button":0x4abbd5,
"Bachimitsu Gold":0xfddea5,
"Back In Black":0x16141c,
"Back Stage":0x6b625b,
"Back To Basics":0x726747,
"Back to Nature":0xbdb98f,
"Back to School":0xc1853b,
"Backcountry":0x7c725f,
"Backdrop":0xa7a799,
"Backlight":0xfcf0e5,
"Backwater":0x687078,
"Backwoods":0x4a6546,
"Backyard":0x879877,
"Bacon Strips":0xdf3f32,
"Bad Hair Day":0xf1c983,
"Bad Moon Yellow":0xf2e5b4,
"Badab Black Wash":0x0a0908,
"Badlands Orange":0xff6316,
"Badlands Sunset":0x936a5b,
"Badshahi Brown":0xd3a194,
"Bag of Gold":0xe1bd88,
"Bagel":0xf6cd9b,
"Bagpiper":0x1c5544,
"Baguette":0xb5936a,
"Bahama Blue":0x25597f,
"Bahaman Bliss":0x3fa49b,
"Baharroth Blue":0x58c1cd,
"Bahia":0xa9c01c,
"Bahia Grass":0xc4c5ad,
"Bái Sè White":0xecefef,
"Baikō Brown":0x887938,
"Bailey Bells":0x8a8ec9,
"Bainganī":0x8273fd,
"Baize":0x4b5445,
"Baize Green":0xc7cda8,
"Baja":0xd2c1a8,
"Baja Blue":0x66a6d9,
"Baja White":0xfff8d1,
"Baked Apple":0xb34646,
"Baked Bean":0xb2754d,
"Baked Biscotti":0xdad3cc,
"Baked Bread":0xdacba9,
"Baked Brie":0xede9d7,
"Baked Clay":0x9c5642,
"Baked Cookie":0x89674a,
"Baked Potato":0xb69e87,
"Baked Salmon":0xdf9876,
"Baked Scone":0xe5d3bc,
"Baked Sienna":0x9b775e,
"Bakelite":0xe6d4a5,
"Bakelite Gold":0xd7995d,
"Bakelite Yellow":0xc6b788,
"Baker-Miller Pink":0xff92ae,
"Baker's Chocolate":0x5c3317,
"Bakery Box":0xf0f4f2,
"Bakery Brown":0xab9078,
"Baklava":0xefb435,
"Bakos Blue":0x273f4b,
"Balance":0xd1dbc2,
"Balance Green":0xc3c5a7,
"Balanced":0xd7d2d1,
"Balanced Beige":0xc0b2a2,
"Balboa":0xafd3da,
"Balcony Rose":0xe2bcb8,
"Balcony Sunset":0xd78e6b,
"Baleine Blue":0x155187,
"Bali Batik":0x6f5937,
"Bali Bliss":0x5e9ea0,
"Bali Deep":0x8a8e93,
"Bali Hai":0x849ca9,
"Bali Sand":0xf6e8d5,
"Balinese Sunset":0xf1a177,
"Ball Blue":0x21abcd,
"Ball Gown":0x525661,
"Ballad":0xcab6c6,
"Ballad Blue":0xc0ceda,
"Ballerina":0xf2cfdc,
"Ballerina Beauty":0xe8ded6,
"Ballerina Gown":0xf9eaea,
"Ballerina Pink":0xf7b6ba,
"Ballerina Silk":0xf0dee0,
"Ballerina Tears":0xf2bbb1,
"Ballerina Tutu":0xc8647f,
"Ballet Blue":0xafc4d9,
"Ballet Cream":0xfc8258,
"Ballet Rose":0xd3adb1,
"Ballet Shoes":0xedb9bd,
"Ballet Slipper":0xebced5,
"Ballet White":0xf2e7d8,
"Ballie Scott Sage":0xb2b29c,
"Ballroom Blue":0xa6b3c9,
"Ballyhoo":0x58a83b,
"Balmy":0xc5d8de,
"Balmy Seas":0xb4dcd3,
"Balor Brown":0x9c6b08,
"Balsa Stone":0xcbbb92,
"Balsam":0xbec4b7,
"Balsam Fir":0x909e91,
"Balsam Green":0x576664,
"Balsam Pear":0xb19338,
"Balsamic Reduction":0x434340,
"Balthasar Gold":0xa47552,
"Baltic":0x279d9f,
"Baltic Blue":0x6c969a,
"Baltic Bream":0x9fbbda,
"Baltic Green":0x3aa098,
"Baltic Prince":0x135952,
"Baltic Sea":0x3c3d3e,
"Baltic Trench":0x125761,
"Baltic Turquoise":0x00a49a,
"Bambino":0x8edacc,
"Bamboo":0xe3dec6,
"Bamboo Beige":0xc1aba0,
"Bamboo Brown":0xc87f00,
"Bamboo Charcoal":0x454a48,
"Bamboo Forest":0xb1a979,
"Bamboo Grass Green":0x82994c,
"Bamboo Leaf":0x99b243,
"Bamboo Mat":0xe5da9f,
"Bamboo Screen":0xbcab8c,
"Bamboo Shoot":0xa3b6a4,
"Bamboo White":0xc6cfad,
"Bamboo Yellow":0xae884b,
"Banafš Violet":0x5a1991,
"Banafsaji Purple":0xa50b5e,
"Banana":0xfffc79,
"Banana Bandanna":0xf8f739,
"Banana Biscuit":0xffde7b,
"Banana Blossom":0x933e49,
"Banana Boat":0xfdc838,
"Banana Bread":0xffcf73,
"Banana Brick":0xe8d82c,
"Banana Brulee":0xf7eab9,
"Banana Chalk":0xd6d963,
"Banana Clan":0xeedd00,
"Banana Cream":0xfff49c,
"Banana Crepe":0xe7d3ad,
"Banana Custard":0xfcf3c5,
"Banana Farm":0xffdf38,
"Banana Flash":0xeeff00,
"Banana Ice Cream":0xf1d3b2,
"Banana Leaf":0x9d8f3a,
"Banana Mania":0xfbe7b2,
"Banana Mash":0xfafe4b,
"Banana Milkshake":0xede6cb,
"Banana Palm":0x95a263,
"Banana Peel":0xffe774,
"Banana Pepper":0xfdd630,
"Banana Pie":0xf7efd7,
"Banana Powder":0xd0c101,
"Banana Pudding":0xf4efc3,
"Banana Puree":0xb29705,
"Banana Sparkes":0xf6f5d7,
"Banana Split":0xf7eec8,
"Banana Yellow":0xffe135,
"Banana Yogurt":0xfae7b5,
"Bananarama":0xe4d466,
"Bananas Foster":0xdcbe97,
"Bancroft Village":0x816e54,
"Banded Tulip":0xe0d3bd,
"Bandicoot":0x878466,
"Baneblade Brown":0x937f6d,
"Bangalore":0xbbaa88,
"Bangladesh Green":0x006a4f,
"Banh Bot Loc Dumpling":0xd2b762,
"Banished Brown":0x745e6f,
"Bank Blue":0x3e4652,
"Bank Vault":0x757374,
"Banksia":0xa6b29a,
"Banksia Leaf":0x4b5539,
"Banner Gold":0xa28557,
"Bannister Brown":0x806b5d,
"Bannister White":0xe1e0d6,
"Banshee":0xdaf0e6,
"Banyan Serenity":0x98ab8c,
"Bara Red":0xe9546b,
"Baragon Brown":0x551100,
"Barbados":0x3e6676,
"Barbados Bay":0x006665,
"Barbados Beige":0xb8a983,
"Barbados Blue":0x2766ac,
"Barbados Cherry":0xaa0a27,
"Barbarian Flesh":0xf78c5a,
"Barbarian Leather":0xa17308,
"Barbarossa":0xa84734,
"Barbecue":0xc26157,
"Barberry":0xee1133,
"Barberry Bush":0xd2c61f,
"Barberry Sand":0xe1d4bc,
"Barberry Yellow":0xf3bd32,
"Barbie Pink":0xfe46a5,
"Barcelona Beige":0xc4b39c,
"Barcelona Brown":0x926a46,
"Bare":0x817e6d,
"Bare Beige":0xe8d3c9,
"Bare Bone":0xeeddcc,
"Bare Pink":0xf2e1dd,
"Barely Aqua":0xbae9e0,
"Barely Bloomed":0xddaadd,
"Barely Blue":0xdde0df,
"Barely Brown":0xdd6655,
"Barely Butter":0xf8e9c2,
"Barely Mauve":0xccbdb9,
"Barely Peach":0xffe9c7,
"Barely Pear":0xedebdb,
"Barely Pink":0xf8d7dd,
"Barely Ripe Apricot":0xffe3cb,
"Barely Rose":0xede0e3,
"Barely White":0xe1e3dd,
"Barf Green":0x94ac02,
"Bargeboard Brown":0x68534a,
"Barista":0xbcafa2,
"Barite":0x9e7b5c,
"Baritone":0x708e95,
"Barium":0xf4e1c5,
"Barium Green":0x8fff9f,
"Bark":0x5f5854,
"Bark Brown":0x73532a,
"Bark Sawdust":0xab9004,
"Barking Prairie Dog":0xc5b497,
"Barley Corn":0xb6935c,
"Barley Field":0xc7bcae,
"Barley Groats":0xfbf2db,
"Barley White":0xf7e5b7,
"Barn Door":0x8e5959,
"Barn Red":0x8b4044,
"Barney":0xac1db8,
"Barney Purple":0xa00498,
"Barnfloor":0x9c9480,
"Barnwood":0x554d44,
"Barnwood Ash":0x87857e,
"Barnwood Grey":0x9e9589,
"Barnyard Grass":0x5dac51,
"Baroness":0xa785a7,
"Baroness Mauve":0x847098,
"Baronial Brown":0x5a4840,
"Baroque":0xddaa22,
"Baroque Blue":0x95b6b5,
"Baroque Chalk Soft Blue":0xaecccb,
"Baroque Grey":0x5f5d64,
"Baroque Red":0x7b4f5d,
"Baroque Rose":0xb35a66,
"Barossa":0x452e39,
"Barrel":0xf0b069,
"Barrel Stove":0x8e7e67,
"Barren":0xb9aba3,
"Barrett Quince":0xf5d1b2,
"Barricade":0x84623e,
"Barrier Reef":0x0084a1,
"Barro Verde":0x9f8e71,
"Basalt Black":0x4d423e,
"Basalt Grey":0x999999,
"Base Camp":0x575c3a,
"Base Sand":0xbb9955,
"Baseball Base":0xf4eadc,
"Bashful":0xe3eded,
"Bashful Blue":0x6994cf,
"Bashful Emu":0xb2b0ac,
"Bashful Pansy":0xd9cde5,
"Bashful Rose":0xb88686,
"Basic Coral":0xdbc3b6,
"Basic Khaki":0xc3b69f,
"Basil":0x879f84,
"Basil Chiffonade":0x828249,
"Basil Green":0x54622e,
"Basil Icing":0xe2e6db,
"Basil Mauve":0x6c5472,
"Basil Pesto":0x529d6e,
"Basil Smash":0xb7e1a1,
"Basilica Blue":0x4a9fa7,
"Basilisk":0x9ab38d,
"Basilisk Lizard":0xbcecac,
"Basin Blue":0xb9dee4,
"Basket Beige":0xc0a98b,
"Basket of Gold":0xf4cc3c,
"Basketball":0xee6730,
"Basketry":0xbda286,
"Basketweave Beige":0xcaad92,
"Basmati White":0xebe1c9,
"Basque Green":0x5f6033,
"Bassinet":0xd3c1cb,
"Basswood":0xc9b196,
"Bastard-amber":0xffcc88,
"Bastille":0x2c2c32,
"Bastion Grey":0x4d4a4a,
"Bat Wing":0x7e7466,
"Bat-Signal":0xfeff00,
"Bat's Blood Soup":0xee3366,
"Batch Blue":0x87b2c9,
"Bateau":0x1b7598,
"Bateau Brown":0x7a5f5a,
"Bath Bubbles":0xe6f2ea,
"Bath Green":0x0a696a,
"Bath Salt Green":0xbbded7,
"Bath Turquoise":0x62baa8,
"Bath Water":0x88eeee,
"Bathe Blue":0xc2e0e3,
"Bathing":0x93c9d0,
"Batik Lilac":0x7e738b,
"Batik Pink":0x9c657e,
"Batman":0x656e72,
"Batman's NES Cape":0x940084,
"Baton":0x866f5a,
"Baton Rouge":0x973c6c,
"Bats Cloak":0x1f1518,
"Battered Sausage":0xede2d4,
"Battery Charged Blue":0x1dacd4,
"Battle Blue":0x74828f,
"Battle Cat":0x2b7414,
"Battle Dress":0x7e8270,
"Battle Harbor":0x9c9c82,
"Battleship Green":0x828f72,
"Battleship Grey":0x6f7476,
"Battletoad":0x11cc55,
"Batu Cave":0x595438,
"Bauhaus":0x3f4040,
"Bauhaus Blue":0x006392,
"Bauhaus Buff":0xcfb49e,
"Bauhaus Gold":0xb0986f,
"Bauhaus Tan":0xccc4ae,
"Bavarian":0x4d5e42,
"Bavarian Blue":0x1c3382,
"Bavarian Cream":0xfff9dd,
"Bavarian Gentian":0x20006d,
"Bavarian Green":0x749a54,
"Bavarian Sweet Mustard":0x4d3113,
"Bay":0xbae5d6,
"Bay Area":0xafa490,
"Bay Brown":0x773300,
"Bay Fog":0x9899b0,
"Bay Isle Pointe":0x214048,
"Bay Leaf":0x86793d,
"Bay of Hope":0xbfc9d0,
"Bay of Many":0x353e64,
"Bay Salt":0xd2cdbc,
"Bay Scallop":0xfbe6cd,
"Bay Site":0x325f8a,
"Bay View":0x6a819e,
"Bay Water":0xaaad94,
"Bay Wharf":0x747f89,
"Bay's Water":0x7b9aad,
"Bayberry":0x255958,
"Bayberry Frost":0xd0d9c7,
"Bayberry Wax":0xb6aa89,
"Bayern Blue":0x0098d4,
"Bayou":0x20706f,
"Bayshore":0x89cee0,
"Bayside":0x5fc9bf,
"Bazaar":0x8f7777,
"Bazooka Pink":0xffa6c9,
"BBQ":0xa35046,
"Be Daring":0xffc943,
"Be Mine":0xf4e3e7,
"Be My Valentine":0xec9dc3,
"Be Spontaneous":0xa5cb66,
"Be Yourself":0x9b983d,
"Beach Bag":0xadb864,
"Beach Ball":0xefc700,
"Beach Blue":0x5f9ca2,
"Beach Boardwalk":0xceab90,
"Beach Cabana":0xa69081,
"Beach Casuarina":0x665a38,
"Beach Cottage":0x94adb0,
"Beach Dune":0xc6bb9c,
"Beach Foam":0xcde0e1,
"Beach Glass":0x96dfce,
"Beach Grass":0xdcddb8,
"Beach House":0xedd481,
"Beach Lilac":0xbda2c4,
"Beach Party":0xfbd05c,
"Beach Sand":0xfbb995,
"Beach Towel":0xfce3b3,
"Beach Trail":0xfedeca,
"Beach Umbrella":0x819aaa,
"Beach White":0xf6eed6,
"Beach Wind":0xdce1e2,
"Beach Woods":0xcac0b0,
"Beachcomber":0xd9e4e5,
"Beachcombing":0xe4c683,
"Beachside Drive":0xacdbdb,
"Beachside Villa":0xc3b296,
"Beachwalk":0xd2b17a,
"Beachy Keen":0xe6d0b6,
"Beacon Blue":0x265c98,
"Beacon Yellow":0xf2c98a,
"Beaded Blue":0x494d8b,
"Beagle Brown":0x8d6737,
"Beaming Blue":0x33ffff,
"Beaming Sun":0xfff8df,
"Bean Counter":0x68755d,
"Bean Green":0x685c27,
"Bean Pot":0x8b6b51,
"Bean Shoot":0x91923a,
"Bean Sprout":0xf3f9e9,
"Bean White":0xebf0e4,
"Beanstalk":0x31aa74,
"Bear Brown":0x44382b,
"Bear Hug":0x796359,
"Bear in Mind":0x5b4a44,
"Bear Rug":0x5a4943,
"Bearsuit":0x7d756d,
"Beastly Flesh":0x680c08,
"Beasty Brown":0x663300,
"Beat Around the Bush":0x6e6a44,
"Beaten Copper":0x73372d,
"Beaten Purple":0x4e0550,
"Beaten Track":0xd1be92,
"Beatnik":0x5f8748,
"Beatrice":0xbebad9,
"Beau Blue":0xbcd4e6,
"Beaujolais":0x80304c,
"Beaumont Brown":0x92774c,
"Beauport Aubergine":0x553f44,
"Beautiful Blue":0x186db6,
"Beautiful Darkness":0x686d70,
"Beautiful Dream":0xb6c7e3,
"Beautiful Mint":0xd6dad6,
"Beauty":0x866b8d,
"Beauty Bush":0xebb9b3,
"Beauty Patch":0x834f44,
"Beauty Queen":0xbe5c87,
"Beauty Secret":0xc79ea2,
"Beauty Spot":0x604938,
"Beaver":0x926f5b,
"Beaver Fur":0x997867,
"Beaver Kit":0x9f8170,
"Beaver Pelt":0x60564c,
"Bechamel":0xf4eee0,
"Becker Blue":0x607879,
"Beckett":0x85a699,
"Becquerel":0x4bec13,
"Bed of Roses":0xb893ab,
"Bedazzled":0xd3b9cc,
"Bedbox":0x968775,
"Bedford Brown":0xaa8880,
"Bedrock":0x9e9d99,
"Bedtime Story":0xe1b090,
"Bee":0xf1ba55,
"Bee Cluster":0xffaa33,
"Bee Hall":0xf2cc64,
"Bee Master":0x735b3b,
"Bee Pollen":0xebca70,
"Bee Yellow":0xfeff32,
"Bee's Knees":0xe8d9d2,
"Bee's Wax":0xeabf86,
"Beech":0x5b4f3b,
"Beech Brown":0x574128,
"Beech Fern":0x758067,
"Beech Nut":0xd7b59a,
"Beechnut":0xc2c18d,
"Beechwood":0x6e5955,
"Beef Bourguignon":0xb64701,
"Beef Hotpot":0xa85d2e,
"Beef Jerky":0xa25768,
"Beef Patties":0xbb5533,
"Beehive":0xe1b781,
"Beekeeper":0xf6e491,
"Beer":0xf28e1c,
"Beer Garden":0x449933,
"Beer Glazed Bacon":0x773311,
"Beeswax":0xe9d7ab,
"Beeswax Candle":0xbf7e41,
"Beeswing":0xf5d297,
"Beet Red":0x7a1f3d,
"Beetle":0x55584c,
"Beetroot":0x663f44,
"Beetroot Purple":0xcf2d71,
"Beetroot Rice":0xc58f9d,
"Beets":0x736a86,
"Befitting":0x96496d,
"Before the Storm":0x4d6a77,
"Before Winter":0xbd6f56,
"Beggar":0x5a4d39,
"Begonia":0xfa6e79,
"Begonia Pink":0xec9abe,
"Begonia Rose":0xc3797f,
"Beguiling Mauve":0xafa7ac,
"Beige":0xe6daa6,
"Beige Ganesh":0xcfb095,
"Beige Green":0xe0d8b0,
"Beige Intenso":0xc5a88d,
"Beige Linen":0xe2dac6,
"Beige Red":0xde9408,
"Beige Royal":0xcfc8b8,
"Beige Topaz":0xffc87c,
"Beijing Blue":0x3e7daa,
"Beijing Moon":0xa9a2a3,
"Bel Air Blue":0x819ac1,
"Bel Esprit":0x9bbcc3,
"Belfast":0x558d4f,
"Belgian Block":0xa3a9a6,
"Belgian Blonde":0xf7efd0,
"Belgian Cream":0xf9f1e2,
"Belgian Sweet":0x8d7560,
"Belgian Waffle":0xf3dfb6,
"Believable Buff":0xdbc7a8,
"Belize":0x7fd3d3,
"Belize Green":0xb9c3b3,
"Bell Blue":0x618b97,
"Bell Heather":0xa475b1,
"Bell Tower":0xdad0bb,
"Bella":0x574057,
"Bella Green":0x93c3b1,
"Bella Mia":0xdac5bd,
"Bella Pink":0xe08194,
"Bella Sera":0x40465d,
"Bella Vista":0x0b695b,
"Belladonna":0x220011,
"Belladonna's Leaf":0xadc3a7,
"Bellagio Fountains":0xb7dff3,
"Belle of the Ball":0xe3cbc0,
"Bellflower":0x5d66aa,
"Bellflower Blue":0xe1e9ef,
"Bellflower Violet":0xb2a5b7,
"Bellini":0xf4c9b1,
"Bellini Fizz":0xf5c78e,
"Belly Fire":0x773b38,
"Belly Flop":0x00817f,
"Beloved Pink":0xe9d3d4,
"Below Zero":0x87cded,
"Beluga":0xeff2f1,
"Belvedere Cream":0xe3dbc3,
"Belyi White":0xf0f1e1,
"Benevolence":0x694977,
"Benevolent Pink":0xdd1188,
"Bengal":0xcc974d,
"Bengal Blue":0x38738b,
"Bengal Grass":0x8e773f,
"Bengala Red":0x8f2e14,
"Bengara Red":0x913225,
"Beni Shoga":0xb85241,
"Benifuji":0xbb7796,
"Benihi Red":0xf35336,
"Benikakehana Purple":0x5a4f74,
"Benikeshinezumi Purple":0x44312e,
"Benimidori Purple":0x78779b,
"Benitoite":0x007baa,
"Beniukon Bronze":0xfb8136,
"Benthic Black":0x000011,
"Bento Box":0xcc363c,
"Bergamot":0x95c703,
"Bergamot Orange":0xf59d59,
"Bering Sea":0x4b5b6e,
"Bering Wave":0x3d6d84,
"Berkeley Hills":0x7e613f,
"Berkshire Lace":0xf0e1cf,
"Berlin Blue":0x5588cc,
"Bermuda":0x1b7d8d,
"Bermuda Blue":0x8cb1c2,
"Bermuda Grass":0xa19f79,
"Bermuda Grey":0x6b8ba2,
"Bermuda Onion":0x9d5a8f,
"Bermuda Sand":0xdacbbf,
"Bermuda Shell":0xf9eee3,
"Bermuda Son":0xf0e9be,
"Bermuda Triangle":0x6f8c9f,
"Bermudagrass":0x6bc271,
"Bermudan Blue":0x386171,
"Bern Red":0xe20909,
"Berries and Cream":0x9e6a75,
"Berries n Cream":0xf2b8ca,
"Berry":0x990f4b,
"Berry Blackmail":0x662277,
"Berry Bliss":0x9e8295,
"Berry Blue":0x32607a,
"Berry Blue Green":0x264b56,
"Berry Blush":0xb88591,
"Berry Boost":0xbb5588,
"Berry Bright":0xa08497,
"Berry Brown":0x544f4c,
"Berry Burst":0xac72af,
"Berry Bush":0x77424e,
"Berry Chalk":0xa6aebb,
"Berry Charm":0x4f4763,
"Berry Cheesecake":0xf8e3dd,
"Berry Chocolate":0x3f000f,
"Berry Conserve":0x765269,
"Berry Cream":0x9a8ca2,
"Berry Crush":0xaa6772,
"Berry Frappé":0xb3a1c6,
"Berry Frost":0xebded7,
"Berry Jam":0x655883,
"Berry Light":0x673b66,
"Berry Mix":0x555a90,
"Berry Mojito":0xb6caca,
"Berry Patch":0x84395d,
"Berry Pie":0x4f6d8e,
"Berry Popsicle":0xd6a5cd,
"Berry Riche":0xe5a2ab,
"Berry Rossi":0x992244,
"Berry Smoothie":0x895360,
"Berry Syrup":0x64537c,
"Berry Wine":0x624d55,
"Berta Blue":0x45dcff,
"Beru":0xbfe4d4,
"Beryl Black Green":0x2b322d,
"Beryl Green":0xbcbfa8,
"Beryl Pearl":0xe2e3df,
"Beryl Red":0xa16381,
"Beryllonite":0xe9e5d7,
"Bessie":0x685e5b,
"Best Beige":0xc6b49c,
"Best Bronze":0x5d513e,
"Best in Show":0xb9b7bd,
"Best of Summer":0xf7f2d9,
"Best of the Bunch":0xbd5442,
"Bestial Brown":0x6b3900,
"Bestial Red":0x992211,
"Bestigor Flesh":0xd38a57,
"Betalain Red":0x7d655c,
"Betel Nut Dye":0x352925,
"Bethany":0xcadbbd,
"Bethlehem Red":0xee0022,
"Bethlehem Superstar":0xeaeeda,
"Betsy":0x73c9d9,
"Betta Fish":0x3a6b66,
"Better Than Beige":0xebe2cb,
"Beurre Blanc":0xede1be,
"Beveled Glass":0x7accb8,
"Bewitching":0x75495e,
"Bewitching Blue":0xbbd0e3,
"Beyond the Clouds":0xaaeeff,
"Beyond the Pines":0x688049,
"Beyond the Wall":0xd7e0eb,
"Bff":0xdbb0d3,
"Bhūrā Brown":0x947706,
"Białowieża Forest":0x1c5022,
"Bianca":0xf4efe0,
"Bianchi Green":0x3dcfc2,
"Bicycle Yellow":0xffe58c,
"Bicyclette":0x802c3a,
"Bidwell Blue":0xa9b9b5,
"Bidwell Brown":0xb19c8f,
"Biedermeier Blue":0x507ca0,
"Biel-Tan Green":0x1ba169,
"Bierwurst":0xf0908d,
"Big Band":0xafaba0,
"Big Bang Pink":0xff0099,
"Big Bus Yellow":0xffda8b,
"Big Chill":0x7ecbe2,
"Big Cypress":0xb98675,
"Big Daddy Blue":0x5d6b75,
"Big Dip O’Ruby":0x9c2542,
"Big Dipper":0x41494b,
"Big Fish":0x99a38e,
"Big Fish to Fry":0xdadbe1,
"Big Foot Feet":0xe88e5a,
"Big Horn Mountains":0xb79e94,
"Big Sky":0xcde2de,
"Big Spender":0xacddaf,
"Big Stone":0x334046,
"Big Stone Beach":0x886e54,
"Big Sur":0xb3cadc,
"Big Sur Blue Jade":0x3f6e8e,
"Big Surf":0x96d0d1,
"Big Yellow Streak":0xffee22,
"Big Yellow Taxi":0xffff33,
"Bigfoot":0x715145,
"Bighorn Sheep":0x20120e,
"Bijou Blue":0x4e5e7f,
"Bijou Red":0xa33d3b,
"Bijoux Green":0x676b55,
"Biking Red":0x77212e,
"Biking Trail":0xc3c0b1,
"Bilbao":0x3e8027,
"Bilberry":0x71777e,
"Bile":0xb5c306,
"Bilious Brown":0xe39f08,
"Bilious Green":0xa9d171,
"Billabong":0x1b6f81,
"Billet":0xad7c35,
"Billiard":0x00aa92,
"Billiard Ball":0x276b40,
"Billiard Green":0x305a4a,
"Billiard Room":0x50846e,
"Billiard Table":0x155843,
"Billowing Clouds":0xd8dee3,
"Billowing Sail":0xd8e7e7,
"Billowing Smoke":0x6e726a,
"Billowy Breeze":0xafc7cd,
"Billowy Clouds":0xf6f0e9,
"Billowy Down":0xeff0e9,
"Billycart Blue":0x4c77a4,
"Biloba Flower":0xae99d2,
"Biloxi":0xf4e4cd,
"Biloxi Blue":0x0075b8,
"Biltmore Buff":0xe3c9a1,
"Biltong":0x410200,
"Bimini Blue":0x007a91,
"Binary Star":0x616767,
"Bindi Dot":0x8b3439,
"Bindi Red":0xb0003c,
"Bing Cherry Pie":0xaf4967,
"Binrouji Black":0x433d3c,
"Bio Blue":0x465f9e,
"Biogenic Sand":0xffefd5,
"Biohazard Suit":0xfbfb4c,
"Biology Experiments":0x91a135,
"Bioluminescence":0x55eeff,
"BioShock":0x889900,
"Biotic Grasp":0xeeee44,
"Biotic Orb":0xeedd55,
"Birch":0x3f3726,
"Birch Beige":0xd9c3a1,
"Birch Forest":0x899a8b,
"Birch Leaf Green":0x637e1d,
"Birch Strain":0xdfb45f,
"Birch White":0xf6eedf,
"Birchwood":0xccbeac,
"Birchy Woods":0x806843,
"Bird Blue":0x7b929e,
"Bird Blue Grey":0x7f92a0,
"Bird Flower":0xd0c117,
"Bird Of Paradise":0x0083a8,
"Bird's Child":0xfff1cf,
"Bird's Egg Green":0xaaccb9,
"Bird's Nest":0xcfbb9b,
"Bird’s Eye":0xb9030a,
"Birdhouse Brown":0x6c483a,
"Birdie":0xe9e424,
"Birdie Num Num":0x89acda,
"Birdseed":0xe2c28e,
"Birdseye Maple":0xe4c495,
"Biro Blue":0x2f3946,
"Birōdo Green":0x224634,
"Birth of a Star":0xfce9df,
"Birthday Cake":0xe9d2cc,
"Birthday Candle":0xcfa2ad,
"Birthday King":0x9bdcb9,
"Birthday Suit":0xe2c7b6,
"Birthstone":0x79547a,
"Biscay":0x2f3c53,
"Biscay Bay":0x097988,
"Biscay Green":0x55c6a9,
"Biscotti":0xdac7ab,
"Biscuit":0xfeedca,
"Biscuit Beige":0xe6bfa6,
"Biscuit Cream":0xf9ccb7,
"Biscuit Dough":0xe8dbbd,
"Bishop Red":0xc473a9,
"Bismarck":0x486c7a,
"Bison":0x6e4f3a,
"Bison Beige":0x9f9180,
"Bison Brown":0x584941,
"Bison Hide":0xb5ac94,
"Bisque":0xffe4c4,
"Bisque Tan":0xe5d2b0,
"Bistre":0x3d2b1f,
"Bistre Brown":0x967117,
"Bistro":0x705950,
"Bistro Green":0x395551,
"Bit of Berry":0xdd5599,
"Bit of Blue":0xe2eaeb,
"Bit of Heaven":0xcad7de,
"Bit of Lime":0xe1e5ac,
"Bit of Sugar":0xf4f2ec,
"Bitcoin":0xffbb11,
"Bite the Bullet":0xecebce,
"Bitter":0x88896c,
"Bitter Briar":0x8d7470,
"Bitter Chocolate":0x9e5b40,
"Bitter Clover Green":0x769789,
"Bitter Dandelion":0x6ecb3c,
"Bitter Lemon":0xd2db32,
"Bitter Lime":0xcfff00,
"Bitter Melon":0xcfd1b2,
"Bitter Orange":0xd5762b,
"Bitter Sage":0x97a18d,
"Bitter Violet":0x856d9e,
"Bittersweet":0xfea051,
"Bittersweet Shimmer":0xbf4f51,
"Bittersweet Stem":0xcbb49a,
"Bizarre":0xe7d2c8,
"Black":0x000000,
"Black Bamboo":0x5b5d53,
"Black Bay":0x474a4e,
"Black Bean":0x4e4b4a,
"Black Beauty":0x26262a,
"Black Blueberry":0x2f2f48,
"Black Boudoir":0x454749,
"Black Cat":0x2e2f31,
"Black Chestnut Oak":0x252321,
"Black Chocolate":0x441100,
"Black Coffee":0x3b302f,
"Black Coral":0x54626f,
"Black Dahlia":0x4e434d,
"Black Diamond Apple":0x8a779a,
"Black Dragon's Cauldron":0x545562,
"Black Drop":0x90abd9,
"Black Elder":0xa66e7a,
"Black Elegance":0x50484a,
"Black Emerald":0x12221d,
"Black Evergreen":0x45524f,
"Black Feather":0x112222,
"Black Flame":0x484b5a,
"Black Forest":0x5e6354,
"Black Forest Blue":0x29485a,
"Black Forest Green":0x424740,
"Black Fox":0x4f4842,
"Black Garnet":0x4e4444,
"Black Glaze":0x001111,
"Black Green":0x384e49,
"Black Grey":0x24272e,
"Black Haze":0xe0ded7,
"Black Headed Gull":0x9c856c,
"Black Hills Gold":0xc89180,
"Black Hole":0x010203,
"Black Htun":0x110033,
"Black Ice":0x4d5051,
"Black Ink":0x44413c,
"Black Iris":0x2b3042,
"Black Is Beautiful":0x552222,
"Black Jasmine Rice":0x74563d,
"Black Kite":0x351e1c,
"Black Knight":0x010b13,
"Black Lacquer":0x3f3e3e,
"Black Lead":0x474c4d,
"Black Leather Jacket":0x253529,
"Black Licorice":0x3a3b3b,
"Black Locust":0x646763,
"Black Magic":0x4f4554,
"Black Mana":0x858585,
"Black Market":0x222244,
"Black Marlin":0x383740,
"Black Mesa":0x222211,
"Black Metal":0x060606,
"Black Mocha":0x4b4743,
"Black Oak":0x4e4f4e,
"Black of Night":0x323639,
"Black Olive":0x3b3c36,
"Black Onyx":0x2b272b,
"Black Orchid":0x525463,
"Black Out":0x222222,
"Black Panther":0x424242,
"Black Pearl":0x1e272c,
"Black Pine Green":0x33654a,
"Black Plum":0x6c5765,
"Black Pool":0x4f5552,
"Black Powder":0x34342c,
"Black Power":0x654b37,
"Black Pudding":0xa44a56,
"Black Queen":0x694d27,
"Black Raspberry":0x16110d,
"Black Ribbon":0x484c51,
"Black River Falls":0x343e54,
"Black Rock":0x2c2d3c,
"Black Rooster":0x331111,
"Black Rose":0x532934,
"Black Russian":0x24252b,
"Black Sabbath":0x220022,
"Black Sable":0x434b4d,
"Black Safflower":0x302833,
"Black Sand":0x5b4e4b,
"Black Sapphire":0x434555,
"Black Shadows":0xbfafb2,
"Black Sheep":0x0f0d0d,
"Black Slug":0x332211,
"Black Smoke":0x3e3e3f,
"Black Soap":0x19443c,
"Black Space":0x545354,
"Black Spruce":0x4c5752,
"Black Squeeze":0xe5e6df,
"Black Suede":0x434342,
"Black Swan":0x332200,
"Black Tie":0x464647,
"Black Tortoise":0x353235,
"Black Truffle":0x463d3e,
"Black Velvet":0x222233,
"Black Violet":0x2b2c42,
"Black Walnut":0x5e4f46,
"Black Wash":0x0c0c0c,
"Black Water":0x2e4846,
"Black White":0xe5e4db,
"Blackadder":0x292c2c,
"Blackberry":0x43182f,
"Blackberry Black":0x2e2848,
"Blackberry Burgundy":0x4c3938,
"Blackberry Cobbler":0x404d6a,
"Blackberry Cordial":0x3f2a47,
"Blackberry Cream":0xd9d3da,
"Blackberry Deep Red":0x633654,
"Blackberry Farm":0x62506b,
"Blackberry Harvest":0x504358,
"Blackberry Jam":0x87657e,
"Blackberry Leaf Green":0x507f6d,
"Blackberry Mocha":0xa58885,
"Blackberry Pie":0x64242e,
"Blackberry Sorbet":0xc1a3b9,
"Blackberry Tint":0x8f5973,
"Blackberry Wine":0x4d3246,
"Blackberry Yogurt":0xe5bddf,
"Blackbird":0x3f444c,
"Blackbird's Ggg":0xfce7e4,
"Blackboard Green":0x274c43,
"Blackcurrant":0x2e183b,
"Blackcurrant Conserve":0x52383d,
"Blackcurrant Elixir":0x5c4f6a,
"Blackened Brown":0x442200,
"Blackened Pearl":0x4d4b50,
"Blackest Berry":0x662266,
"Blackest Brown":0x403330,
"Blackfire Earth":0x7a5901,
"Blackheath":0x49454b,
"Blackish Brown":0x453b32,
"Blackish Green":0x5d6161,
"Blackish Grey":0x5b5c61,
"Blackjack":0x51504d,
"Blacklist":0x221133,
"Blackmail":0x220066,
"Blackout":0x0e0702,
"Blackthorn Berry":0x8470ff,
"Blackthorn Blue":0x4c606b,
"Blackthorn Green":0x739c69,
"Blackwater":0x545663,
"Blackwater Park":0x696268,
"Blade Green":0x6a9266,
"Bladed Grass":0x758269,
"Bladerunner":0x6a8561,
"Blair":0xa1bde0,
"Blanc":0xd9d0c2,
"Blanc Cassé":0xf1eee2,
"Blanc De Blanc":0xe7e9e7,
"Blanca Peak":0xf8f9f4,
"Blanched Almond":0xffebcd,
"Blanched Driftwood":0xccbeb6,
"Bland":0xafa88b,
"Blank Canvas":0xffefd6,
"Blanka Green":0x9cd33c,
"Blanket Brown":0x9e8574,
"Blarney":0x00a776,
"Blarney Stone":0x027944,
"Blast-Off Bronze":0xa57164,
"Blasted Lands Rocks":0x6c3550,
"Blaze":0xfa8c4f,
"Blaze Orange":0xfe6700,
"Blazing Autumn":0xf3ad63,
"Blazing Bonfire":0xffa035,
"Blazing Orange":0xffa64f,
"Blazing Yellow":0xfee715,
"Bleach White":0xebe1ce,
"Bleached Almond":0xf3ead5,
"Bleached Apricot":0xfccaac,
"Bleached Aqua":0xbce3df,
"Bleached Bare":0xd0c7c3,
"Bleached Bark":0x8b7f78,
"Bleached Bone":0xefd9a8,
"Bleached Cedar":0x2c2133,
"Bleached Coral":0xffd6d1,
"Bleached Denim":0x646f9b,
"Bleached Grey":0x788878,
"Bleached Jade":0xe2e6d1,
"Bleached Linen":0xf3ece1,
"Bleached Maple":0xc7a06c,
"Bleached Meadow":0xeae5d5,
"Bleached Sand":0xdaccb4,
"Bleached Shell":0xf6e5da,
"Bleached Silk":0xf3f3f2,
"Bleached Spruce":0xbad7ae,
"Bleached Wheat":0xddd2a9,
"Bleached White":0xdfe3e8,
"Bleaches":0xc7c7c3,
"Bleeding Heart":0xc02e4c,
"Blende Blue":0xa9c4c4,
"Blended Fruit":0xf8e3a4,
"Blended Light":0xfffbe8,
"Blessed Blue":0x4499cc,
"Bleu Ciel":0x007ba1,
"Bleu De France":0x318ce7,
"Bleu Nattier":0x9cc2bf,
"Bleuchâtel Blue":0x4488ff,
"Blind Date":0xbcaea1,
"Blind Forest":0x223300,
"Bling Bling":0xeef0ce,
"Blinking Blue":0x0033ff,
"Blinking Terminal":0x66cc00,
"Bliss Blue":0x7ac7e1,
"Blissful":0xddc4d4,
"Blissful Berry":0xaa1188,
"Blissful Blue":0xb2c8d8,
"Blissful Light":0xe5d2dd,
"Blissful Meditation":0xd5daee,
"Blissful Orange":0xffac39,
"Blissful Serenity":0xeaeed8,
"Blissfully Mine":0xdab6cd,
"Blister Pearl":0xaaffee,
"Blithe":0x0084bd,
"Blithe Blue":0x90bdbd,
"Blizzard":0xe5ebed,
"Blizzard Blue":0xa3e3ed,
"Blobfish":0xffc1cc,
"Blockchain Gold":0xe8bc50,
"Bloedworst":0x560319,
"Blond":0xfaf0be,
"Blonde":0xdcbd92,
"Blonde Beauty":0xf2efcd,
"Blonde Curl":0xefe2c5,
"Blonde Girl":0xedc558,
"Blonde Lace":0xd6b194,
"Blonde Shell":0xf6edcd,
"Blonde Wood":0xab7741,
"Blonde Wool":0xe5d0b1,
"Blood":0x770001,
"Blood Brother":0x770011,
"Blood Burst":0xff474c,
"Blood Donor":0xea1822,
"Blood God":0x67080b,
"Blood Mahogany":0x543839,
"Blood Moon":0xd83432,
"Blood Omen":0x8a0303,
"Blood Orange":0xd1001c,
"Blood Orange Juice":0xfe4b03,
"Blood Organ":0x630f0f,
"Blood Pact":0x771111,
"Blood Red":0x980002,
"Blood Rose":0x73404d,
"Blood Rush":0xaa2222,
"Blood Thorn":0xb03060,
"Bloodhound":0xbb5511,
"Bloodletter":0xe97451,
"Bloodline":0x882200,
"Bloodmyst Isle":0xf02723,
"Bloodstain":0x772200,
"Bloodstone":0x413431,
"Bloodthirsty":0x880011,
"Bloodthirsty Beige":0xf8d7d0,
"Bloodthirsty Vampire":0x9b0503,
"Bloodthirsty Warlock":0xec1837,
"Bloodtracker Brown":0x703f00,
"Bloody Periphylla":0xaa1144,
"Bloody Pico-8":0xff004d,
"Bloody Red":0xca1f1b,
"Bloody Rust":0xda2c43,
"Bloody Salmon":0xcc4433,
"Bloom":0xffaf75,
"Blooming Aster":0xd7e2ee,
"Blooming Dahlia":0xeb9687,
"Blooming Lilac":0xba93af,
"Blooming Perfect":0xd89696,
"Blooming Wisteria":0x88777e,
"Bloomsberry":0xa598c4,
"Blossom":0xfee9d8,
"Blossom Blue":0xaaccee,
"Blossom Mauve":0xa3a7cc,
"Blossom Pink":0xe6d5ce,
"Blossom Powder":0xc3b3b9,
"Blossom Time":0xe5d2c9,
"Blossom White":0xf2eee4,
"Blossom Yellow":0xe1c77d,
"Blossoms in Spring":0xe79acb,
"Blouson Blue":0x67b7c6,
"Blowing Kisses":0xf6dee0,
"Blowout":0x658499,
"Blue":0x0000ff,
"Blue Accolade":0x25415d,
"Blue Agave":0xb1c6c7,
"Blue Alps":0x89a3ae,
"Blue Android Base":0x5a79ba,
"Blue Angel":0x0022dd,
"Blue Angels Yellow":0xf8b800,
"Blue Angora":0xa7cfcb,
"Blue Antarctic":0x4b789b,
"Blue Anthracite":0x555e64,
"Blue Arc":0x0085a1,
"Blue Ash":0x414654,
"Blue Ashes":0x3b5f78,
"Blue Aster":0x0077b3,
"Blue Astro":0x50a7d9,
"Blue Atoll":0x00b1d2,
"Blue Aura":0x6c7386,
"Blue Azure":0x4682bf,
"Blue Ballad":0x7498bd,
"Blue Ballerina":0xb4c7db,
"Blue Ballet":0x576b6b,
"Blue Bauble":0xabdee3,
"Blue Bay":0x619ad6,
"Blue Bayberry":0x2d5360,
"Blue Bayou":0xbec4d3,
"Blue Beads":0x5a809e,
"Blue Beauty":0x7498bf,
"Blue Beetle":0x220099,
"Blue Bell":0x93b4d7,
"Blue Beret":0x40638e,
"Blue Beyond":0x91b8d9,
"Blue Bikini":0x00bbee,
"Blue Bird Day":0x237fac,
"Blue Black Crayfish":0x52593b,
"Blue Blood":0x6b7f81,
"Blue Blouse":0x94a4b9,
"Blue Blue":0x2242c7,
"Blue Blush":0xd6dbd9,
"Blue Boater":0x6181a3,
"Blue Bobbin":0x52b4ca,
"Blue Bolt":0x00b9fb,
"Blue Bonnet":0x335599,
"Blue Booties":0xc8ddee,
"Blue Bottle":0x394e65,
"Blue Bouquet":0x0033ee,
"Blue Bows":0xa4c3d7,
"Blue Brocade":0x70b8d0,
"Blue Bubble":0xa6d7eb,
"Blue Buzz":0xa1a2bd,
"Blue By You":0xa0b7ba,
"Blue Calico":0xa5cde1,
"Blue Calypso":0x55a7b6,
"Blue Carpenter Bee":0x9cd0e4,
"Blue Cascade":0x7b9eb0,
"Blue Catch":0x41788a,
"Blue Chaise":0x4b8ca9,
"Blue Chalk":0x94c0cc,
"Blue Charcoal":0x262b2f,
"Blue Charm":0x82c2db,
"Blue Chill":0x408f90,
"Blue Chip":0x1d5699,
"Blue Chrysocolla":0x77b7d0,
"Blue Clay":0x6b9194,
"Blue Click":0xa7d8e8,
"Blue Cloud":0x627188,
"Blue Cola":0x0088dc,
"Blue Collar Man":0x005f7a,
"Blue Copper Ore":0x4411dd,
"Blue Coral":0x1b5366,
"Blue Crab Escape":0x9ebdd6,
"Blue Cruise":0x6591a8,
"Blue Cuddle":0x7eb4d1,
"Blue Cue":0x84a5dc,
"Blue Curacao":0x32becc,
"Blue Cypress":0xcbdbd7,
"Blue Dacnis":0x44ddee,
"Blue Dahlia":0x415e9c,
"Blue Dam":0xa2c6d3,
"Blue Danube":0x0087b6,
"Blue Darknut":0x0078f8,
"Blue Dart":0x518fd1,
"Blue Dart Frog":0x3a7a9b,
"Blue Depression":0x4428bc,
"Blue Depths":0x263056,
"Blue Diamond":0x4b2d72,
"Blue Dianne":0x35514f,
"Blue Dolphin":0xbcc5cf,
"Blue Dove":0x76799e,
"Blue Dude":0x4a5c94,
"Blue Dusk":0x8c959d,
"Blue Earth":0x375673,
"Blue Echo":0x8dbbc9,
"Blue Edge":0x035e7b,
"Blue Effervescence":0x97d5ea,
"Blue Elemental":0x5588ee,
"Blue Emerald":0x0f5a5e,
"Blue Emulsion":0xd1edef,
"Blue Estate":0x384883,
"Blue et une Nuit":0x0652ff,
"Blue Expanse":0x253f74,
"Blue Exult":0x2b2f43,
"Blue Eyed Boy":0x87bde3,
"Blue Fantastic":0x2c3b4d,
"Blue Feather":0xaed9ec,
"Blue Fin":0x577fae,
"Blue Fir":0x51645f,
"Blue Fire":0x00aadd,
"Blue Fjord":0x628daa,
"Blue Flag":0x3b506f,
"Blue Flame":0x005e88,
"Blue Flower":0xd0d9d4,
"Blue Fog":0x9babbb,
"Blue Fox":0xb9bcb6,
"Blue Frosting":0x86d2c1,
"Blue Garter":0xa2b8ce,
"Blue Gem":0x4b3c8e,
"Blue Genie":0x6666ff,
"Blue Glass":0xc6e3e1,
"Blue Glaze":0x56597c,
"Blue Glint":0x92c6d7,
"Blue Glow":0xb2d4dd,
"Blue Gossamer":0xcdd7df,
"Blue Granite":0x717388,
"Blue Graphite":0x323137,
"Blue Grass":0x007c7a,
"Blue Green":0x137e6d,
"Blue Green Gem":0x7ccbc5,
"Blue Green Rules":0xd8eeed,
"Blue Green Scene":0x56b78f,
"Blue Grey":0x758da3,
"Blue Grotto":0x5cacce,
"Blue Grouse":0x9abcdc,
"Blue Haze":0xbdbace,
"Blue Heath Butterfly":0x5566ff,
"Blue Heather":0xaebbc1,
"Blue Heaven":0x5b7e98,
"Blue Heeler":0x939cab,
"Blue Heist":0x006384,
"Blue Hepatica":0x6666ee,
"Blue Heron":0x96a3c7,
"Blue Highlight":0x324a8b,
"Blue Hijab":0xd0eefb,
"Blue Hill":0x1e454d,
"Blue Horizon":0x4e6482,
"Blue Horror":0xa2bad2,
"Blue Hour":0x0034ab,
"Blue Hue":0x394d60,
"Blue Hyacinth":0x8394c5,
"Blue Hydrangea":0xbbc3dd,
"Blue Ice":0x70789b,
"Blue Iguana":0x539ccc,
"Blue Indigo":0x49516d,
"Blue Insignia":0x566977,
"Blue Intrigue":0x7f809c,
"Blue Iolite":0x587ebe,
"Blue Iris":0x5a5b9f,
"Blue Island":0x22aaaa,
"Blue Jacket":0x597193,
"Blue Jasmine":0x828596,
"Blue Jay":0x5588dd,
"Blue Jeans":0x5dadec,
"Blue Jewel":0x465383,
"Blue Karma":0xbce6e8,
"Blue Kelp":0x1d7881,
"Blue Lagoon":0x00626f,
"Blue Lava":0x2e5169,
"Blue League":0x006284,
"Blue Lechery":0x779ecb,
"Blue Light":0xacdfdd,
"Blue Limewash":0x7fcce2,
"Blue Linen":0x5a5e6a,
"Blue Lips":0xa6bce2,
"Blue Lobelia":0x28314d,
"Blue Lobster":0x0055aa,
"Blue Lullaby":0xc8d7d2,
"Blue Lust":0x012389,
"Blue Luxury":0x007593,
"Blue Magenta":0x5f34e7,
"Blue Magenta Violet":0x553592,
"Blue Mana":0x68c2f5,
"Blue Marble":0x6594bc,
"Blue Marguerite":0x6a5bb1,
"Blue Martina":0x1fcecb,
"Blue Martini":0x52b4d3,
"Blue Me Away":0xc9dce7,
"Blue Mediterranean":0x1e7e9a,
"Blue Mercury":0x67a6ac,
"Blue Metal":0x5a6370,
"Blue Mirage":0x5c6d7c,
"Blue Mist":0x5bacc3,
"Blue Monday":0x637983,
"Blue Mood":0x7a808d,
"Blue Moon":0x3686a0,
"Blue Moon Bay":0x588496,
"Blue Mosque":0x21426b,
"Blue Mountain":0x759dbe,
"Blue Nebula":0x1199ff,
"Blue Nights":0x363b48,
"Blue Nile":0x779fb9,
"Blue Nuance":0xd2dde0,
"Blue Nude":0x29518c,
"Blue Oar":0x647e9c,
"Blue Oasis":0x296d93,
"Blue Oblivion":0x26428b,
"Blue Ocean":0x00729e,
"Blue Odyssey":0x4f6997,
"Blue Opal":0x0f3b57,
"Blue Overdose":0x0000ee,
"Blue Oyster Cult":0x5577ee,
"Blue Paisley":0x2282a8,
"Blue Parlor":0x85abdb,
"Blue Party Parrot":0x8080ff,
"Blue Pearl":0xc5d9e3,
"Blue Pencil":0x2200ff,
"Blue Perennial":0xbcd7df,
"Blue Period":0x075158,
"Blue Phlox":0xd2e6e8,
"Blue Pink":0xb5a3c5,
"Blue Planet":0x545e6a,
"Blue Plate":0x5b7a9c,
"Blue Plaza":0x30363c,
"Blue Pointer":0x95b9d6,
"Blue Potato":0x64617b,
"Blue Prince":0x6a808f,
"Blue Promise":0x729cc2,
"Blue Purple":0x5729ce,
"Blue Quarry":0x43505e,
"Blue Racer":0x4ba4a9,
"Blue Radiance":0x58c9d4,
"Blue Ranger":0x00177d,
"Blue Raspberry":0x0cbfe9,
"Blue Reflection":0xccd7e1,
"Blue Refrain":0xb0d8e7,
"Blue Regal":0x303048,
"Blue Regatta":0x376298,
"Blue Regent":0x285991,
"Blue Review":0x4e5878,
"Blue Rhapsody":0x3d4655,
"Blue Ribbon":0x0066ff,
"Blue Ribbon Beauty":0x3e6490,
"Blue Rice":0xb3d9f3,
"Blue Rinse":0xb7bdc6,
"Blue Romance":0xd8f0d2,
"Blue Rose":0x292d74,
"Blue Royale":0x29217a,
"Blue Ruin":0x0066dd,
"Blue Sabre":0x575f6a,
"Blue Sage":0x57747a,
"Blue Sail":0x24549a,
"Blue Sapphire":0x126180,
"Blue Sari":0x666a76,
"Blue Sarong":0x9ad6e8,
"Blue Sash":0x494d58,
"Blue Satin":0x9eb6d0,
"Blue Screen of Death":0x0033bb,
"Blue Shade Wash":0x293f54,
"Blue Shadow":0x66829a,
"Blue Shamrock":0xbacbc4,
"Blue Shell":0x9bb3bc,
"Blue Shimmer":0xb3dae2,
"Blue Shutters":0x93bde7,
"Blue Silk":0xd0dce8,
"Blue Skies Today":0x95afdc,
"Blue Slate":0x5a5f68,
"Blue Slushie":0x008793,
"Blue Smart":0x5786b4,
"Blue Smoke":0xd7e0e2,
"Blue Sonki":0x4a87cb,
"Blue Sou'wester":0x404956,
"Blue Sparkle":0x0077ff,
"Blue Spell":0x3b5c6c,
"Blue Spruce":0xadc5c9,
"Blue Square":0x508a9a,
"Blue Steel":0x535a61,
"Blue Stone":0x577284,
"Blue Streak":0x2266bb,
"Blue Stream":0x95cdd8,
"Blue Suede":0x687b92,
"Blue Suede Shoes":0x484b62,
"Blue Surf":0x90a8a4,
"Blue Syzygy":0x1b4556,
"Blue Tang":0x2a4b6e,
"Blue Tapestry":0x475c62,
"Blue Thistle":0xadc0d6,
"Blue Tint":0x9fd9d7,
"Blue Titmouse":0x4466ff,
"Blue To You":0xbabfc5,
"Blue Tone Ink":0x2b4057,
"Blue Topaz":0x78bdd4,
"Blue Torus":0x042993,
"Blue Tourmaline":0x4997d0,
"Blue Tribute":0xa9b8c8,
"Blue Trust":0x120a8f,
"Blue Tulip":0x5c4671,
"Blue Tuna":0x6f95c1,
"Blue Turquoise":0x53b0ae,
"Blue Vacation":0x1e7eae,
"Blue Vault":0x4e83bd,
"Blue Veil":0xaecbe5,
"Blue Velvet":0x0d6183,
"Blue Venus":0x397c80,
"Blue Violet":0x324ab2,
"Blue Vortex":0x3d4457,
"Blue Whale":0x1e3442,
"Blue Willow":0xa8bbba,
"Blue Wing Teal":0x2c4053,
"Blue Winged Teal":0x00827c,
"Blue With A Hint Of Purple":0x533cc6,
"Blue Yonder":0x5a77a8,
"Blue Zephyr":0x5b6676,
"Blue Zodiac":0x3c4354,
"Blue-Black":0x24313d,
"Blue-Eyed Boy":0x2277cc,
"Bluealicious":0x0000dd,
"Bluebeard":0xabb5c4,
"Bluebell":0x333399,
"Bluebell Frost":0x9999cc,
"Blueberry":0x464196,
"Blueberry Blush":0x836268,
"Blueberry Buckle":0x8c99b3,
"Blueberry Dream":0x586e84,
"Blueberry Glaze":0xcc66dd,
"Blueberry Lemonade":0xd01343,
"Blueberry Muffin":0x5588ab,
"Blueberry Patch":0x627099,
"Blueberry Pie":0x314d67,
"Blueberry Popover":0x5488c0,
"Blueberry Soda":0x8290a6,
"Blueberry Soft Blue":0x5e96c3,
"Blueberry Tart":0x3f4050,
"Blueberry Twist":0x24547d,
"Blueberry Whip":0xd1d4db,
"Bluebird":0x009dae,
"Bluebird Feather":0x6f9db3,
"Bluebird's Belly":0x7395b8,
"Blueblood":0x015086,
"Bluebonnet":0x1c1cf0,
"Bluebonnet Frost":0x4d6eb0,
"Bluebottle":0x8ecfe8,
"Bluebound":0x4f9297,
"Bluejay":0x157ea0,
"Blueprint":0x35637c,
"Blues":0x296a9d,
"Blues White Shoes":0x99badd,
"Bluesy Note":0x7c9ab5,
"Bluetiful":0x3c69e7,
"Bluette":0x9ebed8,
"Bluewash":0xe2e6e0,
"Bluey":0x375978,
"Bluff Stone":0xd2bd9e,
"Bluish":0x2976bb,
"Bluish Black":0x413f44,
"Bluish Green":0x10a674,
"Bluish Grey":0x748b97,
"Bluish Lilac Purple":0xd0d5d3,
"Bluish Purple":0x703be7,
"Bluish Purple Anemone":0x6666bb,
"Bluish Water":0x89cfdb,
"Blumine":0x305c71,
"Blunt":0xb5bbc7,
"Blunt Violet":0x8d6c7a,
"Blurple":0x5539cc,
"Blush":0xf29e8e,
"Blush Beige":0xedd5c7,
"Blush Bomb":0xdd99aa,
"Blush d'Amour":0xde5d83,
"Blush Essence":0xcc88dd,
"Blush Mint":0xd9e6e0,
"Blush Pink":0xff6fff,
"Blush Rush":0xf0bcbe,
"Blush Sand":0xe2e0d8,
"Blush Sky":0xdee1ed,
"Blush Tint":0xf4e1e6,
"Blushed Bombshell":0xee88cc,
"Blushed Cotton":0xf0e0d2,
"Blushed Velvet":0xdec5d3,
"Blushing":0xf0d1c3,
"Blushing Apricot":0xfbbca7,
"Blushing Bride":0xeedad1,
"Blushing Bud":0xdd9999,
"Blushing Cherub":0xffcdaf,
"Blushing Peach":0xffd79f,
"Blushing Senorita":0xf3cacb,
"Blushing Tulip":0xe3a1b8,
"Bluster Blue":0x4a5a6f,
"Blustery Day":0xd6dfe7,
"Blustery Sky":0x6f848c,
"Blustery Wind":0xb6c5c1,
"Bnei Brak Bay":0x1d5bd6,
"Boa":0x8e855f,
"Boardman":0x757760,
"Boat Anchor":0x6c6b6a,
"Boat Blue":0x2d5384,
"Boat House":0x4e89be,
"Boat Orchid":0xc0448f,
"Boathouse":0x577190,
"Boating Green":0x087170,
"Boatswain":0x243256,
"Bobby Blue":0x97c5da,
"Bobcat Whiskers":0xeadfd0,
"Boboli Gardens":0x22bb11,
"Bock":0x5d341a,
"Bockwurst":0xdf8f67,
"Bodacious":0xb76ba3,
"Bodega Bay":0x5e81c1,
"Bodhi Tree":0xb09870,
"Boeing Blue":0x3d4652,
"Boerewors":0x973443,
"Bog":0xbab696,
"Bogart":0x8b8274,
"Bogey Green":0x116f26,
"Bogong Moth":0x663b3a,
"Bohemian Black":0x3b373c,
"Bohemian Blue":0x0000aa,
"Bohemian Jazz":0x9d777c,
"Bohemianism":0xb8b3c8,
"Boho":0x7b684d,
"Boiling Acid":0x00ee11,
"Boiling Magma":0xff3300,
"Boiling Mud":0xa59c9b,
"Boiling Point":0xd7e9e8,
"Bok Choy":0xbccab3,
"Bokara Grey":0x2a2725,
"Bold Avocado":0x879550,
"Bold Bolection":0x1d6575,
"Bold Brandy":0x796660,
"Bold Brick":0x8c5e55,
"Bold Eagle":0x463d2f,
"Bold Irish":0x2a814d,
"Bold Sangria":0x7a4549,
"Bole":0x79443b,
"Bolero":0x88464a,
"Bollywood":0xdebb32,
"Bollywood Gold":0xfffbab,
"Bologna Sausage":0xffcfdc,
"Bolognese":0xbb4400,
"Bolt from the Blue":0x2277ff,
"Boltgun Metal":0x393939,
"Bombay":0xaeaead,
"Bombay Brown":0x9f5130,
"Bombay Pink":0xc9736a,
"Bon Nuit":0x3a4866,
"Bon Voyage":0x8baeb2,
"Bona Fide":0x304471,
"Bona Fide Beige":0xcbb9ab,
"Bonaire":0xe6e2d7,
"Bonanza":0x523b2c,
"Bonbon Red":0x8c4268,
"Bondi":0x16698c,
"Bondi Blue":0x0095b6,
"Bone":0xe0d7c6,
"Bone Brown":0x9d7446,
"Bone China":0xf3edde,
"Bone Dust":0xe7ece6,
"Bone Trace":0xd7d0c0,
"Bone White":0xf1e1b0,
"Boneyard":0xbb9977,
"Bonfire":0xf78058,
"Bonfire Flame":0xce4e35,
"Bonfire Night":0xde6a41,
"Bongo Drum":0xd2c2b2,
"Bongo Skin":0xdece96,
"Bonjour":0xdfd7d2,
"Bonnie Blue":0x8dbbd1,
"Bonnie Cream":0xfdefd2,
"Bonnie Dune Beach":0xe4d1bc,
"Bonnie's Bench":0x7c644a,
"Bonny Belle":0xc58eab,
"Bonsai":0x787b54,
"Bonsai Garden":0x9e9e7c,
"Bonsai Pot":0xb8b19a,
"Bonsai Tint":0xc5d1b2,
"Bonsai Trunk":0x6c6d62,
"Bonus Level":0xffa00a,
"Bonza Green":0x5e6b44,
"Booger":0x9bb53c,
"Booger Buster":0x00ff77,
"Boogie Blast":0x119944,
"Book Binder":0x805d5b,
"Bookstone":0x8c3432,
"Bookworm":0xebe3de,
"Boot Cut":0xafc2cf,
"Boot Hill Ghost":0xddaf8e,
"Bootstrap Leather":0x793721,
"Booty Bay":0x7fc6be,
"Bora Bora Shore":0x92d0d0,
"Borage":0x507ea4,
"Borage Blue":0x5566cc,
"Bordeaux":0x7b002c,
"Bordeaux Hint":0xefbcde,
"Bordeaux Leaf":0x5c3944,
"Bordeaux Red":0x6f2c4f,
"Borderline Pink":0xee1166,
"Boreal":0x717e73,
"Bored Accent Green":0xdedd98,
"Boredom":0x8c9c9c,
"Boredom Buster":0xff8e51,
"Borg Drone":0x06470c,
"Borg Queen":0x054907,
"Boring Green":0x63b365,
"Borlotti Bean":0xd9b1aa,
"Borscht":0x8c2c24,
"Bosc Pear":0xc09056,
"Bosco Blue":0x76a0af,
"Boson Brown":0x552c1c,
"Bōsōzoku Pink":0xe7dbe1,
"Bosphorus":0x007558,
"Bosporus":0x015d75,
"Bossa Nova":0x4c3d4e,
"Bossa Nova Blue":0x767c9e,
"Boston Blue":0x438eac,
"Boston Brick":0x87544e,
"Boston Fern":0x90966d,
"Boston University Red":0xcc0002,
"Bōtan":0xa2345c,
"Botanical Beauty":0x227700,
"Botanical Garden":0x44aa11,
"Botanical Green":0x77976e,
"Botanical Night":0x12403c,
"Botanical Tint":0xa7e6d4,
"Botticelli":0x92acb4,
"Botticelli Angel":0xfbdfd6,
"Bottle Green":0x006a4e,
"Bottlebrush Blossom":0xe8edb0,
"Boudin":0xdab27d,
"Boudoir Blue":0x7ea3d2,
"Bougainvillea":0x9884b9,
"Boulder":0x7c817c,
"Boulder Brown":0x655e4e,
"Boulder Creek":0x8c9496,
"Bouncy Ball Green":0x49a462,
"Boundless":0x5b6d84,
"Bouquet":0xa78199,
"Bourbon":0xaf6c3e,
"Bourbon Spice":0xe6be8a,
"Bourbon Truffle":0x6c5654,
"Bourgeois":0xee0066,
"Bournonite Green":0x637a72,
"Boutique Beige":0xe1cead,
"Bovine":0x52585c,
"Bow Tie":0xbe2633,
"Bowen Blue":0x126da8,
"Bowerbird Blue":0x006585,
"Bowling Green":0xbfdeaf,
"Bowman Blue":0x587176,
"Bowser Shell":0x536b1f,
"Bowstring":0xd6d1c8,
"Box Office":0x898790,
"Boxcar":0x873d30,
"Boxwood":0x707b71,
"Boxwood Yellow":0xefe4a5,
"Boy Blue":0x8cacd6,
"Boy Red":0xb3111d,
"Boycott":0x635c53,
"Boynton Canyon":0x9f4e3e,
"Boysenberry":0x873260,
"Boysenberry Shadow":0xf1f3f9,
"Boyzone":0x2a96d5,
"Bracing Blue":0x014182,
"Bracken":0x5b3d27,
"Bracken Fern":0x31453b,
"Bracken Green":0x626f5d,
"Bradford Brown":0x84726c,
"Braid":0x77675b,
"Braided Raffia":0xe1d0af,
"Brain Freeze":0x00eeff,
"Brain Pink":0xf2aeb1,
"Brainstem Grey":0xb5b5b5,
"Brainstorm":0xd1d3c0,
"Brainstorm Bronze":0x74685a,
"Braintree":0x65635b,
"Brake Light Trails":0xee0033,
"Bramble Bush":0x503629,
"Bramble Jam":0xc71581,
"Brampton Grey":0x9ba29d,
"Bran":0xa66e4a,
"Brandeis Blue":0x0070ff,
"Brandied Apple":0xa37c79,
"Brandied Apricot":0xca848a,
"Brandied Melon":0xce7b5b,
"Brandied Pears":0xeae2d1,
"Brandy":0xdcb68a,
"Brandy Alexander":0xf3e2dc,
"Brandy Bear":0xaa5412,
"Brandy Brown":0x73362a,
"Brandy Butter":0xf3bb8f,
"Brandy Punch":0xc07c40,
"Brandy Rose":0xb6857a,
"Brandy Snaps":0xb58e8b,
"Brandywine":0x490206,
"Brandywine Raspberry":0x5555aa,
"Brandywine Spritz":0xe69dad,
"Brass":0xb5a642,
"Brass Balls":0xe7bd42,
"Brass Button":0x927149,
"Brass Buttons":0xdfac4c,
"Brass Mesh":0xe1a84b,
"Brass Nail":0xdbbd76,
"Brass Scorpion":0x773b2e,
"Brass Trumpet":0xecae58,
"Brass Yellow":0xb58735,
"Brassed Off":0xcfa743,
"Brassica":0x788879,
"Brasso":0xf3bc6b,
"Brassy":0xd5ab2c,
"Brassy Brass":0x776022,
"Brattle Spruce":0x454743,
"Bratwurst":0x582f2b,
"Braun":0x897058,
"Bravado Red":0xa0524e,
"Brave Orange":0xff631c,
"Brave Purple":0x968db8,
"Bravo Blue":0xd3e7e9,
"Brazen Brass":0x7b6623,
"Brazen Orange":0xce7850,
"Brazil Nut":0x856765,
"Brazilian Brown":0x7f5131,
"Brazilian Citrine":0xaf915d,
"Brazilian Green":0x296d23,
"Brazilian Sand":0xdacab7,
"Brazilian Tan":0xddc5af,
"Bread 'n Butter":0xffd182,
"Bread and Butter":0xfaedd2,
"Bread Basket":0xab8659,
"Bread Crumb":0xe4d4be,
"Bread Crust":0xb78b43,
"Bread Flavour":0xdcd6d2,
"Bread Pudding":0xbfa270,
"Break of Day":0xfffabd,
"Break the Ice":0xb2e1ee,
"Breakaway":0xcedac3,
"Breakaway Blue":0x424d60,
"Breaker":0xe5eded,
"Breaker Bay":0x517b78,
"Breakfast Biscuit":0xf6e3d3,
"Breakfast Blend":0x6d5542,
"Breaking Wave":0x00a0b0,
"Breaktime":0xc4d9ce,
"Breakwater":0xd1dee4,
"Breakwater White":0xebf1e9,
"Breakwaters":0xd9e5e0,
"Breath of Fire":0xee0011,
"Breath of Spring":0xe9e1a7,
"Breath Of Spring":0xdfeeda,
"Breathe":0xd1d2b8,
"Breathless":0xdfdae0,
"Breathtaking":0x536193,
"Breathtaking Evening":0xc3acb7,
"Breathtaking View":0x809bac,
"Bredon Green":0x5e9948,
"Breen":0x795d34,
"Breeze":0xc2dde6,
"Breeze in June":0xc4dfe8,
"Breeze of Green":0xcffdbc,
"Breezeway":0xd6dbc0,
"Breezy":0xaec9ea,
"Breezy Aqua":0xd9e4de,
"Breezy Beige":0xf7f2d7,
"Breezy Blue":0xbad9e5,
"Breonne Blue":0x2d567c,
"Bresaola":0xa9203e,
"Brescian Blue":0x0080ff,
"Bretzel Brown":0xaa5555,
"Brevity Brown":0x715243,
"Brewed Mustard":0xe68364,
"Brewing Storm":0x777788,
"Briar":0x745443,
"Briar Rose":0xc07281,
"Briar Wood":0x695451,
"Brick":0xa03623,
"Brick Brown":0x77603f,
"Brick Dust":0xb07069,
"Brick Fence":0xb38070,
"Brick Hearth":0x956159,
"Brick Orange":0xc14a09,
"Brick Path":0xc2977c,
"Brick Paver":0x93402f,
"Brick Red":0x8f1402,
"Brick Yellow":0xd2a161,
"Brick-A-Brack":0xa75c3d,
"Brickhouse":0x864a36,
"Bricks of Hope":0xdb5856,
"Bricktone":0x825943,
"Brickwork Red":0x986971,
"Bridal Blush":0xeee2dd,
"Bridal Bouquet":0xebbdb8,
"Bridal Heath":0xf8ebdd,
"Bridal Rose":0xd69fa2,
"Bridal Veil":0xe7e1de,
"Bride's Blush":0xf9e2e1,
"Bridesmaid":0xfae6df,
"Bridge Troll Grey":0x817f6e,
"Bridgeport":0x004683,
"Bridgewater":0x527065,
"Bridgewater Bay":0xbcd7e2,
"Bridgewood":0x575144,
"Bridle Leather":0x8f7d70,
"Bridle Path":0xa29682,
"Brierwood Green":0x545e4f,
"Brig":0x4fa1c0,
"Brig O'Doon":0xddcfbf,
"Brigade":0x365d73,
"Brigadier Blue":0x0063a0,
"Bright Aqua":0x0bf9ea,
"Bright Blue":0x0165fc,
"Bright Blue Violet":0x8a2be2,
"Bright Bluebell":0x9da7cf,
"Bright Bluebonnet":0x90b3c2,
"Bright Bronze":0xa05822,
"Bright Brown":0x533b32,
"Bright Bubble":0xffc42a,
"Bright Camouflage":0x1cac78,
"Bright Cerulean":0x1dacd6,
"Bright Chambray":0xadbfc8,
"Bright Chartreuse":0xdfff11,
"Bright Citrus":0xffc6a5,
"Bright Clove":0xefcf9b,
"Bright Cobalt":0x385d8d,
"Bright Cyan":0x41fdfe,
"Bright Delight":0xcd5b26,
"Bright Dusk":0xeee9f9,
"Bright Ecru":0xfeffca,
"Bright Eggplant":0x5a4e88,
"Bright Gold":0xcf9f52,
"Bright Greek":0x3844f4,
"Bright Green":0x66ff00,
"Bright Grey":0xebecf0,
"Bright Halo":0xffd266,
"Bright Idea":0xecbe63,
"Bright Indigo":0x6f00fe,
"Bright Khaki":0xf1e78c,
"Bright Lady":0x9f3645,
"Bright Laughter":0xf0edd1,
"Bright Lavender":0xbf94e4,
"Bright Lettuce":0x8dce65,
"Bright Light Green":0x2dfe54,
"Bright Lilac":0xd891ef,
"Bright Lime":0x87fd05,
"Bright Lime Green":0x65fe08,
"Bright Loam":0xc1b9aa,
"Bright Magenta":0xff08e8,
"Bright Manatee":0x979aaa,
"Bright Mango":0xff8830,
"Bright Marigold":0xff8d00,
"Bright Maroon":0xc32148,
"Bright Midnight":0x011993,
"Bright Midnight Blue":0x1a4876,
"Bright Mint":0x98ff98,
"Bright Moon":0xf6f1e5,
"Bright Nautilus":0x225869,
"Bright Navy Blue":0x1974d2,
"Bright Nori":0x2d5e22,
"Bright Ocarina":0xf0e8da,
"Bright Olive":0x9cbb04,
"Bright Orange":0xff7034,
"Bright Pink":0xfe01b1,
"Bright Purple":0xbe03fd,
"Bright Red":0xff000d,
"Bright Rose":0xc51959,
"Bright Saffron":0xffcf09,
"Bright Sage":0xd1ceb4,
"Bright Scarlet":0xfc0e34,
"Bright Sea Green":0x9fe2bf,
"Bright Sepia":0xb1aa9c,
"Bright Sienna":0xd68a59,
"Bright Sky Blue":0x02ccfe,
"Bright Spark":0x76c1e1,
"Bright Star":0xdde2e6,
"Bright Sun":0xecbd2c,
"Bright Teal":0x01f9c6,
"Bright Turquoise":0x08e8de,
"Bright Ube":0xd19fe8,
"Bright Umber":0x826644,
"Bright Violet":0xad0afd,
"Bright White":0xf4f5f0,
"Bright Winter Cloud":0xf5efe8,
"Bright Yarrow":0xface6d,
"Bright Yellow":0xfffd01,
"Bright Yellow Green":0x9dff00,
"Bright Zenith":0x757cae,
"Brihaspati Orange":0xe2681b,
"Brik Dough":0xdab77f,
"Brilliance":0xfdfdfd,
"Brilliant":0x0094a7,
"Brilliant Azure":0x3399ff,
"Brilliant Beige":0xefc5b5,
"Brilliant Blue":0x0075b3,
"Brilliant Carmine":0xad548f,
"Brilliant Green":0x88b407,
"Brilliant Impression":0xefc600,
"Brilliant Lavender":0xf4bbff,
"Brilliant Rose":0xfe54a3,
"Brilliant Sea":0x009cb7,
"Brilliant Silver":0xa9b0b4,
"Brilliant Turquoise":0x00a68b,
"Brilliant White":0xedf1fe,
"Brilliant Yellow":0xe8e5d8,
"Brimstone":0xffbd2b,
"Brimstone Butterfly":0xc2c190,
"Brindle":0x82776b,
"Brink Pink":0xfb607f,
"Briny":0x08808e,
"Brioche":0xdfcfc3,
"Briquette":0xe15f65,
"Briquette Grey":0x505050,
"Brisa De Mar":0xd2e0ef,
"Brisk Blue":0x6d829d,
"Brisket":0x6e4534,
"Bristle Grass":0xa28450,
"Bristol Beige":0x93836f,
"Bristol Blue":0x558f91,
"Bristol Green":0x83a492,
"Britches":0xa09073,
"British Grey Mauve":0x7d7081,
"British Khaki":0xbcaf97,
"British Mauve":0x35427b,
"British Racing Green":0x05480d,
"British Rose":0xf4c8db,
"British Shorthair":0x5f6672,
"Brittany Blue":0x4c7e86,
"Brittany's Bow":0xf3d8e0,
"Brittlebush":0xeaae47,
"Broad Daylight":0xbbddff,
"Broadleaf Forest":0x014421,
"Broadwater Blue":0x034a71,
"Broadway":0x434442,
"Broadway Lights":0xfee07c,
"Brocade":0x8c87c5,
"Brocade Violet":0x7b4d6b,
"Broccoflower":0x8fa277,
"Broccoli Brown":0x9b856b,
"Broccoli Green":0x4b5338,
"Broccoli Paradise":0x008833,
"Brochantite Green":0x486262,
"Broiled Flounder":0xffdd88,
"Broken Blue":0x74bbfb,
"Broken Tube":0x060310,
"Broken White":0xeeebe3,
"Bronco":0xa79781,
"Bronze":0xa87900,
"Bronze Blue":0x3a4856,
"Bronze Brown":0x825e2f,
"Bronze Fig":0x6e6654,
"Bronze Flesh":0xf7944a,
"Bronze Green":0x8d8752,
"Bronze Icon":0x585538,
"Bronze Medal":0x6d6240,
"Bronze Mist":0x9c7e41,
"Bronze Olive":0x584c25,
"Bronze Sand":0xe6be9c,
"Bronze Satin":0xcc5533,
"Bronze Tone":0x434c28,
"Bronze Treasure":0xb08d57,
"Bronze Yellow":0x737000,
"Bronzed":0xdd6633,
"Bronzed Brass":0x9b7e4e,
"Bronzed Flesh":0xeb9552,
"Bronzed Orange":0xd78a6c,
"Brood":0x69605a,
"Brooding Storm":0x5e6d6e,
"Brook Green":0xafddcc,
"Brook Trout":0xdacecd,
"Brooklet":0xe7eeee,
"Brooklyn":0x586766,
"Brookside":0x5a7562,
"Brookview":0x99b792,
"Broom":0xeecc24,
"Broom Butterfly Blue":0x6bb3db,
"Broomstick":0x74462d,
"Brother Blue":0xb0b7c6,
"Brown":0x653700,
"Brown 383":0x443724,
"Brown Alpaca":0xb86d29,
"Brown Bag":0xdeac6e,
"Brown Bear":0x4a3f37,
"Brown Beauty":0x4a3832,
"Brown Beige":0xcc8833,
"Brown Bramble":0x53331e,
"Brown Bread":0xd4c5a9,
"Brown Butter":0xac7c00,
"Brown Cerberus":0x995555,
"Brown Chocolate":0x5f1933,
"Brown Clay":0xc37c59,
"Brown Coffee":0x4a2c2a,
"Brown Derby":0x594537,
"Brown Eyes":0x9e6b4a,
"Brown Fox":0x544a42,
"Brown Green":0x706c11,
"Brown Grey":0x8d8468,
"Brown Knapweed":0xf485ac,
"Brown Labrador":0x97382c,
"Brown Magenta":0x7b2039,
"Brown Moelleux":0x662211,
"Brown Mouse":0xd8cbb5,
"Brown Mustard":0xdfac59,
"Brown Orange":0xb96902,
"Brown Patina":0x834f3d,
"Brown Pepper":0x4e403b,
"Brown Pod":0x3c241b,
"Brown Rabbit":0xae8e65,
"Brown Red":0x922b05,
"Brown Rice":0xdabd84,
"Brown Ridge":0x735852,
"Brown Rose":0x8d736c,
"Brown Rum":0xbc9b4e,
"Brown Rust":0xaf593e,
"Brown Sand":0xf7945f,
"Brown Stone":0x593c39,
"Brown Suede":0x5b4f41,
"Brown Sugar":0xa17249,
"Brown Sugar Coating":0xc8ae96,
"Brown Teepee":0xbca792,
"Brown Thrush":0x906151,
"Brown Tumbleweed":0x37290e,
"Brown Velvet":0x704e40,
"Brown Wood":0xb4674d,
"Brown Yellow":0xdd9966,
"Brown-Bag-It":0xddbda3,
"Browned Off":0xbb4433,
"Brownie":0x964b00,
"Brownish":0x9c6d57,
"Brownish Black":0x413936,
"Brownish Green":0x6a6e09,
"Brownish Grey":0x86775f,
"Brownish Orange":0xcb7723,
"Brownish Pink":0xc27e79,
"Brownish Purple":0x76424e,
"Brownish Purple Red":0x8d746f,
"Brownish Red":0x9e3623,
"Brownish Yellow":0xc9b003,
"Brownstone":0x785441,
"Browse Brown":0x6e615f,
"Bruin Spice":0xd3b99b,
"Bruise":0x7e4071,
"Bruised Bear":0x5d3954,
"Bruised Burgundy":0x5b4148,
"Brume":0xc6c6c2,
"Brunette":0x664238,
"Brunnera Blue":0x9ba9ca,
"Bruno Brown":0x433430,
"Brunswick":0x236649,
"Brunswick Green":0x1b4d3e,
"Bruschetta":0xa75949,
"Bruschetta Tomato":0xff6347,
"Brush":0xb99984,
"Brush Blue":0xd4e1ed,
"Brushed Clay":0xdb9351,
"Brushed Nickel":0x73706f,
"Brushstroke":0xf1dfba,
"Brushwood":0x8c5939,
"Brusque Brown":0xcc6611,
"Brusque Pink":0xee00ff,
"Brussels":0x6c7c6d,
"Brussels Sprout Green":0x665e0d,
"Brutal Doom":0xe61626,
"Brutal Pink":0xff00bb,
"Bryophyte":0xa6bea6,
"Bryopsida Green":0x9fe010,
"Bubble":0xeaf5e7,
"Bubble Algae":0x90e4c1,
"Bubble Bath":0xe8e0e9,
"Bubble Bobble Green":0x00b800,
"Bubble Bobble P2":0x0084ff,
"Bubble Gum":0xff85ff,
"Bubble Shell":0xd3a49a,
"Bubble Turquoise":0x43817a,
"Bubblegum":0xea738d,
"Bubblegum Baby Girl":0xcc55ee,
"Bubblegum Pink":0xf6b0ba,
"Bubbles":0xe7feff,
"Bubbles in the Air":0xd3e3e5,
"Bubbly Barracuda":0x77ccff,
"Bubonic Brown":0xc68400,
"Bucatini Noodle":0xfdf5d7,
"Buccaneer":0x6e5150,
"Buccaneer Blue":0x035b8d,
"Büchel Cherry":0xaa1111,
"Buckeye":0x674834,
"Bucking Bronco":0x996655,
"Buckingham Palace":0x6b5140,
"Buckram Binding":0xd9c3a6,
"Buckskin":0xd4ba8c,
"Buckthorn Brown":0xa76f1f,
"Buckwheat":0xd4dcd6,
"Buckwheat Flour":0xefe2cf,
"Buckwheat Groats":0xe0d8a7,
"Buckwheat Mauve":0xb9a4b0,
"Bucolic Blue":0x98acb0,
"Bud":0xa5a88f,
"Bud Green":0x79b465,
"Bud's Sails":0xe9e3d3,
"Budapest Brown":0x553d3e,
"Budder Skin":0xfce2c4,
"Buddha Gold":0xbc9b1b,
"Buddha Green":0x37b575,
"Buddha's Love Handles":0xffbb33,
"Budding Bloom":0xdeeabd,
"Budding Fern":0xedecd4,
"Budding Leaf":0xeef0d7,
"Budding Peach":0xf3d4bf,
"Budgie Blue":0x84c9e1,
"Budōnezumi Grape":0x63424b,
"Buenos Aires":0xf4dcc1,
"Buff":0xf0dc82,
"Buff It":0xd9cfbe,
"Buff Leather":0xaa7733,
"Buff Orange":0xffbb7c,
"Buff Tone":0xe8d0b9,
"Buff Yellow":0xf1bf70,
"Buffalo Bill":0xae9274,
"Buffalo Dance":0x695645,
"Buffalo Herd":0x705046,
"Buffalo Hide":0xbb9f6a,
"Buffalo Soldier":0x95786c,
"Buffalo Trail":0xe2ac78,
"Buffed Copper":0xdd9475,
"Buffed Plum":0xaeafb9,
"Buffhide":0xa79c81,
"Bugle Boy":0xbb8f4f,
"Bugman's Glow":0xcd5b45,
"Built on Sand":0xe9e3da,
"Bulbasaur":0x73a263,
"Bulfinch Blue":0x94b1b6,
"Bulgarian Rose":0x480607,
"Bull Kelp":0x636153,
"Bull Ring":0x6b605b,
"Bull Shot":0x75442b,
"Bullet Hell":0xfaf1c8,
"Bullfighters Red":0xcd4646,
"Bullfrog":0x8a966a,
"Bulma Hair":0x359e6b,
"Bulrush":0x6d5837,
"Bumangués Blue":0x0777bc,
"Bumble Baby":0xf5f1de,
"Bumblebee":0xffc82a,
"Bunchberry":0x674961,
"Bundaberg Sand":0xffc58a,
"Bungalow Beige":0xcbbeaa,
"Bungalow Brown":0xad947b,
"Bungalow Gold":0xad8047,
"Bungalow Maple":0xe4c590,
"Bungalow Taupe":0xcebe9f,
"Bungee Cord":0x696156,
"Bunglehouse Blue":0x46616e,
"Bunglehouse Gray":0x988f7b,
"Bunker":0x292c2f,
"Bunni Brown":0x6c4522,
"Bunny Cake":0xf1b5cc,
"Bunny Fluff":0xfb8da6,
"Bunny Hop":0xf3ecea,
"Bunny Pink":0xdec3c9,
"Bunny Soft":0xd3bfc4,
"Bunny Tail":0xffe3f4,
"Bunny's Nose":0xfad9dd,
"Bunting":0x2b3449,
"Bunting Blue":0x35537c,
"Buoyancy":0x79b0b6,
"Buoyant":0x65707e,
"Buoyant Blue":0x84addb,
"Burdock":0x717867,
"Bureaucracy":0x746c8f,
"Burgundy":0x900020,
"Burgundy Grey":0xdadba0,
"Burgundy Snail":0x7e7150,
"Burgundy Wine":0x6c403e,
"Buried Treasure":0xd28b42,
"Burj Khalifa Fountain":0xd4dee8,
"Burka Black":0x353e4f,
"Burlap":0x8b7753,
"Burlap Grey":0x81717e,
"Burlat Red":0x6e314f,
"Burled Redwood":0x8f4c3a,
"Burley Wood":0x695641,
"Burlwood":0x9b716b,
"Burma Jade":0x94b1a0,
"Burmese Gold":0xbc8143,
"Burned Brown":0x6f4b3e,
"Burnham":0x234537,
"Burning Brier":0x884736,
"Burning Bush":0xa0403e,
"Burning Coals":0xf79d72,
"Burning Fireflies":0xff1166,
"Burning Flame":0xffb162,
"Burning Gold":0xccaa77,
"Burning Idea":0x8f8b72,
"Burning Orange":0xff7124,
"Burning Sand":0xd08363,
"Burning Steppes":0x742100,
"Burning Tomato":0xeb5030,
"Burning Trail":0xee9922,
"Burning Ultrablue":0x150aec,
"Burnished Bark":0x6a3d36,
"Burnished Brandy":0x8b664e,
"Burnished Bronze":0x9c7e40,
"Burnished Brown":0xa17a74,
"Burnished Caramel":0xbe9167,
"Burnished Clay":0xd2ccc4,
"Burnished Copper":0xbb8833,
"Burnished Cream":0xfce5bf,
"Burnished Gold":0xaa9855,
"Burnished Lilac":0xc5aeb1,
"Burnished Mahogany":0x734842,
"Burnished Metal":0xc8cbc8,
"Burnished Pewter":0x716a62,
"Burnished Russet":0x794029,
"Burns Cave":0x7b5847,
"Burnside":0xd0a664,
"Burnt Almond":0xb0724a,
"Burnt Ash":0x746572,
"Burnt Bagel":0x9a4e12,
"Burnt Bamboo":0x4d3b3c,
"Burnt Brick":0xa14d3a,
"Burnt Butter":0xa47c53,
"Burnt Caramel":0x846242,
"Burnt Coffee":0x271b10,
"Burnt Coral":0xe9897e,
"Burnt Crimson":0x582124,
"Burnt Crust":0x885533,
"Burnt Earth":0x9d4531,
"Burnt Grape":0x75625e,
"Burnt Henna":0x7e392f,
"Burnt Maroon":0x420303,
"Burnt Ochre":0xbb4f35,
"Burnt Olive":0x646049,
"Burnt Orange":0xcc5500,
"Burnt Pumpkin":0xca955c,
"Burnt Red":0x9f2305,
"Burnt Russet":0x7e3940,
"Burnt Sienna":0xb75203,
"Burnt Terra":0x82634e,
"Burnt Tile":0x774645,
"Burnt Toffee":0xab7e5e,
"Burnt Umber":0x8a3324,
"Burnt Yellow":0xd5ab09,
"Burple":0x6832e3,
"Burrito":0xeed7c1,
"Burro":0x947764,
"Burst of Gold":0xdeb368,
"Bursting Lemon":0xfce282,
"Burtuqali Orange":0xff6700,
"Bush":0x0d2e1c,
"Bush Buck":0xa28d82,
"Bush Viper":0xa0bcd0,
"Bushland Grey":0x7f7b73,
"Bussell Lace":0xe5a1a0,
"Buster":0x3e4b69,
"Busty Blue":0x3300cc,
"Butter":0xffff81,
"Butter Base":0xc28a35,
"Butter Cake":0xfdff52,
"Butter Caramel":0xa67a4c,
"Butter Cookie":0xf0e4b2,
"Butter Creme":0xfee5ba,
"Butter Cupcake":0xffdd99,
"Butter Fingers":0xfce9ad,
"Butter Fudge":0xaa6600,
"Butter Icing":0xf5e5da,
"Butter Lettuce":0xcfe7cb,
"Butter Nut":0xcba578,
"Butter Ridge":0xf9e097,
"Butter Rum":0xc38650,
"Butter Tart":0xfee99f,
"Butter Up":0xf4e0bb,
"Butter White":0xfddebd,
"Butter Yellow":0xfffd74,
"Butterball":0xfff4c4,
"Butterblond":0xf1c766,
"Butterbrot":0xc5ae7c,
"Buttercream":0xefe0cd,
"Buttercream Frosting":0xf5edd7,
"Buttercup":0xda9429,
"Buttercup Yellow":0xe3c2a3,
"Buttered Popcorn":0xfff0a4,
"Buttered Rum":0x9d702e,
"Butterfield":0xf7be5b,
"Butterfly":0xcadea5,
"Butterfly Blue":0x2099bb,
"Butterfly Bush":0x68578c,
"Butterfly Garden":0x908aba,
"Butterfly Green":0x0b6863,
"Butterfly Wing":0xf8cfb4,
"Buttermilk":0xfffee4,
"Butternut":0xffa177,
"Butternut Pizazz":0xe59752,
"Butternut Wood":0x7e6f59,
"Butterscotch":0xfdb147,
"Butterscotch Amber":0xd3b090,
"Butterscotch Bliss":0xd7ad62,
"Butterscotch Glaze":0xc48446,
"Butterscotch Mousse":0xa97d54,
"Butterscotch Ripple":0xb08843,
"Butterscotch Sundae":0xdbb486,
"Butterscotch Syrup":0xd9a05f,
"Butterum":0xc68f65,
"Buttery":0xffc283,
"Buttery Leather":0xd4b185,
"Buttery Salmon":0xffb19a,
"Buttery White":0xf1ebda,
"Button Blue":0x24a0ed,
"Button Eyes":0x4f3a32,
"Button Mushroom":0xece6c8,
"Buzz":0xf0c641,
"Buzz-In":0xffd756,
"Buzzard":0x5f563f,
"Buzzards Bay":0x017a79,
"By Gum":0x816a38,
"By the Bayou":0x007b90,
"By The Sea":0x8d999e,
"Byakuroku Green":0xa5ba93,
"Bygone":0x918e8a,
"Bypass":0xb6c4d2,
"Byron Place":0x31667d,
"Byte Blue":0xc5dce0,
"Byzantine":0xbd33a4,
"Byzantine Blue":0x006c6e,
"Byzantine Night Blue":0x6a79f7,
"Byzantium":0x702963,
"C-3PO":0xc33140,
"C'est La Vie":0x83bce5,
"C64 Blue":0x003aff,
"C64 NTSC":0x4e7fff,
"C64 Purple":0x6f6ed1,
"Cab Sav":0x4a2e32,
"Cabal":0x7f6473,
"Cabana Bay":0x8ec1c0,
"Cabana Blue":0x5b9099,
"Cabana Melon":0xc88567,
"Cabaret":0xcd526c,
"Cabaret Charm":0x7c8ea6,
"Cabbage":0x87d7be,
"Cabbage Blossom Violet":0x724c7b,
"Cabbage Green":0x807553,
"Cabbage Leaf":0xdfe8d0,
"Cabbage Patch":0x93c460,
"Cabbage Pont":0x4c5544,
"Cabbage Rose":0xc59f91,
"Cabernet":0x8e5b68,
"Cabernet Craving":0x6d3445,
"Cabin Fever":0x5e5349,
"Cabin in the Woods":0x5d4d47,
"Cabo":0xcec0aa,
"Caboose":0xa8a4a1,
"Cacao":0x6b5848,
"Cachet Cream":0xf3d9ba,
"Cacodemon Red":0x9f0000,
"Cactus":0x5b6f55,
"Cactus Blooms":0xf6c79d,
"Cactus Blossom":0xd8e5dd,
"Cactus Flower":0xa83e6c,
"Cactus Garden":0x7b8370,
"Cactus Green":0x56603d,
"Cactus Hill":0xb1a386,
"Cactus Sand":0x9c9369,
"Cactus Spike":0xc1e0a3,
"Cactus Valley":0x88976b,
"Cactus Water":0xd0f7e4,
"Cadaverous":0x009977,
"Caddies Silk":0x3e354d,
"Cadet":0x536872,
"Cadet Blue":0x5f9ea0,
"Cadet Grey":0x91a3b0,
"Cadian Fleshtone":0x90766e,
"Cadillac":0x984961,
"Cadillac Coupe":0xc0362c,
"Cadmium Blue":0x0a1195,
"Cadmium Green":0x006b3c,
"Cadmium Orange":0xed872d,
"Cadmium Purple":0xb60c26,
"Cadmium Red":0xe30022,
"Cadmium Violet":0x7f3e98,
"Cadmium Yellow":0xfff600,
"Caduceus Gold":0xffee66,
"Caduceus Staff":0xeedd22,
"Caen Stone":0xecd0b1,
"Café Au Lait":0xa57c5b,
"Cafe Cream":0xf9e8d3,
"Cafe Creme":0xc79685,
"Café de Paris":0x889944,
"Cafe Expreso":0x5e4c48,
"Cafe Latte":0xd6c6b4,
"Café Noir":0x4b3621,
"Cafe Ole":0x9a7f79,
"Cafe Pink":0xecc1c2,
"Café Renversé":0xae8774,
"Cafe Royale":0x6a4928,
"Caffeinated Cinnamon":0x885511,
"Caffeine":0x8a796a,
"Caicos Turquoise":0x26b7b5,
"Cairns":0x0a6b92,
"Cajun Brown":0x5f3e41,
"Cajun Red":0xa45a4a,
"Cajun Spice":0xc3705f,
"Cake Batter":0xf0eddb,
"Cake Crumbs":0xe8d4bb,
"Cake Dough":0xfce0a8,
"Cake Frosting":0xf9dfe5,
"Cake Spice":0xd6a672,
"Cal Poly Pomona Green":0x1e4d2b,
"Cala Benirrás Blue":0x0ac2c2,
"Calabash":0xf8eb97,
"Calabash Clash":0x728478,
"Calabrese":0xf4a6a3,
"Calamansi":0xfcffa4,
"Calamansi Green":0xc4cc7a,
"Calc Sinter":0xe7e1dd,
"Calcareous Sinter":0xddeeff,
"Calcite Blue":0x94b2b2,
"Calcite Grey Green":0x52605f,
"Calcium":0xf2f4e8,
"Calcium Rock":0xeee9d9,
"Calculus":0xa1ccb1,
"Caledor Sky":0x31639c,
"Calf Skin":0xb1aa9d,
"Calgar Blue":0x0485d1,
"Caliban Green":0x005726,
"Calico":0xd5b185,
"Calico Cat":0xc48e36,
"Calico Dress":0x3d4e67,
"Calico Rock":0x9c9584,
"Calico Rose":0xe5c1b3,
"Caliente":0x95594a,
"California":0xe98c3a,
"California Chamois":0xe6b76c,
"California Coral":0xe3aa94,
"California Dreamin'":0x93807f,
"California Dreaming":0xdec569,
"California Girl":0xfca716,
"California Gold Rush":0x95743f,
"California Lilac":0xbbc5e2,
"California Peach":0xfcbe6a,
"California Poppy":0xa83c3f,
"California Roll":0xa09574,
"California Sagebrush":0x959988,
"California Stucco":0xc5ad9a,
"California Sunset":0xca1850,
"California Wine":0xca4b65,
"Calla":0xf2dfb5,
"Calla Green":0x6a6f34,
"Calla Lily":0xe4eaed,
"Calligraphy":0x59636a,
"Calliope":0xc89a8d,
"Calliste Green":0x757a4e,
"Calm":0xdfe9e6,
"Calm Air":0xeed2ae,
"Calm Balm":0x5e9d47,
"Calm Breeze":0xe9ece4,
"Calm Day":0x7caacf,
"Calm Interlude":0xa7b0d5,
"Calm Thoughts":0xe5ede2,
"Calm Tint":0xeae3e9,
"Calm Water":0xcdd9e8,
"Calm Waters":0xe7fafa,
"Calming Effect":0xcfd3a2,
"Calming Retreat":0xeee0d1,
"Calming Space":0xaab7c1,
"Calmness":0x68a895,
"Calthan Brown":0x6d5044,
"Calypso":0x3d7188,
"Calypso Berry":0xc53a4b,
"Calypso Blue":0x347d8b,
"Calypso Coral":0xee5c6c,
"Calypso Green":0x2e5f60,
"Calypso Red":0xde6b66,
"Camaron Pink":0xfe828c,
"Camarone":0x206937,
"Cambridge Blue":0xa3c1ad,
"Cambridge Leather":0x8c633c,
"Camel":0xc69f59,
"Camel Brown":0xa56639,
"Camel Cardinal":0xcc9944,
"Camel Cord":0xe0cb82,
"Camel Fur":0xbb6600,
"Camel Hair":0xdbb8a4,
"Camel Hair Coat":0xf5b784,
"Camel Hide":0xc1aa91,
"Camel Red":0xe5743b,
"Camel Spider":0xaf8751,
"Camel Toe":0xac8a2a,
"Camel Train":0xbaae9d,
"Camel's Hump":0x817667,
"Camelback":0xc5aa85,
"Camelback Mountain":0xd3b587,
"Camellia":0xf6745f,
"Camellia Pink":0xcd739d,
"Camellia Rose":0xeb6081,
"Camelot":0x803a4b,
"Camembert":0xfbf3df,
"Cameo":0xf2debc,
"Cameo Appearance":0xdfc1c3,
"Cameo Blue":0x769da6,
"Cameo Brown":0xc08a80,
"Cameo Green":0xdce6e5,
"Cameo Peach":0xebcfc9,
"Cameo Pink":0xefbbcc,
"Cameo Role":0xddcaaf,
"Cameo Rose":0xf7dfd7,
"Cameo Stone":0xebdfd8,
"Cameroon Green":0x60746d,
"Camisole":0xfcd9c7,
"Camo":0x7f8f4e,
"Camo Beige":0x8c8475,
"Camo Clay":0x747f71,
"Camo Green":0xa5a542,
"Camouflage":0x3c3910,
"Camouflage Green":0x4b6113,
"Camouflage Olive":0xa28f5c,
"Campanelle Noodle":0xfcf7db,
"Campánula":0x3272af,
"Campanula Purple":0x6c6d94,
"Campfire":0xce5f38,
"Campfire Ash":0xddd9ce,
"Campfire Blaze":0xb67656,
"Campfire Smoke":0xd5d1cb,
"Campground":0xd0a569,
"Camping Tent":0xb6afa0,
"Camping Trip":0x67786e,
"Can Can":0xd08a9b,
"Canada Goose Eggs":0xeae2dd,
"Canadian Lake":0x8f9aa4,
"Canadian Maple":0xcab266,
"Canadian Pancake":0xedd8c3,
"Canadian Pine":0x2e7b52,
"Canadian Voodoo Grey":0xb8b7a3,
"Canal Blue":0x9cc2c5,
"Canal Street":0x969281,
"Canaletto":0x818c72,
"Canary":0xfdff63,
"Canary Diamond":0xffce52,
"Canary Feather":0xefde75,
"Canary Grass":0xd0cca9,
"Canary Green":0xd6dec9,
"Canary Island":0xe9d4a9,
"Canary Wharf":0x91a1b5,
"Canary Yellow":0xffdf01,
"Cancun Sand":0xfbedd7,
"Candela":0xbac4d5,
"Candelabra":0xe1c161,
"Candid Blue":0x6cc3e0,
"Candidate":0xc3bc90,
"Candied Apple":0xb95b6d,
"Candied Blueberry":0x331166,
"Candied Ginger":0xbfa387,
"Candied Snow":0xd8fff3,
"Candied Yam":0xf4935b,
"Candied Yams":0xf9a765,
"Candle Bark":0xc3bdaa,
"Candle Flame":0xfff4a1,
"Candle Glow":0xffe8c3,
"Candle in the Wind":0xf9ebbf,
"Candle Light":0xddc1a6,
"Candle Wax":0xf2eacf,
"Candle Yellow":0xe09b6e,
"Candlelight":0xfcd917,
"Candlelight Dinner":0xceb3be,
"Candlelight Ivory":0xfcf4e2,
"Candlelight Peach":0xf8a39d,
"Candlelight Yellow":0xf7f0c7,
"Candlelit Beige":0xf1ede0,
"Candlestick Point":0xfff1d5,
"Candlewick":0xf2ebd3,
"Candy":0xff9b87,
"Candy Apple Red":0xff0800,
"Candy Bar":0xffb7d5,
"Candy Cane":0xf7bfc2,
"Candy Coated":0xef9faa,
"Candy Corn":0xfcfc5d,
"Candy Drop":0xc25d6a,
"Candy Floss":0xe8a7e2,
"Candy Grape Fizz":0x7755ee,
"Candy Grass":0x33aa00,
"Candy Green":0x33cc00,
"Candy Heart Pink":0xf5a2a1,
"Candy Mix":0xf3dfe3,
"Candy Pink":0xff63e9,
"Candy Tuft":0xf1d7e4,
"Candy Violet":0x895d8b,
"Candyman":0xff9e76,
"Candytuft":0xedc9d8,
"Cane Sugar":0xe3b982,
"Cane Sugar Glaze":0xddbb99,
"Cane Toad":0x977042,
"Caneel Bay":0x00849f,
"Canewood":0xd7b69a,
"Cannery Park":0xbcb09e,
"Cannoli Cream":0xf0efe2,
"Cannon Ball":0x484335,
"Cannon Barrel":0x3c4142,
"Cannon Black":0x251706,
"Cannon Grey":0x646c64,
"Cannon Pink":0x8e5164,
"Canoe":0xddc49e,
"Canoe Blue":0x1d5671,
"Canopy":0x728f02,
"Cantaloupe":0xffd479,
"Cantaloupe Slice":0xfeb079,
"Cantankerous Coyote":0xac8d74,
"Canteen":0x5e5347,
"Canter Peach":0xf6d3bb,
"Cantera":0xcec5af,
"Canterbury Bells":0xb9c3e6,
"Canterbury Cathedral":0xb2ab94,
"Canton":0x6da29e,
"Canton Jade":0xbae7c7,
"Canvas":0xbb8855,
"Canvas Cloth":0xe6dfd2,
"Canvas Luggage":0xe2d7c6,
"Canvas Satchel":0xccb88d,
"Canvas Tan":0xddd6c6,
"Canyon Blue":0x607b8e,
"Canyon Clay":0xce8477,
"Canyon Cliffs":0xece3d1,
"Canyon Cloud":0xaeafbb,
"Canyon Dusk":0xddc3b7,
"Canyon Echo":0xe5e1cc,
"Canyon Falls":0x97987f,
"Canyon Iris":0x49548f,
"Canyon Mist":0xa7a4c0,
"Canyon Peach":0xeedacb,
"Canyon Rose":0xaf6c67,
"Canyon Sand":0xf2d6aa,
"Canyon Stone":0x93625b,
"Canyon Sunset":0xe1927a,
"Canyon Trail":0xd6b8a9,
"Canyon Verde":0x8a7e5c,
"Canyon View":0xc3b39f,
"Canyon Wind":0xe3e5df,
"Canyonville":0xf5ded1,
"Cǎo Lǜ Grass":0x1fa774,
"Cape Cod":0x4e5552,
"Cape Cod Bay":0x557080,
"Cape Cod Blue":0x91a2a6,
"Cape Honey":0xfee0a5,
"Cape Hope":0xd8d6d7,
"Cape Jasmine":0xffb95a,
"Cape Lee":0x50818b,
"Cape Palliser":0x75482f,
"Cape Pond":0x0092ad,
"Cape Verde":0x01554f,
"Capella":0xd9ced2,
"Caper":0xafc182,
"Caper Green":0x847640,
"Capercaillie Mauve":0x78728c,
"Capers":0x695e4b,
"Capetown Cream":0xfcebce,
"Capital Blue":0x1a4157,
"Capital Grains":0xdbd0a8,
"Capital Yellow":0xe6ba45,
"Capitalino Cactus":0x008f4c,
"Capocollo":0xd9544d,
"Caponata":0x822a10,
"Cappuccino":0x633f33,
"Cappuccino Bombe":0xb4897d,
"Cappuccino Froth":0xc8b089,
"Capri":0x00bfff,
"Capri Breeze":0x008799,
"Capri Cream":0xf1f0d6,
"Capri Fashion Pink":0xac839c,
"Capri Isle":0x4f5855,
"Capri Water Blue":0xabe2d6,
"Capricious Purple":0xbb00dd,
"Caps":0x7e7a75,
"Capsella":0x6d8a74,
"Capsicum Red":0x76392e,
"Capstan":0x007eb0,
"Captain Blue":0x005171,
"Captain Kirk":0x9b870c,
"Captain Nemo":0x828080,
"Captains Blue":0x557088,
"Captivated":0x947cae,
"Captivating Cream":0xf4d9b1,
"Captive":0x005b6a,
"Capture":0x2cbaa3,
"Capulet Olive":0x656344,
"Caput Mortuum":0x592720,
"Caput Mortuum Grey Red":0x6f585b,
"Carafe":0x5d473a,
"Caraïbe":0x795f4d,
"Carambar":0x552233,
"Carambola":0xefebd1,
"Caramel":0xaf6f09,
"Caramel Apple":0xb87a59,
"Caramel Bar":0xcc8654,
"Caramel Brown":0xb18775,
"Caramel Cafe":0x864c24,
"Caramel Candy":0xb3715d,
"Caramel Cloud":0xd4af85,
"Caramel Coating":0xbb7711,
"Caramel Cream":0xf4ba94,
"Caramel Crumb":0xc39355,
"Caramel Cupcake":0xb98c5d,
"Caramel Finish":0xffd59a,
"Caramel Ice":0xeec9aa,
"Caramel Infused":0xcc7755,
"Caramel Kiss":0xb08a61,
"Caramel Latte":0x8c6342,
"Caramel Macchiato":0xc58d4b,
"Caramel Milk":0xddc283,
"Caramel Powder":0xeebb99,
"Caramel Sauce":0xb3804d,
"Caramel Sundae":0xa9876a,
"Caramel Swirl":0x8f6a4f,
"Caramelized":0xba947f,
"Caramelized Orange":0xef924a,
"Caramelized Pears":0xe7d5ad,
"Caramelized Pecan":0xa17b4d,
"Caramelized Walnut":0x6e564a,
"Caramelo Dulce":0xd69e6b,
"Caraquenian Crimson":0x9c0013,
"Caravel Brown":0x8c6e54,
"Caraway":0xa19473,
"Caraway Brown":0x6d563c,
"Caraway Seeds":0xdfd5bb,
"Carbon":0x333333,
"Carbon Copy":0x545554,
"Carbon Dating":0x565b58,
"Carbon Footprint":0x7b808b,
"Card Table Green":0x00512c,
"Cardamom":0xaaaa77,
"Cardamom Green":0x989057,
"Cardamom Spice":0x837165,
"Cardboard":0xc19a6c,
"Cardin Green":0x1b3427,
"Cardinal":0xc41e3a,
"Cardinal Mauve":0x2c284c,
"Cardinal Pink":0x8c055e,
"Cardinal Red":0x9b365e,
"Cardoon":0x9aae8c,
"Cardueline Finch":0x957b38,
"Carefree":0xdce9e9,
"Carefree Sky":0xa6cdde,
"Careys Pink":0xc99aa0,
"Cargo":0x8f755b,
"Cargo Green":0xc8c5a7,
"Cargo Pants":0xcdc4ae,
"Cargo River":0xcfcdbb,
"Caribbean Blue":0x1ac1dd,
"Caribbean Coast":0x93c5dd,
"Caribbean Coral":0xc07761,
"Caribbean Cruise":0x3f9da9,
"Caribbean Current":0x006e6e,
"Caribbean Green":0x00cc99,
"Caribbean Mist":0xcadeea,
"Caribbean Pleasure":0xd5dcce,
"Caribbean Sea":0x00819d,
"Caribbean Sky":0x819ecb,
"Caribbean Splash":0x00697c,
"Caribbean Sunrise":0xf5daaa,
"Caribbean Swim":0x126366,
"Caribbean Turquoise":0x009d94,
"Caribe":0x147d87,
"Caribou":0x816d5e,
"Caribou Herd":0xcda563,
"Carissima":0xe68095,
"Carla":0xf5f9cb,
"Carley's Rose":0xa87376,
"Carlisle":0x45867c,
"Carmel":0x915f3d,
"Carmel Mission":0x927f76,
"Carmel Woods":0x8d6b3b,
"Carmelite":0xb98970,
"Carmen":0x7c383f,
"Carmen Miranda":0x903e2f,
"Carmim":0xa13905,
"Carmine":0x9d0216,
"Carmine Carnation":0xad4b53,
"Carmine Pink":0xeb4c42,
"Carmine Red":0xff0038,
"Carmine Rose":0xe35b8f,
"Carmoisine":0xb31c45,
"Carnaby Tan":0x5b3a24,
"Carnage Red":0x940008,
"Carnal Brown":0xbb8866,
"Carnal Pink":0xef9cb5,
"Carnation":0xfd798f,
"Carnation Bloom":0xf9c0be,
"Carnation Bouquet":0xf5c0d0,
"Carnation Coral":0xedb9ad,
"Carnation Festival":0x915870,
"Carnation Pink":0xff7fa7,
"Carnation Rose":0xce94c2,
"Carnelian":0xb31b1b,
"Carnival":0xeb882c,
"Carnival Night":0x006e7a,
"Carnivore":0x991111,
"Caro":0xffcac3,
"Carob Brown":0x855c4c,
"Carob Chip":0x5a484b,
"Carol":0x338dae,
"Carol's Purr":0x77a135,
"Carolina":0xcbefcb,
"Carolina Blue":0x8ab8fe,
"Carolina Green":0x008b6d,
"Carolina Parakeet":0xd8df80,
"Carolina Reaper":0xff1500,
"Carona":0xfba52e,
"Carotene":0xfdb793,
"Carousel Pink":0xf8dbe0,
"Carpaccio":0xe34234,
"Carpe Diem":0x905755,
"Carpet Moss":0x00aa33,
"Carrageen Moss":0x905d36,
"Carrara":0xeeebe4,
"Carrara Marble":0xe8e7d7,
"Carriage":0x6c6358,
"Carriage Door":0x958d79,
"Carriage Green":0x254d48,
"Carriage Red":0x8c403d,
"Carriage Ride":0x8a8dc4,
"Carriage Stone":0x7e7265,
"Carriage Yellow":0xffb756,
"Carrier Pigeon Blue":0x889398,
"Carroburg Crimson":0xa82a70,
"Carrot":0xfd6f3b,
"Carrot Cake":0xbf6f31,
"Carrot Curl":0xfe8c18,
"Carrot Flower":0xcbd3c1,
"Carrot Orange":0xed9121,
"Carrot Stick":0xdf7836,
"Carte Blanche":0xeeeeff,
"Carter's Scroll":0x405978,
"Carton":0xbb9e7e,
"Cartwheel":0x665537,
"Carved Wood":0x937a62,
"Carving Party":0xf0c39f,
"Casa Blanca":0xf4ecd8,
"Casa De Oro":0xcf6837,
"Casa del Mar":0xcacfe6,
"Casa Talec":0xc49ca5,
"Casa Verde":0xabb790,
"Casablanca":0xf0b253,
"Casal":0x3f545a,
"Casandora Yellow":0xfece5a,
"Casandra":0x7c4549,
"Cascade":0xd4ede6,
"Cascade Beige":0xe7dbca,
"Cascade Green":0xa1c2b9,
"Cascade Tour":0x697f8e,
"Cascade White":0xecf2ec,
"Cascades":0x273e3e,
"Cascading White":0xf7f5f6,
"Cascara":0xee4433,
"Cashew":0xa47149,
"Cashew Cheese":0xfcf9bd,
"Cashew Nut":0xedccb3,
"Cashmere":0xd1b399,
"Cashmere Blue":0xa5b8d0,
"Cashmere Rose":0xce879f,
"Cashmere Sweater":0xfef2d2,
"Casket":0xa49186,
"Casper":0xaab5b8,
"Caspian Sea":0x4f6f91,
"Caspian Tide":0xaec7db,
"Cassandra's Curse":0xbb7700,
"Cassava Cake":0xe7c084,
"Cassia Buds":0xe0cdda,
"Cassiopeia":0xaed0c9,
"Cassiterite Brown":0x623c1f,
"Cast Iron":0x64645a,
"Castaway":0x6dbac0,
"Castaway Beach":0xd0c19f,
"Castaway Cove":0x7a9291,
"Castaway Lagoon":0x607374,
"Castellan Green":0x455440,
"Castellina":0xa27040,
"Caster Sugar":0xffffe8,
"Castilian Pink":0xd4b3aa,
"Casting Sea":0x4586c7,
"Casting Shadow":0x9da7a0,
"Castle Beige":0xe0d5ca,
"Castle Hill":0x95827b,
"Castle In The Clouds":0xefdcca,
"Castle in the Sky":0xd1eaed,
"Castle Mist":0xbdaeb7,
"Castle Moat":0x8b6b47,
"Castle Path":0xc5baaa,
"Castle Ridge":0xeadec7,
"Castle Stone":0x525746,
"Castle Wall":0xc8c1ab,
"Castlegate":0xa0a5a5,
"Castlerock":0x5f5e62,
"Castleton Green":0x00564f,
"Castlevania Heart":0xa80020,
"Castor Grey":0x646762,
"Castro":0x44232f,
"Casual Blue":0x498090,
"Casual Day":0x95bac2,
"Casual Elegance":0xdfd5c8,
"Casual Grey":0xa09d98,
"Casual Khaki":0xd3c5af,
"Cat Person":0x636d70,
"Cat's Eye Marble":0xd6a75d,
"Cat's Purr":0x0071a0,
"Catachan Green":0x475742,
"Catacomb Bone":0xe2dccc,
"Catacomb Walls":0xdbd7d0,
"Catalan":0x429395,
"Catalina":0x72a49f,
"Catalina Blue":0x062a78,
"Catalina Coast":0x5c7884,
"Catalina Green":0x859475,
"Catalina Tile":0xefac73,
"Catarina Green":0x90c4b4,
"Catawba":0x703642,
"Catawba Grape":0x5d3c43,
"Catch The Wave":0xb5dcd8,
"Caterpillar":0x66a545,
"Caterpillar Green":0x146b47,
"Catfish":0x657d82,
"Cathay Spice":0x99642c,
"Cathedral":0xacaaa7,
"Cathedral Glass":0x7a999c,
"Cathedral Grey":0xaba9a7,
"Cathedral Stone":0x80796e,
"Cathode Green":0x00ff55,
"Catkin Yellow":0xcca800,
"Catmint":0xc9a8ce,
"Catnap":0x9fc3ac,
"Catnip":0x80aa95,
"Catnip Wood":0x6f6066,
"Catskill Brown":0x595452,
"Catskill White":0xe0e4dc,
"Cattail Brown":0x917546,
"Cattail Red":0xb64925,
"Catwalk":0x4a4649,
"Caulerpa Lentillifera":0x599c99,
"Cauliflower":0xebe5d0,
"Cauliflower Cream":0xf2e4c7,
"Caustic Green":0x11dd00,
"Cautious Blue":0xd5dde5,
"Cautious Grey":0xdfd8d9,
"Cautious Jade":0xdae4de,
"Cavalry":0x3f4c5a,
"Cavalry Brown":0x990003,
"Cavan":0xdce2ce,
"Cave Lake":0x52b7c6,
"Cave of the Winds":0x86736e,
"Cave Painting":0xaa1100,
"Cave Pearl":0xd6e5e2,
"Caveman":0x625c58,
"Cavendish":0xfed200,
"Cavern Clay":0xb69981,
"Cavern Echo":0xcec3b3,
"Cavern Moss":0x92987d,
"Cavern Pink":0xe0b8b1,
"Cavern Sand":0x947054,
"Cavernous":0x515252,
"Caviar":0x292a2d,
"Caviar Black":0x533e39,
"Caviar Couture":0x772244,
"Cavolo Nero":0x72939e,
"Cay":0xa6d0d6,
"Cayenne":0x941100,
"Cayman Bay":0x52798d,
"Cayman Green":0x495a44,
"Ce Soir":0x9271a7,
"Cedar":0x463430,
"Cedar Chest":0xc95a49,
"Cedar Forest":0x788078,
"Cedar Glen":0x686647,
"Cedar Green":0x5e6737,
"Cedar Grove":0xbf6955,
"Cedar Plank":0x8b786f,
"Cedar Plank Salmon":0xa96a50,
"Cedar Ridge":0x9b6663,
"Cedar Staff":0x91493e,
"Cedar Wood":0xa1655b,
"Cedar Wood Finish":0x711a00,
"Cedarville":0xdda896,
"Ceil":0x92a1cf,
"Ceiling Bright White":0xe9ebe7,
"Celadon":0xace1af,
"Celadon Blue":0x007ba7,
"Celadon Glaze":0xccd4cb,
"Celadon Green":0x2f847c,
"Celadon Porcelain":0x7ebea5,
"Celadon Sorbet":0xb1dac6,
"Celadon Tint":0xcbcebe,
"Celandine":0xebdf67,
"Celandine Green":0xb8bfaf,
"Celeb City":0x9d86ad,
"Celebration":0xe6c17a,
"Celebration Blue":0x008bc4,
"Celery":0xb4c04c,
"Celery Bunch":0xd4e0b3,
"Celery Green":0xc5cc7b,
"Celery Ice":0xeaebd1,
"Celery Mousse":0xc1fd95,
"Celery Powder":0xc5bda5,
"Celery Satin":0xd0d8be,
"Celery Sprig":0x9ed686,
"Celery Stick":0xcaedd0,
"Celery Victor":0xcceec2,
"Celery White":0xdbd9cd,
"Celeste":0xb2ffff,
"Celeste Blue":0x406374,
"Celestial":0x006380,
"Celestial Alien":0x11cc00,
"Celestial Blue":0x2c4d69,
"Celestial Coral":0xdd4455,
"Celestial Dragon":0x992266,
"Celestial Glow":0xeaebe9,
"Celestial Green":0x2ddfc1,
"Celestial Horizon":0x7c94b3,
"Celestial Indigo":0x091f92,
"Celestial Light":0xc7dae8,
"Celestial Moon":0xe3d4b9,
"Celestial Pink":0x9c004a,
"Celestial Plum":0x3c7ac2,
"Celestine":0x85c1c4,
"Celestine Spring":0x24a4c8,
"Celestra Grey":0x99a7ab,
"Celestyn":0xb5c7d2,
"Celine":0x826167,
"Cellar Door":0x75553f,
"Cellini Gold":0xddb582,
"Cello":0x3a4e5f,
"Celluloid":0x515153,
"Celosia Orange":0xe8703a,
"Celtic":0x2b3f36,
"Celtic Blue":0x246bce,
"Celtic Clover":0x006940,
"Celtic Green":0x1f6954,
"Celtic Grey":0xc5d4ce,
"Celtic Linen":0xf5e5ce,
"Celtic Queen":0x00886b,
"Celtic Rush":0x2e4c5b,
"Celtic Spring":0xaadeb2,
"Celuce":0x8bab68,
"Cembra Blossom":0x725671,
"Cement":0xa5a391,
"Cement Feet":0x7b737b,
"Cement Greige":0xb5aba4,
"Cemetery Ash":0xc0c7d0,
"Cendre Blue":0x3e7fa5,
"Census":0x327a68,
"Centaur":0x90673f,
"Centaur Brown":0x8b6a4f,
"Centennial Rose":0xb3a7a6,
"Centeōtl Yellow":0xf7e077,
"Center Earth":0x685549,
"Center Ridge":0x817a69,
"Center Stage":0xffc100,
"Centipede Brown":0x6d2400,
"Centra":0xc08f45,
"Centre Stage":0xc8c7cb,
"Century's Last Sunset":0x9c7b87,
"Ceramic":0xfcfff9,
"Ceramic Beige":0xedd1ac,
"Ceramic Blue Turquoise":0x16a29a,
"Ceramic Brown":0xa05843,
"Ceramic Glaze":0xe8a784,
"Ceramic Green":0x3bb773,
"Ceramic Pot":0x908268,
"Ceramite White":0xfefee0,
"Cereal Flake":0xefd7ab,
"Cerebellum Grey":0xcbcbcb,
"Cerebral Grey":0xcccccc,
"Ceremonial Gold":0xd69e59,
"Ceremonial Grey":0x91998e,
"Ceremonial Purple":0x2a2756,
"Cerise":0xa41247,
"Cerise Pink":0xec3b83,
"Cerise Red":0xde3163,
"Certain Peach":0xf2bda2,
"Cerulean":0x55aaee,
"Cerulean Blue":0x2a52be,
"Cerulean Frost":0x6d9bc3,
"Cetacean Blue":0x001440,
"Ceylanite":0x33431e,
"Ceylon Cream":0xf3e9d6,
"Ceylon Yellow":0xd4ae40,
"Ceylonese":0x756858,
"CG Blue":0x007aa5,
"CG Red":0xe03c31,
"CGA Blue":0x56ffff,
"CGA Pink":0xfc0fc0,
"Chá Lǜ Green":0x77926f,
"Chaat Masala":0xec7d2c,
"Chablis":0xfde9e0,
"Chafed Wheat":0xf6e0cf,
"Chagall Green":0x008b62,
"Chai":0xebcfae,
"Chai Latte":0xf9cba0,
"Chai Spice":0xbd7c4f,
"Chai Tea":0xb1832f,
"Chai Tea Latte":0xefd7b3,
"Chain Gang Grey":0x708090,
"Chain Mail":0x81777f,
"Chain Reaction":0xa4a6a4,
"Chaise Mauve":0xc1b2b3,
"Chakra":0x8b5e8f,
"Chalcedony":0xdddd99,
"Chalcedony Green":0x4b6057,
"Chalcedony Violet":0x6770ae,
"Chalet":0xc29867,
"Chalet Green":0x5a6e41,
"Chalk":0xedeae5,
"Chalk Beige":0xd6c5b4,
"Chalk Blue":0xccdad7,
"Chalk Dust":0xeaebe6,
"Chalk Pink":0xe6c5ca,
"Chalk Violet":0x8f7da5,
"Chalkware":0xe0ceb7,
"Chalky":0xdfc281,
"Chalky Blue White":0xd0ebf1,
"Challah Bread":0xcd7a50,
"Chambray":0x475877,
"Chambray Blue":0x9eb4d3,
"Chameleon":0xb6a063,
"Chameleon Skin":0xcedaac,
"Chameleon Tango":0xc0c2a0,
"Chamois":0xe8cd9a,
"Chamois Cloth":0xf0e1d0,
"Chamois Leather":0xad8867,
"Chamois Tan":0xb3a385,
"Chamois Yellow":0x986e19,
"Chamoisee":0xa0785a,
"Chamomile":0xe8d0a7,
"Chamomile Tea":0xdac395,
"Champagne":0xe9d2ac,
"Champagne Beige":0xd4c49e,
"Champagne Bliss":0xf0e1c5,
"Champagne Bubbles":0xddcead,
"Champagne Burst":0xf1e4cb,
"Champagne Cocktail":0xe3d7ae,
"Champagne Elegance":0xebd3e4,
"Champagne Flute":0xf6ece2,
"Champagne Gold":0xe8d6b3,
"Champagne Grape":0xc5b067,
"Champagne Ice":0xf3e5dd,
"Champagne Pink":0xf1ddcf,
"Champagne Rose":0xe3d6cc,
"Champagne Wishes":0xefd4ae,
"Champignon":0x949089,
"Champion":0x7b5986,
"Champion Blue":0x606788,
"Champlain Blue":0x435572,
"Chance of Rain":0xa0a6a9,
"Chandra Cream":0xecba5d,
"Changeling Pink":0xf4afcd,
"Channel":0xf1c3c2,
"Channel Marker Green":0x04d8b2,
"Chanoyu":0xeee8d2,
"Chanterelle":0xdaa520,
"Chanterelle Sauce":0xa28776,
"Chanterelles":0xffc66e,
"Chanticleer":0x870000,
"Chantilly":0xedb8c7,
"Chantilly Lace":0xf1e2de,
"Chaos Black":0x0f0f0f,
"Chaotic Red":0x740600,
"Chaotic Roses":0xbb2266,
"Chaparral":0xe5d0b0,
"Chapeau Violet":0xdee5ec,
"Chapel Wall":0xede2ac,
"Chaps":0x644b41,
"Chapter":0x9f9369,
"Charade":0x394043,
"Charadon Granite":0x504d4c,
"Charcoal":0x343837,
"Charcoal Blue":0x67778a,
"Charcoal Briquette":0x5d625c,
"Charcoal Dust":0x9497b3,
"Charcoal Grey":0x6e6969,
"Charcoal Light":0x726e68,
"Charcoal Plum":0x6a6a6f,
"Charcoal Sketch":0x5d5b56,
"Charcoal Smoke":0x474f43,
"Charcoal Smudge":0x60605e,
"Chard":0x48553f,
"Chardon":0xf8eadf,
"Chardonnay":0xefe8bc,
"Charisma":0x632a60,
"Charismatic":0xe7c180,
"Charismatic Red":0xee2244,
"Charismatic Sky":0x9ac1dc,
"Charleston Cherry":0x9f414b,
"Charleston Chocolate":0xc09278,
"Charleston Green":0x232b2b,
"Charlie Brown":0x995500,
"Charlie Horse":0x948263,
"Charlock":0xe5e790,
"Charlotte":0xa4dce6,
"Charm":0xd0748b,
"Charm Pink":0xe68fac,
"Charmed Green":0x007f3a,
"Charming":0xd4e092,
"Charming Cherry":0xff90a2,
"Charming Nature":0x11bb44,
"Charming Pink":0xedd3d2,
"Charming Violet":0x8c7281,
"Charoite Violet":0x6a577f,
"Charolais Cattle":0xf1ebea,
"Charred Brown":0x3e0007,
"Charred Chocolate":0x553b3d,
"Charred Clay":0x885132,
"Charred Hickory":0x5b4e4a,
"Charter":0x69b2cf,
"Charter Blue":0x546e91,
"Chartreuse":0xc1f80a,
"Chartreuse Frost":0xe4dcc6,
"Chartreuse Shot":0xdad000,
"Charybdis":0x16a3cb,
"Chasm":0x876044,
"Chasm Green":0x63b521,
"Chaste Blossoms":0x9944ee,
"Chat Orange":0xf79a3e,
"Chateau":0xb5a28a,
"Chateau Brown":0x5b4b44,
"Chateau de Chillon":0xa2aab3,
"Chateau Green":0x419f59,
"Chateau Grey":0xbbb1a8,
"Chateau Rose":0xdba3ce,
"Chatelle":0xb3abb6,
"Chathams Blue":0x2c5971,
"Chatroom":0xb0ab9c,
"Chatty Cricket":0x89b386,
"Chatura Gray":0xa09287,
"Chayote":0xc7e2c6,
"Che Guevara Red":0xed214d,
"Cheater":0xeeb15d,
"Cheddar Biscuit":0xd2ad87,
"Cheddar Cheese":0xf0843a,
"Cheddar Chunk":0xf9c982,
"Cheddar Corn":0xf5d4b5,
"Cheddar Pink Mauve":0xb67daf,
"Cheek Red":0xb67ca2,
"Cheeky Chestnut":0x7b4d3a,
"Cheerful":0xffc723,
"Cheerful Heart":0xdcc7c0,
"Cheerful Hue":0xffe195,
"Cheerful Tangerine":0xfda471,
"Cheerful Whisper":0xd3d7e7,
"Cheerful Wine":0x7e4258,
"Cheers!":0xc09962,
"Cheery":0xf08a88,
"Cheese":0xffa600,
"Cheese Please":0xff9613,
"Cheese Powder":0xffe4be,
"Cheese Puff":0xffb96f,
"Cheesecake":0xfffcda,
"Cheesus":0xffcc77,
"Cheesy Frittata":0xf0e093,
"Cheesy Grin":0xfae195,
"Chefchaouen Blue":0xa3d1e8,
"Chelsea Cucumber":0x88a95b,
"Chelsea Garden":0x546d66,
"Chelsea Gem":0x95532f,
"Chelsea Gray":0xb6b7b0,
"Chelsea Mauve":0xbeac9f,
"Chéng Hóng Sè Orange":0xf94009,
"Chenille":0xa6cd91,
"Chenille Spread":0xf1e7d6,
"Chenille White":0xf9efe2,
"Chenin":0xdec371,
"Cherenkov Radiation":0x22bbff,
"Cherish Cream":0xf4e3cb,
"Cherish is the Word":0xe6e4da,
"Cherish the Moment":0xccacd7,
"Cherished":0xba97b1,
"Cherished One":0xfc9293,
"Chernobog":0xac0132,
"Chernobog Breath":0xe3dcda,
"Cherokee":0xf5cd82,
"Cherokee Dignity":0xdd7722,
"Cherokee Red":0x824e4a,
"Cherries Jubilee":0xa22452,
"Cherry":0xcf0234,
"Cherry Bark":0x908279,
"Cherry Berry":0x9f4d65,
"Cherry Black":0x422329,
"Cherry Blink":0xad5344,
"Cherry Blossom":0xf7cee0,
"Cherry Blossom Pink":0xffb7c5,
"Cherry Blush":0xffc9dd,
"Cherry Bomb":0xb73d3f,
"Cherry Brandy":0xe26b81,
"Cherry Chip":0xffbbb4,
"Cherry Cobbler":0x883f41,
"Cherry Cocoa":0x8e5e65,
"Cherry Cola":0x894c3b,
"Cherry Cordial":0xebbed3,
"Cherry Fizz":0xbd6973,
"Cherry Flower":0xfbdae8,
"Cherry Foam":0xf392a0,
"Cherry Hill":0xcc5160,
"Cherry Juice":0xbd9095,
"Cherry Juice Red":0x6c2c45,
"Cherry Kiss":0xa32e39,
"Cherry Lolly":0xc8385a,
"Cherry Mahogany":0x66352b,
"Cherry On Top":0xac495c,
"Cherry Paddle Pop":0xfe314b,
"Cherry Pearl":0xf9e7f4,
"Cherry Pie":0x372d52,
"Cherry Pink":0xc7607b,
"Cherry Plum":0xa10047,
"Cherry Race":0xa64137,
"Cherry Red":0xf7022a,
"Cherry Tart":0x933d3e,
"Cherry Tomato":0xf2013f,
"Cherry Tree":0xdfb7b4,
"Cherry Velvet":0xe10646,
"Cherry Wine":0xb04556,
"Cherrywood":0x651a14,
"Chert":0x848182,
"Cherub":0xf5d7dc,
"Cherubic":0xffe6f1,
"Chervil Leaves":0xabbd90,
"Chess Ivory":0xffe9c5,
"Chester Brown":0x876b4b,
"Chestnut":0x742802,
"Chestnut Bisque":0xc19c86,
"Chestnut Brown":0x6d1008,
"Chestnut Butter":0xbca486,
"Chestnut Chest":0x8e5637,
"Chestnut Gold":0xab8508,
"Chestnut Green":0x2a4f21,
"Chestnut Leather":0x60281e,
"Chestnut Peel":0x6d3c32,
"Chestnut Plum":0x852e19,
"Chestnut Red":0x6c333f,
"Chestnut Rose":0xcd5252,
"Chestnut Shell":0xadff2f,
"Chestnut Stallion":0x995d3b,
"Chestnut White":0xeaf1e6,
"Chesty Bond":0x516fa0,
"Chetwode Blue":0x666fb4,
"Cheviot":0xf6f2e8,
"Chewing Gum":0xe6b0af,
"Chewing Gum Pink":0xe292b6,
"Chewy Caramel":0x977043,
"Cheyenne Rock":0x9f918a,
"Chi-Gong":0xd52b2d,
"Chianti":0x734342,
"Chic Brick":0xa4725a,
"Chic Green":0xd8ebd6,
"Chic Grey":0xcfccc5,
"Chic Magnet":0xede1c8,
"Chic Peach":0xf0d1c8,
"Chic Shade":0x7c9270,
"Chic Taupe":0xaa9788,
"Chicago":0x5b5d56,
"Chicago Blue":0xb6dbe9,
"Chicago Fog":0xcac2bd,
"Chicago Skyline":0x96adba,
"Chicha Morada":0x7e6072,
"Chick Flick":0xbf7d80,
"Chickadee":0xffcf65,
"Chicken Comb":0xdd2222,
"Chicken Masala":0xcc8822,
"Chickpea":0xefe7df,
"Chickweed":0xd9dfe3,
"Chicon":0xd9eeb4,
"Chicory":0xa78658,
"Chicory Coffee":0x4a342e,
"Chicory Flower":0x66789a,
"Chicory Green":0xbbab75,
"Chicory Root":0x5f423f,
"Chieftain":0x6a5637,
"Chiffon":0xf0f5bb,
"Chifle Yellow":0xdbc963,
"Child of Heaven":0xeae5c5,
"Child of Light":0xf0f4f8,
"Child of the Moon":0xc68d37,
"Child of the Night":0x220077,
"Child's Play":0xe7bcd4,
"Childhood Crush":0xe26d68,
"Childish Wonder":0xa5a8d6,
"Childlike":0xe8c0cf,
"Children's Soft Blue":0xa1ced7,
"Chilean Fire":0xd05e34,
"Chilean Heath":0xf9f7de,
"Chili":0xbe5141,
"Chili Con Carne":0x985e2b,
"Chili Green":0x8d7040,
"Chili Oil":0x8e3c36,
"Chili Pepper":0x9b1b30,
"Chili Sauce":0xbc4e40,
"Chili Soda":0xca7c74,
"Chill in the Air":0xd1d5e7,
"Chilled Cucumber":0xcbcdb2,
"Chilled Lemonade":0xffe696,
"Chilled Mint":0xe4efde,
"Chilled Wine":0x6d4052,
"Chilli Black Red":0x4b1c35,
"Chilli Cashew":0xcc5544,
"Chilly Blue":0x8aaec3,
"Chilly Spice":0xfd9989,
"Chilly White":0xe5f1ed,
"Chimayo Red":0xb16355,
"Chimera":0x74626d,
"Chimera Brown":0xc89b75,
"Chimes":0xc7ca86,
"Chimney":0x4a5257,
"Chimney Sweep":0x272f38,
"Chin-Chin Cherry":0xdd3355,
"China Aster":0x444c60,
"China Blue":0x546477,
"China Cinnamon":0x8a7054,
"China Clay":0x718b9a,
"China Cup":0xf8f0e5,
"China Doll":0xf3e4d5,
"China Green Blue":0x3a6468,
"China Ivory":0xfbf3d3,
"China Light Green":0xbcc9c7,
"China Pattern":0x3d5c77,
"China Pink":0xdf6ea1,
"China Red":0xad2b10,
"China Rose":0xa8516e,
"China Seas":0x034f7c,
"China Silk":0xe3d1cc,
"China White":0xeae6d9,
"Chinaberry":0x464960,
"Chinchilla":0x9c8e7b,
"Chinchilla Chenille":0xd0bba7,
"Chinchilla Grey":0x7f746e,
"Chinese Bellflower":0x4d5aaf,
"Chinese Black":0x111100,
"Chinese Blue":0x365194,
"Chinese Bronze":0xcd8032,
"Chinese Brown":0xab381f,
"Chinese Cherry":0xf1d7cb,
"Chinese Dragon":0xcb5251,
"Chinese Garden":0x006967,
"Chinese Gold":0xddaa00,
"Chinese Goldfish":0xf34723,
"Chinese Green":0xd0db61,
"Chinese Hamster":0xebdbca,
"Chinese Ibis Brown":0xe09e87,
"Chinese Ink":0x3f312b,
"Chinese Jade":0xcbd1ba,
"Chinese Lacquer":0x60c7c2,
"Chinese Lantern":0xf09056,
"Chinese Leaf":0xccd6b0,
"Chinese Money Plant":0xa4be5c,
"Chinese New Year":0xff3366,
"Chinese Night":0xaa381e,
"Chinese Orange":0xf37042,
"Chinese Pink":0xde70a1,
"Chinese Porcelain":0x3a5f7d,
"Chinese Purple":0x720b98,
"Chinese Red":0xcd071e,
"Chinese Safflower":0xb94047,
"Chinese Silver":0xdddcef,
"Chinese Tea Green":0xacad98,
"Chinese Tzu":0x8fbfbd,
"Chinese Violet":0x835e81,
"Chinese White":0xe2e5de,
"Chinese Yellow":0xffb200,
"Chino":0xb8ad8a,
"Chino Green":0xd9caa5,
"Chinois Green":0x7c8c87,
"Chinook":0x9dd3a8,
"Chinook Salmon":0xc8987e,
"Chinotto":0x554747,
"Chintz":0xd5c7b9,
"Chintz Rose":0xeec4be,
"Chipmunk":0xcfa14a,
"Chipolata":0xaa4433,
"Chipotle Paste":0x683e3b,
"Chips Provencale":0xddd618,
"Chitin Green":0x026b67,
"Chivalrous":0xaeb2c0,
"Chivalry Copper":0xbf784e,
"Chive":0x4a5335,
"Chive Bloom":0x4f3650,
"Chive Blossom":0x7d5d99,
"Chive Flower":0xa193bf,
"Chlorella Green":0x56ae57,
"Chloride":0x93d8c2,
"Chlorite":0x5e8e82,
"Chlorophyll":0x44891a,
"Chlorophyll Cream":0xb3d6c3,
"Chlorophyll Green":0x4aff00,
"Chlorosis":0x75876e,
"Choco Biscuit":0xb4835b,
"Choco Chic":0x993311,
"Choco Death":0x63493e,
"Choco Loco":0x7d5f53,
"Chocobo Feather":0xf9bc08,
"Chocoholic":0x993300,
"Chocolate":0xd2691e,
"Chocolate Bar":0x773333,
"Chocolate Bells":0x775130,
"Chocolate Bhut Jolokia":0x782a2e,
"Chocolate Brown":0x411900,
"Chocolate Caliente":0x765841,
"Chocolate Castle":0x452207,
"Chocolate Chiffon":0x928178,
"Chocolate Chip":0x685a4e,
"Chocolate Chunk":0x6b574a,
"Chocolate Coco":0x644d42,
"Chocolate Cosmos":0x58111a,
"Chocolate Cupcake":0x605647,
"Chocolate Curl":0x916d5e,
"Chocolate Delight":0x96786d,
"Chocolate Eclair":0x674848,
"Chocolate Escape":0x623d2e,
"Chocolate Explosion":0x8e473b,
"Chocolate Fondant":0x56352d,
"Chocolate Fondue":0x9a3001,
"Chocolate Froth":0xded5c8,
"Chocolate Hazelnut":0x742719,
"Chocolate Heart":0x8f786c,
"Chocolate Kiss":0x3c1421,
"Chocolate Lab":0x5c3e35,
"Chocolate Lust":0x993322,
"Chocolate Magma":0x7a463a,
"Chocolate Melange":0x331100,
"Chocolate Milk":0x976f4c,
"Chocolate Moment":0x998069,
"Chocolate Pancakes":0x884400,
"Chocolate Plum":0x3c2d2e,
"Chocolate Powder":0xa58c7b,
"Chocolate Praline":0x66424d,
"Chocolate Pretzel":0x60504b,
"Chocolate Pudding":0x6f6665,
"Chocolate Rain":0x714f29,
"Chocolate Red":0x4d3635,
"Chocolate Ripple":0x76604e,
"Chocolate Soul":0x5c4945,
"Chocolate Sparkle":0x8c6c6f,
"Chocolate Sprinkle":0x6f4e43,
"Chocolate Stain":0x84563c,
"Chocolate Swirl":0x68574b,
"Chocolate Temptation":0x956e5f,
"Chocolate Therapy":0x5f4940,
"Chocolate Torte":0x382e2d,
"Chocolate Truffle":0x612e35,
"Chocolate Velvet":0x7f7453,
"Choice Cream":0xf2e1d1,
"Chōjicha Brown":0x8f583c,
"Chokecherry":0x92000a,
"Choo Choo":0x867578,
"Chopped Chive":0x336b4b,
"Chopped Dill":0xb6c2a1,
"Chopsticks":0xe0d1b8,
"Choral Singer":0xb77795,
"Chorizo":0xaa0011,
"Chōshun Red":0xb95754,
"Chowder Bowl":0xe5d2b2,
"Christalle":0x382161,
"Christi":0x71a91d,
"Christina Brown":0x009094,
"Christmas Blue":0x2a8fbd,
"Christmas Brown":0x5d2b2c,
"Christmas Gold":0xcaa906,
"Christmas Green":0x3c8d0d,
"Christmas Holly":0x68846a,
"Christmas Ivy":0x477266,
"Christmas Orange":0xd56c2b,
"Christmas Ornament":0x6e5a49,
"Christmas Pink":0xe34285,
"Christmas Purple":0x4d084b,
"Christmas Red":0xb01b2e,
"Christmas Rose":0xffddbb,
"Christmas Silver":0xe1dfe0,
"Christobel":0xd4c5ba,
"Christy's Smile":0xf6bbca,
"Chrome Aluminum":0xa8a9ad,
"Chrome Chalice":0xcdc8d2,
"Chrome White":0xcac7b7,
"Chrome Yellow":0xffa700,
"Chromis Damsel Blue":0x82cafc,
"Chromophobia Green":0x06b48b,
"Chronicle":0x3e4265,
"Chronus Blue":0x72a8d1,
"Chrysanthemum":0xbe454f,
"Chrysanthemum Leaf":0x9db8ab,
"Chrysocolla Dark Green":0x004f39,
"Chrysocolla Green":0x378661,
"Chrysocolla Medium Green":0x006b57,
"Chrysolite":0x8e9849,
"Chrysomela Goettingensis":0x39334a,
"Chrysopal Light Green":0x8fb2a3,
"Chrysoprase":0xadba98,
"Chuckles":0xbf413a,
"Chuff Blue":0x91c1c6,
"Chun-Li Blue":0x1559db,
"Chunky Bee":0xffc84b,
"Chupacabra Grey":0xcfcdcf,
"Church Blue":0x3d4161,
"Church Mouse":0xb3b5af,
"Churchill":0x4d4d58,
"Chutney":0x98594b,
"Chutney Brown":0xa97765,
"Chyornyi Black":0x0f0809,
"Cider Mill":0x938a43,
"Cider Pear Green":0x8a946f,
"Cider Spice":0xae8167,
"Cider Toddy":0xb98033,
"Cider Yellow":0xe7d6af,
"Cielo":0xa5cee8,
"Cigar":0x7d4e38,
"Cigar Box":0x9c7351,
"Cigar Smoke":0x78857a,
"Cigarette Glow":0xee5500,
"Cilantro":0x43544b,
"Cilantro Cream":0xcecbae,
"Cimarron":0x6b3d38,
"Cinder":0x242a2e,
"Cinderella":0xfbd7cc,
"Cinderella Pink":0xffc6c4,
"Cinema Screen":0x95878e,
"Cinereous":0x98817b,
"Cinnabar":0x730113,
"Cinnabark":0x634d45,
"Cinnamon":0xd26911,
"Cinnamon Brandy":0xcf8d6c,
"Cinnamon Brown":0x9e6a19,
"Cinnamon Bun":0xac4f06,
"Cinnamon Cake":0xe8ddcf,
"Cinnamon Candle":0xb15d63,
"Cinnamon Cherry":0x794344,
"Cinnamon Cocoa":0xd1a79c,
"Cinnamon Crumble":0x705742,
"Cinnamon Crunch":0xa37d5a,
"Cinnamon Diamonds":0xa97673,
"Cinnamon Frost":0xd3b191,
"Cinnamon Ice":0xdbbba7,
"Cinnamon Milk":0xebdab5,
"Cinnamon Roast":0xbb9988,
"Cinnamon Roll":0xc0737a,
"Cinnamon Sand":0xb78153,
"Cinnamon Satin":0xcd607e,
"Cinnamon Spice":0x935f43,
"Cinnamon Stick":0x9b4722,
"Cinnamon Stone":0xc9543a,
"Cinnamon Tea":0xdec0ad,
"Cinnamon Toast":0x8d7d77,
"Cinnamon Twist":0x9f7250,
"Cinnamon Whip":0xdab2a4,
"Cinnapink":0xa6646f,
"Cinque Foil":0xffff88,
"Cioccolato":0x5d3b2e,
"Cipher":0xaa7691,
"Cipollino":0xc8cec3,
"Circumorbital Ring":0x6258c4,
"Circus":0xfc5e30,
"Circus Peanut":0xad835c,
"Circus Red":0x954a4c,
"Cistern":0xa9b0b6,
"Citadel":0x748995,
"Citadel Blue":0x9eabad,
"Citrine":0xe4d00a,
"Citrine Brown":0x933709,
"Citrine White":0xfaf7d6,
"Citrino":0xe9e89b,
"Citron":0xd5c757,
"Citron Goby":0xdeff00,
"Citronella":0x66bb77,
"Citronelle":0xb8af23,
"Citronette":0xc4aa27,
"Citronne":0xcd9c2b,
"Citrus":0x9fb70a,
"Citrus Blast":0xe1793a,
"Citrus Butter":0xe4de8e,
"Citrus Delight":0xd0d557,
"Citrus Hill":0xf9a78d,
"Citrus Honey":0xf6b96b,
"Citrus Leaf":0xb3d157,
"Citrus Lime":0xc3dc68,
"Citrus Mist":0xf7edde,
"Citrus Notes":0xd26643,
"Citrus Peel":0xb7bb6b,
"Citrus Punch":0xfdea83,
"Citrus Sachet":0xf2c6a7,
"Citrus Spice":0xe2cd52,
"Citrus Splash":0xffc400,
"Citrus Sugar":0xe6d943,
"Citrus Yellow":0xd7c275,
"Citrus Zest":0xedc85a,
"City Bench":0x675c49,
"City Brume":0xe0e0dc,
"City Dweller":0xc0b9ac,
"City Hunter Blue":0x0022aa,
"City Lights":0xdfe6ea,
"City Loft":0xa79b8a,
"City of Bridges":0xb3ada4,
"City of Diamonds":0xfae6cb,
"City of Pink Angels":0xe6b4a6,
"City Rain":0x525c61,
"City Roast":0x663333,
"City Street":0xbab2ab,
"City Sunrise":0xd1a67d,
"City Tower":0xaeaba5,
"Cityscape":0xdae3e7,
"Civara":0xc56138,
"Clair De Lune":0xdbe9df,
"Clairvoyance":0x838493,
"Clairvoyant":0x480656,
"Clam":0xdad1c0,
"Clam Chowder":0xf4d9af,
"Clam Shell":0xd2b3a9,
"Clam Up":0xebdbc1,
"Clambake":0xe0d1bb,
"Clamshell":0xedd0b6,
"Claret":0x680018,
"Claret Red":0xc84c61,
"Clarified Butter":0xe69c23,
"Clarified Orange":0xfea15b,
"Clarinet":0x002255,
"Clarity":0xeaf0e0,
"Clary":0x684976,
"Clary Sage":0xc7c0ce,
"Classic":0xbbaaa1,
"Classic Avocado":0x6e7042,
"Classic Berry":0x7c5261,
"Classic Blue":0x0f4c81,
"Classic Bouquet":0xa38bbf,
"Classic Bronze":0x6d624e,
"Classic Brown":0x6a493d,
"Classic Calm":0x6b8885,
"Classic Chalk":0xf4f4f0,
"Classic Cherry":0x974146,
"Classic Cloud":0x9197a3,
"Classic Cool":0xb7b2ac,
"Classic French Gray":0x888782,
"Classic Gold":0xc9a367,
"Classic Green":0x39a845,
"Classic Ivory":0xf2e0c3,
"Classic Light Buff":0xf0eadc,
"Classic Olive":0x685e3f,
"Classic Rose":0xfbcce7,
"Classic Sand":0xd6bcaa,
"Classic Silver":0xb9b9b4,
"Classic Taupe":0xd3bca4,
"Classic Terra":0xe4ceae,
"Classic Waltz":0x71588d,
"Classical Gold":0xebb875,
"Classical White":0xece1cb,
"Classical Yellow":0xf8d492,
"Classy":0xaeacad,
"Classy Mauve":0xbb99aa,
"Classy Plum":0x887e82,
"Classy Red":0x911f21,
"Clay":0xb66a50,
"Clay Ash":0xbdc8b3,
"Clay Bake":0xe1c68f,
"Clay Bath":0x8a7d69,
"Clay Beige":0xd5d1c3,
"Clay Brown":0xb2713d,
"Clay Court":0xa9765d,
"Clay Creek":0x897e59,
"Clay Dust":0xf8dca3,
"Clay Fire":0xd8a686,
"Clay Ground":0xbd856c,
"Clay Mug":0xd37959,
"Clay Ochre":0xae895d,
"Clay Pebble":0xbdb298,
"Clay Pipe":0xd9c8b7,
"Clay Play":0x774433,
"Clay Pot":0xc3663f,
"Clay Red":0xaf604d,
"Clay Ridge":0x956a66,
"Clay Slate Wacke":0xcdcace,
"Clay Terrace":0xd4823c,
"Clayton":0x83756c,
"Clean Air":0xd8ddb6,
"Clean Canvas":0xf6e9d3,
"Clean Green":0x8fe0c6,
"Clean N Crisp":0xd0e798,
"Clean Slate":0x577396,
"Clear Aqua":0xc4eae0,
"Clear Blue":0x247afd,
"Clear Brook":0x60949b,
"Clear Calamine":0xf6e6e4,
"Clear Camouflage Green":0xdae8e1,
"Clear Chill":0x1e90ff,
"Clear Cinnamon":0xdfdbd8,
"Clear Concrete":0xbab6b2,
"Clear Day":0xdfefea,
"Clear Green":0x12732b,
"Clear Lake Trail":0xa3bbda,
"Clear Mauve":0x766cb0,
"Clear Moon":0xfaf6ea,
"Clear Orange":0xee8800,
"Clear Plum":0x64005e,
"Clear Pond":0xb4cccb,
"Clear Purple":0x412a7a,
"Clear Red":0xce261c,
"Clear Sand":0xeae7da,
"Clear Skies":0xe8f7fd,
"Clear Turquoise":0x008a81,
"Clear View":0xe2eae7,
"Clear Viridian":0x367588,
"Clear Vision":0xe7f0f7,
"Clear Vista":0xa3bec4,
"Clear Water":0xaad5db,
"Clear Weather":0x66bbdd,
"Clear Yellow":0xf1f1e6,
"Clearly Aqua":0xcee1d4,
"Clearview":0xfbfbe5,
"Clematis":0x7e6596,
"Clematis Blue":0x363b7c,
"Clematis Green":0x98b652,
"Clematis Magenta":0xe05aec,
"Clementine":0xe96e00,
"Clementine Jelly":0xffad01,
"Cleo's Bath":0x00507f,
"Cleopatra":0x007590,
"Cleopatra's Gown":0x795088,
"Clichy White":0xf6ebee,
"Cliff Brown":0xd0ab8c,
"Cliff Ridge":0xc5ae80,
"Cliff Rock":0xb19475,
"Cliff Swallow":0xecddd4,
"Cliff's View":0xddc5aa,
"Cliffside Park":0x6f8165,
"Climate Change":0xe5e1cd,
"Climate Control":0x466082,
"Climbing Ivy":0x58714a,
"Clinical Soft Blue":0xb2cfd3,
"Clinker":0x463623,
"Clinker Red":0x663145,
"Clipped Grass":0xa1b841,
"Clippership Twill":0xa6937d,
"Cloak and Dagger":0x550055,
"Cloak Gray":0x605e63,
"Clock Chimes Thirteen":0x002211,
"Clockworks":0x72573d,
"Cloisonne":0x0075af,
"Cloisonne Blue":0x84a1ad,
"Cloistered Garden":0x99b090,
"Clooney":0x5f6c84,
"Close Knit":0xd5d6cf,
"Closed Shutter":0x25252c,
"Clotted Cream":0xf3efcd,
"Clotted Red":0x991115,
"Cloud Abyss":0xdfe7eb,
"Cloud Blue":0xa2b6b9,
"Cloud Burst":0x899c96,
"Cloud Cream":0xe6ddc5,
"Cloud Dancer":0xf0eee9,
"Cloud Grey":0xb8a9af,
"Cloud Nine":0xe9e0db,
"Cloud Number Nine":0xf9cec6,
"Cloud Over London":0xc2bcb1,
"Cloud Pink":0xf5d1c8,
"Cloud White":0xf2f2ed,
"Cloudberry":0xffa168,
"Cloudburst":0x837f7f,
"Clouded Blue":0x1f75fe,
"Clouded Sky":0x7d93a2,
"Clouded Vision":0xd1d0d1,
"Cloudless":0xd6eafc,
"Cloudless Day":0x9ab1bf,
"Cloudy":0xd8d7d3,
"Cloudy Blue":0xacc2d9,
"Cloudy Camouflage":0x177245,
"Cloudy Carrot":0xffa812,
"Cloudy Cinnamon":0x87715f,
"Cloudy Day":0xdfe6da,
"Cloudy Desert":0xb0a99f,
"Cloudy Grey":0xece3e1,
"Cloudy Plum":0x9d7aac,
"Cloudy Sea":0x6699aa,
"Cloudy Sky":0xc2d5da,
"Cloudy Today":0xa6a096,
"Cloudy Viridian":0x4b5f56,
"Clove":0x876155,
"Clove Brown":0x766051,
"Clove Dye":0xa96232,
"Clove Yellow Brown":0x523f21,
"Clovedust":0xb0705d,
"Clover":0x008f00,
"Clover Brook":0x1c6a53,
"Clover Green":0x006c44,
"Clover Honey":0xf0e2bc,
"Clover Mist":0x6fc288,
"Clover Patch":0x4a9d5b,
"Clover Pink":0xcd9bc4,
"Clown Green":0xc4d056,
"Clown Nose":0xe94257,
"Club Cruise":0x8bc3e1,
"Club Grey":0x464159,
"Club Mauve":0x834370,
"Club Moss":0x6b977a,
"Club Navy":0x3e4a54,
"Club Soda":0xe2edeb,
"Club-Mate":0xf8de7e,
"Clumsy Caramel":0xd3b683,
"Clytemnestra":0xe8e2e0,
"Co Pilot":0x4978a9,
"CO₂":0xcadfec,
"Coach Green":0x003527,
"Coal Mine":0x54555d,
"Coal Miner":0x777872,
"Coalmine":0x220033,
"Coarse Wool":0x181b26,
"Coast Cream":0xf6e6db,
"Coastal Beige":0xf0ebd9,
"Coastal Breeze":0xe0f6fb,
"Coastal Calm":0x538f94,
"Coastal Crush":0xb4c0af,
"Coastal Fjord":0x505d7e,
"Coastal Foam":0xb0e5c9,
"Coastal Fog":0xe5e8e4,
"Coastal Fringe":0x80b9c0,
"Coastal Jetty":0x006e7f,
"Coastal Mist":0xd2e8ec,
"Coastal Plain":0x9fa694,
"Coastal Sand":0xc9a985,
"Coastal Storm":0x7d807b,
"Coastal Surf":0x2d4982,
"Coastal Trim":0xbdffca,
"Coastal Vista":0x8293a0,
"Coastline Trail":0x6e6c5b,
"Coated":0x2e2f30,
"Cobalite":0x9999ff,
"Cobalt":0x030aa7,
"Cobalt Flame":0x4e719d,
"Cobalt Glaze":0x0072b5,
"Cobalt Night":0x353739,
"Cobalt Stone":0x0264ae,
"Cobble Brown":0x7a6455,
"Cobbler":0xc4ab7d,
"Cobblestone":0xa89a8e,
"Cobblestone Path":0x9e8779,
"Cobblestone Street":0xcfc7b9,
"Cobra Leather":0xb08e08,
"Cobre":0x996515,
"Cobrizo":0xb56d5d,
"Coca Mocha":0xbd9d95,
"Cochin Chicken":0xf8b862,
"Cochineal Red":0x7a4848,
"Cochineal Red/Rouge":0x9d2933,
"Cochise":0xddcdb3,
"Cochonnet":0xff88bb,
"Cockatoo":0x58c8b6,
"Cockatrice Brown":0xa46422,
"Cockleshell":0xe3c6af,
"Cockscomb Red":0xbc5378,
"Cocktail Blue":0x5a7aa2,
"Cocktail Green":0x8eb826,
"Cocktail Hour":0xfd9a52,
"Cocktail Olive":0x9fa36c,
"Coco":0xd1bba1,
"Coco Malt":0xe4dcc9,
"Coco Rum":0x9b7757,
"Coco-Lemon Tart":0xeedd88,
"Cocoa":0x875f42,
"Cocoa Bean":0x4f3835,
"Cocoa Berry":0xa08882,
"Cocoa Brown":0x35281e,
"Cocoa Butter":0xf5f4c1,
"Cocoa Craving":0xb9a39a,
"Cocoa Cream":0xdbc8b6,
"Cocoa Cupcake":0x967859,
"Cocoa Delight":0x8d725a,
"Cocoa Milk":0x7d675d,
"Cocoa Nib":0xbc9f7e,
"Cocoa Nutmeg":0xa8816f,
"Cocoa Parfait":0xdfcec2,
"Cocoa Pecan":0x967b5d,
"Cocoa Powder":0x766a5f,
"Cocoa Shell":0x7e6657,
"Cocoa Whip":0xa08e7e,
"Cocobolo":0x784848,
"Cocoloco":0xaa8f7a,
"Coconut":0x965a3e,
"Coconut Aroma":0xeeeedd,
"Coconut Butter":0xf2efe1,
"Coconut Cream":0xe1dabb,
"Coconut Crumble":0xe2cea6,
"Coconut Grove":0x676d43,
"Coconut Husk":0x7d6044,
"Coconut Ice":0xddd4c7,
"Coconut Macaroon":0xdacac0,
"Coconut Milk":0xf0ede5,
"Coconut Pulp":0xfbf9e1,
"Coconut Shell":0x917a56,
"Coconut Twist":0xf7f1e1,
"Coconut White":0xe9edf6,
"Cocoon":0xdedbcc,
"Cod Grey":0x2d3032,
"Codex Grey":0x9c9c9c,
"Codium Fragile":0x524b2a,
"Codman Claret":0x8c4040,
"Coelia Greenshade":0x0e7f78,
"Coelin Blue":0x497d93,
"Coffee":0x6f4e37,
"Coffee Addiction":0x883300,
"Coffee Adept":0x775511,
"Coffee Bag":0xdbd6d3,
"Coffee Bar":0x825c43,
"Coffee Bean":0x362d26,
"Coffee Bean Brown":0x765640,
"Coffee Beans":0x6e544b,
"Coffee Clay":0xb7997c,
"Coffee Cream":0xfff2d7,
"Coffee Custard":0xab9b9c,
"Coffee Diva":0xbea88d,
"Coffee House":0x6c5b4d,
"Coffee Kiss":0xb19576,
"Coffee Liqueur":0x6a513b,
"Coffee Rose":0xa9898d,
"Coffee Shop":0x725042,
"Coffee With Cream":0xa68966,
"Cognac":0xd48c46,
"Cognac Brown":0xb98563,
"Cogswell Cedar":0x90534a,
"Coin Purse":0xe0d5e3,
"Coin Slot":0xff4411,
"Coincidence":0xc7de88,
"Cola":0x3c2f23,
"Cola Bubble":0x3c3024,
"Cold Air Turquoise":0xc1dcdb,
"Cold Blooded":0xbbeeee,
"Cold Blue":0x88dddd,
"Cold Brew Coffee":0x785736,
"Cold Canada":0xdbfffe,
"Cold Current":0x234272,
"Cold Foam":0xefece3,
"Cold Front Green":0x85b3b2,
"Cold Green":0x008b3c,
"Cold Grey":0x9f9f9f,
"Cold Heights":0x22ddee,
"Cold Light":0xdde3e6,
"Cold Light of Day":0x00eeee,
"Cold Lips":0x9ba0ef,
"Cold Morning":0xe6e5e4,
"Cold North":0x559c9b,
"Cold Pack":0x0033dd,
"Cold Pilsner":0xd09351,
"Cold Pink":0xbca5ad,
"Cold Purple":0x9d8abf,
"Cold Sea Currents":0x32545e,
"Cold Shoulder":0xd4e0ef,
"Cold Soft Blue":0xd9e7e6,
"Cold Spring":0x88bb66,
"Cold Steel":0x262335,
"Cold Turbulence":0xcfe1ef,
"Cold Turkey":0xcab5b2,
"Cold Turquoise":0xa5d0cb,
"Cold Water":0xd9dfe0,
"Cold Wave":0xc2e2e3,
"Cold Well Water":0xc1e2e3,
"Cold White":0xedfcfb,
"Cold Wind":0xe1e3e4,
"Cold Winter's Morn":0xb4bcd1,
"Coliseum Marble":0xcec8b6,
"Collard Green":0x536861,
"Collectible":0x9b8467,
"Colleen Green":0xebecda,
"Collensia":0xbdb7cd,
"Cologne":0x75bfd2,
"Colombo Red Mauve":0xba7ab3,
"Colonel Mustard":0xb68238,
"Colonial Aqua":0xa1bdbf,
"Colonial Blue":0x2d6471,
"Colonial Brick":0xad6961,
"Colonial Revival Gray":0xb4b9b9,
"Colonial Revival Green Stone":0xa39b7e,
"Colonial Revival Sea Green":0xaebea6,
"Colonial Revival Stone":0xa7947c,
"Colonial Revival Tan":0xd3b699,
"Colonial Rose":0xe7b6bc,
"Colonial White":0xffedbc,
"Colonial Yellow":0xefc488,
"Colonnade Gray":0xc6c0b6,
"Colonnade Grey":0xb2b1ad,
"Colony":0x67a195,
"Colony Blue":0x65769a,
"Colony Buff":0xddc6ab,
"Color Blind":0xc6d2de,
"Color Me Green":0x7cb77b,
"Colorado Bronze":0xee7766,
"Colorado Dawn":0xe09cab,
"Colorado Peach":0xe6994c,
"Colorado Peak":0x9c9ba7,
"Colorado Springs":0x88aac4,
"Colorado Trail":0xb49375,
"Colorful Leaves":0xaa5c43,
"Colossus":0x625c91,
"Columbia":0x009288,
"Columbia Blue":0x9bddff,
"Columbine":0xf5dae3,
"Columbo's Coat":0xd0cbce,
"Columbus":0x5f758f,
"Column Of Oak Green":0x006f37,
"Colusa Wetlands":0x7f725c,
"Combed Cotton":0xf4f0de,
"Come Sail Away":0x5c92c5,
"Comet":0x636373,
"Comfort":0xe3ceb8,
"Comfort Gray":0xbec3bb,
"Comforting":0xd6c0ab,
"Comforting Cherry":0xcc1144,
"Comforting Green":0xd5e0cf,
"Comforting Grey":0xc5c3b4,
"Comfrey":0x5b7961,
"Comfy Beige":0xe3d2b6,
"Comical Coral":0xf3d1c8,
"Coming up Roses":0xde7485,
"Commandes":0x0b597c,
"Commercial White":0xedece6,
"Commodore":0x25476a,
"Common Chalcedony":0xc8ad7f,
"Common Chestnut":0xcd5c5c,
"Common Dandelion":0xfed85d,
"Common Feldspar":0x858f94,
"Common Jasper":0x946943,
"Common Teal":0x009193,
"Communist":0xcc0000,
"Community":0xd0b997,
"Como":0x4c785c,
"Compact Disc Grey":0xcdcdcd,
"Compass":0x8a877b,
"Compass Blue":0x35475b,
"Compatible Cream":0xe8c89e,
"Complex Grey":0x847975,
"Composed":0xbbc8b2,
"Composer's Magic":0x7a6e7e,
"Composite Artefact Green":0x55cc00,
"Concealed Green":0x263130,
"Concealment":0x405852,
"Concept Beige":0xd5bda3,
"Conceptual":0x7ac34f,
"Concerto":0x9e6b75,
"Conch":0xa0b1ae,
"Conch Pink":0xdba496,
"Conch Shell":0xfc8f9b,
"Conclave":0xabb9d7,
"Concord":0x827f79,
"Concord Buff":0xe2ceb0,
"Concord Grape":0x7c5379,
"Concord Jam":0x695a82,
"Concrete":0xd2d1cd,
"Concrete Jungle":0x999988,
"Concrete Sidewalk":0x8d8a81,
"Condiment":0xb98142,
"Conditioner":0xffffcc,
"Cone Green Blue":0x4a6169,
"Coney Island":0x6d7e7d,
"Confection":0xf4ecda,
"Confederate":0x5c6272,
"Confetti":0xddcb46,
"Confidence":0xa98a6b,
"Confident White":0xe4dfce,
"Confident Yellow":0xffcc13,
"Cōng Lǜ Green":0x01c08d,
"Congo":0xe8c3be,
"Congo Brown":0x654d49,
"Congo Capture":0x776959,
"Congo Green":0x00a483,
"Congo Pink":0xf98379,
"Congress Blue":0x02478e,
"Congressional Navy":0x100438,
"Conifer":0xb1dd52,
"Conifer Blossom":0xffdd49,
"Conifer Cone":0x885555,
"Conifer Green":0x747767,
"Conker":0xb94e41,
"Conker Brown":0x552200,
"Connaisseur":0x654e44,
"Connect Red":0xeb6651,
"Connected Gray":0x898473,
"Connecticut Lilac":0xccbbee,
"Connor's Lakefront":0x175a6c,
"Cono De Vainilla":0xf2d9b8,
"Conservation":0x796e54,
"Conservative Gray":0xd1d0c6,
"Conspiracy Velvet":0x57465d,
"Constant Coral":0xcd8e7f,
"Constellation":0xbccedb,
"Constellation Blue":0x3c4670,
"Construction Zone":0xee8442,
"Contemplation":0xbec6bb,
"Contented":0xbdc0b3,
"Contessa":0xc16f68,
"Continental Waters":0x98c6cb,
"Contrail":0xdedeff,
"Contrasting Yellow":0xf2c200,
"Convivial Yellow":0xe9d6b0,
"Cook's Bay":0x014e83,
"Cookie":0xffe2b7,
"Cookie Crumb":0xb19778,
"Cookie Crust":0xe3b258,
"Cookie Dough":0xab7100,
"Cookies And Cream":0xeee0b1,
"Cool":0x96b3b3,
"Cool Aloe":0xa9d99c,
"Cool Ashes":0x929291,
"Cool Avocado":0xc4b47d,
"Cool Beige":0xc6b5a7,
"Cool Black":0x002e63,
"Cool Blue":0x4984b8,
"Cool Camel":0xae996b,
"Cool Camo":0x827566,
"Cool Cantaloupe":0xf1d3ca,
"Cool Charcoal":0x807b76,
"Cool Clay":0xba947b,
"Cool Concrete":0xd9d0c1,
"Cool Copper":0xad8458,
"Cool Crayon":0xb0e6e3,
"Cool Cream":0xfbe5d9,
"Cool Current":0x283c44,
"Cool December":0xfdfbf8,
"Cool Dive":0x00606f,
"Cool Dusk":0x7b9dad,
"Cool Elegance":0xcfcfd0,
"Cool Frost":0xe7e6ed,
"Cool Granite":0xabaca8,
"Cool Green":0x33b864,
"Cool Grey":0x8c93ad,
"Cool Icicle":0xe1eee6,
"Cool Jazz":0xbee7e0,
"Cool Lava":0xe97c6b,
"Cool Lavender":0xb3a6a5,
"Cool Melon":0xebd1cd,
"Cool Pink":0xe5ccd1,
"Cool Purple":0xaa23ff,
"Cool Quiet":0xcbb5c6,
"Cool Reflection":0xeaf0eb,
"Cool Sky":0xcfe0e4,
"Cool Slate":0xd0ccc5,
"Cool Spring":0xbbd9c3,
"Cool Touch":0x7295c9,
"Cool Water Lake":0x9bd9e5,
"Cool Waters":0x487678,
"Cool White":0xdae6e2,
"Cool Yellow":0xeaefce,
"Coolbox Ice Turquoise":0x499c9d,
"Cooled Blue":0x75b9ae,
"Cooled Cream":0xfadc97,
"Cooler Than Ever":0x77bbff,
"Cooling Trend":0xe6e2e4,
"Copacabana":0x006c8d,
"Copacabana Sand":0xe5d68e,
"Copen Blue":0x516b84,
"Copenhagen":0xadc8c0,
"Copenhagen Blue":0x21638b,
"Copper":0xb87333,
"Copper Beech":0xb1715a,
"Copper Blush":0xe8c1ab,
"Copper Brown":0x9a6051,
"Copper Canyon":0x77422c,
"Copper Coin":0xda8a67,
"Copper Cove":0xd89166,
"Copper Creek":0xa35d31,
"Copper Harbor":0xd57e52,
"Copper Lake":0xc09078,
"Copper Mine":0xb2764c,
"Copper Mineral Green":0x398174,
"Copper Mining":0x945c54,
"Copper Moon":0xc29978,
"Copper Mountain":0xab714a,
"Copper Patina":0x9db4a0,
"Copper Penny":0xad6f69,
"Copper Pink":0x946877,
"Copper Pipe":0xda8f67,
"Copper Pot":0x936647,
"Copper Pyrite Green":0x3e4939,
"Copper Red":0xcb6d51,
"Copper River":0xf7a270,
"Copper Roof Green":0x6f978e,
"Copper Rose":0x996666,
"Copper Rust":0x95524c,
"Copper Tan":0xde8e65,
"Copper Trail":0xc18978,
"Copper Turquoise":0x38887f,
"Copper Wire":0xdb8b67,
"Copper-Metal Red":0xad6342,
"Copperfield":0xda8a88,
"Copperleaf":0xcf8874,
"Coppersmith":0xd98a3f,
"Coppery Orange":0x7f4330,
"Copra":0x654636,
"Coquelicot":0xff3800,
"Coquette":0xe5dcdc,
"Coquina":0x9d8d8e,
"Cor-de-pele":0xf4c2c2,
"Coral":0xff7f50,
"Coral Almond":0xe29d94,
"Coral Atoll":0xdc938d,
"Coral Bay":0xddb8a3,
"Coral Beach":0xffbbaa,
"Coral Bead":0xef9a93,
"Coral Bells":0xfbc5bb,
"Coral Bisque":0xf7c6b1,
"Coral Blossom":0xf7bea2,
"Coral Blush":0xe5a090,
"Coral Burst":0xdd5544,
"Coral Candy":0xf5d0c9,
"Coral Clay":0xc2b1a1,
"Coral Cloud":0xe2a9a1,
"Coral Coast":0x068e9e,
"Coral Commander":0xee6666,
"Coral Confection":0xfccca7,
"Coral Corn Snake":0xe9adca,
"Coral Cove":0xdda69f,
"Coral Cream":0xead6ce,
"Coral Dune":0xfcd5c5,
"Coral Dusk":0xffb48a,
"Coral Dust":0xedaa86,
"Coral Expression":0xd76a69,
"Coral Fountain":0xe3a9a2,
"Coral Garden":0xcf8179,
"Coral Gold":0xd27d56,
"Coral Green":0xabe2cf,
"Coral Haze":0xe38e84,
"Coral Kiss":0xffddc7,
"Coral Mantle":0xfcd6cb,
"Coral Orange":0xe4694c,
"Coral Pink":0xf88379,
"Coral Quartz":0xf77464,
"Coral Red":0xff4040,
"Coral Reef":0xc7bca2,
"Coral Rose":0xf3774d,
"Coral Sand":0xca884e,
"Coral Serenade":0xf9a48e,
"Coral Silk":0xf2a37d,
"Coral Springs":0xabd1af,
"Coral Stone":0xddc3b6,
"Coral Trails":0xff8b87,
"Coral Tree":0xab6e67,
"Coralette":0xf08674,
"Corallite":0xf0dfcd,
"Corally":0xfea89f,
"Corazon":0x9d6663,
"Corbeau":0x111122,
"Cordial":0x864c52,
"Cordite":0x616665,
"Cordon Bleu Crust":0xebe0c8,
"Cordova Burgundy":0x7c3744,
"Cordovan":0x893f45,
"Cordovan Leather":0x57443d,
"Corduroy":0x404d49,
"Corfu Shallows":0x008e8d,
"Corfu Sky":0x8993c3,
"Corfu Waters":0x008aad,
"Coriander":0xbbb58d,
"Coriander Ochre":0x7e7463,
"Coriander Powder":0xba9c75,
"Coriander Seed":0xbdaa6f,
"Corinthian Column":0xdedecf,
"Corinthian Pillar":0xe1d1b1,
"Cork":0x5a4c42,
"Cork Bark":0x7e6b43,
"Cork Brown":0xcc8855,
"Cork Wedge":0xc1a98a,
"Cork Wood":0xcc7744,
"Corkboard":0x9d805d,
"Corkscrew Willow":0xd1b9ab,
"Corn":0xfbec5d,
"Corn Bread":0xeec657,
"Corn Chowder":0xe1c595,
"Corn Field":0xf8f3c4,
"Corn Harvest":0x8d702a,
"Corn Husk":0xf2d6ae,
"Corn Husk Green":0xcecd95,
"Corn Kernel":0xffcba4,
"Corn Maze":0xdeaa6e,
"Corn Poppy Cherry":0xee4411,
"Corn Snake":0xab6134,
"Corn Stalk":0xfcdba6,
"Cornell Red":0xb31b11,
"Cornerstone":0xe3d7bb,
"Cornflake":0xf0e68c,
"Cornflower":0x5170d7,
"Cornflower Blue":0x7391c8,
"Cornflower Lilac":0xffb0ac,
"Cornmeal":0xffd691,
"Cornmeal Beige":0xebd5c5,
"Cornsilk":0xfff8dc,
"Cornsilk Yellow":0xf4c96c,
"Cornstalk":0xa9947a,
"Cornucopia":0xed9b44,
"Cornwall Slate":0x949488,
"Corona":0xffb437,
"Coronado Dunes":0xd5a68d,
"Coronado Moss":0x9ba591,
"Coronation":0xedecec,
"Coronation Blue":0x59529c,
"Coronet Blue":0x59728e,
"Corporate Green":0x78a486,
"Corral":0x61513d,
"Corral Brown":0x937360,
"Corrosion Red":0x772f21,
"Corsair":0x18576c,
"Corsican":0x85ac9d,
"Corsican Blue":0x646093,
"Corsican Purple":0x7a85af,
"Cortex":0xa99592,
"Cortez Chocolate":0xa4896a,
"Corundum Blue":0x4a6267,
"Corundum Red":0x95687d,
"Corvette":0xe9ba81,
"Corydalis Blue":0xa9cada,
"Cos":0xa4c48e,
"Cosmetic Blush":0xf6e7e2,
"Cosmetic Mauve":0xd3bed5,
"Cosmetic Peach":0xf3c1ab,
"Cosmetic Red":0xa56078,
"Cosmic":0xb8b9cb,
"Cosmic Aura":0xcfb3a6,
"Cosmic Bit Flip":0x001000,
"Cosmic Blue":0x93c3cb,
"Cosmic Cobalt":0x2e2d88,
"Cosmic Coral":0xe77e6c,
"Cosmic Dust":0xdce2e5,
"Cosmic Energy":0x9392ab,
"Cosmic Explorer":0x551155,
"Cosmic Latte":0xfff8e7,
"Cosmic Quest":0x9ea19f,
"Cosmic Ray":0xcadada,
"Cosmic Sky":0xaaaac4,
"Cosmo Purple":0xa09bc6,
"Cosmopolitan":0x528bab,
"Cosmos":0xfcd5cf,
"Cosmos Blue":0x003249,
"Cossack Dancer":0x4d8aa1,
"Costa Del Sol":0x625d2a,
"Costa Rica Blue":0x77bce2,
"Costa Rican Palm":0xc44041,
"Costume Blue":0x6477a0,
"Cote D'Azur":0x017c85,
"Cotswold Dill":0xdbcdad,
"Cottage Cream":0xeddbbd,
"Cottage Green":0xdcecdc,
"Cottage Hill":0xacb397,
"Cottage Rose":0xd9a89a,
"Cottage Walk":0xa08e77,
"Cottage White":0xf7efdd,
"Cottingley Fairies":0xeddbd7,
"Cotton":0xeeebe1,
"Cotton Ball":0xf2f7fd,
"Cotton Blossom":0xf5f1e4,
"Cotton Boll":0xe7effb,
"Cotton Candy":0xffbcd9,
"Cotton Candy Explosions":0xdd22ff,
"Cotton Candy Grape":0xdec74b,
"Cotton Cardigan":0x7596b8,
"Cotton Cloth":0xfaf4d4,
"Cotton Club":0xf3e4d3,
"Cotton Denim":0x91abbe,
"Cotton Field":0xf2f0e8,
"Cotton Flannel":0x9090a2,
"Cotton Fluff":0xf9f4e5,
"Cotton Grey":0xd1ccc3,
"Cotton Indigo":0x066976,
"Cotton Knit":0xe5dfd2,
"Cotton Puff":0xffffe7,
"Cotton Ridge":0xf1ebdb,
"Cotton Seed":0xbfbaaf,
"Cotton Sheets":0xf7ebdd,
"Cotton Tail":0xfff8d7,
"Cotton Whisper":0xfaf1df,
"Cotton White":0xe4e3d8,
"Cotton Wool Blue":0x83abd2,
"Cottonseed":0xf5e6c7,
"Cougar":0x9a7f78,
"Count's Wardrobe":0x772277,
"Country Air":0x9fb6c6,
"Country Beige":0xeae1cb,
"Country Blue":0x717f9b,
"Country Breeze":0xe0d9d5,
"Country Charm":0xc7c0a7,
"Country Club":0x948675,
"Country Cork":0xb8a584,
"Country Cottage":0xd9c1b7,
"Country Dairy":0xf1e9d2,
"Country Dweller":0xb0967c,
"Country House Green":0x414634,
"Country Lake":0x5d7a85,
"Country Lane":0xfcead1,
"Country Lane Red":0x894340,
"Country Linens":0xd7c2a6,
"Country Mist":0xdfebe2,
"Country Rubble":0xd0bca2,
"Country Sky":0x49545a,
"Country Sleigh":0x7e4337,
"Country Squire":0x124a42,
"Country Summer":0xfffbd7,
"Country Tweed":0x837b68,
"Country Weekend":0x88c096,
"County Green":0x1b4b35,
"Courgette Yellow":0xdaa135,
"Court Green":0xb9b7a0,
"Court Jester":0x926d9d,
"Court-Bouillon":0xcecb97,
"Courteous":0xd2d3de,
"Courtly Purple":0xbbafc1,
"Courtyard":0xc8bda4,
"Courtyard Blue":0x718084,
"Courtyard Green":0x978d71,
"Couscous":0xffe29b,
"Cousteau":0x55a9d6,
"Cover of Night":0x494e4f,
"Covered Bridge":0x6a3c3b,
"Covered in Platinum":0xb9baba,
"Covered Wagon":0x726449,
"Covert Green":0x80765f,
"Coverts Wood Pigeon":0xd4cdd2,
"Coveted Gem":0xb6b3bf,
"Cow's Milk":0xf1ede5,
"Cowardly Custard":0xfbf1c0,
"Cowbell":0xffe481,
"Cowboy":0x443736,
"Cowboy Boots":0x695239,
"Cowboy Hat":0xb27d50,
"Cowboy Trails":0x8d6b4b,
"Cowgirl Blue":0x6a87ab,
"Cowgirl Boots":0x9e7c60,
"Cowhide":0x884344,
"Cowpeas":0x661100,
"Coy":0xfff4f3,
"Coy Pink":0xf9dad8,
"Coyote":0xdc9b68,
"Coyote Brown":0x81613c,
"Coyote Tracks":0xb08f7f,
"Cozumel":0x0aafa4,
"Cozy Blanket":0xc3a598,
"Cozy Cocoa":0xaa8f7d,
"Cozy Cottage":0xf2ddd8,
"Cozy Cover":0xe4c38f,
"Cozy Cream":0xe0dbc7,
"Cozy Wool":0xd1b99b,
"Crab Bisque":0xf0b599,
"Crab Nebula":0x004455,
"Crab-Apple":0xf0e681,
"Crabapple":0x87382f,
"Crabby Apple":0x753531,
"Crack Willow":0xb0a470,
"Cracked Earth":0xc5b1a0,
"Cracked Pepper":0x4f5152,
"Cracked Slate":0x69656a,
"Cracked Wheat":0xf4dfbd,
"Cracker Bitz":0xd1b088,
"Cracker Crumbs":0xd3b9b0,
"Crackled Leather":0xa27c4f,
"Crackling Lake":0xb3c5cc,
"Cradle Pillow":0xf1d3d9,
"Cradle Pink":0xedd0dd,
"Craft":0x293b4a,
"Craft Brown":0xb7a083,
"Craft Juggler":0xe3c8aa,
"Craft Paper":0x8a6645,
"Craftsman Blue":0x008193,
"Craftsman Brown":0xae9278,
"Craftsman Gold":0xd3b78b,
"Craggy Skin":0xf7bd7b,
"Crail":0xa65648,
"Cranach Blue":0x2b8288,
"Cranapple":0xdb8079,
"Cranapple Cream":0xe6c4c5,
"Cranberry":0x9e003a,
"Cranberry Blue":0x7494b1,
"Cranberry Jam":0xa34f55,
"Cranberry Pie":0xc27277,
"Cranberry Red":0x7e5350,
"Cranberry Sauce":0xa53756,
"Cranberry Splash":0xda5265,
"Cranberry Tart":0x893e40,
"Cranberry Whip":0x8e4541,
"Cranberry Zing":0x944944,
"Cranbrook":0xa65570,
"Crantini":0x954c52,
"Crash Dummy":0xeeee66,
"Crash Pink":0xcc88ff,
"Crashing Waves":0x3e6f87,
"Crater Brown":0x4d3e3c,
"Crater Crawler":0xc8ced6,
"Crater Lake":0x63797e,
"Cray":0xbc763c,
"Crayola Green":0x1dac78,
"Crayola Orange":0xfe7438,
"Crazy":0xe5cb3f,
"Crazy Eyes":0x5eb68d,
"Crazy Horse":0xa57648,
"Crazy Horse Mountain":0xe9dbd2,
"Cream":0xffffc2,
"Cream and Sugar":0xddcfb9,
"Cream Blush":0xf8c19a,
"Cream Cake":0xe3d0ad,
"Cream Can":0xeec051,
"Cream Cheese Avocado":0xd7d3a6,
"Cream Cheese Frosting":0xf4efe2,
"Cream Clear":0xf1f3da,
"Cream Custard":0xf2d7b0,
"Cream Filling":0xf5f1da,
"Cream Gold":0xdec05f,
"Cream of Mushroom":0xebd1be,
"Cream Pink":0xf6e4d9,
"Cream Puff":0xffbb99,
"Cream Rose":0xf7e4df,
"Cream Silk":0xeee3c6,
"Cream Tan":0xe4c7b8,
"Cream Violet":0xa9aabd,
"Cream Washed":0xf2e0c5,
"Cream Wave":0xe8dbc5,
"Cream White":0xf2eee2,
"Cream Yellow":0xf3daa7,
"Creamed Avocado":0x70804d,
"Creamed Butter":0xfffcd3,
"Creamed Caramel":0xb79c94,
"Creamed Muscat":0x8b6962,
"Creamed Raspberry":0xbd6883,
"Creamery":0xedd2b7,
"Creamy":0xefe8db,
"Creamy Apricot":0xffe8bd,
"Creamy Axolotl":0xffdae8,
"Creamy Beige":0xfde1c5,
"Creamy Cameo":0xf9eedc,
"Creamy Cappuccino":0xdbccb5,
"Creamy Caramel":0xb3956c,
"Creamy Chenille":0xe1cfaf,
"Creamy Coral":0xdd7788,
"Creamy Corn":0xfff2c2,
"Creamy Custard":0xf9e7bf,
"Creamy Freesia":0xebd0db,
"Creamy Gelato":0xf0e2c5,
"Creamy Ivory":0xeeddaa,
"Creamy Mauve":0xdccad8,
"Creamy Mint":0xaaffaa,
"Creamy Mushroom":0xcabdae,
"Creamy Nougat":0xd4b88f,
"Creamy Orange":0xfce9d1,
"Creamy Orange Blush":0xfe9c7b,
"Creamy Peach":0xf4a384,
"Creamy Spinach":0xb2bfa6,
"Creamy Strawberry":0xfcd2df,
"Creamy White":0xf0e9d6,
"Crease":0x7a6d44,
"Create":0xc9cabf,
"Credo":0xdcba42,
"Creed":0xc1a44a,
"Creek Bay":0xab9d89,
"Creek Bend":0x928c87,
"Creek Pebble":0xdbd7d9,
"Creeping Bellflower":0xb48ac2,
"Crema":0xc16104,
"Crème":0xffffb6,
"Creme Angels":0xf8ede2,
"Creme Brulee":0xf5e9ce,
"Crème Brûlée":0xffe39b,
"Crème De Caramel":0xd4b38f,
"Crème de la Crème":0xf3e7b4,
"Crème De La Crème":0xe2ded7,
"Crème de Menthe":0xf1fde9,
"Creme De Peche":0xf5d6c6,
"Creme Fraiche":0xeadbc9,
"Crème Fraîche":0xf7f0e2,
"Cremini":0xcfa33b,
"Creole":0x393227,
"Creole Cottage":0xe7b89a,
"Creole Pink":0xf7d5cc,
"Creole Sauce":0xee8833,
"Crepe":0xd4bc94,
"Crepe Myrtle":0xe399ca,
"Crêpe Papier":0xdbd7c4,
"Crepe Silk White":0xf0eee3,
"Crescendo":0xe3df84,
"Crescent Cream":0xedd1b1,
"Crescent Moon":0xf1e9cf,
"Cress Green":0xbca949,
"Cress Vinaigrette":0xbcb58a,
"Cressida":0x8aae7c,
"Crestline":0xb4bcbf,
"Cretan Green":0x598784,
"Crete":0x77712b,
"Crete Shore":0x96908b,
"Crewel Tan":0xcbb99b,
"Cria Wool":0xe4d5bc,
"Cricket":0xa6a081,
"Cricket Chirping":0xc7c10c,
"Cricket Field":0xc3d29c,
"Cricket Green":0x6a7b6b,
"Cricket's Cross":0x908a78,
"Crimson":0x8c000f,
"Crimson Glory":0xbe0032,
"Crimson Red":0x980001,
"Crimson Silk":0xb5413b,
"Crimson Strawberry":0x9f2d47,
"Crisis Red":0xbb2222,
"Crisp":0xeaebaf,
"Crisp Candlelight":0xf4ebd0,
"Crisp Capsicum":0x5d6e3b,
"Crisp Celery":0xcdcca6,
"Crisp Cyan":0x22ffff,
"Crisp Green":0xabc43a,
"Crisp Lettuce":0x4f9785,
"Crisp Linen":0xe7e1d3,
"Crisp Muslin":0xe9e2d7,
"Crisp Wonton":0xf3dcc6,
"Crispa":0xe7dfc1,
"Crispy Chicken Skin":0xddaa44,
"Crispy Crust":0xebe0cf,
"Crispy Gingersnap":0xbb7838,
"Crispy Gold":0xc49832,
"Crispy Samosa":0xffbb66,
"Crocker Grove":0xb1a685,
"Crockery":0xa49887,
"Crocodile":0x706950,
"Crocodile Eye":0x777722,
"Crocodile Green":0xb7ac87,
"Crocodile Smile":0x898e58,
"Crocodile Tears":0xd6d69b,
"Crocodile Tooth":0xd1ccc2,
"Crocus":0xc67fae,
"Crocus Petal":0xb99bc5,
"Crocus Tint":0xfdf1c7,
"Croissant":0xc4ab86,
"Croissant Crumbs":0xf8efd8,
"Crooked River":0x797869,
"Crop Circle":0xe9bf63,
"Cropper Blue":0x5c7b97,
"Croque Monsieur":0xac9877,
"Croquet Blue":0x4971ad,
"Cross My Heart":0xad2a2d,
"Crossbow":0x60543f,
"Crossed Fingers":0xddb596,
"Crossroads":0xedd2a3,
"Crow":0x180614,
"Crow Black":0x263145,
"Crow Black Blue":0x112f4b,
"Crowberry":0x220055,
"Crowberry Blue":0x003447,
"Crowd Pleaser":0x5b4459,
"Crown Blue":0x464b65,
"Crown Gold":0xb48c60,
"Crown Jewel":0x482d54,
"Crown Jewels":0x946dad,
"Crown of Thorns":0x763c33,
"Crown Point Cream":0xfff0c1,
"Crowned One":0xd4b597,
"Crowning":0x5a4f6c,
"Crowshead":0x1c1208,
"Crucified Red":0xcc0044,
"Crude Banana":0x21c40e,
"Cruel Ruby":0xdd3344,
"Cruel Sea":0x213638,
"Cruise":0xb4e2d5,
"Cruising":0x018498,
"Crumble Topping":0xefcea0,
"Crumbling Statue":0xcabfb4,
"Crunch":0xf2b95f,
"Crusade King":0xdbc364,
"Crushed Almond":0xd4cac5,
"Crushed Berries":0xd15b9b,
"Crushed Berry":0x804f5a,
"Crushed Cashew":0xffedd5,
"Crushed Cinnamon":0xb7735e,
"Crushed Clay":0xae7f71,
"Crushed Grape":0x7a547f,
"Crushed Ice":0xc4fff7,
"Crushed Limestone":0xd6ddd3,
"Crushed Orange":0xe37730,
"Crushed Oregano":0x635d46,
"Crushed Peony":0xe4ddd8,
"Crushed Pineapple":0xefcc44,
"Crushed Raspberry":0xb06880,
"Crushed Silk":0xd8cfbe,
"Crushed Stone":0xbcaa9f,
"Crushed Velvet":0x445397,
"Crushed Violets":0x643a4c,
"Crusoe":0x165b31,
"Crust":0x898076,
"Crusta":0xf38653,
"Crustose Lichen":0xc04e01,
"Cry Baby Blue":0xc3d4e7,
"Cryo Freeze":0xddece0,
"Crypt":0x373b40,
"Cryptic Light":0x6d434e,
"Crystal":0xa7d8de,
"Crystal Apple":0xcee9a0,
"Crystal Ball":0x365955,
"Crystal Bell":0xefeeef,
"Crystal Blue":0x68a0b0,
"Crystal Brooke":0xe4e6dc,
"Crystal Clear":0xf4e9ea,
"Crystal Cut":0xf8f4ed,
"Crystal Dark Red":0x6d2c32,
"Crystal Falls":0xe1e6f2,
"Crystal Gem":0x79d0a7,
"Crystal Glass":0xddffee,
"Crystal Glass Green":0xb1e2cb,
"Crystal Green":0xa4d579,
"Crystal Grey":0xd7cbc4,
"Crystal Haze":0xe7e2d6,
"Crystal Lake":0x88b5c4,
"Crystal Oasis":0xafc7bf,
"Crystal Palace":0xd3cfab,
"Crystal Pink":0xedd0ce,
"Crystal Rapids":0xb2e4d0,
"Crystal River":0xb1e2ee,
"Crystal Rose":0xfdc3c6,
"Crystal Salt White":0xd9e5dd,
"Crystal Seas":0x5dafce,
"Crystal Teal":0x00637c,
"Crystal Waters":0xb4cedf,
"Crystal Yellow":0xe4d99f,
"Crystalline":0xe9e3de,
"Crystalline Falls":0xd9e6e2,
"Crystalsong Blue":0x4fb3b3,
"Cub":0x6e5c4b,
"Cub Scout":0x4e6341,
"Cuba Brown":0x623d3d,
"Cuba Libre":0x73383c,
"Cuban Cigar":0x927247,
"Cuban Rhythm":0x9b555d,
"Cuban Sand":0xc1a68d,
"Cucumber":0x006400,
"Cucumber Cream":0xe4ebb1,
"Cucumber Crush":0xa2ac86,
"Cucumber Green":0x466353,
"Cucumber Ice":0xcdd79d,
"Cucumber Milk":0xc2f177,
"Cucuzza Verde":0x9ba373,
"Cuddle":0xbccae8,
"Cuddlepot":0xad8068,
"Cuddly Yarn":0xfffce4,
"Culinary Blue":0x7bb6c1,
"Culpeo":0xe69b3a,
"Cultured":0xf6f4f5,
"Cultured Pearl":0xe5dcd6,
"Cultured Rose":0xe5867b,
"Cumberland Fog":0xdadbdf,
"Cumberland Sausage":0xe5dfdc,
"Cumin":0xa58459,
"Cumin Ochre":0xa06600,
"Cummings Oak":0x695a45,
"Cumquat Cream":0xf19b7d,
"Cumulus":0xf3f3e6,
"Cumulus Cloud":0xb0c6df,
"Cup of Cocoa":0xbaa087,
"Cup of Tea":0xcaae7b,
"Cupcake":0x8a6e53,
"Cupcake Pink":0xf6d8d2,
"Cupcake Rose":0xe6c7b7,
"Cupid":0xf5b2c5,
"Cupid Arrow":0xf5e2e2,
"Cupid's Arrow":0xee6b8b,
"Cupid's Eye":0xff22dd,
"Cupid's Revenge":0xeedcdf,
"Cupola Yellow":0xdcbc8e,
"Cuppa Coffee":0xb09f8f,
"Curaçao Blue":0x008894,
"Curd":0xf8e1ba,
"Curds and Whey":0xbca483,
"Cure All":0xaa6988,
"Cured Eggplant":0x380835,
"Curio":0xd3d8d2,
"Curio Gray":0x988977,
"Curious":0xd9e49e,
"Curious Blue":0x3d85b8,
"Curious Chipmunk":0xdabfa4,
"Curious Collection":0xd2bb98,
"Curlew":0x766859,
"Curly Maple":0xd8c8be,
"Curly Willow":0xb1a387,
"Currant Jam":0x884a50,
"Currant Violet":0x553e51,
"Curry":0xd6a332,
"Curry Brown":0x845038,
"Curry Bubbels":0xf5b700,
"Curry Powder":0xcc6600,
"Curry Sauce":0xbe9e6f,
"Currywurst":0xddaa33,
"Curtain Call":0x70666a,
"Curtsy":0xffd6b8,
"Cushion Bush":0xc1c8af,
"Custard":0xfffd78,
"Custard Cream":0xfbefd0,
"Custard Powder":0xf8dcaa,
"Custard Puff":0xfceeae,
"Customs Green":0x003839,
"Cut Heather":0x9e909e,
"Cut of Mustard":0xbc914d,
"Cut the Mustard":0xba7f38,
"Cut Velvet":0xb391c8,
"Cute Crab":0xdd4444,
"Cute Little Pink":0xf4e2e1,
"Cute Pixie":0x8d8d40,
"Cuticle Pink":0xe3a49a,
"Cutlery Polish":0xf4dda5,
"Cuttlefish":0x7fbbc2,
"Cutty Sark":0x5c8173,
"Cyan":0x0ff0fe,
"Cyan Azure":0x4e82b4,
"Cyan Blue":0x14a3c7,
"Cyan Cobalt Blue":0x28589c,
"Cyan Cornflower Blue":0x188bc2,
"Cyan Sky":0x00b5b8,
"Cyanara":0x779080,
"Cyanite":0x00b7eb,
"Cyber Grape":0x58427c,
"Cyber Lavender":0xe6e6fa,
"Cyber Yellow":0xffd400,
"Cyberpink":0xff2077,
"Cyberspace":0x44484d,
"Cyclamen":0xd687ba,
"Cyclamen Red":0xa7598d,
"Cymophane Yellow":0xf3e4a7,
"Cynical Black":0x171717,
"Cypress":0x545a3e,
"Cypress Bark Red":0x6f3028,
"Cypress Garden":0x667c71,
"Cypress Green":0x9e8f57,
"Cypress Grey Blue":0x6a7786,
"Cypress Vine":0x5e6552,
"Cyprus":0x0f4645,
"Cyprus Green":0x699a88,
"Cyprus Spring":0xacb7b0,
"Cyrus Grass":0xcfc5a7,
"Czarina":0x775859,
"Czech Bakery":0xdec9a9,
"D. Darx Blue":0x030764,
"Da Blues":0x516172,
"Daah-Ling":0xaa6179,
"Dachshund":0x704f37,
"Dad's Coupe":0x2f484e,
"Daddy-O":0xb0af8a,
"Daemonette Hide":0x696684,
"Daffodil":0xffff31,
"Daffodil Yellow":0xffe285,
"Dagger Moth":0xe8e1d5,
"Dahlia":0x843e83,
"Dahlia Delight":0xf8bbd3,
"Dahlia Matte Red":0x765067,
"Dahlia Mauve":0xa64f82,
"Dahlia Purple":0x7e6eac,
"Daikon White":0xd4d4c4,
"Daintree":0x012731,
"Dainty Apricot":0xfdc592,
"Dainty Debutante":0xf4bdb3,
"Dainty Flower":0xe9dfe5,
"Dainty Lace":0xdecfbb,
"Dainty Pink":0xecbcce,
"Daiquiri Green":0xc9d77e,
"Dairy Cream":0xedd2a4,
"Dairy Made":0xf0b33c,
"Daisy":0xfed340,
"Daisy Bush":0x5b3e90,
"Daisy Chain":0xfff09b,
"Daisy Desi":0xfcdf8a,
"Daisy Field":0xf4f3e8,
"Daisy Leaf":0x55643b,
"Daisy White":0xf8f3e3,
"Dakota Wheat":0xe1bd8e,
"Dallas":0x664a2d,
"Dallas Dust":0xece0d6,
"Dallol Yellow":0xfddc00,
"Dalmatian Sage":0x97a3da,
"Daly Waters":0xafdadf,
"Damask":0xfcf2df,
"Dame Dignity":0x999ba8,
"Damp Basement":0x5f6171,
"Damsel":0xc69eae,
"Damson":0x854c65,
"Damson Mauve":0x583563,
"Damson Plum":0xdda0dd,
"Dana":0x576780,
"Dance Studio":0x064d83,
"Dancer":0xdc9399,
"Dancing Butterfly":0xfcf3c6,
"Dancing Crocodiles":0x254a47,
"Dancing Daisy":0xefc857,
"Dancing Dogs":0x6e493d,
"Dancing Dolphin":0xc4baa1,
"Dancing Dragonfly":0x006658,
"Dancing Green":0xc5cd8f,
"Dancing in the Rain":0xabc5d6,
"Dancing in the Spring":0x7b7289,
"Dancing Jewel":0x429b77,
"Dancing Kite":0xc8cc9e,
"Dancing Mist":0xbfc8d8,
"Dancing Sea":0x1c4d8f,
"Dancing Wand":0xc8a4bd,
"Dancing-Lady Orchid":0xdfff00,
"Dandelion":0xfedf08,
"Dandelion Floatie":0xeae8ec,
"Dandelion Tea":0xf7eac1,
"Dandelion Tincture":0xf0e130,
"Dandelion Whisper":0xfff0b5,
"Dandelion Wine":0xfcf2b9,
"Dandelion Wish":0xe3bb65,
"Dandelion Yellow":0xfcd93b,
"Dandy Lion":0xfacc51,
"Danger":0xff0e0e,
"Danger Ridge":0x595539,
"Dangerous Robot":0xcbc5c6,
"Dangerously Elegant":0x616b89,
"Dangerously Red":0xd84139,
"Daniel Boone":0x5e4235,
"Danish Pine":0xba9967,
"Dante Peak":0xb4d5d5,
"Danube":0x5b89c0,
"Daphne":0x0f5f9a,
"Daphne Rose":0xc37cb3,
"Dapper":0x715b49,
"Dapper Dingo":0xe2c299,
"Dapper Greyhound":0x697078,
"Dapper Tan":0x947f65,
"Dapple Grey":0x959486,
"Dappled Sunlight":0xf2e3c9,
"Dard Hunter Green":0x3a4a3f,
"Daredevil":0xab4343,
"Daring":0xdf644e,
"Daring Deception":0xf0dfe0,
"Daring Indigo":0x374874,
"Dark":0x1b2431,
"Dark & Stormy":0x353f51,
"Dark Ages":0x9698a3,
"Dark as Night":0x495252,
"Dark Ash":0x6a6d6d,
"Dark Berry":0x5c464a,
"Dark Blackberry":0x533958,
"Dark Blond":0xa68a6e,
"Dark Blue":0x305679,
"Dark Brazilian Topaz":0x92462f,
"Dark Burgundy Wine":0x4b4146,
"Dark Cavern":0x55504d,
"Dark Cherry Mocha":0x774d41,
"Dark Citron":0xaabb00,
"Dark Clove":0x4c3d31,
"Dark Cobalt Blue":0x33578a,
"Dark Crimson":0x843c41,
"Dark Crypt":0x3f4551,
"Dark Cyan":0x008b8b,
"Dark Denim":0x005588,
"Dark Denim Blue":0x00334f,
"Dark Dreams":0x332266,
"Dark Earth":0x884455,
"Dark Eclipse":0x112244,
"Dark Elf":0x3b3f42,
"Dark Emerald":0x00834e,
"Dark Energy":0x503d4d,
"Dark Engine":0x3e3f41,
"Dark Envy":0xa4a582,
"Dark Everglade":0x3e554f,
"Dark Fern":0x0a480d,
"Dark Fig Violet":0x573b4c,
"Dark Forest":0x556962,
"Dark Galaxy":0x0018a8,
"Dark Granite":0x4f443f,
"Dark Green":0x033500,
"Dark Grey":0x363737,
"Dark Grey Mauve":0x4e4459,
"Dark Horizon":0x666699,
"Dark Imperial Blue":0x00416a,
"Dark Iris":0x4d5a7e,
"Dark Ivy":0x5b7763,
"Dark Jade":0x5c8774,
"Dark Knight":0x151931,
"Dark Lagoon":0x6a7f7d,
"Dark Lavender":0x856798,
"Dark Lemon Lime":0x8bbe1b,
"Dark Lilac":0x9c6da5,
"Dark Lime":0x84b701,
"Dark Lime Green":0x7ebd01,
"Dark Limestone":0x989a98,
"Dark LUA Console":0x5f574f,
"Dark Magenta":0x8b008b,
"Dark Mahogany":0x482029,
"Dark Marmalade":0x994939,
"Dark Maroon":0x3c0008,
"Dark Matter":0x110101,
"Dark Midnight Blue":0x003377,
"Dark Mountain Meadow":0x1ab385,
"Dark Navy":0x40495b,
"Dark Night":0x404b57,
"Dark Olive":0x373e02,
"Dark Olive Green":0x454636,
"Dark Olive Paste":0x6e5160,
"Dark Onyx":0x2e2d30,
"Dark Orange":0xc65102,
"Dark Pansy":0x653d7c,
"Dark Periwinkle":0x665fd1,
"Dark Pewter":0x606865,
"Dark Pine Green":0x193232,
"Dark Pink":0xcb416b,
"Dark Potion":0x603e53,
"Dark Princess Pink":0xd9308a,
"Dark Puce":0x4f3a3c,
"Dark Purple":0x35063e,
"Dark Purple Grey":0x6e576b,
"Dark Rainforest":0x505838,
"Dark Raspberry":0x872657,
"Dark Reaper":0x3b5150,
"Dark Red":0x840000,
"Dark Red Brown":0x4a2125,
"Dark River":0x3e4445,
"Dark Room":0x626d7b,
"Dark Rose":0xb5485d,
"Dark Royalty":0x02066f,
"Dark Rum":0x45362b,
"Dark Sage":0x6d765b,
"Dark Sakura":0xa2646f,
"Dark Salmon":0xc85a53,
"Dark Sanctuary":0x3f012c,
"Dark Sand":0xa88f59,
"Dark Sapphire":0x082567,
"Dark Sea":0x4c5560,
"Dark Seagreen":0x666655,
"Dark Seashore Night":0x113691,
"Dark Secret":0x3e5361,
"Dark Shadow":0x4a4b4d,
"Dark Shadows":0x5b595d,
"Dark Shamrock":0x33cc99,
"Dark Side":0x004444,
"Dark Side of the Moon":0x070d0d,
"Dark Sienna":0x3c1414,
"Dark Sky":0x909989,
"Dark Slate":0x465352,
"Dark Slate Blue":0x214761,
"Dark Slate Grey":0x2f4f4f,
"Dark Slimelime":0x66aa11,
"Dark Sorrel":0x587a65,
"Dark Soul":0x112255,
"Dark Souls":0xa3a3a2,
"Dark Spell":0x303b4c,
"Dark Sting":0x7e736d,
"Dark Storm Cloud":0x819094,
"Dark Strawberry":0x80444c,
"Dark Summoning":0x383839,
"Dark Taupe":0x483c3c,
"Dark Tavern":0x634e43,
"Dark Teal":0x014d4e,
"Dark Tone Ink":0x121212,
"Dark Topaz":0x817c87,
"Dark Truffle":0x594d46,
"Dark Turquoise":0x045c5a,
"Dark Veil":0x141311,
"Dark Violet":0x34013f,
"Dark Void":0x151517,
"Dark Walnut":0x56443e,
"Dark Wood":0x855e42,
"Dark Wood Grain":0x4f301f,
"Dark Yellow":0xe7bf8e,
"Darkest Dungeon":0x660011,
"Darkest Grape":0x625768,
"Darkest Navy":0x43455e,
"Darkest Spruce":0x303f3d,
"Darkness":0x16160e,
"Darkness Green":0x3a4645,
"Darkout":0x2d1608,
"Darkroom":0x443e40,
"Darkshore":0x464964,
"Darlak":0x4f4969,
"Darling Bud":0xff88ff,
"Darling Clementine":0xd29f7a,
"Darling Lilac":0xc9acd6,
"Darth Torus":0x1d045d,
"Darth Umber":0x932904,
"Darth Vader":0x0b0b0b,
"Dartmoor Mist":0xcddce3,
"Dartmouth Green":0x00703c,
"Dash of Curry":0xca6e5f,
"Dash of Oregano":0x928459,
"Dashing":0xeaebe8,
"Date Fruit Brown":0xaf642b,
"DaVanzo Beige":0xccac86,
"DaVanzo Green":0x58936d,
"Davao Green":0xb1d27b,
"Dave's Den":0xc3bfae,
"Davy's Grey":0x555555,
"Dawn":0x9f9d91,
"Dawn Blue":0xcacccb,
"Dawn Departs":0xccffff,
"Dawn Grey":0x6d7273,
"Dawn of the Fairies":0x770044,
"Dawn Pink":0xe6d6cd,
"Dawnstone":0x70756e,
"Day At The Zoo":0xffa373,
"Day Dreamer":0xd9cdc4,
"Day Glow":0xeadd82,
"Day Glow Orange":0xeb5c34,
"Day Lily":0xfff9ec,
"Day On Mercury":0xd5d2d1,
"Day Spa":0xeaefed,
"Daybreak":0x8981a0,
"Daybreak Sun":0xf7eecb,
"Daydream":0xe3ebae,
"Daydreaming":0xf4f0e1,
"Dayflower":0x38a1db,
"Daylight Lilac":0xa385b3,
"Daylily Yellow":0xf8f0d2,
"Daystar":0xfff8da,
"Dazzle":0x5287b9,
"Dazzle and Delight":0xd99b7b,
"Dazzle Me":0xedebea,
"Dazzling Blue":0x3850a0,
"De York":0x85ca87,
"Dead 99":0x99dead,
"Dead Blue Eyes":0x0055cc,
"Dead Flesh":0x849b63,
"Dead Forest":0x434b4f,
"Dead Grass":0xe4dc8a,
"Dead Lake":0x2e5a88,
"Dead Nettle White":0xd2dad0,
"Dead Pixel":0x3b3a3a,
"Dead Sea":0x77eeee,
"Dead Sea Mud":0x3a403b,
"Deadlock":0x8f666a,
"Deadly Depths":0x111144,
"Deadsy":0xc2a84b,
"Deadwind Pass":0x596d7f,
"Death by Chocolate":0x60443f,
"Death Cap":0xe7d9db,
"Death Guard":0x9eb37b,
"Death Valley Beige":0xddbb88,
"Deathclaw Brown":0xb36853,
"Deathworld Forest":0x5c6730,
"Deauville Mauve":0xaf9294,
"Debian Red":0xd70a53,
"Debonair":0x90a0a6,
"Debonaire":0xcbd0dd,
"Debrito":0xee7744,
"Debutante Ball":0x6e8dbb,
"Decadence":0x73667b,
"Decadent Chocolate":0x513235,
"Decadial Pink":0xdecade,
"Decanter":0xada3bb,
"Decanting":0xbfa1ad,
"Decaying Leave":0xd57835,
"December Dawn":0xdfe2ea,
"December Eve":0x415064,
"December Forest":0xe0e8db,
"December Rain":0xd6dddc,
"December Sky":0xd5d7d9,
"Decency":0xbfb5ca,
"Dechala Lilac":0xb69fcc,
"Dechant Pear Yellow":0xd79e62,
"Decisive Yellow":0xfdcc4e,
"Deck Crew":0x5e7cac,
"Deco":0xcccf82,
"Deco Grey":0x89978e,
"Deco Pink":0xf6c2cc,
"Deco Red":0x824942,
"Deco Rose":0x985f68,
"Deco Shell":0xf9d5c9,
"Deco-Rate":0x8fcbc0,
"Deconstruction":0x7b736b,
"Décor White":0xf2e5cf,
"Decor Yellow":0xf6bb00,
"Decoration Blue":0x3f74a3,
"Decorative Iris":0x817181,
"Decorator White":0xf6f4ec,
"Decore Splash":0x00829e,
"Decorous Amber":0xac7559,
"Decorum":0xb39aa0,
"Dedication":0xfee2c8,
"Deduction":0xd4cb83,
"Deep Amethyst":0x5b3082,
"Deep Aquamarine":0x78dbe2,
"Deep Atlantic Blue":0x004f57,
"Deep Aubergine":0x5c4a4d,
"Deep Azure":0x3e5580,
"Deep Bamboo Yellow":0xd99f50,
"Deep Bloom":0xc57776,
"Deep Blue":0x040273,
"Deep Blue Sea":0x1a5d72,
"Deep Blush":0xe36f8a,
"Deep Bottlebrush":0x5e675a,
"Deep Breath":0x27275f,
"Deep Bronze":0x51412d,
"Deep Brown":0x342a2a,
"Deep Cerulean":0x007bbb,
"Deep Champagne":0xfad6c5,
"Deep Cherrywood":0x6b473d,
"Deep Chestnut":0xb94e48,
"Deep Claret":0x771133,
"Deep Cobalt":0x404466,
"Deep Coral":0xda7c55,
"Deep Cove":0x051040,
"Deep Current":0x007381,
"Deep Denim":0x6688ff,
"Deep Depths":0x46483c,
"Deep Dive":0x29495c,
"Deep Diving":0x5e97a9,
"Deep Dungeon":0x553d3a,
"Deep Earth":0x4d4b4b,
"Deep Emerald":0x556551,
"Deep Evergreen":0x4c574b,
"Deep Exquisite":0x614454,
"Deep Fir":0x193925,
"Deep Fire":0xbf5c42,
"Deep Forest":0x37413a,
"Deep Forest Brown":0x393437,
"Deep Garnet":0x5f4246,
"Deep Green":0x02590f,
"Deep Indigo":0x4c567a,
"Deep into the Jungle":0x004b49,
"Deep into the Wood":0x306030,
"Deep Jungle":0x3f564a,
"Deep Koamaru":0x343467,
"Deep Lagoon":0x005265,
"Deep Lake":0x00656b,
"Deep Lavender":0x565a7d,
"Deep Loch":0x2e5767,
"Deep Magenta":0xa0025c,
"Deep Marine":0x2e6469,
"Deep Maroon":0x623f45,
"Deep Marsh":0x938565,
"Deep Merlot":0x574958,
"Deep Mint":0x55aa66,
"Deep Mulberry":0x544954,
"Deep Mystery":0x494c59,
"Deep Night":0x494c55,
"Deep Ocean":0x2a4b5f,
"Deep Orange":0xdc4d01,
"Deep Orange-coloured Brown":0x864735,
"Deep Orchid":0x525476,
"Deep Pacific":0x006e62,
"Deep Peacock Blue":0x008381,
"Deep Periwinkle":0x7c83bc,
"Deep Pond":0x014420,
"Deep Purple":0x36013f,
"Deep Red":0x9a0200,
"Deep Reddish Orange":0xbb603c,
"Deep Reservoir":0x424f5f,
"Deep Rhubarb":0x7f5153,
"Deep Rift":0x4c6a68,
"Deep River":0x0079b3,
"Deep Royal":0x364c68,
"Deep Saffron":0xff9932,
"Deep Sanction":0x195155,
"Deep Sea":0x167e65,
"Deep Sea Base":0x2c2c57,
"Deep Sea Blue":0x2a4b5a,
"Deep Sea Coral":0xd9615b,
"Deep Sea Dive":0x376167,
"Deep Sea Diver":0x255c61,
"Deep Sea Dolphin":0x6a6873,
"Deep Sea Dream":0x002d69,
"Deep Sea Exploration":0x2000b1,
"Deep Sea Green":0x095859,
"Deep Sea Grey":0x879294,
"Deep Sea Nightmare":0x002366,
"Deep Sea Shadow":0x4f5a4c,
"Deep Sea Turtle":0x5e5749,
"Deep Seagrass":0x959889,
"Deep Seaweed":0x37412a,
"Deep Serenity":0x7f6968,
"Deep Shadow":0x514a3d,
"Deep Shale":0x737c84,
"Deep Sky Blue":0x0d75f8,
"Deep Smoke Signal":0x7d8392,
"Deep South":0xb4989f,
"Deep Space":0x3f4143,
"Deep Space Rodeo":0x332277,
"Deep Space Sparkle":0x4a646c,
"Deep Tan":0x726751,
"Deep Taupe":0x7b6660,
"Deep Teal":0x00555a,
"Deep Terra Cotta":0x8b483d,
"Deep Velvet":0x313248,
"Deep Violet":0x330066,
"Deep Viridian":0x4b6443,
"Deep Walnut":0x615d58,
"Deep Water":0x266691,
"Deep Well":0x2c2a33,
"Deep Wisteria":0x443f6f,
"Deepest Mauve":0x6d595a,
"Deepest Sea":0x444d56,
"Deepest Water":0x466174,
"Deeply Embarrassed":0xecb2b3,
"Deepsea Kraken":0x082599,
"Deer":0xba8759,
"Deer God":0x96847a,
"Deer Leather":0xac7434,
"Deer Run":0xb2a69a,
"Deer Tracks":0xa1614c,
"Deer Trail":0x6a634c,
"Deer Valley":0xc7a485,
"Defenestration":0xc6d5e4,
"Defense Matrix":0x88ffee,
"Degas Pink":0xb37e8c,
"Déjà Vu":0xbed1cc,
"Del Rio":0xb5998e,
"Del Sol Maize":0xdabf92,
"Delaunay Green":0xaab350,
"Delaware Blue Hen":0x76a09e,
"Delayed Yellow":0xfdf901,
"Delectable":0x9a92a7,
"Delft":0x3d5e8c,
"Delft Blue":0x3311ee,
"Delhi Dance Pink":0xfdc1c5,
"Delhi Spice":0xa36a6d,
"Delicacy":0xf5e3e2,
"Delicacy White":0xebe2e5,
"Delicate Ballet Blue":0xc2d1e2,
"Delicate Bloom":0xdbbfce,
"Delicate Blue":0xbcdfe8,
"Delicate Blue Mist":0xbed7f0,
"Delicate Blush":0xefd7d1,
"Delicate Brown":0xa78c8b,
"Delicate Cloud":0xdddfe8,
"Delicate Daisy":0xe9edc0,
"Delicate Dawn":0xfed9bc,
"Delicate Girl Blue":0x6ab2ca,
"Delicate Green":0x93b0a9,
"Delicate Honeysweet":0xbcab99,
"Delicate Ice":0xb7d2e3,
"Delicate Lace":0xf3e6d4,
"Delicate Lemon":0xeedd77,
"Delicate Lilac Crystal":0xd7d2e2,
"Delicate Mauve":0xc5b5ca,
"Delicate Mint":0xddf3e6,
"Delicate Mist":0xe1ebe5,
"Delicate Pink":0xe4cfd3,
"Delicate Prunus":0xa95c68,
"Delicate Rose":0xf7e0d6,
"Delicate Sapling":0xd7f3dd,
"Delicate Seashell":0xffefdd,
"Delicate Snow Goose":0xd1e2d8,
"Delicate Sweet Apricot":0xfdcdbd,
"Delicate Truffle":0xaa9c8b,
"Delicate Turquoise":0xc0dfe2,
"Delicate Viola":0xd7d6dc,
"Delicate Violet":0x8c8da8,
"Delicate White":0xf1f2ee,
"Délicieux":0x412010,
"Delicioso":0x3f352f,
"Delicious":0x585e46,
"Delicious Berry":0x654254,
"Delicious Dill":0x77cc00,
"Delicious Mandarin":0xffaa11,
"Delicious Melon":0xffd7b0,
"Delightful":0xd2b6be,
"Delightful Camouflage":0xa5a943,
"Delightful Dandelion":0xeeee33,
"Delightful Green":0x00ee00,
"Delightful Pastry":0xf9e7c8,
"Delightful Peach":0xffebd1,
"Delirious Donkey":0xddcccc,
"Dell":0x486531,
"Della Robbia Blue":0x7a9dcb,
"Delltone":0x8ec39e,
"Delos Blue":0x169ec0,
"Delphinium Blue":0x6198ae,
"Delta":0x999b95,
"Delta Break":0x979147,
"Delta Green":0x2d4a4c,
"Delta Waters":0xc4c2ab,
"Deluge":0x0077aa,
"Delusional Dragonfly":0x66bbcc,
"Deluxe Days":0x8bc7e6,
"Demerara Sugar":0xe1b270,
"Demeter":0xecda9e,
"Demeter Green":0x00cc00,
"Demitasse":0x40342b,
"Democrat":0x00aef3,
"Demon":0x224376,
"Demonic":0xbb2233,
"Demonic Presence":0x7c0a02,
"Demonic Purple":0xd725de,
"Demonic Yellow":0xffe700,
"Demure":0xe8d4d5,
"Demure Pink":0xf7d2c4,
"Denali Green":0x7d775d,
"Denim":0x2243b6,
"Denim Blue":0x2f6479,
"Denim Drift":0x7c8d96,
"Denim Light":0xb8cad5,
"Denim Tradition":0x7f97b5,
"Dense Shrub":0x636d65,
"Dent Corn":0xf2b717,
"Dentist Green":0x99d590,
"Denver River":0x7795c1,
"Dépaysement":0xe7d8c7,
"Depth Charge":0x355859,
"Derby":0xf9e4c6,
"Derby Brown":0x8a7265,
"Derby Green":0x599c89,
"Derbyshire":0x245e36,
"Derry Coast Sunrise":0xf9e1cf,
"Desaturated Cyan":0x669999,
"Descent to the Catacombs":0x445155,
"Desert":0xccad60,
"Desert Bud":0xc28996,
"Desert Cactus":0xafca9d,
"Desert Camel":0xc2ae88,
"Desert Caravan":0xd3a169,
"Desert Chaparral":0x727a60,
"Desert Clay":0x9e6e43,
"Desert Convoy":0xf7d497,
"Desert Coral":0xd16459,
"Desert Cover":0xd0c8a9,
"Desert Dawn":0xeddbe8,
"Desert Dune":0xb5ab9c,
"Desert Dusk":0xad9a91,
"Desert Dust":0xe3bc8e,
"Desert Echo":0xb6a29d,
"Desert Field":0xefcdb8,
"Desert Floor":0xc6b183,
"Desert Flower":0xff9687,
"Desert Grey":0xb8a487,
"Desert Hot Springs":0xc4c8aa,
"Desert Iguana":0xf3f2e1,
"Desert Khaki":0xd6cdb7,
"Desert Lights":0xbd9c9d,
"Desert Lily":0xfef5db,
"Desert Locust":0xa9a450,
"Desert Mauve":0xe8d2d6,
"Desert Mesa":0xefcfbc,
"Desert Mirage":0xb9e0cf,
"Desert Mist":0xe0b589,
"Desert Morning":0xd0bbb0,
"Desert Moss":0xbea166,
"Desert Night":0x5f727a,
"Desert Palm":0x5a4632,
"Desert Panzer":0xc0cabc,
"Desert Pear":0xaaae9a,
"Desert Pebble":0xcab698,
"Desert Plain":0xe5ddc9,
"Desert Powder":0xfbefda,
"Desert Red":0xb3837f,
"Desert Riverbed":0xd5a884,
"Desert Rock":0xd5c6bd,
"Desert Rose":0xcf6977,
"Desert Sage":0x90926f,
"Desert Sand":0xedc9af,
"Desert Sandstorm":0xb9a795,
"Desert Shadow":0x403c39,
"Desert Shadows":0x9f927a,
"Desert Soil":0xa15f3b,
"Desert Spice":0xc66b30,
"Desert Springs":0xdcddcb,
"Desert Star":0xf9f0e1,
"Desert Storm":0xede7e0,
"Desert Suede":0xd5c7b3,
"Desert Sun":0xc87629,
"Desert Sunrise":0xfcb58d,
"Desert Tan":0xa38c6c,
"Desert Taupe":0x8d7e71,
"Desert Temple":0xddcc99,
"Desert Willow":0x89734b,
"Desert Wind":0xe5d295,
"Desert Yellow":0xa29259,
"Deserted Beach":0xe7dbbf,
"Deserted Island":0x857c64,
"Deserted Path":0xe7bf7b,
"Design Delight":0xa47bac,
"Designer Cream Yellow":0xefe5bb,
"Designer Pink":0xe1bcd8,
"Designer White":0xe7ded1,
"Desire":0xea3c53,
"Desire Pink":0xeec5d2,
"Desired Dawn":0xd8d7d9,
"Desireé":0xc4adb8,
"Desolace Dew":0xb5c1a9,
"Desolate Field":0xd3cbc6,
"Dessert Cream":0xf6e4d0,
"Destiny":0xcfc9c6,
"Destroyer Grey":0x98968d,
"Destroying Angels":0xe9e9e1,
"Detailed Devil":0xff3355,
"Detective Coat":0x8b8685,
"Determined Orange":0xc56639,
"Detroit":0xbdd0d1,
"Deutzia White":0xf7fcfe,
"Device Green":0x006b4d,
"Devil Blue":0x277594,
"Devil's Advocate":0xff3344,
"Devil's Flower Mantis":0x8f9805,
"Devil's Grass":0x44aa55,
"Devil's Lip":0x662a2c,
"Devil's Plum":0x423450,
"Devil’s Butterfly":0xbb4422,
"Deviled Egg":0xfdd77a,
"Devilish":0xdd3322,
"Devilish Diva":0xce7790,
"Devlan Mud":0x5a573f,
"Devlan Mud Wash":0x3c3523,
"Devon Rex":0x717e6f,
"Devonshire":0xf5efe7,
"Dew":0xe7f2e9,
"Dew Drop":0xe8eee5,
"Dew Green":0x97b391,
"Dew Not Disturb":0xcee3dc,
"Dew Pointe":0xd7ede8,
"Dewberry":0x8b5987,
"Dewdrop":0xdde4e3,
"Dewkist":0xc4d1c2,
"Dewmist Delight":0xdceedb,
"Dewpoint":0xb2ced2,
"Dewy":0xd6e1d8,
"Dexter":0x6bb1b4,
"Dhalsim's Yoga Flame":0xfae432,
"Dhurrie Beige":0xcabaa8,
"Dhūsar Grey":0xaaaaaa,
"Di Sierra":0xdb995e,
"Diablo Red":0xcd0d01,
"Diamond":0xfaf7e2,
"Diamond Black":0x2b303e,
"Diamond Blue":0xcfe4ee,
"Diamond Dust":0xf8f5e5,
"Diamond Grey":0x3e474b,
"Diamond Light":0xdfe7ec,
"Diamond Soft Blue":0xbcdaec,
"Diamond Stud":0xdcdbdc,
"Diamond White":0xe2eff3,
"Diamonds In The Sky":0xe5e2e1,
"Diamonds Therapy":0xe9e8e0,
"Diantha":0xfcf6dc,
"Dianthus Mauve":0x8d6d89,
"Dickie Bird":0x60b8be,
"Diesel":0x322c2b,
"Different Gold":0xbc934d,
"Diffused Light":0xebe5d5,
"Diffused Orchid":0x9879a2,
"Digger's Gold":0xa37336,
"Digital":0x636365,
"Digital Garage":0xb7b3a4,
"Digital Violets":0xaa00ff,
"Digital Yellow":0xffeb7e,
"Dignified":0x3b695f,
"Dignified Purple":0x716264,
"Dignity Blue":0x094c73,
"Diisha Green":0x007044,
"Dijon":0x97754c,
"Dijon Mustard":0xe2ca73,
"Dijonnaise":0x9b8f55,
"Dill":0x6f7755,
"Dill Grass":0xa2a57b,
"Dill Green":0xb6ac4b,
"Dill Pickle":0x67744a,
"Dill Powder":0x9da073,
"Dill Seed":0xb3b295,
"Dillard's Blue":0xd6e9e4,
"Dilly Blue":0x35495a,
"Dilly Dally":0xf6db5d,
"Diluno Red":0xf46860,
"Diluted Blue":0xb8def2,
"Diluted Green":0xddeae0,
"Diluted Lilac":0xdadfea,
"Diluted Lime":0xe8efdb,
"Diluted Mint":0xdaf4ea,
"Diluted Orange":0xfbe8e2,
"Diluted Pink":0xe9dfe8,
"Diluted Red":0xe8dde2,
"Dim":0xc8c2be,
"Dim Grey":0x696969,
"Diminished Blue":0xbce1eb,
"Diminished Brown":0xe7ded7,
"Diminished Green":0xe3e6d6,
"Diminished Lime":0xedf5dd,
"Diminished Mint":0xe9f3dd,
"Diminished Orange":0xfae9e1,
"Diminished Pink":0xf1e5e0,
"Diminished Red":0xe8d8da,
"Diminished Sky":0xd3f2ed,
"Diminishing Green":0x062e03,
"Diminutive Pink":0xf1dede,
"Dimple":0xe9808b,
"Dingley":0x607c47,
"Dingy Dungeon":0xc53151,
"Dingy Sticky Note":0xe6f2a2,
"Dinner Mint":0xe8f3e4,
"Dinosaur":0x7f997d,
"Dinosaur Bone":0x827563,
"Dinosaur Egg":0xcabaa9,
"Diopside Blue":0x8391a0,
"Dioptase Green":0x439e8d,
"Diorite":0x9dbfb1,
"Diplomatic":0x3a445d,
"Dire Wolf":0x282828,
"Direct Green":0x3f8a24,
"Directoire Blue":0x0061a3,
"Diroset":0x5acaa4,
"Dirt":0x9b7653,
"Dirt Brown":0x836539,
"Dirt Track":0xbb6644,
"Dirt Yellow":0x926e2e,
"Dirty Blonde":0xdfc393,
"Dirty Blue":0x3f829d,
"Dirty Brown":0xb5651e,
"Dirty Green":0x667e2c,
"Dirty Leather":0x430005,
"Dirty Martini":0xddd0b6,
"Dirty Orange":0xc87606,
"Dirty Pink":0xca7b80,
"Dirty Purple":0x734a65,
"Dirty Snow":0xcdced5,
"Dirty White":0xe8e4c9,
"Dirty Yellow":0xcdc50a,
"Disappearing Island":0xbbdee5,
"Disappearing Memories":0xeae3e0,
"Disappearing Purple":0x3f313a,
"Disarm":0x006e9d,
"Disc Jockey":0x47c6ac,
"Disco":0x892d4f,
"Discover":0xbdb0a0,
"Discover Deco":0x4a934e,
"Discovery Bay":0x276878,
"Discreet Orange":0xffad98,
"Discreet Romance":0xf5e5e1,
"Discreet White":0xdfdcdb,
"Discrete Pink":0xebdbdd,
"Discretion":0x9f6f62,
"Disembark":0x5bb4d7,
"Disguise":0xb7b698,
"Dishy Coral":0xed9190,
"Dissolved Denim":0xe2ecf2,
"Distance":0x566a73,
"Distant Blue":0x2c66a0,
"Distant Cloud":0xe5eae6,
"Distant Flare":0xead1da,
"Distant Haze":0xdfe4da,
"Distant Homeworld":0xacdcee,
"Distant Horizon":0xf1f8fa,
"Distant Land":0xa68a71,
"Distant Landscape":0xe1efdd,
"Distant Searchlight":0xf2f3ce,
"Distant Shore":0xc2d8e3,
"Distant Sky":0x6f8daf,
"Distant Star":0xbac1c3,
"Distant Tan":0xcfbda5,
"Distant Thunder":0x7f8688,
"Distant Valley":0xc2b79a,
"Distant Wind Chime":0xeaeff2,
"Distilled Moss":0xccffcc,
"Distilled Rose":0xffbbff,
"Distilled Venom":0xc7fdb5,
"Distilled Watermelon":0xede3e0,
"Distinct Purple":0xa294c9,
"Dithered Amber":0xfeb308,
"Dithered Sky":0xbcdfff,
"Diva":0xc9a0ff,
"Diva Blue":0x007bb2,
"Diva Girl":0xe1cbda,
"Diva Glam":0xb24e76,
"Diva Mecha":0xee99ee,
"Diva Rouge":0xe8b9a5,
"Diva Violet":0x5077ba,
"Dive In":0x3c4d85,
"Diver Lady":0x27546e,
"Diver's Eden":0x3a797e,
"Diverse Beige":0xc2b4a7,
"Diversion":0xa99a89,
"Divine":0x9a7aa0,
"Divine Dove":0xeeddee,
"Divine Inspiration":0xd8e2e1,
"Divine Pleasure":0xf4efe1,
"Divine Purple":0x69005f,
"Divine White":0xe6dccd,
"Divine Wine":0x583e3e,
"Dixie":0xcd8431,
"Dizzy Days":0xd14e2f,
"Do Not Disturb":0x99a456,
"Dobunezumi Brown":0x4b3c39,
"Dockside":0x95aed0,
"Dockside Blue":0xa0b3bc,
"Doctor":0xf9f9f9,
"Dodge Pole":0xa37355,
"Dodger Blue":0x3e82fc,
"DodgeRoll Gold":0xf79a12,
"Dodie Yellow":0xfef65b,
"Doe":0xb98e68,
"Doeskin":0xfff2e4,
"Doeskin Grey":0xccc3ba,
"Dogwood":0xfaeae2,
"Dogwood Bloom":0xc58f94,
"Dogwood Rose":0xd71868,
"Doll House":0xfacfc1,
"Dollar":0x7d8774,
"Dollar Bill":0x85bb65,
"Dollie":0xf590a0,
"Dollop of Cream":0xf8ebd4,
"Dolly":0xf5f171,
"Dolomite Crystal":0xfee8f5,
"Dolomite Red":0xc5769b,
"Dolphin":0x86c4da,
"Dolphin Blue":0x7d9da9,
"Dolphin Daze":0x659fb5,
"Dolphin Dream":0x6b6f78,
"Dolphin Fin":0xcccac1,
"Dolphin Grey":0x9a9997,
"Dolphin Tales":0xc7c7c2,
"Domain":0x9c9c6e,
"Dominant Grey":0x5a5651,
"Domino":0x6c5b4c,
"Don Juan":0x5a4f51,
"Donegal Green":0x115500,
"Donegal Tweed":0xc19964,
"Döner Kebab":0xbb7766,
"Donkey Brown":0x816e5c,
"Donkey Kong":0xab4210,
"Donnegal":0x8caea3,
"Doodle":0xfbdca8,
"Doombull Brown":0x7c1e08,
"Dorado":0x6e5f56,
"Dorian Gray":0xaca79e,
"Doric White":0xd5cfbd,
"Dormer Brown":0xad947c,
"Dormitory":0x5d71a9,
"Dorn Yellow":0xfff200,
"Dorset Naga":0x9d2c31,
"Dotted Dove":0x6c6868,
"Dòu Lǜ Green":0x009276,
"Dòu Shā Sè Red":0xa52939,
"Double Chocolate":0x6f5245,
"Double Click":0xd0d2d1,
"Double Colonial White":0xe4cf99,
"Double Cream":0xf3e0ac,
"Double Dragon Skin":0xfca044,
"Double Duty":0x686858,
"Double Espresso":0x54423e,
"Double Fudge":0x6d544b,
"Double Jeopardy":0x4d786c,
"Double Latte":0xa78c71,
"Double Pearl Lusta":0xe9dcbe,
"Double Spanish White":0xd2c3a3,
"Dough Yellow":0xf6d0b6,
"Douglas Fir Green":0x6f9881,
"Douro":0x555500,
"Dove":0xb3ada7,
"Dove Feather":0x755d5b,
"Dove Grey":0x6d6c6c,
"Dove Tail":0x91b0c5,
"Dove White":0xe6e2d8,
"Dove's Wing":0xf4f2ea,
"Dover Cliffs":0xf0e9d8,
"Dover Grey":0x848585,
"Dover Plains":0xccaf92,
"Dover Straits":0x326ab1,
"Dover White":0xf1ebdd,
"Dovetail":0x908a83,
"Dowager":0x838c82,
"Down Dog":0xbaafb9,
"Down Feathers":0xfff9e7,
"Down Home":0xcbc0ba,
"Down Pour":0x43718b,
"Down-to-Earth":0x5c6242,
"Downing Earth":0x887b67,
"Downing Sand":0xcbbca5,
"Downing Slate":0x777f86,
"Downing Stone":0xa6a397,
"Downing Straw":0xcaab7d,
"Downing to Earth":0x635a4f,
"Download Progress":0x58d332,
"Downpour":0x9b9ea2,
"Downriver":0x092256,
"Downtown Benny Brown":0x7d6a58,
"Downtown Grey":0xadaaa2,
"Downwell":0x001100,
"Downy":0x6fd2be,
"Downy Feather":0xfeaa66,
"Downy Fluff":0xede9e4,
"Dozen Roses":0x803f3f,
"Dr Who":0x78587d,
"Dr. White":0xfafafa,
"Drab":0x828344,
"Drab Green":0x749551,
"Dracula Orchid":0x2c3539,
"Dragon Ball":0xff9922,
"Dragon Bay":0x5da99f,
"Dragon Fire":0xfc642d,
"Dragon Fruit":0xd75969,
"Dragon Red":0x9e0200,
"Dragon Scale":0x00a877,
"Dragon's Blood":0xb84048,
"Dragon's Breath":0xd41003,
"Dragon's Fire":0x9c2d5d,
"Dragonfly":0x314a76,
"Dragonfly Blue":0x45abca,
"Dragonlord Purple":0x6241c7,
"Dragons Lair":0xd50c15,
"Drake Tooth":0xbbb0a4,
"Drake’s Neck":0x31668a,
"Drakenhof Nightshade":0x1f5da0,
"Drama Queen":0xa37298,
"Drama Violet":0xb883b0,
"Dramatical Red":0x991100,
"Dramatist":0x4b4775,
"Draw Your Sword":0x6c7179,
"Dream Blue":0xd7e6ee,
"Dream Catcher":0xe5ebea,
"Dream Dust":0xebe2e8,
"Dream Green":0x35836a,
"Dream Seascape":0xd5dec3,
"Dream Setting":0xff77bb,
"Dream State":0xefdde1,
"Dream Sunset":0x9b868d,
"Dream Vapor":0xcc99ee,
"Dreamcatcher":0xa5b2a9,
"Dreaming Blue":0x8ac2d6,
"Dreaming of the Day":0xabc1bd,
"Dreamland":0xb5b1bf,
"Dreamless Sleep":0x111111,
"Dreams of Peach":0xffd29d,
"Dreamscape Grey":0xc6c5c5,
"Dreamsicle":0xf5d5c2,
"Dreamweaver":0xccc6d7,
"Dreamy Cloud":0xe5e6eb,
"Dreamy Heaven":0x594158,
"Dreamy White":0xe3d8d5,
"Drenched Rain":0xc1d1e2,
"Dresden Blue":0x0086bb,
"Dresden Doll":0x8ca8c6,
"Dresden Dream":0x8ea7b9,
"Dress Blues":0x2a3244,
"Dress Pink":0xf4ebef,
"Dress Up":0xfac7bf,
"Dressed to Impress":0x714640,
"Dressy Rose":0xb89d9a,
"Dreyfus":0xb2aba1,
"Dried Basil":0x898973,
"Dried Blood":0x4b0101,
"Dried Chamomile":0xd1b375,
"Dried Chervil":0xb5bda3,
"Dried Chive":0x7b7d69,
"Dried Coconut":0xebe7d9,
"Dried Dates":0x4a423a,
"Dried Edamame":0xb19f80,
"Dried Flower Purple":0x752653,
"Dried Goldenrod":0xe2a829,
"Dried Grass":0xaca08d,
"Dried Herb":0x847a59,
"Dried Lavender":0xebe9ec,
"Dried Lavender Flowers":0x77747f,
"Dried Leaf":0x5c5043,
"Dried Lilac":0xbbbbff,
"Dried Magenta":0xff40ff,
"Dried Moss":0xccb97e,
"Dried Mustard":0x804a00,
"Dried Palm":0xe1dbac,
"Dried Pipe Clay":0xd8d6cc,
"Dried Plantain":0xe5cea9,
"Dried Plum":0x683332,
"Dried Thyme":0xbbbca1,
"Dried Tobacco":0x997b38,
"Dried Tomatoes":0xab6057,
"Drift of Mist":0xdcd8d0,
"Drift on the Sea":0x87cefa,
"Drifting":0xbeb4a8,
"Drifting Cloud":0xdbe0e1,
"Drifting Downstream":0x61736f,
"Drifting Dream":0xccbbe3,
"Drifting Sand":0xa89f93,
"Drifting Tide":0xdfefeb,
"Driftwood":0xa67a45,
"Drip":0xa6ccd6,
"Dripping Ice":0xd2dfed,
"Drippy Honey":0xeebb22,
"Drisheen":0xa24857,
"Drive-In Cherry":0xa62e30,
"Drizzle":0xa0af9d,
"Droëwors":0x523839,
"Dromedary":0xe3c295,
"Dromedary Camel":0xcaad87,
"Drop Green":0x69bd5a,
"Drop of Lemon":0xfcf1bd,
"Droplet":0xaaddff,
"Dropped Brick":0xbb3300,
"Drops of Honey":0xd4ae76,
"Drought":0xd5d1cc,
"Drover":0xfbeb9b,
"Drowsy Lavender":0xd4dbe1,
"Druchii Violet":0x842994,
"Druid Green":0x427131,
"Drum Solo":0xa66e4b,
"Drunk-Tank Pink":0xdd11dd,
"Drunken Dragonfly":0x33dd88,
"Drunken Flamingo":0xff55cc,
"Dry Bone":0xeadfce,
"Dry Brown":0x968374,
"Dry Catmint":0xb9bdae,
"Dry Clay":0xbd5c00,
"Dry Creek":0xd8c7b6,
"Dry Dock":0x817665,
"Dry Dune":0xefdfcf,
"Dry Grass":0x9ea26b,
"Dry Hemlock":0x909373,
"Dry Highlighter Green":0x2ba727,
"Dry Lichen":0xc7d9cc,
"Dry Moss":0x769958,
"Dry Mud":0x777672,
"Dry Pasture":0x948971,
"Dry Peach":0xde7e5d,
"Dry Riverbed":0xd2c5ae,
"Dry Rose":0xc22f4d,
"Dry Sand":0xeae4d6,
"Dry Sea Grass":0xccb27a,
"Dry Season":0xd4cecd,
"Dry Seedlings":0xc7dc68,
"Dry Starfish":0xb09a77,
"Dryad Bark":0x33312d,
"Drying Grass Green":0x7bb369,
"Dubarry":0xf25f66,
"Dubbin":0xae8b64,
"Dublin":0x73be6e,
"Dublin Jack":0x6fab92,
"Dubloon":0xd5b688,
"Dubuffet Green":0x6f7766,
"Ducal":0x763d35,
"Ducal Pink":0xce9096,
"Ducati":0x16a0a6,
"Duchamp Light Green":0xd1dbc7,
"Duchess Lilac":0x9b909d,
"Duchess Rose":0xf7aa97,
"Duck Butter":0xddc75b,
"Duck Egg Blue":0xc3fbf4,
"Duck Egg Cream":0xc8e3d2,
"Duck Green":0x53665c,
"Duck Hunt":0x005800,
"Duck Sauce":0xcc9922,
"Duck Tail":0xe9d6b1,
"Duck Willow":0x6a695a,
"Duck's Egg Blue":0xccdfe8,
"Duckie Yellow":0xffff11,
"Duckling":0xfcb057,
"Duckling Fluff":0xfafc5d,
"Duct Tape Grey":0xaeacac,
"Duffel Bag":0x394034,
"Dugong":0x71706e,
"Duke Blue":0x00009c,
"Dulcet":0x9ad4d8,
"Dulcet Violet":0x59394c,
"Dull":0x727171,
"Dull Apricot":0xd09c97,
"Dull Blue":0x49759c,
"Dull Brown":0x876e4b,
"Dull Desert":0xdcd6d3,
"Dull Dusky Pink":0x8f6d73,
"Dull Gold":0x8a6f48,
"Dull Green":0x74a662,
"Dull Lavender":0xa899e6,
"Dull Light Yellow":0xe5d9b4,
"Dull Magenta":0x8d4856,
"Dull Mauve":0x7d7485,
"Dull Olive":0x7a7564,
"Dull Orange":0xd8863b,
"Dull Pink":0xd5869d,
"Dull Purple":0x84597e,
"Dull Red":0xbb3f3f,
"Dull Sage":0xdbd4ab,
"Dull Teal":0x5f9e8f,
"Dull Turquoise":0x557d73,
"Dull Violet":0x803790,
"Dull Yellow":0xeedc5b,
"Dumpling":0xf7ddaa,
"Dun Morogh Blue":0x80b4dc,
"Dune":0xd5c0a1,
"Dune Drift":0xb88d70,
"Dune Grass":0xcbc5b1,
"Dune Shadow":0x867665,
"Dunes Manor":0x514f4a,
"Dungeon Keeper":0xef3038,
"Dunnock Egg":0xd9ece6,
"Duomo":0x6e6064,
"Dupain":0x58a0bc,
"Duqqa Brown":0x442211,
"Durango Blue":0x566777,
"Durango Dust":0xfbe3a1,
"Durazno Maduro":0xffb978,
"Durazno Palido":0xffd8bb,
"Durban Sky":0x5d8a9b,
"Durian":0xb07939,
"Durian Smell":0xe5e0db,
"Durian White":0xe6d0ab,
"Durian Yellow":0xe1bd27,
"Durotar Fire":0xf06126,
"Dusk":0x4e5481,
"Dusk Blue":0x7ba0c0,
"Dusk Green":0x6e7a77,
"Dusk Mauve":0x545883,
"Dusk Orange":0xfe4c40,
"Duskwood":0x123d55,
"Dusky":0xc3aba8,
"Dusky Alpine Blue":0x296767,
"Dusky Citron":0xe3cc81,
"Dusky Cyclamen":0x7d6d70,
"Dusky Damask":0xb98478,
"Dusky Dawn":0xe5e1de,
"Dusky Flesh":0x774400,
"Dusky Grape":0x877f95,
"Dusky Green":0x746c57,
"Dusky Grouse":0x8e969e,
"Dusky Haze":0xa77572,
"Dusky Lilac":0xd6cbda,
"Dusky Mood":0x979ba8,
"Dusky Moon":0xedecd7,
"Dusky Orchid":0x9a7182,
"Dusky Pink":0xcc7a8b,
"Dusky Purple":0x895b7b,
"Dusky Rose":0xba6873,
"Dusky Taupe":0xc9bdb7,
"Dusky Violet":0xd0bfbe,
"Dusky Yellow":0xffff05,
"Dust":0xb2996e,
"Dust Bowl":0xe2d8d3,
"Dust Green":0xc6c8be,
"Dust Storm":0xe7d3b7,
"Dust to Dust":0xbbbcbc,
"Dustblu":0x959ba0,
"Dusted Clay":0xcc7357,
"Dusted Olive":0xbea775,
"Dusted Peri":0x696ba0,
"Dusted Truffle":0x9c8373,
"Dusting Powder":0xe7ece8,
"Dustwallow Marsh":0x685243,
"Dusty Aqua":0xc0dccd,
"Dusty Attic":0xbfb6a3,
"Dusty Blue":0x8c9dad,
"Dusty Cedar":0xdd9592,
"Dusty Chestnut":0x847163,
"Dusty Chimney":0x888899,
"Dusty Coral":0xd29b83,
"Dusty Dream":0x97a2a0,
"Dusty Gold":0xd7b999,
"Dusty Green":0x76a973,
"Dusty Grey":0xcdccd0,
"Dusty Heather":0x8990a3,
"Dusty Ivory":0xf1ddbe,
"Dusty Jade Green":0x7bb5a3,
"Dusty Lavender":0xac86a8,
"Dusty Lilac":0xd3cacd,
"Dusty Mountain":0x716d63,
"Dusty Olive":0x646356,
"Dusty Orange":0xe27a53,
"Dusty Path":0x8c7763,
"Dusty Pink":0xd58a94,
"Dusty Plum":0xd7d0e1,
"Dusty Purple":0x825f87,
"Dusty Red":0xb9484e,
"Dusty Rose":0xba797d,
"Dusty Rosewood":0xc0aa9f,
"Dusty Sand":0xbdbaae,
"Dusty Sky":0x95a3a6,
"Dusty Teal":0x4c9085,
"Dusty Trail":0xc9bba3,
"Dusty Trail Rider":0xc3b9a6,
"Dusty Turquoise":0x649b9e,
"Dusty Warrior":0xbab7b3,
"Dusty Yellow":0xd4cc9a,
"Dutch Blue":0x4a638d,
"Dutch Cocoa":0x8c706a,
"Dutch Jug":0xa5abb6,
"Dutch Orange":0xdfa837,
"Dutch Tile Blue":0x9aabab,
"Dutch White":0xf0dfbb,
"Dutchess Dawn":0xc9a7ac,
"Duvall":0x0f8b8e,
"Dwarf Fortress":0x1d0200,
"Dwarf Pony":0xaf7b57,
"Dwarf Rabbit":0xc8ac89,
"Dwarf Spruce":0x71847d,
"Dwarven Bronze":0xbf652e,
"Dwarven Flesh":0xffa07a,
"Dwindling Damon":0xefdfe7,
"Dwindling Dandelion":0xf9e9d7,
"Dwindling Denim":0xcce1ee,
"Dyer's Woad":0x7b99b0,
"Dying Light":0x364141,
"Dying Moss":0x669c7d,
"Dynamic":0x6d5160,
"Dynamic Blue":0x0192c6,
"Dynamic Green":0xa7e142,
"Dynamic Magenta":0x8a547f,
"Dynamic Yellow":0xffe36d,
"Dynamite":0xff4422,
"Dynamite Red":0xdd3311,
"Dynamo":0x953d68,
"Dynasty Celadon":0xc7cbbe,
"Dynasty Green":0x008e80,
"E. Honda Beige":0xf8d77f,
"Eagle":0xb0ac94,
"Eagle Eye":0x736665,
"Eagle Ridge":0x7d776c,
"Eagle Rock":0x5c5242,
"Eagle's Meadow":0x8d7d68,
"Eagle's View":0xd4cbcc,
"Eagles Nest":0x8a693f,
"Eaglet Beige":0xe9d9c0,
"Eames for Blue":0x466b82,
"Earhart Emerald":0x416659,
"Earl Grey":0xa6978a,
"Earls Green":0xb8a722,
"Early Blossom":0xffe5ed,
"Early Crocus":0xeae7e7,
"Early Dawn":0x797287,
"Early Dew":0x44aa00,
"Early Dog Violet":0xd3d6e9,
"Early Evening":0xcac7bf,
"Early Forget-Me-Not":0xbae5ee,
"Early Frost":0xdae3e9,
"Early Harvest":0xb9be82,
"Early July":0xa5ddea,
"Early June":0xb1d2df,
"Early September":0xadcddc,
"Early Snow":0xfdf3e4,
"Early Spring":0x96bc4a,
"Early Spring Night":0x3c3fb1,
"Early Sunset":0xf3e3d8,
"Earth":0xa2653e,
"Earth Black":0x49433b,
"Earth Brown":0x4f1507,
"Earth Brown Violet":0x705364,
"Earth Chi":0xc7af88,
"Earth Chicory":0x664b40,
"Earth Crust":0x8c4f42,
"Earth Eclipse":0x71bab4,
"Earth Fired Red":0x785240,
"Earth Green":0x545f5b,
"Earth Happiness":0xe3edc8,
"Earth Red":0x95424e,
"Earth Rose":0xb57770,
"Earth Tone":0xa06e57,
"Earth Warming":0xbf9f91,
"Earth Yellow":0xe1a95f,
"Earthbound":0xa48a80,
"Earthen Cheer":0x667971,
"Earthen Jug":0xa85e39,
"Earthenware":0xa89373,
"Earthling":0xded6c7,
"Earthly Delight":0xab8a68,
"Earthly Pleasure":0x693c3b,
"Earthly Pleasures":0x9f8863,
"Earthnut":0x9d8675,
"Earthtone":0x5d3a1a,
"Earthworm":0xc3816e,
"Earthy Cane":0xc5b28b,
"Earthy Khaki Green":0x666600,
"Earthy Ocher":0xb89e78,
"Earthy Ochre":0xbeae88,
"Eased Pink":0xfae3e3,
"Easily Suede":0xb29d8a,
"East Bay":0x47526e,
"East Cape":0xb0eee2,
"East Side":0xaa8cbc,
"Easter Bunny":0xebe5eb,
"Easter Egg":0x919bc9,
"Easter Green":0x8cfd7e,
"Easter Purple":0xc071fe,
"Easter Rabbit":0xc7bfc3,
"Eastern Amber":0xebb67e,
"Eastern Bamboo":0x5e5d3d,
"Eastern Blue":0x00879f,
"Eastern Bluebird":0x748695,
"Eastern Breeze":0xdae0e6,
"Eastern Gold":0xb89b6c,
"Eastern Sky":0x8fc1d2,
"Eastern Spice":0xdba87f,
"Eastern Wind":0xede6d5,
"Eastern Wolf":0xdbd7d2,
"Eastlake Gold":0xc28e61,
"Eastlake Lavender":0x887d79,
"Eastlake Olive":0xa9a482,
"Easy":0xbeb394,
"Easy Breezy Blue":0x9eb1ae,
"Easy Green":0x9fb289,
"Easy On The Eyes":0xf9ecb6,
"Eat Your Greens":0x696845,
"Eat Your Peas":0x80987a,
"Eaton Gold":0xbb9f60,
"Eaves":0xcecdad,
"Ebb":0xe6d8d4,
"Ebbing Tide":0x688d8a,
"Ebbtide":0x84b4be,
"Ebi Brown":0x773c30,
"Ebicha Brown":0x5e2824,
"Ebizome Purple":0x6d2b50,
"Ebony":0x313337,
"Ebony Clay":0x323438,
"Ebony Lips":0xb06a40,
"Ebony Wood":0x2c3227,
"Eburnean":0xffffee,
"Eccentric Magenta":0xb576a7,
"Eccentricity":0x968a9f,
"Echelon Ecru":0xe7d8be,
"Echinoderm":0xffa565,
"Echinoidea Thorns":0xffa756,
"Echo":0xd7e7e0,
"Echo Blue":0xa4afcd,
"Echo Iris":0xb6dff4,
"Echo Isles Water":0x95b5db,
"Echo Mist":0xd8dfdf,
"Echo One":0x629da6,
"Echo Park":0x758883,
"Echo Valley":0xe6e2d6,
"Echoes of Love":0xeededd,
"Eclectic":0xaaafbd,
"Eclectic Plum":0x8c6e67,
"Eclectic Purple":0x483e45,
"Eclipse":0x3f3939,
"Eclipse Blue":0x456074,
"Eco Green":0xa89768,
"Ecological":0x677f70,
"Ecru":0xc2b280,
"Ecru Ochre":0xa48d83,
"Ecru Olive":0x927b3c,
"Ecru Wealth":0xd5cdb4,
"Ecru White":0xd6d1c0,
"Ecstasy":0xc96138,
"Ecstatic Red":0xaa1122,
"Ecuadorian Banana":0xffff7e,
"Edamame":0x9ca389,
"Edelweiss":0xeee8d9,
"Eden":0x266255,
"Eden Prairie":0x95863c,
"Edge of Black":0x54585e,
"Edge of Space":0x330044,
"Edge of the Galaxy":0x303d3c,
"Edgewater":0xc1d8c5,
"Edgy Gold":0xb1975f,
"Edgy Red":0xba3d3c,
"Edocha":0xa13d2d,
"Edward":0x5e7e7d,
"Edwardian Lace":0xf6ede0,
"Eerie Black":0x1b1b1b,
"Effervescent":0xfbf4d1,
"Effervescent Blue":0x00315a,
"Effervescent Lime":0x98da2c,
"EGA Green":0x01ff07,
"Egg Blue":0xc1e7eb,
"Egg Cream":0xffd98c,
"Egg Liqueur":0xdccaa8,
"Egg Noodle":0xf1e3bd,
"Egg Sour":0xf9e4c5,
"Egg Toast":0xf2c911,
"Egg Wash":0xe2e1c8,
"Egg White":0xffefc1,
"Egg Yolk":0xffce81,
"Eggnog":0xfdea9f,
"Eggplant":0x430541,
"Eggplant Ash":0x656579,
"Eggplant Tint":0x531b93,
"Eggshell":0xf0ead6,
"Eggshell Blue":0xa3ccc9,
"Eggshell Cream":0xf5eedb,
"Eggshell Paper":0xe2be9f,
"Eggshell White":0xf3e4dc,
"Eggwhite":0xf3e5d2,
"Egret":0xf3ece0,
"Egret White":0xdfd9cf,
"Egyptian Blue":0x1034a6,
"Egyptian Enamel":0x005c69,
"Egyptian Gold":0xefa84c,
"Egyptian Green":0x08847c,
"Egyptian Jasper":0x7a4b3a,
"Egyptian Javelin":0xfebcad,
"Egyptian Nile":0x70775c,
"Egyptian Pyramid":0xc19a7d,
"Egyptian Red":0x983f4a,
"Egyptian Sand":0xbeac90,
"Egyptian Teal":0x008c8d,
"Egyptian Temple":0xd6b378,
"Egyptian Violet":0x3d496d,
"Egyptian White":0xe5f1ec,
"Eider White":0xe1ded7,
"Eiffel Tower":0x998e83,
"Eigengrau":0x16161d,
"Eiger Nordwand":0x7799bb,
"El Capitan":0xb7a696,
"El Caramelo":0x946e48,
"El Niño":0xd0cacd,
"El Paso":0x39392c,
"El Salva":0x8f4e45,
"Elastic Pink":0xeca6ca,
"Elation":0xdfdce5,
"Eldar Flesh":0xecc083,
"Elder Creek":0xafa892,
"Elderberry":0x2e2249,
"Elderberry Black":0x1e323b,
"Elderberry Grey":0xaea8b0,
"Elderberry White":0xeae5cf,
"Elderflower":0xfbf9e8,
"Eleanor Ann":0x40373e,
"Election Night":0x110320,
"Electra":0x55b492,
"Electric Blue":0x7df9ff,
"Electric Brown":0xb56257,
"Electric Crimson":0xff003f,
"Electric Cyan":0x0ff0fc,
"Electric Eel":0x88bbee,
"Electric Energy":0xc9e423,
"Electric Flamingo":0xfc74fd,
"Electric Glow":0xffd100,
"Electric Green":0x21fc0d,
"Electric Indigo":0x6600ff,
"Electric Lavender":0xf4bfff,
"Electric Leaf":0x89dd01,
"Electric Lime":0xccff00,
"Electric Orange":0xff3503,
"Electric Pink":0xff0490,
"Electric Purple":0xbf00ff,
"Electric Red":0xe60000,
"Electric Sheep":0x55ffff,
"Electric Slide":0x9db0b9,
"Electric Ultramarine":0x3f00ff,
"Electric Violet":0x8f00f1,
"Electric Yellow":0xfffc00,
"Electrify":0x5665a0,
"Electromagnetic":0x2e3840,
"Electron Blue":0x0881d1,
"Electronic":0x556d88,
"Electrum":0xe7c697,
"Elegant Ice":0xc4b9b7,
"Elegant Ivory":0xf1e6d6,
"Elegant Light Rose":0xfdcaca,
"Elegant Midnight":0x5500bb,
"Elegant Navy":0x48516a,
"Elegant White":0xf5f0e1,
"Elemental":0xd0d3d3,
"Elemental Green":0x969783,
"Elemental Grey":0xa0a09f,
"Elemental Tan":0xcab79c,
"Elephant":0x243640,
"Elephant Ear":0x988f85,
"Elephant Grey":0x95918c,
"Elephant in the Room":0xa8a9a8,
"Elephant Skin":0x8f8982,
"Elevated":0xb3c3d4,
"Elf Flesh":0xf7c380,
"Elf Green":0x1b8a6b,
"Elf Shoe":0x68b082,
"Elf Skintone":0xf7c985,
"Elf Slippers":0xa6a865,
"Elfin Games":0x9dd196,
"Elfin Herb":0xcab4d4,
"Elfin Magic":0xeddbe9,
"Elfin Yellow":0xeeea97,
"Elise":0xd8d7b9,
"Elite Blue":0x1b3053,
"Elite Green":0x133700,
"Elite Pink":0xbb8da8,
"Elite Teal":0x133337,
"Elite Wisteria":0x987fa9,
"Elizabeth Blue":0xa1b8d2,
"Elizabeth Rose":0xfadfd2,
"Elk Horn":0xe9e2d3,
"Elk Skin":0xeae6dc,
"Elkhound":0x897269,
"Ellen":0xe2c8b7,
"Ellie Gray":0xaaa9a4,
"Ellis Mist":0x778070,
"Elm":0x297b76,
"Elm Brown Red":0xb25b09,
"Elm Green":0x547053,
"Elmer's Echo":0x264066,
"Elmwood":0x8c7c61,
"Elote":0xffe8ab,
"Elusion":0xd2cfcc,
"Elusive":0xfed7cf,
"Elusive Blue":0xdde4e8,
"Elusive Dawn":0xd5bfad,
"Elusive Dream":0xcdbfc6,
"Elusive Mauve":0xdec4d2,
"Elusive Violet":0xd4c0c5,
"Elusive White":0xe8e3d6,
"Elven Flesh":0xf7cf8a,
"Elwynn Forest Olive":0x7a8716,
"Elysia Chlorotica":0x9aae07,
"Elysian Green":0xa5b145,
"Elysium Gold":0xce9500,
"Emanation":0xb4a3bb,
"Embarcadero":0x5d4643,
"Embarrassed Frog":0x996611,
"Embarrassment":0xff7777,
"Embellished Blue":0x8bc7c8,
"Embellishment":0xcbdee2,
"Ember Red":0x792445,
"Emberglow":0xea6759,
"Embrace":0xe8b8a7,
"Embracing":0x246453,
"Embroidered Silk":0xb8dca7,
"Embroidery":0xd4bebf,
"Emerald":0x028f1e,
"Emerald City":0x6a7e5f,
"Emerald Clear Green":0x4f8129,
"Emerald Coast":0x009185,
"Emerald Dream":0x007a5e,
"Emerald Forest":0x224347,
"Emerald Glitter":0x66bb00,
"Emerald Green":0x046307,
"Emerald Lake":0x069261,
"Emerald Light Green":0x00a267,
"Emerald Pool":0x155e60,
"Emerald Reflection":0x50c878,
"Emerald Ring":0x578758,
"Emerald Spring":0x095155,
"Emerald Starling":0x11bb11,
"Emerald Stone":0x016360,
"Emerald Succulent":0x55aaaa,
"Emerald Wave":0x4fb3a9,
"Emerald-Crested Manakin":0x5c6b8f,
"Emergency":0x911911,
"Emergency Zone":0xe36940,
"Emerging Leaf":0xe1e1cf,
"Emerging Taupe":0xb8a196,
"Emerson":0x3e6058,
"Emilie's Dream":0xeccee5,
"Emily":0xabd1e1,
"Emily Ann Tan":0xd5c7b6,
"Eminence":0x6e3974,
"Eminent Bronze":0x7a6841,
"Emoji Yellow":0xffde34,
"Emotional":0xc65f47,
"Emotive Ring":0x856d70,
"Emperador":0x684832,
"Emperor":0x50494a,
"Emperor Cherry Red":0xac2c32,
"Emperor Jade":0x007b75,
"Emperor Jewel":0x715a8d,
"Emperor's Children":0xf0a0b6,
"Emperor's Gold":0xb0976d,
"Emperor's Robe":0x99959d,
"Emperor's Silk":0x00816a,
"Emperors Children":0xb94278,
"Empire Blue":0x6193b4,
"Empire Gold":0xc19f6e,
"Empire Porcelain":0xe0dbd3,
"Empire Ranch":0x93826a,
"Empire Rose":0xe7c5c1,
"Empire State Grey":0xd9dbdf,
"Empire Violet":0x9264a2,
"Empire Yellow":0xf7d000,
"Empower":0xb54644,
"Empress":0x7c7173,
"Empress Envy":0x2a9ca0,
"Empress Teal":0x10605a,
"Emptiness":0xfcfdfc,
"Emu":0x756e6d,
"Emu Egg":0x3d8481,
"En Plein Air":0xd0c5be,
"Enamel Antique Green":0x427f85,
"Enamel Blue":0x007a8e,
"Enamel Green":0xbacca8,
"Enamelled Dragon":0x54c589,
"Enamelled Jewel":0x045c61,
"Enamored":0xc67d84,
"Encaje Aperlado":0xf7ebd6,
"Encarnado":0xfd0202,
"Enchant":0xd1c6d2,
"Enchanted":0xc9e2cf,
"Enchanted Blue":0x047495,
"Enchanted Eve":0x79837f,
"Enchanted Evening":0xd3e9ec,
"Enchanted Meadow":0xb1d4b7,
"Enchanted Silver":0xb5b5bd,
"Enchanted Wells":0x26ad8d,
"Enchanted Wood":0x94895f,
"Enchanting":0x82badf,
"Enchanting Ginger":0xac7435,
"Enchanting Ivy":0x315955,
"Enchanting Sapphire":0x276dd6,
"Enchanting Sky":0x7886aa,
"Enchantress":0x5d3a47,
"Encore":0x6d7383,
"Encore Teal":0x30525b,
"Encounter":0xff9552,
"End of Summer":0xcc8f15,
"End of the Rainbow":0xd2eed6,
"Endearment":0xffd8a1,
"Endeavour":0x29598b,
"Ending Autumn":0x8b6f64,
"Ending Dawn":0xfcc9b9,
"Ending Navy Blue":0x1c305c,
"Endive":0xcee1c8,
"Endless":0x5b976a,
"Endless Galaxy":0x000044,
"Endless Possibilities":0xe0413a,
"Endless Sea":0x32586e,
"Endless Silk":0xddddbb,
"Endless Sky":0xcae3ea,
"Endless Slumber":0xb1aab3,
"Endo":0x5da464,
"Enduring":0x586683,
"Enduring Bronze":0x554c3e,
"Enduring Ice":0xebe8db,
"Energetic Orange":0xd85739,
"Energetic Pink":0xf3c6cc,
"Energic Eggplant":0xb300b3,
"Energise":0x7cca6b,
"Energized":0xd2d25a,
"Energos":0xc0e740,
"Energy Green":0x1ca350,
"Energy Orange":0xff9532,
"Energy Peak":0xbb5f60,
"Energy Yellow":0xf5d752,
"Enfield Brown":0xa73211,
"Engagement Silver":0xc2c6c0,
"English Bartlett":0xa17548,
"English Breakfast":0x441111,
"English Channel":0x4e6173,
"English Channel Fog":0xcbd3e6,
"English Coral":0xc64a55,
"English Custard":0xe2b66c,
"English Daisy":0xffca46,
"English Forest":0x606256,
"English Green":0x1b4d3f,
"English Holly":0x274234,
"English Hollyhock":0xb5c9d3,
"English Ivy":0x61845b,
"English Lavender":0x9d7bb0,
"English Manor":0x7181a4,
"English Meadow":0x028a52,
"English Red":0xab4b52,
"English River":0x3c768a,
"English Rose":0xf4c6c3,
"English Rose Bud":0xe9c9cb,
"English Saddle":0x8e6947,
"English Scone":0xe9cfbb,
"English Vermillion":0xcc474b,
"English Violet":0x563d5d,
"English Walnut":0x3e2b23,
"Enhance":0xd2a5be,
"Enigma":0xbdbf35,
"Enigmatic":0x7e7275,
"Enjoy":0xead4c4,
"Enjoyable Yellow":0xf5d6a9,
"Enlightened Lime":0xe3ead6,
"Enoki":0xf8faee,
"Enokitake Mushroom":0xffeedd,
"Enough Is Enough":0x898c4a,
"Enraged":0xee0044,
"Enshūcha Red":0xcb6649,
"Ensign Blue":0x384c67,
"Entan Red":0xec6d51,
"Enterprise":0x65788c,
"Enthroned Above":0xac92b0,
"Enthusiasm":0x00ffaa,
"Enticing Red":0xb74e4f,
"Entrapment":0x005961,
"Enviable":0x53983c,
"Envious Pastel":0xddf3c2,
"Environmental":0xb1b5a0,
"Environmental Green":0x006c4b,
"Environmental Study":0x88bb00,
"Envisage":0x96bfb7,
"Envy":0x8ba58f,
"Eon":0xd4d3c9,
"Ephemera":0x6f5965,
"Ephemeral Blue":0xcbd4df,
"Ephemeral Fog":0xd6ced3,
"Ephemeral Mist":0xc7cdd3,
"Ephemeral Peach":0xfce2d4,
"Ephemeral Red":0xe4cfd7,
"Ephren Blue":0x1164b4,
"Epic Blue":0x0066ee,
"Epicurean Orange":0xea6a0a,
"Epidote Olvene Ore":0xab924b,
"Epimetheus":0x4bb2d5,
"Epink":0xdd33ff,
"Epiphany":0xdbc1de,
"Epsom":0x849161,
"Equanimity":0x83a9b3,
"Equator":0xdab160,
"Equator Glow":0xffe6a0,
"Equatorial":0xffce84,
"Equatorial Forest":0x70855e,
"Equestrian":0xbea781,
"Equestrian Green":0x54654f,
"Equestrian Leather":0x5b5652,
"Equilibrium":0xa49f9f,
"Equinox":0x62696b,
"Era":0xd7e3e5,
"Erebus Blue":0x060030,
"Ermine":0x836b4f,
"Eros Pink":0xc84f68,
"Erosion":0xddd1bf,
"Errigal White":0xf2f2f4,
"Erythrosine":0xfc7ab0,
"Escalope":0xcc8866,
"Escapade Gold":0xb89b59,
"Escape from Columbia":0xd2e2ef,
"Escape Gray":0xabac9f,
"Escargot":0xfff1d8,
"Escarpment":0xd5b79b,
"Eshin Grey":0x4a4f52,
"Eskimo":0x55a0b7,
"Eskimo White":0xc2bdc2,
"Esmeralda":0x45be76,
"Espalier":0x2f5f3a,
"Esper's Fungus Green":0x80f9ad,
"Esplanade":0xd5bda4,
"Espresso":0x4e312d,
"Espresso Beans":0x4c443e,
"Espresso Macchiato":0x4f4744,
"Espresso Martini":0xaa9c8e,
"Esprit":0xbebd99,
"Essence of Violet":0xefedee,
"Essential Brown":0x7d6848,
"Essential Gray":0xbcb8b6,
"Essential Teal":0x007377,
"Essentially Bright":0xffde9f,
"Essex Blue":0xb0ccda,
"Establish Mint":0xe2eddd,
"Estate Blue":0x233658,
"Estate Limestone":0xdccdb4,
"Estate Vineyard":0x68454b,
"Estragon":0xa5af76,
"Estroruby":0x9b101f,
"Estuary Blue":0x70a5b7,
"Etcetera":0xe1c6d4,
"Etched Glass":0xdde2e2,
"Eternal Cherry":0xdd0044,
"Eternal Elegance":0xb3c3dd,
"Eternal Flame":0xa13f49,
"Eternal White":0xfaf3dc,
"Eternity":0x2d2f28,
"Ether":0x9eb6b8,
"Etherea":0xa5958f,
"Ethereal":0xf9eecb,
"Ethereal Blue":0x5ca6ce,
"Ethereal Green":0xf1ecca,
"Ethereal Mood":0xcce7eb,
"Ethereal White":0xe6f1f1,
"Etherium Blue":0xb9c4de,
"Ethiopia":0x968777,
"Ethiopian Wolf":0x985629,
"Etiquette":0xe2d0d6,
"Eton Blue":0x96c8a2,
"Etruscan Red":0xa2574b,
"Etude Lilac":0xd5d2d7,
"Eucalipto":0x4bc3a8,
"Eucalyptus":0x329760,
"Eucalyptus Green":0x1e675a,
"Eucalyptus Leaf":0xbad2b8,
"Eucalyptus Wreath":0x88927e,
"Eugenia":0xf2e8d4,
"Eunry":0xcda59c,
"Euphoria":0xeebbff,
"Euphoric Lilac":0xdac7da,
"Euphoric Magenta":0x7f576d,
"Euro Linen":0xf2e8db,
"Eurolinen":0xeee2d3,
"Europe Blue":0x006796,
"European Pine":0x756556,
"Eva Green":0x36ff9a,
"Evaporation":0xd1d5d3,
"Even Evan":0x998371,
"Even Growth":0xb2aa7a,
"Evening Blue":0x2a293e,
"Evening Blush":0xc49087,
"Evening Canyon":0x454341,
"Evening Cityscape":0x4b535c,
"Evening Crimson":0x8e6b76,
"Evening Dove":0xc2bead,
"Evening Dress":0xd1a19b,
"Evening East":0x585e6a,
"Evening Emerald":0x56736f,
"Evening Fizz":0x4d4970,
"Evening Fog":0x8c9997,
"Evening Glory":0x3a4a62,
"Evening Glow":0xfdd792,
"Evening Green":0x7c7a3a,
"Evening Haze":0xbdb8c7,
"Evening Hush":0x7b8ca8,
"Evening in Paris":0x938f9f,
"Evening Lagoon":0x5868ae,
"Evening Lavender":0x4d4469,
"Evening Mauve":0x463f67,
"Evening Mist":0xe3e9e8,
"Evening Pink":0xa7879a,
"Evening Primrose":0xccdb1e,
"Evening Sand":0xddb6ab,
"Evening Sea":0x26604f,
"Evening Shadow":0xa1838b,
"Evening Slipper":0xa99ec1,
"Evening Star":0xffd160,
"Evening Storm":0x465058,
"Evening Sunset":0xedb06d,
"Evening Symphony":0x51637b,
"Evening White":0xd8dbd7,
"Eventide":0x656470,
"Everblooming":0xf0c8b6,
"Everest":0xa0e3e0,
"Everglade":0x264334,
"Everglade Mist":0xb7d7de,
"Evergreen":0x11574a,
"Evergreen Bough":0x535c55,
"Evergreen Boughs":0x50594f,
"Evergreen Field":0x47534f,
"Evergreen Fog":0x95978a,
"Evergreen Forest":0x0e695f,
"Evergreen Trail":0x6f7568,
"Evergreens":0x405840,
"Everlasting":0xa1bed9,
"Everlasting Ice":0xf6fdfa,
"Everlasting Sage":0x949587,
"Evermore":0x463e3b,
"Eversong Orange":0xffa62d,
"Everyday White":0xe4dcd4,
"Everything's Rosy":0xd8aca0,
"Evil Centipede":0xaa2211,
"Evil Eye":0x1100cc,
"Evil Forces":0x770022,
"Evil Sunz Scarlet":0xc2191f,
"Evil-Lyn":0xfed903,
"Evolution":0x704a3d,
"Evora":0x538b89,
"Ewa":0x454042,
"Exaggerated Blush":0xb55067,
"Excalibur":0x676168,
"Excelsior":0x908b85,
"Exciting Orange":0xf0b07a,
"Exclusive Elixir":0xf9f1dd,
"Exclusive Green":0x38493e,
"Exclusive Ivory":0xe2d8c3,
"Exclusive Plum":0x736f78,
"Exclusive Violet":0xb9adbb,
"Exclusively":0x6b515f,
"Exclusively Yours":0xf2aeb8,
"Executive Course":0x8f8a70,
"Existential Angst":0x0a0a0a,
"Exit Light":0x55bb33,
"Exodus Fruit":0x6264dc,
"Exotic Bloom":0xac6292,
"Exotic Blossom":0xfd9d43,
"Exotic Eggplant":0x705660,
"Exotic Escape":0x96d9df,
"Exotic Evening":0x58516e,
"Exotic Flower":0xffa24c,
"Exotic Flowers":0x833f51,
"Exotic Honey":0xc47f33,
"Exotic Incense":0xb86f73,
"Exotic Life":0xae7543,
"Exotic Lilac":0xd198b5,
"Exotic Liras":0xde0c62,
"Exotic Orange":0xf96531,
"Exotic Orchid":0x75566c,
"Exotic Palm":0x909969,
"Exotic Purple":0x6a5078,
"Exotic Violet":0xe1a0cf,
"Exotica":0x938586,
"Expanse":0x777e65,
"Expedition Khaki":0xdbbf90,
"Experience":0x64acb5,
"Exploding Star":0xfed83a,
"Exploration Green":0x55a860,
"Explore Blue":0x30aabc,
"Explorer Blue":0x57a3b3,
"Explorer Khaki":0xb6ac95,
"Exploring Khaki":0xaa9a79,
"Express Blue":0x395a73,
"Expressionism":0x39497b,
"Expressionism Green":0x52bc9a,
"Expressive Plum":0x695c62,
"Exquisite":0xc8a3bb,
"Exquisite Eggplant":0x330033,
"Exquisite Emerald":0x338860,
"Exquisite Turquoise":0x11ccbb,
"Extinct":0x9490b2,
"Extinct Volcano":0x4a4f5a,
"Extra Life":0x6ab417,
"Extra Mile":0x91916d,
"Extra White":0xeeefea,
"Extraordinaire":0xbda6c5,
"Extravagance":0x4e4850,
"Extravehicular Activity":0x0011aa,
"Extraviolet":0x661188,
"Extreme":0x536078,
"Extreme Lavender":0xdfc5d5,
"Extreme Yellow":0xffb729,
"Exuberance":0xe86800,
"Exuberant Orange":0xf0622f,
"Exuberant Pink":0xb54d7f,
"Eye Blue":0x1e80c7,
"Eye Catching":0xddb835,
"Eye Grey":0x607b7b,
"Eye Of Newt":0xae3d3b,
"Eye of the Storm":0xd9e3d9,
"Eye Patch":0x232121,
"Eye Popping Cherry":0xbb0077,
"Eyeball":0xfffbf8,
"Eyefull":0x8db6b7,
"Eyelash Camel":0x553300,
"Eyelash Viper":0xf4c54b,
"Eyelids":0x440000,
"Eyeshadow":0xd9d9ea,
"Eyeshadow Blue":0x6b94c5,
"Eyeshadow Turquoise":0x008980,
"Eyeshadow Viola":0xada6c2,
"Eyre":0x8f9482,
"Fabric of Space":0x341758,
"Fabulous Fantasy":0xba90ad,
"Fabulous Fawn":0xe5c1a3,
"Fabulous Find":0xabe3c9,
"Fabulous Forties":0xddcdab,
"Fabulous Frog":0x88cc00,
"Fabulous Fuchsia":0xee1188,
"Fabulous Grape":0x9083a5,
"Facemark":0xf7cf89,
"Fade to Black":0x676965,
"Faded Blue":0x658cbb,
"Faded Denim":0x798ea4,
"Faded Firebrick":0xe5d9dc,
"Faded Flaxflower":0x9eb4c0,
"Faded Forest":0xe3e2d7,
"Faded Fuchsia":0xede2ee,
"Faded Green":0x7bb274,
"Faded Grey":0xeae8e4,
"Faded Jade":0x427977,
"Faded Jeans":0x5dbdcb,
"Faded Khaki":0xa5975b,
"Faded Light":0xf5e4de,
"Faded Orange":0xf0944d,
"Faded Pink":0xde9dac,
"Faded Poster":0x80dbeb,
"Faded Purple":0x916e99,
"Faded Red":0xd3494e,
"Faded Rose":0xbf6464,
"Faded Sea":0x8d9cae,
"Faded Shells":0xebdcd7,
"Faded Violet":0xddbedd,
"Faded Yellow":0xfeff7f,
"Fading Ember":0xdf691e,
"Fading Fog":0xe8e4e0,
"Fading Horizon":0x442266,
"Fading Love":0xc973a2,
"Fading Night":0x3377cc,
"Fading Parchment":0xece6dc,
"Fading Rose":0xfad0d1,
"Fading Sunset":0xb3b3c2,
"Fahrenheit":0xfbd2bb,
"Faience":0x2a6a8b,
"Faience Green":0x81762b,
"Fail Whale":0x99ccee,
"Faint Clover":0xb2eed3,
"Faint Coral":0xeeded5,
"Faint Fawn":0xe2c59c,
"Faint Fern":0xdadbe0,
"Faint Fuchsia":0xe6deea,
"Faint Gold":0xb59410,
"Faint Green":0xa58b2c,
"Faint Peach":0xf5ddc5,
"Fainting Light":0x1f2847,
"Fair Aqua":0xb8e2dc,
"Fair Green":0x92af88,
"Fair Ivory":0xfce7cf,
"Fair Maiden":0xf1e7dc,
"Fair Orchid":0xc0aac0,
"Fair Pink":0xf3e5dc,
"Fair Spring":0x93977f,
"Fair Winds":0xf3e6d6,
"Fairbank Green":0x9d9c7e,
"Fairest Jade":0xd8e3d7,
"Fairfax Brown":0x61463a,
"Fairstar":0x6ba5a9,
"Fairview Taupe":0xdac7c4,
"Fairway":0x477050,
"Fairway Green":0x26623f,
"Fairway Mist":0xcde8b6,
"Fairy Dust":0xffe8f4,
"Fairy Pink":0xeed3cb,
"Fairy Princess":0xf6dbdd,
"Fairy Sparkles":0xb0e0f7,
"Fairy Tail":0xecdde5,
"Fairy Tale":0xf2c1d1,
"Fairy Wand":0xaea4c1,
"Fairy White":0xded4d8,
"Fairy Wings":0xffebf2,
"Fairy Wren":0x9479af,
"Fairy-Nuff":0xe2d7da,
"Fairytale":0xe5dbeb,
"Fairytale Blue":0x3e9abd,
"Fairytale Dream":0xfacfcc,
"Faith":0xd5ebac,
"Fake Jade":0x13eac9,
"Fake Love":0xcc77ee,
"Falafel":0xaa7711,
"Falcon":0x6e5a5b,
"Falcon Grey":0x898887,
"Falcon Turquoise":0x007062,
"Fall Canyon":0xc69896,
"Fall Chill":0xe1dddb,
"Fall Foliage":0xc28359,
"Fall Gold":0xffbc35,
"Fall Green":0xecfcbd,
"Fall Harvest":0xa78a59,
"Fall Heliotrope":0xa49491,
"Fall in Season":0x7f6144,
"Fall Leaf":0xe5b7a5,
"Fall Leaves":0xc17a3c,
"Fall Mood":0xc2ac9b,
"Fall Straw":0xfee3c5,
"Fallen Leaves":0x917347,
"Fallen Rock":0x807669,
"Falling Leaves":0xa55a3b,
"Falling Snow":0xf0f1e7,
"Falling Star":0xcad5c8,
"Falling Tears":0xc2d7df,
"Fallout Green":0xb6c121,
"Fallow":0xc19a51,
"Fallow Deer":0x9f8d57,
"False Cypress":0x939b88,
"False Morel":0x784d4c,
"False Puce":0xa57e52,
"Falu Red":0x801818,
"Fame Orange":0xdb9c7b,
"Familiar Beige":0xcab3a0,
"Family Tree":0xa7b191,
"Fanatic Fuchsia":0xee1199,
"Fancy Flamingo":0xffb1b0,
"Fancy Flirt":0xb4b780,
"Fancy Fuchsia":0xff0088,
"Fancy Pants":0xf3dae1,
"Fancy Pink":0xf6e9e8,
"Fandangle":0xe4de65,
"Fandango":0xb53389,
"Fandango Pink":0xe04f80,
"Fanfare":0x006d70,
"Fangtooth Fish":0xbbaa97,
"Fanlight":0xf2eeaf,
"Fantan":0x9f7e53,
"Fantasia":0x73788b,
"Fantastic Pink":0xe6c8c9,
"Fantasy":0xf2e6dd,
"Fantasy Console Sky":0x29adff,
"Fantasy Grey":0x8591a2,
"Far Away Grey":0x2d383a,
"Faraway Blue":0xe5eeee,
"Faraway Sky":0x8980c1,
"Farfalle Noodle":0xe5d4c9,
"Farm Fresh":0x8e9b88,
"Farm House":0xefe8d7,
"Farm Straw":0xd5b54c,
"Farmer's Market":0x8f917c,
"Farmers Green":0x96a69f,
"Farmers Milk":0xeee3d6,
"Farmhouse Ochre":0xbd8339,
"Farmhouse Red":0xa34b41,
"Farmyard":0xa6917d,
"Farrago":0x456f6e,
"Farro":0xc1a485,
"Farsighted":0xe5e3ef,
"Fashion Blue":0x006b64,
"Fashion Fuchsia":0xf400a1,
"Fashion Green":0xb3d26d,
"Fashion Grey":0xa29c94,
"Fashion Mauve":0xb5a8a8,
"Fashion Week":0x998988,
"Fashion Yellow":0xedc537,
"Fashionable Gray":0xbdb8b8,
"Fashionably Plum":0xb28ca9,
"Fashionista":0x66616f,
"Fast as the Wind":0xc7cbc8,
"Fast Velvet":0x8b94c7,
"Fat Tuesday":0x352235,
"Fatal Fields":0x008822,
"Fatback":0xfff7ed,
"Fate":0x6ba0bf,
"Fatty Fuchsia":0xee0077,
"Favored One":0xfae6cc,
"Favorite Fudge":0x877252,
"Favorite Jeans":0x8aa3b1,
"Favorite Lavender":0xd3a5d6,
"Favorite Tan":0xc1ae91,
"Favourite Lady":0xe3c5d6,
"Fawn":0xcfaf7b,
"Fawn Brindle":0xa7a094,
"Fawn Brown":0x71452a,
"Feasty Fuchsia":0xee0088,
"Feather Boa":0xf1c9cd,
"Feather Falls":0x606972,
"Feather Fern":0xd5dcd0,
"Feather Gold":0xedd382,
"Feather Green":0xa3d0b6,
"Feather Grey":0xb8ad9e,
"Feather Plume":0xffdcb2,
"Feather Soft Blue":0xa2aebf,
"Feather Stone":0xe3ded2,
"Feather White":0xe7eae5,
"Featherbed":0xafcbe5,
"Featherstone":0xcdc7bb,
"Feathery Blue":0xabc2c7,
"Feathery Lilac":0xece7ed,
"February Frost":0xe0dee3,
"Federal Blue":0x43628b,
"Federal Fund":0x30594b,
"Federation Brown":0x634041,
"Fedora":0x625665,
"Fēi Hóng Scarlet":0xfe420f,
"Feijoa":0xa5d785,
"Feijoa Flower":0xedf2c3,
"Feldgrau":0x4d5d53,
"Feldspar":0xd19275,
"Feldspar Grey":0xbca885,
"Feldspar Silver":0xa0ada9,
"Felicia":0x917292,
"Felicity":0xe5e4df,
"Felix":0x00608f,
"Felt":0x247345,
"Felt Green":0x6fc391,
"Felted Wool":0x979083,
"Felwood Leaves":0x2bc51b,
"Feminin Nightshade":0x4f4352,
"Feminine Fancy":0xc4a8cf,
"Femininity":0xc7c2ce,
"Feminism":0x9d5783,
"Femme Fatale":0x948593,
"Fěn Hóng Pink":0xff6cb5,
"Fence Green":0x09332c,
"Feng Shui":0xd7d9c2,
"Fenland":0xac9d83,
"Fennec Fox":0xdad7c8,
"Fennel Bulb":0xddeebb,
"Fennel Flower":0x77aaff,
"Fennel Seed":0x998456,
"Fennel Stem":0xb1b6a3,
"Fennel Tea":0xd2f4dd,
"Fennelly":0x9a9e80,
"Fenrisian Grey":0xcedee7,
"Fenugreek":0xc0916c,
"Feralas Lime":0x8de07c,
"Fern":0x548d44,
"Fern Canopy":0x758a5f,
"Fern Flower":0x576a7d,
"Fern Frond":0x657220,
"Fern Green":0x008c45,
"Fern Grove":0x837b53,
"Fern Gully":0x595646,
"Fern Leaf":0x99a787,
"Fern Shade":0x797447,
"Ferocious Flamingo":0xee00cc,
"Ferocious Fuchsia":0xaa00cc,
"Ferra":0x876a68,
"Ferrari Red":0xff2800,
"Ferris Wheel":0xad7d76,
"Ferrous":0xcc926c,
"Ferry":0x383e44,
"Fertile Green":0x8b8757,
"Fertility Green":0x66fc00,
"Fervent Brass":0xbc9042,
"Fervent Green":0x469f4e,
"Festering Brown":0xcb8e00,
"Festival":0xeacc4a,
"Festival De Verano":0xb5e1db,
"Festival Fuchsia":0x9e2c6a,
"Festival Green":0x6ea43c,
"Festive Fennec":0xff5566,
"Festive Ferret":0xdfdfe5,
"Festive Green":0x008c6c,
"Festoon Aqua":0xa0bbb8,
"Feta":0xdbe0d0,
"Feverish":0xdd6677,
"Feverish Pink":0xcb3e50,
"Fibre Moss":0xbec0af,
"Ficus":0x3b593a,
"Ficus Elastica":0x006131,
"Fiddle Leaf":0x5f674b,
"Fiddle-Leaf Fig":0xa6c875,
"Fiddlehead Fern":0xc8c387,
"Fiddler":0x5a9589,
"Fiddlesticks":0xbb9fb1,
"Field Blue":0x4477aa,
"Field Day":0xc5e6a4,
"Field Drab":0x6c541e,
"Field Green":0x60b922,
"Field Khaki":0xb1a891,
"Field Maple":0x80884e,
"Field of Wheat":0xdeb699,
"Field Poppy":0xd86f3c,
"Fieldstone":0x807e77,
"Fierce Mantis":0x7fc15c,
"Fiery Brown":0x5d3831,
"Fiery Coral":0xe26058,
"Fiery Flamingo":0xf96d7b,
"Fiery Fuchsia":0xb7386e,
"Fiery Glow":0xf0531c,
"Fiery Orange":0xb1592f,
"Fiery Red":0xd01c1f,
"Fiery Rose":0xff5470,
"Fiery Salmon":0xf76564,
"Fiesta":0xedd8d2,
"Fiesta Blue":0x6fc0b1,
"Fiesta Pink":0xd47194,
"Fiesta Rojo":0xb67c80,
"Fife":0xa9a5c2,
"Fifth Olive-Nue":0x8e8779,
"Fig":0x532d3b,
"Fig Balsamic":0x550022,
"Fig Branches":0x7a634d,
"Fig Fruit Mauve":0xa98691,
"Fig Leaf":0x556b2f,
"Fig Mustard Yellow":0xbb8610,
"Fig Preserves":0xa7989e,
"Fig Tree":0x605f4b,
"Fight the Sunrise":0xff99aa,
"Figue":0x9469a2,
"Figue Pulp":0x962c54,
"Figure Stone":0xeedac3,
"Figurine":0xe4d5c0,
"Fiji":0x00aaac,
"Fiji Coral":0x6b5f68,
"Fiji Green":0x636f22,
"Fiji Palm":0x528d3c,
"Fiji Sands":0xd8caa9,
"Filigree":0xdfe7e8,
"Filigree Green":0xa5af89,
"Film Fest":0x93877c,
"Film Noir":0x473933,
"Filmy Green":0xd1d3c7,
"Filtered Forest":0xb7e1d2,
"Filtered Light":0xb1b2c4,
"Filtered Moon":0xecca9a,
"Filtered Rays":0xd0b064,
"Filthy Brown":0xe8aa08,
"Final Straw":0xd0bf9e,
"Finch":0x75785a,
"Fine Alabaster":0xecd3cb,
"Fine Blue":0xb6e1e1,
"Fine Burgundy":0x815158,
"Fine Grain":0xd8cfc1,
"Fine Greige":0xb5a998,
"Fine Linen":0xfaf5c3,
"Fine Pine":0x008800,
"Fine Porcelain":0xfaf0e1,
"Fine Purple":0x5e548d,
"Fine Sand":0xf1d5ae,
"Fine White":0xfaede1,
"Fine White Sand":0xe4d4c0,
"Fine Wine":0x744e5b,
"Finesse":0x96a8c8,
"Finest Blush":0xdd8888,
"Finest Silk":0xf1e5d7,
"Finger Banana":0xe1c12f,
"Fingerpaint":0x8a7e61,
"Fingerprint":0x555356,
"Finishing Touch":0xcbbfb3,
"Finlandia":0x61755b,
"Finn":0x694554,
"Finnish Fiord":0x5db0be,
"Fioletowy Beige":0xfffce3,
"Fioletowy Purple":0xfc44a3,
"Fiord":0x4b5a62,
"Fiorito":0xbfbfaf,
"Fir":0x3a725f,
"Fir Blue":0x46807b,
"Fir Green":0x67592a,
"Fir Spruce Green":0x6d7969,
"Fire":0x8f3f2a,
"Fire Ant":0xbe6400,
"Fire Axe Red":0xce1620,
"Fire Bolt":0xcc4411,
"Fire Bush":0xe09842,
"Fire Chalk":0xd2806c,
"Fire Chi":0x92353a,
"Fire Coral":0xe3b46f,
"Fire Dance":0xe3d590,
"Fire Dragon Bright":0xf97306,
"Fire Dust":0xb98d68,
"Fire Engine":0xfe0002,
"Fire Flower":0xf68f37,
"Fire Hydrant":0xff0d00,
"Fire Island":0xd95137,
"Fire Lord":0xbb7733,
"Fire Mist":0xfbd9c4,
"Fire Opal":0xfd3c06,
"Fire Orange":0xff8e57,
"Fire Roasted":0x79483e,
"Fire Yellow":0xffb70b,
"Fireball":0xce2029,
"Firebird Tail Lights":0xdd5522,
"Firebrick":0xb22222,
"Firebug":0xcd5c51,
"Firecracker":0xf36944,
"Firecracker Salmon":0xf36363,
"Fired Brick":0x6a2e2a,
"Fired Clay":0x884444,
"Fired Up":0xd37a38,
"Fireflies":0xf6daa7,
"Firefly":0x314643,
"Firefly Glow":0xfff3a1,
"Fireglow":0xd65e40,
"Firelight":0xf9d97b,
"Fireplace Glow":0xd08b73,
"Fireplace Kitten":0xc5c9c7,
"Fireplace Mantel":0x847c70,
"Fireside":0x6e4a44,
"Firewatch":0xee8866,
"Fireweed":0xb38491,
"Fireworks":0x44363d,
"Firm Green":0x47654a,
"Firm Pink":0xda93c1,
"Firmament Blue":0x11353f,
"First Blush":0xf4edec,
"First Colors of Spring":0xdbe64c,
"First Crush":0xf6e2ea,
"First Date":0xf5b1a2,
"First Daughter":0xf7d2d8,
"First Day of School":0xfadba0,
"First Day of Summer":0xf1e798,
"First Frost":0xcfe5f0,
"First Impression":0xf4e5e7,
"First Lady":0xc47967,
"First Landing":0x59a6cf,
"First Light":0xd9e6ee,
"First Lilac":0xe7d6ed,
"First Love":0xcf758a,
"First of July":0xbce6ef,
"First Peach":0xf4cac6,
"First Plum":0xb87592,
"First Post":0x2fbda1,
"First Rain":0xbdd8ec,
"First Shade of Blue":0xcbe1f2,
"First Snow":0xe8eff8,
"First Star":0xdad9d4,
"First Timer Green":0x00e8d8,
"First Tulip":0xffe79c,
"First Waltz":0xd5bcb2,
"Fischer Blue":0x32a0b1,
"Fish Bone":0xe4d9c5,
"Fish Boy":0x11dddd,
"Fish Camp Woods":0x7a9682,
"Fish Ceviche":0xe1e1d5,
"Fish Finger":0xeecc55,
"Fish Net Blue":0x1e446e,
"Fish Pond":0x86c8ed,
"Fisher King":0x5182b9,
"Fishy House":0x1ba590,
"Fist of the North Star":0x225599,
"Fistfull of Green":0xa2a415,
"Fitness Blue":0x5bb9d2,
"Fitzgerald Smoke":0xb3b6b0,
"Five Star":0xffaa4a,
"Fizz":0xb1dbaa,
"Fizzing Whizbees":0xddbcbc,
"Fizzle":0xd8e4de,
"Fjord":0x616242,
"Fjord Blue":0x007290,
"Fjord Green":0x005043,
"Flag Green":0x717c00,
"Flagstaff Green":0xb3bfb0,
"Flagstone":0xacadad,
"Flagstone Quartzite":0x9a9e88,
"Flamboyant":0x129c8b,
"Flamboyant Plum":0x694e52,
"Flame":0xe25822,
"Flame Hawkfish":0x960018,
"Flame Orange":0xfb8b23,
"Flame Pea":0xbe5c48,
"Flame Red":0x86282e,
"Flame Scarlet":0xcd212a,
"Flame Yellow":0xffcf49,
"Flamenco":0xea8645,
"Flaming Flamingo":0xdd55ff,
"Flaming June":0xeebb66,
"Flaming Torch":0xd2864e,
"Flamingo":0xe1634f,
"Flamingo Diva":0xff44dd,
"Flamingo Dream":0xee888b,
"Flamingo Feather":0xf8bdd9,
"Flamingo Fury":0xdf01f0,
"Flamingo Peach":0xf6e2d8,
"Flamingo Pink":0xfc8eac,
"Flamingo Queen":0xcc33ff,
"Flamingo Red":0xef8e87,
"Flan":0xf6e3b4,
"Flannel Grey":0xaeadac,
"Flannel Pajamas":0x8b8d98,
"Flapper Dance":0x495762,
"Flare Gun":0xff4519,
"Flash Gitz Yellow":0xfffb05,
"Flash in the Pan":0xff9977,
"Flash of Orange":0xffaa00,
"Flashlight":0xf9eed6,
"Flashman":0x7cbd85,
"Flashpoint":0xf9f2d1,
"Flashy Sapphire":0x2c538a,
"Flat Aluminum":0xc3c6cd,
"Flat Blue":0x3c73a8,
"Flat Brown":0x754600,
"Flat Earth":0xaa5533,
"Flat Flesh":0xf7d48f,
"Flat Green":0x699d4c,
"Flat Yellow":0xfff005,
"Flattered Flamingo":0xee6655,
"Flattering Peach":0xf4d3b3,
"Flattery":0x6b4424,
"Flavescent":0xf7e98e,
"Flavoparmelia Caperata":0x8fb67b,
"Flax":0xeedc82,
"Flax Beige":0xd4c3b3,
"Flax Bloom":0xd2d8f4,
"Flax Fiber":0xe0d68e,
"Flax Fibre Grey":0xb7a99a,
"Flax Flower":0x5577aa,
"Flax Flower Blue":0x4499dd,
"Flax Smoke":0x7b8265,
"Flax Straw":0xcbaa7d,
"Flax-Flower Blue":0x6f88af,
"Flaxen":0xfbecc9,
"Flaxen Fair":0xe3ddbd,
"Flaxen Field":0xbba684,
"Flaxseed":0xf7e6c6,
"Flayed One Flesh":0xfcfcde,
"Fleck":0x97bbe1,
"Fleeting Green":0xd8e2d8,
"Flemish Blue":0xadd0e0,
"Flesh":0xffcbc4,
"Flesh Fly":0x894585,
"Flesh Grey":0xaaa197,
"Flesh Pink":0xf9cbd3,
"Flesh Red":0xe9c49d,
"Flesh Wash":0xce8c42,
"Fleshtone Shade Wash":0xcf9346,
"Fleur de Sel":0xdcddd8,
"Fleur-De-Lis":0xb090c7,
"Flexible Gray":0xb1a3a1,
"Flickering Firefly":0xf8f6e6,
"Flickering Flame":0xaa6e49,
"Flickering Gold":0xc6a668,
"Flickering Light":0xfff1dc,
"Flickering Sea":0x5566ee,
"Flickery C64":0x4f81ff,
"Flickery CRT Green":0x90f215,
"Flickr Blue":0x216bd6,
"Flickr Pink":0xfb0081,
"Flier Lie":0xcdb891,
"Flight Time":0xa3b8ce,
"Flinders Green":0x6d7058,
"Fling Green":0x8ecfd0,
"Flint":0x716e61,
"Flint Corn Red":0xd9623b,
"Flint Grey":0xa09c98,
"Flint Purple":0x42424d,
"Flint Rock":0x989493,
"Flint Shard":0x8f9395,
"Flint Smoke":0xa8b2b1,
"Flintstone":0x677283,
"Flintstone Blue":0x434252,
"Flip":0x45747e,
"Flip a Coin":0xccddcc,
"Flip-Flop":0xf2c4a7,
"Flipper":0x7f726b,
"Flirt":0x7a2e4d,
"Flirt Alert":0xbe3c37,
"Flirtatious":0xffd637,
"Flirtatious Flamingo":0xcc22ff,
"Flirtatious Indigo Tea":0x473f2d,
"Flirty Pink":0x9e88b1,
"Flirty Salmon":0xfa7069,
"Floating Blue":0xb0c9cd,
"Floating Feather":0xe9d8c2,
"Floating Island":0xece5cf,
"Floating Lily":0xedebce,
"Floating Lily Pad":0xccc7a1,
"Flood":0x6677bb,
"Flood Mud":0x877966,
"Flood Out":0x579dab,
"Floppy Disk":0x110044,
"Flor Lila":0xe0e0eb,
"Flora":0x73fa79,
"Flora Green":0x91ad8a,
"Floral Arrangement":0xc6ac9f,
"Floral Bluff":0xe7cfb9,
"Floral Bouquet":0xbacb7c,
"Floral Leaf":0xffb94e,
"Floral Linen":0xf5e2de,
"Floral Scent":0xeeede9,
"Floral Tapestry":0xc39191,
"Floral White":0xfffaf0,
"Florence":0x96b576,
"Florence Brown":0x835740,
"Florence Red":0x753f38,
"Florentine Brown":0x7a5544,
"Florentine Clay":0xc1937a,
"Florentine Lapis":0x1c5798,
"Florida Grey":0xbea4a2,
"Florida Keys":0x56beab,
"Florida Mango":0xed9f6c,
"Florida Sunrise":0xf7aa6f,
"Florida Turquoise":0x6bb8b1,
"Florida Waters":0x2a4983,
"Floriography":0xa54049,
"Floss":0xd7b3b9,
"Flotation":0x7bb0ba,
"Flounce":0x4a8791,
"Flour Sack":0xb9b297,
"Flourish":0xebdc9c,
"Flower Bulb":0xd9e8c9,
"Flower Centre":0xfde6c6,
"Flower Field":0xd9a96f,
"Flower Girl":0xf498ad,
"Flower Girl Dress":0xede7e6,
"Flower Hat Jellyfish":0xf9d593,
"Flower of Oahu":0xf5dfc5,
"Flower Pot":0x8f4438,
"Flower Spell":0xffc9d7,
"Flower Stem":0xb5d5b0,
"Flower Wood":0x988378,
"Flowerbed":0xffebda,
"Flowering Cactus":0xa2d4bd,
"Flowering Chestnut":0x875657,
"Flowering Raspberry":0xa16c94,
"Flowering Reed":0xe1d8b8,
"Flowerpot":0xd8b0a0,
"Flowers of May":0xe3d7e3,
"Flowery":0xe4dcbf,
"Flowing Breeze":0xb9c6cb,
"Flowing River":0x335e6f,
"Fluffy Duckling":0xfcdf39,
"Fluffy Pink":0xf7d6cb,
"Fluid Blue":0xc5d6eb,
"Fluor Spar":0xa77d35,
"Fluorescence":0x89d178,
"Fluorescent Fire":0x984427,
"Fluorescent Green":0x08ff08,
"Fluorescent Lime":0xbdc233,
"Fluorescent Orange":0xffcf00,
"Fluorescent Pink":0xfe1493,
"Fluorescent Red":0xff5555,
"Fluorescent Red Orange":0xfc8427,
"Fluorescent Turquoise":0x00fdff,
"Fluorescent Yellow":0xccff02,
"Fluorite Blue":0xb4ccc2,
"Fluorite Green":0x699158,
"Fluro Green":0x0aff02,
"Flurries":0xf2ede3,
"Flush Mahogany":0xca2425,
"Flush Orange":0xff6f01,
"Flush Pink":0xf8cbc4,
"Flushed":0xdd5555,
"Fly a Kite":0xc8daf5,
"Fly Agaric":0xff2052,
"Fly by Night":0x1c1e4d,
"Flying Carpet":0x787489,
"Flying Fish":0x5376ab,
"Flying Fish Blue":0x024aca,
"Flyway":0x5db3d4,
"Foam":0xd0eae8,
"Foam Green":0x90fda9,
"Foaming Surf":0x90d1dd,
"Foamy Milk":0xf7f4f7,
"Focus":0xe5e0d2,
"Focus on Light":0xfef9d3,
"Focus Point":0x91c3bd,
"Fog":0xd6d7d2,
"Fog Beacon":0xd8d6d1,
"Fog Green":0xc2cbb4,
"Fog of War":0x112233,
"Fog White":0xf1efe4,
"Foggy Amethyst":0x57317e,
"Foggy Blue":0x99aebb,
"Foggy Day":0xe7e3db,
"Foggy Dew":0xd1d5d0,
"Foggy Grey":0xa7a69d,
"Foggy Heath":0xe2c9ff,
"Foggy London":0x5c5658,
"Foggy Love":0xd5c7e8,
"Foggy Mist":0xc8d1cc,
"Foggy Morn":0xcad0ce,
"Foggy Night":0xa79c8e,
"Foggy Quartz":0xbfa2a1,
"Fogtown":0xeef0e7,
"Foil":0xc0c3c4,
"Foille":0xb0b99c,
"Foliage":0x95b388,
"Foliage Green":0x3e6f58,
"Folk Guitar":0x7a634f,
"Folk Song":0x65a19f,
"Folk Tale":0xb2e1bc,
"Folk Tales":0xa5c1b6,
"Folklore":0x684141,
"Folkstone":0x6d6562,
"Folkstone Grey":0x626879,
"Folksy Gold":0xd69969,
"Follow the Leader":0xf7e5d0,
"Folly":0xfd004d,
"Fond de Teint":0xffaaaa,
"Fond Memory":0xc8bcb7,
"Fondue":0xc99f97,
"Fondue Fudge":0x5d4236,
"Fool's Gold":0xcad175,
"Football":0x825736,
"Football Field":0x7eaf34,
"Foothill Drive":0xcab48e,
"Foothills":0xe1cfa5,
"Footie Pajamas":0xe6cee6,
"For the Love of Hue":0x457e87,
"Forbidden Blackberry":0x323f75,
"Forbidden Forest":0x215354,
"Forbidden Fruit":0xfe7b7c,
"Forbidden Red":0x8a4646,
"Forbidden Thrill":0x856363,
"Force of Nature":0xd5ce69,
"Forceful Orange":0xf29312,
"Foresight":0x94a8d3,
"Forest":0x0b5509,
"Forest Berry":0x956378,
"Forest Biome":0x184a45,
"Forest Blues":0x0d4462,
"Forest Bound":0x738f50,
"Forest Canopy":0x969582,
"Forest Edge":0x627b72,
"Forest Fern":0x63b76c,
"Forest Floor":0x555142,
"Forest Floor Khaki":0x78766d,
"Forest Found":0xe1dfbb,
"Forest Frolic":0x88bb95,
"Forest Fruit Pink":0x68393b,
"Forest Fruit Red":0x6e2759,
"Forest Green":0x154406,
"Forest Greenery":0x3e645b,
"Forest Lichen":0x9aa22b,
"Forest Maid":0x52b963,
"Forest Moss":0x858f83,
"Forest Night":0x434237,
"Forest Path":0x708d6c,
"Forest Rain":0x216957,
"Forest Ride":0x006800,
"Forest Ridge":0x555d46,
"Forest Shade":0x91ac80,
"Forest Spirit":0x667028,
"Forest Splendor":0x016e61,
"Forest Tapestry":0xa4ba8a,
"Forest Tent":0xbba748,
"Forester":0x9aa77c,
"Forestwood":0x4d5346,
"Forever Blue":0x899bb8,
"Forever Denim":0x778590,
"Forever Fairytale":0xd2bbb2,
"Forever Faithful":0xefe6e1,
"Forever Green":0xaab4a7,
"Forever Lilac":0xafa5c7,
"Forged Iron":0x48464a,
"Forged Steel":0x5b5b59,
"Forget-Me-Not":0x0087bd,
"Forget-Me-Not Blue":0x358094,
"Forgive Quickly":0xe1e1be,
"Forgiven Sin":0xff1199,
"Forgotten Blue":0xc0e5ec,
"Forgotten Gold":0xc7b89f,
"Forgotten Mosque":0xe2d9db,
"Forgotten Pink":0xffd9d6,
"Forgotten Purple":0x9878f8,
"Forgotten Sunset":0xfdd5b1,
"Formal Affair":0x848391,
"Formal Garden":0x3a984d,
"Formal Grey":0x97969a,
"Formal Maroon":0x70474b,
"Forsythia":0xffc801,
"Forsythia Blossom":0xf6d76e,
"Forsythia Bud":0xbbcc55,
"Fortitude":0xc6c5c1,
"Fortress Grey":0xb8b8b8,
"Fortress Stone":0xc5c0b0,
"Fortune":0x9f97a3,
"Fortune Cookie":0xe0c5a1,
"Fortune Red":0xb0534d,
"Fortune's Prize":0xdaa994,
"Forward Fuchsia":0x92345b,
"Fossil":0x806f63,
"Fossil Butte":0xa78f65,
"Fossil Green":0x6c6a43,
"Fossil Sand":0xd2c8bb,
"Fossil Stone":0xe3ddcc,
"Fossil Tan":0xd1af90,
"Fossilized":0xb6b8b0,
"Fossilized Leaf":0x756a43,
"Foul Green":0x85c7a1,
"Foundation":0xf8e8c5,
"Foundation White":0xefeeff,
"Fountain":0x56b5ca,
"Fountain Blue":0x65adb2,
"Fountain City":0x9cd4cf,
"Fountain Frolic":0xe4e4c5,
"Fountain Spout":0xcdebec,
"Fountains of Budapest":0xb9def0,
"Four Leaf Clover":0x738f5d,
"Fox":0xc38743,
"Fox Hill":0xc8aa92,
"Fox Red":0xca4e33,
"Fox Tails":0xdd8800,
"Foxen":0xbf8e7f,
"Foxfire Brown":0x9f6949,
"Foxflower Viola":0xa2acc5,
"Foxglove":0xb98391,
"Foxgloves":0xc6c0ca,
"Foxhall Green":0x454b40,
"Foxtail":0xbc896e,
"Foxy":0xa85e53,
"Foxy Fuchsia":0x9f00c5,
"Foxy Lady":0xd5a6ad,
"Foxy Pink":0xdb95ab,
"Fozzie Bear":0x70625c,
"Fragile":0xbbb8d0,
"Fragile Beauty":0xe7d7c6,
"Fragile Fern":0xeff2db,
"Fragrant Cherry":0x8e545c,
"Fragrant Cloves":0xac5e3a,
"Fragrant Jasmine":0xfbf6e7,
"Fragrant Lilac":0xceadbe,
"Fragrant Satchel":0xa99fba,
"Fragrant Snowbell":0xd5c5d4,
"Fragrant Wand":0xadb1c1,
"Frail Fuchsia":0xee88ee,
"Framboise":0xe40058,
"Frangipane":0xf4d5b2,
"Frangipani":0xffd7a0,
"Frank Blue":0x225288,
"Frank Lloyd White":0xefebdb,
"Frankenstein":0x7ba05b,
"Frankly Earnest":0xe2dbca,
"Frappe":0xd1b7a0,
"Freckles":0xd78775,
"Free Green":0x74a690,
"Free Reign":0xd1cdca,
"Free Speech Aquamarine":0x029d74,
"Free Speech Blue":0x4156c5,
"Free Speech Green":0x09f911,
"Free Speech Magenta":0xe35bd8,
"Free Speech Red":0xc00000,
"Free Spirit":0xdeeeed,
"Freedom":0x3b5e68,
"Freedom Found":0x657682,
"Freefall":0x565266,
"Freesia":0xf3c12c,
"Freesia Purple":0xb3b0d4,
"Freezing Vapor":0xd4e9f5,
"Freezy Breezy":0x99eeee,
"Freezy Wind":0x99ffdd,
"Freinacht Black":0x232f36,
"French 75":0xf9f3d5,
"French Beige":0xa67b50,
"French Bistre":0x856d4d,
"French Blue":0x0072bb,
"French Bustle":0xf2d5d4,
"French Castle":0xcdc0b7,
"French Colony":0x90a1aa,
"French Court":0x6a8ea2,
"French Creme":0xf2e6cf,
"French Diamond":0x597191,
"French Fuchsia":0xfd3f92,
"French Grey":0xbfbdc1,
"French Grey Linen":0xcac8b6,
"French Heirloom":0xe9e2e0,
"French Lavender":0xdfc9d1,
"French Lilac":0xdeb7d9,
"French Lilac Blue":0xadbae3,
"French Lime":0xc0ff00,
"French Limestone":0xc9d6c2,
"French Manicure":0xfee6dc,
"French Market":0xa2c7a3,
"French Mauve":0xd473d4,
"French Mirage Blue":0x446688,
"French Moire":0x9fbbc3,
"French Oak":0xbb9e7c,
"French Pale Gold":0xd4ab60,
"French Parsley":0x9ea07d,
"French Pass":0xa4d2e0,
"French Pastry":0xc4aa92,
"French Pear":0x9e9f7d,
"French Pink":0xfd6c9e,
"French Plum":0x811453,
"French Porcelain":0xf6f4f6,
"French Porcelain Clay":0xfaf1d7,
"French Puce":0x4e1609,
"French Raspberry":0xc72c48,
"French Roast":0x58423f,
"French Rose":0xf64a8a,
"French Shutter":0xbab6a0,
"French Silver":0xb8bcbc,
"French Sky Blue":0x77b5fe,
"French Tarragon":0x667255,
"French Taupe":0xd3c2bf,
"French Toast":0xdd8822,
"French Truffle":0x896d61,
"French Vanilla":0xefe1a7,
"French Vanilla Sorbet":0xfbe8ce,
"French Violet":0x8806ce,
"French White":0xf1e7db,
"French Wine":0xac1e44,
"French Winery":0x991133,
"Frenzied Red":0x814a5c,
"Frenzy":0xfeb101,
"Fresco":0xf4dbd9,
"Fresco Blue":0x034c67,
"Fresco Cream":0xfcc9a6,
"Fresco Green":0x7bd9ad,
"Fresh Acorn":0xd2693e,
"Fresh Air":0xa6e7ff,
"Fresh Apple":0x97a346,
"Fresh Apricot":0xffd7a5,
"Fresh Artichoke":0x7c8447,
"Fresh Auburn":0xa52a24,
"Fresh Baked Bread":0xf8d7be,
"Fresh Basil":0x5c5f4b,
"Fresh Blue":0x8bd6e2,
"Fresh Blue of Bel Air":0x069af3,
"Fresh Breeze":0xbeeddc,
"Fresh Brew":0xb8aa7d,
"Fresh Cantaloupe":0xff9c68,
"Fresh Cedar":0xa77f74,
"Fresh Cinnamon":0x995511,
"Fresh Clay":0xbe8035,
"Fresh Cream":0xfcf7e0,
"Fresh Croissant":0xcc9f76,
"Fresh Cut":0xf2003c,
"Fresh Cut Grass":0x91cb7d,
"Fresh Day":0xdfe9e5,
"Fresh Dew":0xf0f4e5,
"Fresh Dough":0xf2ebe6,
"Fresh Eggplant":0x4f467e,
"Fresh Eggs":0xfaf4ce,
"Fresh Eucalyptus":0xadbcb4,
"Fresh Frappe":0xdbe69d,
"Fresh Gingerbread":0xd3691f,
"Fresh Granny Smith":0x7ff217,
"Fresh Green":0x69d84f,
"Fresh Greens":0x3fad71,
"Fresh Grown":0xf0f7c4,
"Fresh Guacamole":0xa2b07e,
"Fresh Gum":0xffaadd,
"Fresh Heather":0xd1c1dd,
"Fresh Herb":0x77913b,
"Fresh Herbs":0x3a5f49,
"Fresh Honeydew":0xf6efc5,
"Fresh Ivy Green":0x006a5b,
"Fresh Lavender":0x8e90b4,
"Fresh Lawn":0x88aa00,
"Fresh Leaf":0x93ef10,
"Fresh Lemonade":0xece678,
"Fresh Lettuce":0xb2d58c,
"Fresh Lime":0xd8f1cb,
"Fresh Linen":0xebe8da,
"Fresh Mint":0x2a5443,
"Fresh Nectar":0xdaa674,
"Fresh Neon Pink":0xff11ff,
"Fresh Olive":0xa69e73,
"Fresh Onion":0x5b8930,
"Fresh Oregano":0x4faa6c,
"Fresh Peaches":0xf6b98a,
"Fresh Piglet":0xfddde6,
"Fresh Pine":0x4f5b49,
"Fresh Pineapple":0xf3d64f,
"Fresh Pink":0xe19091,
"Fresh Pink Lemonade":0xd2adb5,
"Fresh Popcorn":0xf4f3e9,
"Fresh Praline":0xe7bb95,
"Fresh Salmon":0xff7f6a,
"Fresh Sawdust":0xc8a278,
"Fresh Scent":0xf1c11c,
"Fresh Snow":0xf6efe1,
"Fresh Sod":0x91a085,
"Fresh Soft Blue":0x6ab9bb,
"Fresh Sprout":0xc7c176,
"Fresh Squeezed":0xffad00,
"Fresh Start":0xcfd4a4,
"Fresh Straw":0xeecc66,
"Fresh Take":0x505b93,
"Fresh Thyme":0xaebda8,
"Fresh Tone":0xb2c7c0,
"Fresh Turquoise":0x40e0d0,
"Fresh Up":0xdfebb1,
"Fresh Water":0xc6e3f7,
"Fresh Watermelon":0xdf9689,
"Fresh Willow":0xe1d9aa,
"Fresh Wood Ashes":0xeae6cc,
"Fresh Yellow":0xf7e190,
"Fresh Zest":0xf5e9cf,
"Freshly Roasted Coffee":0x663322,
"Freshman":0xe6f2c4,
"Freshmint":0xd9f4ea,
"Freshwater":0x4da6b2,
"Freshwater Marsh":0x535644,
"Fretwire":0xb2a490,
"Friar Brown":0x6e493a,
"Friar Grey":0x807e79,
"Friar Tuck":0xddb994,
"Friar's Brown":0x5e5241,
"Fricassée":0xffe6c2,
"Friend Flesh":0xf1a4b7,
"Friendly Basilisk":0xe2f5e1,
"Friendly Homestead":0xc8a992,
"Friendly Yellow":0xf5e0b1,
"Friends":0xe8c5c1,
"Friendship":0xfed8c2,
"Fright Night":0x004499,
"Frijid Pink":0xee77ff,
"Frilled Shark":0x939fa9,
"Frills":0x8fa6c1,
"Fringy Flower":0xb4e1bb,
"Frisky":0xccdda1,
"Frisky Blue":0x7bb1c9,
"Frittata":0xfeebc8,
"Frivolous Folly":0xcfd2c7,
"Frog":0x58bc08,
"Frog Green":0x00693c,
"Frog Hollow":0x7da270,
"Frog Prince":0xbbd75a,
"Frog's Legs":0x8c8449,
"Frogger":0x8cd612,
"Frolic":0xf9e7e1,
"Froly":0xe56d75,
"Frond":0x7b7f56,
"Front Porch":0xcdccc5,
"Frontier":0x314a49,
"Frontier Brown":0x9a8172,
"Frontier Fort":0xc3b19f,
"Frontier Land":0xbca59a,
"Frontier Shadow":0x655a4a,
"Frontier Shingle":0x7b5f46,
"Frost":0xe1e4c5,
"Frost Bite":0xf6f0e5,
"Frost Blue":0x5d9aa6,
"Frost Grey":0x848283,
"Frost Gum":0x8ecb9e,
"Frost Wind":0xdaebef,
"Frostbite":0xacfffc,
"Frosted Almond":0xd2c2ac,
"Frosted Blueberries":0x0055dd,
"Frosted Cocoa":0xa89c91,
"Frosted Emerald":0x78b185,
"Frosted Fern":0xa7a796,
"Frosted Garden":0xe2f7d9,
"Frosted Glass":0xeaf0f0,
"Frosted Grape":0xd4c4d2,
"Frosted Iris":0xb1b9d9,
"Frosted Jade":0xc2d1c4,
"Frosted Juniper":0xf0f4eb,
"Frosted Lemon":0xffedc7,
"Frosted Lilac":0xd3d1dc,
"Frosted Mint":0xe2f2e4,
"Frosted Pomegranate":0xad3d46,
"Frosted Sage":0xc6d1c4,
"Frosted Silver":0xc5c9c5,
"Frosted Sugar":0xd5bcc2,
"Frosted Toffee":0xf1dbbf,
"Frosted Tulip":0xf6d8d7,
"Frostee":0xdbe5d2,
"Frosting Cream":0xfffbee,
"Frostini":0xdbf2d9,
"Frostproof":0xd1f0f6,
"Frostwork":0xeff1e3,
"Frosty Dawn":0xcbe9c9,
"Frosty Day":0xccebf5,
"Frosty Fog":0xdee1e9,
"Frosty Glade":0xa0c0bf,
"Frosty Green":0xa3b5a6,
"Frosty Mint":0xe2f7f1,
"Frosty Morning":0xefe8e8,
"Frosty Pine":0xc7cfbe,
"Frosty Soft Blue":0xb4e0de,
"Frosty Spruce":0x578270,
"Frosty White":0xddddd6,
"Frosty White Blue":0xcce9e4,
"Froth":0xc6b8ae,
"Frothy Milk":0xfaede6,
"Frothy Surf":0xe7ebe6,
"Frozen Banana":0xfbf5d6,
"Frozen Blue":0xa5c5d9,
"Frozen Civilization":0xe1f5e5,
"Frozen Custard":0xfbeabd,
"Frozen Dew":0xd8cfb2,
"Frozen Edamame":0x9ca48a,
"Frozen Forest":0xcfe8b6,
"Frozen Frappe":0xddc5d2,
"Frozen Fruit":0xe1ca99,
"Frozen Grass":0xdeeadc,
"Frozen Lake":0x7b9cb3,
"Frozen Mammoth":0xdfd9da,
"Frozen Margarita":0xdbe2cc,
"Frozen Mint":0xd8e8e6,
"Frozen Moss Green":0xaddfad,
"Frozen Pea":0xc4ead5,
"Frozen Pond":0xa5b4ae,
"Frozen Salmon":0xfea993,
"Frozen State":0x26f7fd,
"Frozen Statues":0xe1dee5,
"Frozen Stream":0x30555d,
"Frozen Tomato":0xdd5533,
"Frozen Tundra":0xa3bfcb,
"Frozen Turquoise":0x53f6ff,
"Frozen Wave":0x56acca,
"Frugal":0xa5d7b2,
"Fruit Bowl":0xfdc9d0,
"Fruit Cocktail":0xd08995,
"Fruit Dove":0xce5b78,
"Fruit Of Passion":0x946985,
"Fruit Red":0xfa8970,
"Fruit Salad":0x4ba351,
"Fruit Shake":0xf39d8d,
"Fruit Yard":0x604241,
"Fruit Yellow":0xeac064,
"Fruitful Orchard":0x773b3e,
"Fruitless Fig Tree":0x448822,
"Fruity Licious":0xf69092,
"Fuchsia":0xed0dd9,
"Fuchsia Berries":0x333322,
"Fuchsia Blue":0x7a58c1,
"Fuchsia Blush":0xe47cb8,
"Fuchsia Fever":0xff5599,
"Fuchsia Flair":0xbb22bb,
"Fuchsia Flash":0xdd55cc,
"Fuchsia Flock":0xab446b,
"Fuchsia Flourish":0xbb2299,
"Fúchsia Intenso":0xd800cc,
"Fuchsia Kiss":0xcb6e98,
"Fuchsia Nebula":0x7722aa,
"Fuchsia Pink":0xff77ff,
"Fuchsia Purple":0xd33479,
"Fuchsia Red":0xab3475,
"Fuchsia Rose":0xc74375,
"Fuchsia Tint":0xc255c1,
"Fuchsite":0xc3d9ce,
"Fuchsite Green":0x5b7e70,
"Fudge":0x493338,
"Fudge Bar":0x997964,
"Fudge Truffle":0x604a3f,
"Fudgesicle":0xd46bac,
"Fuegan Orange":0xc77e4d,
"Fuego":0xee5533,
"Fuego Nuevo":0xee6622,
"Fuego Verde":0xc2d62e,
"Fuel Town":0x596472,
"Fuel Yellow":0xd19033,
"Fugitive Flamingo":0xee66aa,
"Fuji Peak":0xf6eee2,
"Fuji Purple":0x89729e,
"Fuji Snow":0xf1efe8,
"Fujinezumi":0x766980,
"Fulgrim Pink":0xf5b3ce,
"Fulgurite Copper":0xe6b77e,
"Full Bloom":0xfbcdc3,
"Full City Roast":0x662222,
"Full Cream":0xfae4ce,
"Full Glass":0x916b77,
"Full Moon":0xf4f3e0,
"Full Moon Grey":0xcfeae9,
"Full Of Life":0xde5f2f,
"Full Yellow":0xf9bc4f,
"Fully Purple":0x514c7e,
"Fulvous":0xe48400,
"Fun and Games":0x33789c,
"Fun Blue":0x335083,
"Fun Green":0x15633d,
"Fun Yellow":0xf7e594,
"Funchal Yellow":0xb6884d,
"Functional Blue":0x3f6086,
"Functional Gray":0xaba39a,
"Fundy Bay":0xcdd2c9,
"Fungal Hallucinations":0xcc00dd,
"Fungi":0x8f8177,
"Funhouse":0xf3d9dc,
"Funk":0x3ea380,
"Funki Porcini":0xee9999,
"Funkie Friday":0x4a3c4a,
"Funky Frog":0x98bd3c,
"Funky Yellow":0xedd26f,
"Funnel Cloud":0x113366,
"Funny Face":0xedc8ce,
"Furious Frog":0x55ee00,
"Furious Fuchsia":0xee2277,
"Furious Red":0xff1100,
"Furnace":0xdd4124,
"Furry Lady":0xf5efeb,
"Furry Lion":0xf09338,
"Fury":0xff0011,
"Fuschia Flair":0xa44769,
"Fuscia Fizz":0xb56e91,
"Fuscous Grey":0x54534d,
"Fusilli":0xf1e8d6,
"Fusion":0xb0ae26,
"Fusion Coral":0xff8576,
"Fusion Red":0xff6163,
"Fussy Pink":0xe6a3b9,
"Futaai Indigo":0x614e6e,
"Futon":0xedf6db,
"Future":0x15abbe,
"Future Hair":0x20b562,
"Future Vision":0xbcb6bc,
"Futuristic":0x998da8,
"Fuzzy Duckling":0xffea70,
"Fuzzy Navel":0xffd69f,
"Fuzzy Peach":0xffbb8f,
"Fuzzy Sheep":0xf0e9d1,
"Fuzzy Unicorn":0xeae3db,
"Fuzzy Wuzzy":0xcc6666,
"Fuzzy Wuzzy Brown":0xc45655,
"Fynbos Leaf":0xaeb1ac,
"Gable Green":0x2c4641,
"Gaboon Viper":0x8c6450,
"Gabriel's Light":0xdacca8,
"Gabriel's Torch":0xf8e6c6,
"Gadabout":0xffc4ae,
"Gaelic Garden":0xa5b3ab,
"Gaharā Lāl":0xac0c20,
"Gaia":0xd3bc9e,
"Gaiety":0xf4e4e5,
"Gainsboro":0xdcdcdc,
"Gala Ball":0x785d7a,
"Gala Pink":0xb04b63,
"Galactic Civilization":0x442288,
"Galactic Highway":0x3311bb,
"Galactic Mediator":0xe0dfdb,
"Galactic Tint":0xc0c4c6,
"Galactic Wonder":0x442255,
"Galactica":0xc4dde2,
"Galago":0x95a69f,
"Galah":0xd28083,
"Galapagos":0x085f6d,
"Galapagos Green":0x29685f,
"Galaxy Blue":0x2a4b7c,
"Galaxy Green":0x79afad,
"Gale Force":0x35454e,
"Gale of the Wind":0x007844,
"Galenite Blue":0x374b52,
"Gallant Gold":0xa4763c,
"Gallant Green":0x99aa66,
"Galleon Blue":0x3f95bf,
"Gallery":0xdcd7d1,
"Gallery Blue":0x9bbce4,
"Gallery Green":0x88a385,
"Gallery Grey":0xc5c2be,
"Gallery Red":0x935a59,
"Gallery Taupe":0xd0c5b8,
"Gallery White":0xeaebe4,
"Galley Gold":0xd5aa5e,
"Galliano":0xd8a723,
"Gallstone Yellow":0xa36629,
"Galveston Tan":0xe8c8b8,
"Galway":0xc4ddbb,
"Galway Bay":0x95a7a4,
"Gamboge":0xe49b0f,
"Gamboge Brown":0x996600,
"Gamboge Yellow":0xe6d058,
"Gambol Gold":0xe1b047,
"Game Over":0x7e8181,
"Gameboy Contrast":0x0f380f,
"Gameboy Light":0x9bbc0f,
"Gameboy Screen":0x8bac0f,
"Gameboy Shade":0x306230,
"Gamin":0xbfd1af,
"Gǎn Lǎn Huáng Olive":0xc9ff27,
"Gǎn Lǎn Lǜ Green":0x658b38,
"Ganache":0x34292a,
"Gangsters Gold":0xffdd22,
"Ganon Blue":0xa4e4fc,
"Ganymede":0x8b7d82,
"Garbanzo Bean":0xf1d5a5,
"Garbanzo Paste":0xeec684,
"Garden Aroma":0x9c6989,
"Garden Country":0xd5c5a8,
"Garden Cucumber":0x506a48,
"Garden Dawn":0xf1f8ec,
"Garden Fairy":0xccd4ec,
"Garden Flower":0xa892a8,
"Garden Fountain":0x729588,
"Garden Gate":0xdadcc1,
"Garden Gazebo":0xabc0bb,
"Garden Glade":0xdcd8a8,
"Garden Glory":0xffc1d0,
"Garden Glow":0x7dcc98,
"Garden Gnome Red":0x9b2002,
"Garden Goddess":0x99cea0,
"Garden Green":0x495e35,
"Garden Greenery":0x658369,
"Garden Grove":0x5e7f57,
"Garden Hedge":0x6f7d6d,
"Garden Lattice":0xe1d4b4,
"Garden Lettuce Green":0x87762b,
"Garden Medley":0x28a873,
"Garden of Eden":0x7fa771,
"Garden Pansy":0xa890b8,
"Garden Party":0xe3a4b8,
"Garden Path":0x424330,
"Garden Pebble":0xe4e4d5,
"Garden Picket":0xe4d195,
"Garden Plum":0x9d8292,
"Garden Pond":0xafc09e,
"Garden Promenade":0xa4a99b,
"Garden Room":0xaccfa9,
"Garden Rose White":0xf7ead4,
"Garden Salt Green":0xa18b62,
"Garden Seat":0xebe6c7,
"Garden Shadow":0x334400,
"Garden Shed":0xd6efda,
"Garden Snail":0xcdb1ab,
"Garden Spot":0xb1ca95,
"Garden Sprout":0xab863a,
"Garden Statue":0xbfd4c4,
"Garden Stroll":0x7dc683,
"Garden Swing":0x8cbd97,
"Garden Topiary":0x3e524b,
"Garden Twilight":0xa3bbb3,
"Garden View":0x89b89a,
"Garden Vista":0x9fb1ab,
"Garden Wall":0xaea492,
"Garden Weed":0x786e38,
"Gardener Green":0x5e602a,
"Gardener's Soil":0x5c534d,
"Gardenia":0xf1e8df,
"Gardening":0xacba8d,
"Gardens Sericourt":0x337700,
"Garfield":0xa75429,
"Gargantua":0xeeee55,
"Gargoyle":0xabb39e,
"Gargoyle Gas":0xffdf46,
"Garish Blue":0x00a4b1,
"Garish Green":0x51bf8a,
"Garland":0x69887b,
"Garlic Beige":0xb0aaa1,
"Garlic Clove":0xe2d7c1,
"Garlic Pesto":0xbfcf00,
"Garlic Suede":0xcdd2bc,
"Garlic Toast":0xdddd88,
"Garnet":0x733635,
"Garnet Black Green":0x354a41,
"Garnet Evening":0x763b42,
"Garnet Rose":0xac4b55,
"Garnet Sand":0xcc7446,
"Garnet Shadow":0xc89095,
"Garnet Stone Blue":0x384866,
"Garnish":0x1e9752,
"Garret Gray":0x756861,
"Garrison Grey":0x7b8588,
"Garuda Gold":0xffbb31,
"Gas Giant":0x98dcff,
"Gaslight":0xfeffea,
"Gates of Gold":0xd2935d,
"Gateway Gray":0xb2ac9c,
"Gateway Grey":0xa0a09c,
"Gathering Field":0xab8f55,
"Gathering Place":0xad9466,
"Gatsby Brick":0x8e3b2f,
"Gatsby Glitter":0xeed683,
"Gauntlet Gray":0x78736e,
"Gauss Blaster Green":0x84c3aa,
"Gauzy White":0xe3dbd4,
"Gazebo Green":0x76826c,
"Gazebo Grey":0xd1d0cb,
"Gazelle":0x947e68,
"Gazpacho":0xc23b22,
"Gecko":0x9d913c,
"Gédéon Brown":0x7f5f00,
"Gedney Green":0x40534e,
"Geebung":0xc5832e,
"Gehenna's Gold":0xdba674,
"Gellibrand":0xb5acb2,
"Gem":0x4d5b8a,
"Gem Silica":0x73c4a4,
"Gem Turquoise":0x53c2c3,
"Gemstone Blue":0x004f6d,
"Gemstone Green":0x4b6331,
"Generic Viridian":0x007f66,
"Genestealer Purple":0x7761ab,
"Genetic Code":0x18515d,
"Geneva Green":0x1f7f76,
"Geneva Morn":0xbab7b8,
"Genever Green":0x33673f,
"Genevieve":0xbcc4e0,
"Gengiana":0x5f4871,
"Genie":0x3e4364,
"Genoa":0x31796d,
"Genoa Lemon":0xfde910,
"Genteel Blue":0x698eb3,
"Genteel Lavender":0xe2e6ec,
"Gentian":0x9079ad,
"Gentian Blue":0x312297,
"Gentian Flower":0x3366ff,
"Gentian Violet":0x544275,
"Gentle Aquamarine":0x97cbd2,
"Gentle Blue":0xcdd2de,
"Gentle Calm":0xc4cebf,
"Gentle Caress":0xfcd7ba,
"Gentle Cold":0xc3ece9,
"Gentle Doe":0xe8b793,
"Gentle Frost":0xdce0cd,
"Gentle Giant":0xb3ebe0,
"Gentle Glow":0xf6e5b9,
"Gentle Grape":0x908a9b,
"Gentle Mauve":0x958c9e,
"Gentle Rain":0xcbc9c5,
"Gentle Sea":0xb0c8d0,
"Gentle Sky":0x99bdd2,
"Gentle Touch":0xe3d5b8,
"Gentle Yellow":0xfff5be,
"Gentleman's Suit":0xc1becd,
"Geode":0x4b3f69,
"Georgia Clay":0xb06144,
"Georgia On My Mind":0xfdd4c5,
"Georgia Peach":0xf97272,
"Georgian Bay":0x22657f,
"Georgian Leather":0xcf875e,
"Georgian Pink":0xc6b8b4,
"Georgian Revival Blue":0x5b8d9f,
"Georgian Yellow":0xd1974c,
"Geraldine":0xe77b75,
"Geranium":0xda3d58,
"Geranium Bud":0xcfa1c7,
"Geranium Leaf":0x90ac74,
"Geranium Pink":0xf6909d,
"Geranium Red":0xd76968,
"Gerbera Red":0xf6611a,
"German Camouflage Beige":0x9b8c7b,
"German Grey":0x53504e,
"German Hop":0x89ac27,
"German Liquorice":0x2e3749,
"German Mustard":0xcd7a00,
"Germander Speedwell":0x0094c8,
"Germania":0xddc47e,
"Get Up and Go":0x1a9d49,
"Gettysburg Grey":0xc7c1b7,
"Geyser":0xc4d7cf,
"Geyser Basin":0xe3cab5,
"Geyser Steam":0xcbd0cf,
"Ghee Yellow":0xd8bc23,
"Ghost":0xc0bfc7,
"Ghost Grey":0x9c9b98,
"Ghost Pepper":0xc10102,
"Ghost Ship":0x887b6e,
"Ghost Town":0xbeb6a8,
"Ghost Whisperer":0xcbd1d0,
"Ghost White":0xf8f8ff,
"Ghost Writer":0xbcb7ad,
"Ghosted":0xe2e0dc,
"Ghosting":0xcac6ba,
"Ghostlands Coal":0x113c42,
"Ghostly":0xa7a09f,
"Ghostly Green":0xd9d7b8,
"Ghostly Grey":0xccccd3,
"Ghostly Purple":0x7b5d92,
"Ghostwaver":0xe2dbdb,
"Ghoul":0x667744,
"Giant Cactus Green":0x88763f,
"Giant Onion":0x665d9e,
"Giant's Club":0xb05c52,
"Giants Orange":0xfe5a1d,
"Gibraltar":0x626970,
"Gibraltar Grey":0x6f6a68,
"Gibraltar Sea":0x123850,
"Gigas":0x564786,
"Giggle":0xeff0d3,
"Gilded":0xf4db4f,
"Gilded Beige":0xb39f8d,
"Gilded Glamour":0x956841,
"Gilded Leaves":0xeba13c,
"Gilded Pear":0xc09e6c,
"Gilneas Grey":0x6c8396,
"Gimblet":0xb9ad61,
"Gin":0xd9dfcd,
"Gin Fizz":0xf8eaca,
"Gin Tonic":0xecebe5,
"Ginger":0xb06500,
"Ginger Ale":0xc9a86a,
"Ginger Ale Fizz":0xf5dfbc,
"Ginger Beer":0xc27f38,
"Ginger Cream":0xefe0d7,
"Ginger Crunch":0xceaa64,
"Ginger Dough":0xb06d3b,
"Ginger Dy":0x97653c,
"Ginger Flower":0xcf524e,
"Ginger Grey Yellow":0xb8a899,
"Ginger Jar":0xc6a05e,
"Ginger Lemon Tea":0xffffaa,
"Ginger Milk":0xf7a454,
"Ginger Peach":0xf9d09f,
"Ginger Pie":0x9a7d61,
"Ginger Root":0xc17444,
"Ginger Rose":0xbe8774,
"Ginger Shortbread":0xe3cec6,
"Ginger Snap":0x977d70,
"Ginger Spice":0xb65d48,
"Ginger Sugar":0xdddace,
"Ginger Tea":0xb19d77,
"Ginger Whisper":0xcc8877,
"Gingerbread":0x8c4a2f,
"Gingerbread Crumble":0x9c5e33,
"Gingerbread House":0xca994e,
"Gingerbread Latte":0xb39479,
"Gingerline":0xffdd11,
"Gingersnap":0xc79e73,
"Gingery":0xb06c3e,
"Gingko":0xa3c899,
"Gingko Tree":0x918260,
"Ginkgo Green":0xa5aca4,
"Ginnezumi":0x97867c,
"Ginninderra":0xb3d5c0,
"Ginseng Root":0xe6cdb5,
"Ginshu":0xbc2d29,
"Gio Ponti Green":0xb3ceab,
"Giraffe":0xfefe33,
"Girl Power":0xd39bcb,
"Girl Talk":0xe4c7c8,
"Girlie":0xffd3cf,
"Girls Night Out":0xff69b4,
"Girly Nursery":0xf6e6e5,
"Give Me Your Love":0xee88ff,
"Givry":0xebd4ae,
"Gizmo":0xd4a1b5,
"Glacial Green":0x6fb7a8,
"Glacial Ice":0xeae9e7,
"Glacial Stream":0xbcd8e2,
"Glacial Tint":0xeaf2ed,
"Glacial Water Green":0xc9ead4,
"Glacier":0x78b1bf,
"Glacier Bay":0xdef2ee,
"Glacier Blue":0xa9c1c0,
"Glacier Green":0x3e9eac,
"Glacier Grey":0xc5c6c7,
"Glacier Ivy":0xeaf3e6,
"Glacier Lake":0x62b4c0,
"Glacier Pearl":0xd1d2dc,
"Glacier Point":0xb3d8e5,
"Glacier Valley":0xe2e3d7,
"Glad Yellow":0xf5e1ac,
"Glade":0x9ca687,
"Glade Green":0x5f8151,
"Gladeye":0x7a8ca6,
"Gladiator Grey":0x6e6c5e,
"Gladiator Leather":0xa95c3e,
"Gladiola":0xd54f43,
"Gladiola Blue":0x6370b6,
"Gladiola Violet":0x6e5178,
"Glam":0xcf748c,
"Glamorgan Sausage":0xdacba7,
"Glamorous":0xb74e64,
"Glamorous White":0xf0eae0,
"Glamour":0xdb9da7,
"Glamour Pink":0xff1dcd,
"Glamour White":0xfffcec,
"Glasgow Fog":0xbdb8ae,
"Glass Bead":0xc7bec4,
"Glass Bottle":0x93ba59,
"Glass Bull":0x880000,
"Glass Green":0xdcdfb0,
"Glass Jar Blue":0x20b2aa,
"Glass Of Milk":0xfcf3dd,
"Glass Sand":0xcdb69b,
"Glass Sapphire":0x587b9b,
"Glass Sea":0x095d75,
"Glass Tile":0xcdd0c0,
"Glass Violet":0xb7a2cc,
"Glassine":0xd7e2e5,
"Glaucous":0x6082b6,
"Glaze White":0xeae1df,
"Glazed Carrot":0xe9692c,
"Glazed Chestnut":0x967217,
"Glazed Ginger":0x91552b,
"Glazed Granite":0x5b5e61,
"Glazed Pears":0xefe3d2,
"Glazed Pecan":0xd19564,
"Glazed Persimmon":0xd34e36,
"Glazed Pot":0xad7356,
"Glazed Raspberry":0xa44b62,
"Glazed Ringlet":0x89626d,
"Glazed Sugar":0xffdccc,
"Gleam":0xbfd1ad,
"Gleaming Shells":0xf8ded1,
"Gleeful":0x9dbb7d,
"Glen":0x4aac72,
"Glen Falls":0xacb8c1,
"Glendale":0xa1bb8b,
"Glenwood Green":0xa7d3b7,
"Glide Time":0x5d6f80,
"Glimmer":0xe1e8e3,
"Glimpse":0x4fb9ce,
"Glimpse into Space":0x121210,
"Glimpse of Pink":0xfff3f4,
"Glimpse of Void":0x335588,
"Glisten Green":0xf2efdc,
"Glisten Yellow":0xf5e6ac,
"Glistening":0xeed288,
"Glistening Grey":0xb1b3be,
"Glitch":0x2c5463,
"Glitchy Shader Blue":0x99ffff,
"Glitter":0xe6e8fa,
"Glitter is not Gold":0xfedc57,
"Glitter Lake":0x44bbff,
"Glitter Shower":0x88ffff,
"Glitter Yellow":0xf8d75a,
"Glitterati":0x944a63,
"Glittering Gemstone":0xdec0e2,
"Glittering Sun":0xd3ad77,
"Glittery Glow":0xeeeddb,
"Glittery Yellow":0xf9eecd,
"Glitz and Glamour":0x965f73,
"Glitzy Gold":0xd6a02b,
"Glitzy Red":0xaf413b,
"Global Green":0x696e51,
"Global Warming":0xf1d7d3,
"Globe Artichoke":0x5f6c3c,
"Globe Thistle":0x2e0329,
"Globe Thistle Grey Rose":0x998d8d,
"Gloomy Blue":0x3c416a,
"Gloomy Purple":0x8756e4,
"Gloomy Sea":0x4a657a,
"Glorious Gold":0xcba956,
"Glorious Green Glitter":0xaaee11,
"Glossy Black":0x110011,
"Glossy Gold":0xffdd77,
"Glossy Grape":0xab92b3,
"Glossy Kiss":0xeee3de,
"Glossy Olive":0x636340,
"Glow":0xf9f2da,
"Glow in the Dark":0xbefdb7,
"Glow Pink":0xd8979e,
"Glow Worm":0xbed565,
"Glowing Brake Disc":0xee4444,
"Glowing Coals":0xbc4d39,
"Glowing Firelight":0xaf5941,
"Glowing Lantern":0xfbb736,
"Glowing Meteor":0xee4400,
"Glowing Scarlet":0xbd4649,
"Glowlight":0xfff6b9,
"Gloxinia":0x622e5a,
"Gluon Grey":0x1a1b1c,
"Gluten":0xddcc66,
"Gnarls Green":0x00754b,
"Gnocchi Beige":0xffeebb,
"Gnome":0x81a19b,
"Gnome Green":0xc4bc84,
"Gnu Tan":0xb09f84,
"Go Alpha":0x007f87,
"Go Bananas":0xf7ca50,
"Go Ben":0x786e4c,
"Go Go Glow":0xfcecd5,
"Go Go Green":0x008a7d,
"Go Go Lime":0xc6be6b,
"Go Go Mango":0xfeb87e,
"Go Go Pink":0xfdd8d4,
"Go Green!":0x00ab66,
"Go To Grey":0xdcd8d7,
"Goat":0xa89a91,
"Gobelin Mauve":0x5e5a6a,
"Gobi Desert":0xcdbba2,
"Gobi Sand":0xd4aa6f,
"Gobi Tan":0xbba587,
"Goblin":0x34533d,
"Goblin Blue":0x5f7278,
"Goblin Eyes":0xeb8931,
"Goblin Green":0x76ff7a,
"Goblin Warboss":0x4efd54,
"Gobo Brown":0x635147,
"Gochujang Red":0x770000,
"God of Nights":0x550066,
"God of Rain":0x4466cc,
"God-Given":0xfaf4e0,
"God’s Own Junkyard Pink":0xf56991,
"Goddess":0xd0e1e8,
"Goddess Green":0x76ad83,
"Goddess of Dawn":0xa8d4b0,
"Godzilla":0x3c4d03,
"Gogo Blue":0x0087a1,
"Going Grey":0x83807a,
"Goji Berry":0xb91228,
"Goku Orange":0xf0833a,
"Gold":0xffd700,
"Gold Black":0x2a2424,
"Gold Buff":0xecc481,
"Gold Bullion":0xeedd99,
"Gold Buttercup":0xffe8bb,
"Gold Canyon":0xae9769,
"Gold Coast":0xc78538,
"Gold Crest":0xdf9938,
"Gold Deposit":0xe0ce57,
"Gold Digger":0xd1b075,
"Gold Drop":0xd56c30,
"Gold Dust":0xa4803f,
"Gold Earth":0xdd9c6b,
"Gold Estate":0x977a41,
"Gold Flame":0xb45422,
"Gold Foil":0xd99f4d,
"Gold Fusion":0xffb000,
"Gold Gleam":0xcfb352,
"Gold Hearted":0xe6c28c,
"Gold Metal":0xb17743,
"Gold of Midas":0xffeac7,
"Gold Orange":0xdb7210,
"Gold Pheasant":0xc6795f,
"Gold Plate":0xe6bd8f,
"Gold Plated":0xb0834f,
"Gold Ransom":0xb39260,
"Gold Red":0xeb5406,
"Gold Rush":0xc4a777,
"Gold Sand":0xf7e5a9,
"Gold Season":0xb19971,
"Gold Sparkle":0x786b3d,
"Gold Spell":0xc19d61,
"Gold Spike":0x907047,
"Gold Strand":0xf3dfa6,
"Gold Taffeta":0xbb9a39,
"Gold Tangiers":0x9e865e,
"Gold Thread":0xfee8b0,
"Gold Tips":0xe2b227,
"Gold Tooth":0xdbb40c,
"Gold Torch":0xbd955e,
"Gold Tweed":0xc9ab73,
"Gold Varnish Brown":0xb95e33,
"Gold Vein":0xd6b956,
"Gold Vessel":0xeaba8a,
"Gold Wash":0xd4c19e,
"Gold's Great Touch":0xffc265,
"Goldbrown":0x9c8a53,
"Golden":0xf5bf03,
"Golden Age":0xceab77,
"Golden Appeal":0xe6be59,
"Golden Apricot":0xdda758,
"Golden Aura":0xd29e68,
"Golden Aurelia":0xffee77,
"Golden Banner":0xfcc62a,
"Golden Bear":0xba985f,
"Golden Beige":0xcea277,
"Golden Bell":0xca8136,
"Golden Beryl Yellow":0xd9a400,
"Golden Blond":0xccaa55,
"Golden Blood":0xff1155,
"Golden Boy":0xffdd44,
"Golden Brown":0xb27a01,
"Golden Buddha Belly":0xffcc22,
"Golden Buff":0xf8e6c8,
"Golden Cadillac":0xac864b,
"Golden Cartridge":0xbdb76b,
"Golden Chalice":0xe7c068,
"Golden Chandelier":0xdddd11,
"Golden Coin":0xfcd975,
"Golden Cream":0xf7b768,
"Golden Crest":0xf6ca69,
"Golden Crested Wren":0xccddbb,
"Golden Cricket":0xd7b056,
"Golden Delicious":0xd2d88f,
"Golden Dream":0xf1cc2b,
"Golden Ecru":0xd8c39f,
"Golden Egg":0xb29155,
"Golden Elm":0xbdd5b1,
"Golden Field":0xc39e44,
"Golden Fizz":0xebde31,
"Golden Fleece":0xedd9aa,
"Golden Fog":0xf0ead2,
"Golden Foil":0xcccc00,
"Golden Foliage":0xbdd043,
"Golden Fragrance":0xeeee99,
"Golden Freesia":0x876f4d,
"Golden Gate":0xd9c09c,
"Golden Gate Bridge":0xc0362d,
"Golden Ginkgo":0xf9f525,
"Golden Glam":0xeebb44,
"Golden Glitter":0xfbe573,
"Golden Glove":0x9e7551,
"Golden Glow":0xf9d77e,
"Golden Grain":0xc59137,
"Golden Granola":0xb8996b,
"Golden Grass":0xdaa631,
"Golden Green":0xbdb369,
"Golden Griffon":0xa99058,
"Golden Guernsey":0xe1c3bb,
"Golden Gun":0xdddd00,
"Golden Hamster":0xda9e38,
"Golden Handshake":0xffcc44,
"Golden Harmony":0x9f8046,
"Golden Harvest":0xcccc11,
"Golden Haystack":0xeddfc1,
"Golden Haze":0xfbd897,
"Golden Hermes":0xffffbb,
"Golden Hind":0xa37111,
"Golden History":0xbb993a,
"Golden Hominy":0xedc283,
"Golden Hop":0xcfdd7b,
"Golden Impression":0xffefcb,
"Golden Key":0xdd9911,
"Golden Kiwi":0xf3dd3e,
"Golden Koi":0xeaa34b,
"Golden Lake":0xd8c7a2,
"Golden Leaf":0xc48b42,
"Golden Lime":0x9a9738,
"Golden Lion Tamarin":0xca602a,
"Golden Lock":0xf5bc1d,
"Golden Lotus":0xe9dbc4,
"Golden Marguerite":0xfdcc37,
"Golden Mary":0xf0be3a,
"Golden Mist":0xd5cd94,
"Golden Moray Eel":0xffcf60,
"Golden Mushroom":0xf4e8d1,
"Golden Nectar":0xffda68,
"Golden Nugget":0xdb9b59,
"Golden Oak":0xbe752d,
"Golden Oat Coloured":0xecbe91,
"Golden Ochre":0xc77943,
"Golden Olive":0xaf9841,
"Golden Opportunity":0xf7c070,
"Golden Orange":0xd7942d,
"Golden Palm":0xaa8805,
"Golden Passionfruit":0xb4bb31,
"Golden Pastel":0xf4d9b9,
"Golden Pheasant":0xcf9632,
"Golden Pilsner":0x956f3f,
"Golden Plumeria":0xfbd073,
"Golden Pop":0xebcebd,
"Golden Poppy":0xfcc200,
"Golden Pumpkin":0xca884b,
"Golden Quartz Ochre":0xaa8a58,
"Golden Rain Yellow":0xffb657,
"Golden Raspberry":0xf8d878,
"Golden Rays":0xf6da74,
"Golden Relic":0xe8ce49,
"Golden Retriever":0xeedec7,
"Golden Rice":0xe3d474,
"Golden Rule":0xdaae49,
"Golden Sage":0xb09d73,
"Golden Sand":0xeace6a,
"Golden Schnitzel":0xddbb11,
"Golden Slumber":0xb98841,
"Golden Snitch":0xf1e346,
"Golden Spice":0xc6973f,
"Golden Staff":0xf7eb83,
"Golden Straw":0xf5edae,
"Golden Summer":0x816945,
"Golden Syrup":0xebd8b3,
"Golden Tainoi":0xffc152,
"Golden Thistle Yellow":0xcaa375,
"Golden Thread":0xe8c47a,
"Golden Wash":0xfffec6,
"Golden Weave":0xeadcc0,
"Golden West":0xe9ca94,
"Golden Yarrow":0xe2c74f,
"Golden Yellow":0xffdf00,
"Goldenrod":0xfdcb18,
"Goldenrod Field":0xf0b053,
"Goldenrod Tea":0xa17841,
"Goldenrod Yellow":0xffce8f,
"Goldfinch":0xf8dc6c,
"Goldfinger":0xeebb11,
"Goldfish":0xf2ad62,
"Goldie":0xc89d3f,
"Goldie Oldie":0xbaad75,
"Goldilocks":0xfff39a,
"Goldvreneli 1882":0xe7de54,
"Golem":0x836e59,
"Golf Blazer":0x53a391,
"Golf Course":0x5a9e4b,
"Golf Day":0x5a8b3f,
"Golf Green":0x008763,
"Golfer Green":0x5e6841,
"Golgfag Brown":0xd77e70,
"Goluboy Blue":0x8bb9dd,
"Gomashio Yellow":0xcc9933,
"Gondola":0x373332,
"Gondolier":0x5db1c5,
"Gone Giddy":0xd9c737,
"Gonzo Violet":0x5d06e9,
"Good Graces":0xf3f0d6,
"Good Karma":0x333c76,
"Good Life":0xc49e69,
"Good Luck":0x86c994,
"Good Luck Charm":0x9d865c,
"Good Morning":0xfcfcda,
"Good Morning Akihabara":0xf4ead5,
"Good Night!":0x46565f,
"Good Samaritan":0x3f6782,
"Good-Looking":0xedd2a7,
"Goodbye Kiss":0xd9cac3,
"Goody Gumdrop":0xccd87a,
"Goody Two Shoes":0xc2ba8e,
"Goose Bill":0xffba80,
"Goose Down":0xf4e7df,
"Goose Pond Green":0x629b92,
"Goose Wing Grey":0xa89dac,
"Gooseberry Fool":0xacb75f,
"Gooseberry Yellow":0xc7a94a,
"Gorā White":0xf0f0e0,
"Gordons Green":0x29332b,
"Gorgeous Green":0x287c37,
"Gorgeous Hydrangea":0xa495cb,
"Gorgeous White":0xe7dbd3,
"Gorgonzola Blue":0x4455cc,
"Gorse":0xfde336,
"Gorse Yellow Orange":0xe99a3c,
"Gorthor Brown":0x654741,
"Gory Movie":0xb42435,
"Gory Red":0xa30800,
"Goshawk Grey":0x444444,
"Gossamer":0x399f86,
"Gossamer Green":0xb2cfbe,
"Gossamer Pink":0xfac8c3,
"Gossamer Veil":0xd3cec4,
"Gossamer Wings":0xe8eee9,
"Gossip":0x9fd385,
"Gotham Grey":0x8a9192,
"Gothic":0x698890,
"Gothic Amethyst":0xa38b93,
"Gothic Gold":0xbb852f,
"Gothic Grape":0x473951,
"Gothic Olive":0x7c6e4f,
"Gothic Purple":0x92838a,
"Gothic Revival Green":0xa0a160,
"Gothic Spire":0x7c6b6f,
"Gotta Have It":0xd0c2b4,
"Gouda Gold":0xeecc11,
"Goulash":0x8d6449,
"Gould Blue":0x7d9ea2,
"Gould Gold":0xbc9d70,
"Gourmet Honey":0xe3cba8,
"Gourmet Mushroom":0x968d8c,
"Government Green":0x32493e,
"Governor Bay":0x51559b,
"Graceful":0xa8c0ce,
"Graceful Ballerina":0xdd897c,
"Graceful Flower":0xbddfb2,
"Graceful Garden":0xcba9d0,
"Graceful Gazelle":0xa78a50,
"Graceful Green":0xacb7a8,
"Graceful Grey":0xbeb6ac,
"Graceful Mint":0xdaeed5,
"Graceland Grass":0x546c46,
"Gracilis":0xc4d5cb,
"Gracious":0xf8edd7,
"Gracious Glow":0xbab078,
"Gracious Rose":0xe3b7b1,
"Graham Cracker":0xc0a480,
"Graham Crust":0x806240,
"Grain Brown":0xcab8a2,
"Grain Mill":0xd8c095,
"Grain of Salt":0xd8dbe1,
"Grain White":0xefe3d8,
"Grainfield":0xb79e66,
"Gram's Hair":0xf5f6f7,
"Gran Torino Red":0xee3300,
"Granada Sky":0x5d81bb,
"Grand Avenue":0x665a48,
"Grand Bleu":0x015482,
"Grand Canal":0x3c797d,
"Grand Grape":0x645764,
"Grand Gusto":0x86bb9d,
"Grand Heron":0xecece1,
"Grand Piano":0xd8d0bd,
"Grand Plum":0x6c5657,
"Grand Poobah":0x864764,
"Grand Purple":0x534778,
"Grand Rapids":0x38707e,
"Grand Soiree":0xd9c2a8,
"Grand Sunset":0xc38d87,
"Grandeur Plum":0x92576f,
"Grandiflora Rose":0xe0ebaf,
"Grandiose":0xcaa84c,
"Grandis":0xffcd73,
"Grandma's Cameo":0xf7e7dd,
"Grandview":0x6b927f,
"Grange Hall":0x857767,
"Granita":0xa52350,
"Granite":0x746a5e,
"Granite Black":0x313238,
"Granite Boulder":0x816f6b,
"Granite Brown":0x3d2d24,
"Granite Canyon":0x6c6f78,
"Granite Dust":0xd7cec4,
"Granite Falls":0x638496,
"Granite Green":0x8b8265,
"Granite Grey":0x615e5f,
"Granite Peak":0x606b75,
"Granny Apple":0xc5e7cd,
"Granny Smith":0x7b948c,
"Granny Smith Apple":0x9de093,
"Granola":0xf5ce9f,
"Grant Drab":0x8f8461,
"Grant Grey":0x918f8a,
"Grant Village":0x6c90b2,
"Grant Wood Ivy":0xa8b989,
"Granular Limestone":0xe3e0da,
"Granulated Sugar":0xfffdf2,
"Grape":0x6c3461,
"Grape Arbor":0xa598c7,
"Grape Blue":0x24486c,
"Grape Candy":0x905284,
"Grape Cassata":0xdfe384,
"Grape Compote":0x6b5876,
"Grape Creme":0xbebbbb,
"Grape Expectations":0x6a587e,
"Grape Fizz":0x64435f,
"Grape Gatsby":0xa19abd,
"Grape Glimmer":0xdccae0,
"Grape Green":0xa8e4a0,
"Grape Grey":0x6d6166,
"Grape Harvest":0x807697,
"Grape Haze":0x606a88,
"Grape Hyacinth":0x5533cc,
"Grape Illusion":0xb4a6d5,
"Grape Jam":0x7f779a,
"Grape Jelly":0x7e667f,
"Grape Juice":0x682961,
"Grape Kiss":0x7b4368,
"Grape Lavender":0xc2c4d4,
"Grape Leaf":0x545144,
"Grape Leaves":0x576049,
"Grape Mist":0xc5c0c9,
"Grape Nectar":0x8d5c74,
"Grape Oil Green":0xd3d9ce,
"Grape Parfait":0x8677a9,
"Grape Popsicle":0x60406d,
"Grape Purple":0x5d1451,
"Grape Royale":0x4f2d54,
"Grape Shake":0x886971,
"Grape Soda":0xae94a6,
"Grape Taffy":0xf4daf1,
"Grape Vine":0x797f5a,
"Grape Wine":0x5a2f43,
"Grape's Treasure":0xbeaecf,
"Grapeade":0xaa9fb2,
"Grapefruit":0xfd5956,
"Grapefruit Juice":0xee6d8a,
"Grapefruit Pulp":0xfe6f5e,
"Grapefruit Yellow":0xdfa01a,
"Grapemist":0x8398ca,
"Grapes of Wrath":0x58424c,
"Grapeshot":0x71384b,
"Grapest":0x880066,
"Grapevine":0xb194a6,
"Grapevine Canyon":0x62534f,
"Graphic Charcoal":0x5c5e5f,
"Graphic Grape":0x824e78,
"Graphical 80's Sky":0x0000fc,
"Graphite":0x383428,
"Graphite Black":0x262a2b,
"Graphite Black Green":0x32494b,
"Graphite Grey Green":0x7c7666,
"Grapple":0x92786a,
"Grapy":0x786e70,
"Grasping Grass":0x92b300,
"Grass":0x5cac2d,
"Grass Blade":0x636f46,
"Grass Cloth":0xb8b97e,
"Grass Court":0x088d46,
"Grass Daisy":0xceb02a,
"Grass Green":0x3f9b0b,
"Grass Root":0xc3c175,
"Grass Sands":0xa1afa0,
"Grass Skirt":0xe2dac2,
"Grass Stain Green":0xc0fb2d,
"Grass Valley":0xf4f7ee,
"Grasshopper":0x77824a,
"Grasshopper Wing":0x87866f,
"Grassland":0xc1bca7,
"Grasslands":0x407548,
"Grassroots":0xd8c475,
"Grassy Field":0x5c7d47,
"Grassy Glade":0xd8ddca,
"Grassy Green":0x419c03,
"Grassy Meadow":0x76a55b,
"Grassy Savannah":0x9b9279,
"Grated Beet":0xa60e46,
"Gratefully Grass":0x71714e,
"Gratifying Green":0xdae2cd,
"Gratin Dauphinois":0xe0d2a9,
"Gratitude":0xe0ead7,
"Grauzone":0x85a3b2,
"Gravel":0x4a4b46,
"Gravel Dust":0xbab9a9,
"Gravel Fint":0xbbbbbb,
"Gravel Grey Blue":0x637a82,
"Gravelstone":0xd3c7b8,
"Graveyard Earth":0x68553a,
"Gravlax":0xec834f,
"Gray Area":0xafa696,
"Gray Clouds":0xb7b7b2,
"Gray Matters":0xa7a8a2,
"Gray Screen":0xc6caca,
"Gray Shingle":0x949392,
"Grayish":0xcfcac7,
"Grays Harbor":0x596368,
"Grayve-Yard":0xa1a19f,
"Great Blue Heron":0xd5e0ee,
"Great Coat Grey":0x7f8488,
"Great Dane":0xd1a369,
"Great Falls":0x9fa6b3,
"Great Fennel Flower":0x719ba2,
"Great Frontier":0x908675,
"Great Grape":0x6b6d85,
"Great Graphite":0xa5a6a1,
"Great Green":0xabb486,
"Great Joy":0xd8e6cb,
"Great Serpent":0x4a72a3,
"Great Tit Eggs":0xe9e2db,
"Great Void":0x3b5760,
"Great White":0xbdbdc6,
"Grecian Gold":0x9e7e54,
"Grecian Isle":0x00a49b,
"Grecian Ivory":0xd6cfbe,
"Greedo Green":0x00aa66,
"Greedy Gecko":0xaa9922,
"Greedy Gold":0xc4ce3b,
"Greedy Green":0xd1ffbd,
"Greek Aubergine":0x3d0734,
"Greek Blue":0x009fbd,
"Greek Flag Blue":0x0d5eaf,
"Greek Garden":0x8cce86,
"Greek Isles":0xbbdcf0,
"Greek Lavender":0x9b8fb0,
"Greek Sea":0x72a7e1,
"Greek Villa":0xf0ece2,
"Green":0x00ff00,
"Green 383":0x3e3d29,
"Green Acres":0x53a144,
"Green Adirondack":0x688878,
"Green Agate":0x3f6253,
"Green Alabaster":0xc8ccba,
"Green Amazons":0x98a893,
"Green Apple":0x5edc1f,
"Green Apple Martini":0xd2c785,
"Green Aqua":0xd0e8db,
"Green Ash":0xa0daa9,
"Green Balloon":0x80c4a9,
"Green Balsam":0xa0ac9e,
"Green Banana":0xa8b453,
"Green Bank":0x79b088,
"Green Bark":0xa9c4a6,
"Green Bay":0x7e9285,
"Green Bayou":0x566e57,
"Green Bean Casserole":0xb0a36e,
"Green Bell Pepper":0x228800,
"Green Belt":0x2d7f6c,
"Green Beret":0x516a62,
"Green Blob":0x22dd00,
"Green Blue":0x42b395,
"Green Blue Slate":0x358082,
"Green Bonnet":0x8bb490,
"Green Bottle":0x446a4b,
"Green Brocade":0xdaf1e0,
"Green Brown":0x696006,
"Green Buoy":0x32a7b5,
"Green Bush":0x7f8866,
"Green Cacophony":0xbbee11,
"Green Cape":0x89ce01,
"Green Cast":0x919365,
"Green Caterpillar":0x98be3c,
"Green Chalk":0xbcdf8a,
"Green Charm":0xe7dda7,
"Green Coconut":0x868e65,
"Green Column":0x465149,
"Green Cow":0xbeef69,
"Green Crush":0x62ae9e,
"Green Cyan":0x009966,
"Green Darner Tail":0x75bbfd,
"Green Day":0xbbee88,
"Green Daze":0x8bd3c6,
"Green Dragon":0x006c67,
"Green Dragon Spring":0xc1cab0,
"Green Dynasty":0x728942,
"Green Eggs":0xe3ecc5,
"Green Eggs and Ham":0x7cb68e,
"Green Elliott":0x00bb66,
"Green Emulsion":0xdaeae2,
"Green Energy":0x80905f,
"Green Envy":0x77aa00,
"Green Epiphany":0x7efbb3,
"Green Essence":0xe9eac8,
"Green Eyes":0x7d956d,
"Green Fiasco":0xaaee00,
"Green Field":0x88aa77,
"Green Fig":0xb3a476,
"Green Fingers":0x297e6b,
"Green Flash":0x79c753,
"Green Flavor":0xbbaa22,
"Green Fluorite":0x55bbaa,
"Green Fog":0x989a87,
"Green Frost":0xd0d6bf,
"Green Frosting":0xd8f1eb,
"Green Gables":0x324241,
"Green Gamora":0x11bb00,
"Green Gardens":0x009911,
"Green Garlands":0x008176,
"Green Garter":0x61ba85,
"Green Gas":0x00ff99,
"Green Gate":0x676957,
"Green Gecko":0xcdd47f,
"Green Glacier":0xe7f0c2,
"Green Glaze":0xeaf1e4,
"Green Glimmer":0x00bb00,
"Green Glimpse":0xe7eae3,
"Green Glint":0xdcf1c7,
"Green Glitter":0xdde26a,
"Green Globe":0x79aa87,
"Green Gloss":0x00955e,
"Green Glow":0xb0c965,
"Green Glutton":0x007722,
"Green Goanna":0x505a39,
"Green Goblin":0x11bb33,
"Green Gold":0xc5b088,
"Green Gone Wild":0x73a236,
"Green Gooseberry":0xb0dfa4,
"Green Granite":0x7c9793,
"Green Grapple":0x3db9b2,
"Green Grass":0x39854a,
"Green Grey":0x7ea07a,
"Green Grey Mist":0xafa984,
"Green Gum":0x95e3c0,
"Green Haze":0x01a368,
"Green Herb":0xa4c08a,
"Green Hills":0x007800,
"Green Hour":0x587d79,
"Green Iced Tea":0xe8e8d4,
"Green Illude":0x6e6f56,
"Green Incandescence":0xc4fe82,
"Green Ink":0x11887b,
"Green Jelly":0x349b82,
"Green Jewel":0x95dabd,
"Green Juice":0x3bde39,
"Green Katamari":0x53fe5c,
"Green Kelp":0x393d2a,
"Green Knoll":0x647f4a,
"Green Lacewing":0x8ad370,
"Green Lane":0xcad6c4,
"Green Lantern":0x9cd03b,
"Green Lapis":0x008684,
"Green Leaf":0x526b2d,
"Green Lentils":0x9c9463,
"Green Lily":0xc1cec1,
"Green Lizard":0xa7f432,
"Green Mallard":0x455f5f,
"Green Mana":0x26b467,
"Green McQuarrie":0x555d50,
"Green Me":0xb2b55f,
"Green Meets Blue":0x8ea8a0,
"Green Mesh":0xd7d7ad,
"Green Milieu":0x8a9992,
"Green Minions":0x99dd00,
"Green Mirror":0xd7e2d5,
"Green Mist":0xbfc298,
"Green Moblin":0x008888,
"Green Moonstone":0x33565e,
"Green Moray":0x3a7968,
"Green Moss":0x857946,
"Green Myth":0xc5e1c3,
"Green Neon":0xb2ac31,
"Green Oasis":0xb0b454,
"Green Oblivion":0x005249,
"Green Ochre":0x9f8f55,
"Green Olive":0x8d8b55,
"Green Olive Pit":0xbdaa89,
"Green Onion":0xc1e089,
"Green Onyx":0x989a82,
"Green Papaya":0xe5ce77,
"Green Parakeet":0x7bd5bf,
"Green Parlor":0xcfddb9,
"Green Patina":0x66d0c0,
"Green Paw Paw":0x0d6349,
"Green Pea":0x266242,
"Green Pear":0x79be58,
"Green People":0x388004,
"Green Pepper":0x97bc62,
"Green Pigment":0x00a550,
"Green Plaza":0x98a76e,
"Green Power":0xe2e1c6,
"Green Priestess":0x11dd55,
"Green Revolution":0x009944,
"Green Room":0x80aea4,
"Green Savage":0x888866,
"Green Scene":0x858365,
"Green Screen":0x22ff00,
"Green Shade Wash":0x45523a,
"Green Sheen":0xd9ce52,
"Green Shimmer":0xccfd7f,
"Green Silk":0xa2c2b0,
"Green Sky":0x859d66,
"Green Sleeves":0xa19675,
"Green Smoke":0x9ca664,
"Green Snow":0x9eb788,
"Green Song":0xd1e9c4,
"Green Spool":0x006474,
"Green Spring":0xa9af99,
"Green Spruce":0x589f7e,
"Green Stain":0x2b553e,
"Green Suede":0x73884d,
"Green Sulphur":0xae8e2c,
"Green Tea":0xb5b68f,
"Green Tea Candy":0x65ab7c,
"Green Tea Ice Cream":0x93b13d,
"Green Tea Leaf":0x939a89,
"Green Tea Mochi":0x90a96e,
"Green Teal":0x0cb577,
"Green Tease":0xe3ede0,
"Green Thumb":0x779900,
"Green Tilberi":0xd5e0d0,
"Green Tint":0xc5ccc0,
"Green Tone Ink":0x47553c,
"Green Tourmaline":0x5eab81,
"Green Trance":0xa0d9a3,
"Green Trellis":0x99a798,
"Green Turquoise":0x679591,
"Green Valley":0x3f4948,
"Green Veil":0xe0f1c4,
"Green Velvet":0x127453,
"Green Venom":0xb8f818,
"Green Vibes":0xd4e7c3,
"Green Vogue":0x23414e,
"Green Wash":0xc6ddcd,
"Green Waterloo":0x2c2d24,
"Green Wave":0xc3dcd5,
"Green Weed":0x548f6f,
"Green Whisper":0xe3eee3,
"Green White":0xdeddcb,
"Green Woodpecker Olive":0x7d7853,
"Green Yellow":0xc6f808,
"Greenalicious":0x00dd00,
"Greenbelt":0x447d5f,
"Greenblack":0x373a3a,
"Greenbrier":0x4b9b69,
"Greenday":0x99ff00,
"Greene & Greene":0x445544,
"Greenella":0x60857a,
"Greener Grass":0x2f8351,
"Greener Pastures":0x495a4c,
"Greenery":0x88b04b,
"Greenette":0xdaecc5,
"Greenfield":0x60724f,
"Greenfinch":0xbda928,
"Greengage":0x8bc28c,
"Greengrass":0x72a355,
"Greenhouse":0x3e6334,
"Greenhouse Glass":0xd7e7cd,
"Greening":0xdfe4d5,
"Greenish":0x40a368,
"Greenish Beige":0xc9d179,
"Greenish Black":0x454445,
"Greenish Blue":0x0b8b87,
"Greenish Brown":0x696112,
"Greenish Cyan":0x2afeb7,
"Greenish Grey":0x96ae8d,
"Greenish Grey Bark":0x66675a,
"Greenish Tan":0xbccb7a,
"Greenish Teal":0x32bf84,
"Greenish Turquoise":0x00fbb0,
"Greenish White":0xd1f1de,
"Greenish Yellow":0xcdfd02,
"Greenlake":0x007d69,
"Greenland":0x737d6a,
"Greenland Blue":0x367f9a,
"Greenland Green":0x22acae,
"Greenland Ice":0xb9d7d6,
"Greens":0x016844,
"Greensleeves":0x39766c,
"Greenway":0x419a7d,
"Greenwich Village":0xafbfbe,
"Greenwood":0xbcbaab,
"Greeny Glaze":0x067376,
"Gregorio Garden":0xcbc8dd,
"Greige":0xb0a999,
"Greige Violet":0x9c8c9a,
"Gremlin":0xa79954,
"Gremolata":0x527e6d,
"Grenache":0x8e6268,
"Grenade":0xc32149,
"Grenadier":0xc14d36,
"Grenadine":0xac545e,
"Gretchin Green":0x5d6732,
"Gretna Green":0x596442,
"Grey":0x808080,
"Grey Aqua":0x88b69f,
"Grey Area":0x8f9394,
"Grey Ashlar":0xcabab1,
"Grey Asparagus":0x465945,
"Grey Blue":0x77a1b5,
"Grey Blueberry":0x6c8096,
"Grey Brown":0x7f7053,
"Grey By Me":0xa1988b,
"Grey Carmine":0x7a5063,
"Grey Chateau":0x9fa3a7,
"Grey Cloth":0xccc9c5,
"Grey Cloud":0x747880,
"Grey Dawn":0xbbc1cc,
"Grey Dolphin":0xc8c7c5,
"Grey Dusk":0x897f98,
"Grey Flannel":0x8d9a9e,
"Grey Frost":0xb8bfc2,
"Grey Ghost":0xdddcda,
"Grey Glimpse":0xe0e4e2,
"Grey Gloss":0xa3a29b,
"Grey Grain":0xa9bdbf,
"Grey Green":0x86a17d,
"Grey Heather":0x868790,
"Grey Heron":0x89928a,
"Grey Jade":0xb9bbad,
"Grey Lilac":0xd4cacd,
"Grey Linnet Egg":0xf2e8d7,
"Grey Locks":0x72695e,
"Grey Marble":0xb9b4b1,
"Grey Matter":0xc87f89,
"Grey Mauve":0xcab8ab,
"Grey Mist":0x99aeae,
"Grey Monument":0x707c78,
"Grey Morn":0xcabeb5,
"Grey Morning":0x9eb0aa,
"Grey Nickel":0xc3c3bd,
"Grey Nurse":0xd1d3cc,
"Grey of Darkness":0xa2a2a2,
"Grey Olive":0xa19a7f,
"Grey Owl":0x776f67,
"Grey Pearl":0xced0cf,
"Grey Pebble":0xcfcac1,
"Grey Pepper":0x84827d,
"Grey Pink":0xc3909b,
"Grey Pinstripe":0x49494d,
"Grey Placidity":0xdddde2,
"Grey Porcelain":0x86837a,
"Grey Purple":0x826d8c,
"Grey Ridge":0x847986,
"Grey River Rock":0x99a1a1,
"Grey Roads":0xc3c0bb,
"Grey Rose":0xc6b6b2,
"Grey Russian":0x8e9598,
"Grey Sand":0xe5ccaf,
"Grey Scape":0xb8b0af,
"Grey Shadows":0xc2bdba,
"Grey Shimmer":0xd6d9d8,
"Grey Spell":0xc8c7c2,
"Grey Squirrel":0x989081,
"Grey Suit":0x9391a0,
"Grey Teal":0x5e9b8a,
"Grey Timber Wolf":0xacaeb1,
"Grey Violet":0x9b8e8e,
"Grey Whisper":0xe6e4e4,
"Grey White":0xd7d5cb,
"Grey Wolf":0x9ca0a6,
"Grey Wonder":0xe5e8e6,
"Grey Wool":0xa9bbbc,
"Grey-Headed Woodpecker Green":0x98916c,
"Greybeard":0xd4d0c5,
"Greyed Jade":0x9bbea9,
"Greyhound":0xb2aca2,
"Greyish":0xa8a495,
"Greyish Black":0x555152,
"Greyish Blue":0x5e819d,
"Greyish Brown":0x7a6a4f,
"Greyish Green":0x82a67d,
"Greyish Pink":0xc88d94,
"Greyish Purple":0x887191,
"Greyish Teal":0x719f91,
"Greyish White":0xd6dee9,
"Greyish Yellow":0x877254,
"Greylac":0x948c8d,
"Greystoke":0x85837e,
"Greystone":0xb7b9b5,
"Greywacke":0xaaccbb,
"Greywood":0x9d9586,
"Griffin":0x8d8f8f,
"Griffon Brown":0x70393f,
"Grill Master":0x863b2c,
"Grilled":0x633f2e,
"Grilled Cheese":0xffc85f,
"Grim Grey":0xe3dcd6,
"Grim Purple":0x441188,
"Grim Reaper":0x0f1039,
"Grim White":0xf6f1f4,
"Grimace":0x50314c,
"Grime":0x565143,
"Gris":0xa5a9a8,
"Gris Morado":0x8f8a91,
"Gris Náutico":0xbcc7cb,
"Gris Volcanico":0x797371,
"Grisaille":0x585e6f,
"Gristmill":0xa29371,
"Grizzle Gray":0x636562,
"Grizzly":0x885818,
"Grog Yellow":0x937043,
"Groovy":0xde6491,
"Groovy Giraffe":0xeeaa11,
"Gropius Grey":0x63615d,
"Gross Green":0xa0bf16,
"Grotesque Green":0x64e986,
"Grouchy Badger":0x6f675c,
"Ground Bean":0x604e42,
"Ground Coffee":0x63554b,
"Ground Cover":0xa8bf8b,
"Ground Cumin":0x8a6c42,
"Ground Fog":0xcfcbc4,
"Ground Ginger":0xd9ca9f,
"Ground Nutmeg":0xa05a3b,
"Ground Pepper":0x766551,
"Groundcover":0x64634d,
"Grounded":0xd18c62,
"Groundwater":0x1100aa,
"Growing Nature":0x88cc11,
"Growing Season":0xc3cdb0,
"Growth":0x6ca178,
"Grubenwald":0x4a5b51,
"Grullo":0xa99a86,
"Grunervetliner":0xc0cf3f,
"Gruyère Cheese":0xf5deb3,
"Gryphonne Sepia Wash":0x883f11,
"Gǔ Tóng Hēi Copper":0x634950,
"Guacamole":0x95986b,
"Guardian Angel":0xe4e1ea,
"Guardsman Red":0x952e31,
"Guava Green":0xa18d0d,
"Guava Jam":0xe08771,
"Guava Jelly":0xee9685,
"Guava Juice":0xf4b694,
"Guerrilla Forest":0x142d25,
"Guesthouse":0xe3e0d2,
"Guide Pink":0xeb4962,
"Guiding Star":0xfee9da,
"Guild Grey":0xd2d1cb,
"Guilliman Blue":0x6495ed,
"Guinea Pig":0x987654,
"Guinea Pig White":0xe8e4d6,
"Guinean Green":0x4a8140,
"Guitar":0x6b4c37,
"Gulab Brown":0x8b2e19,
"Gulābī Pink":0xc772c0,
"Gulf Blue":0x343f5c,
"Gulf Breeze":0xddded3,
"Gulf Harbour":0x225e64,
"Gulf Stream":0x74b2a8,
"Gulf Waters":0x2da6bf,
"Gulf Weed":0x686e43,
"Gulf Wind":0xbcc9cd,
"Gulf Winds":0x93b2b2,
"Gulfstream":0x01858b,
"Gull":0x918c8f,
"Gull Feather":0xc2c2bc,
"Gull Grey":0xa4adb0,
"Gully":0x777661,
"Gully Green":0x4b6e3b,
"Gum Leaf":0xacc9b2,
"Gumball":0xe7b2d0,
"Gumbo":0x718f8a,
"Gumdrop":0xde96c1,
"Gumdrop Green":0x2ea785,
"Gumdrops":0xffc69d,
"Gun Barrel":0x979d9a,
"Gun Corps Brown":0x6b593c,
"Gun Powder":0x484753,
"Gundaroo Green":0x959984,
"Gunjō Blue":0x5d8cae,
"Gunmetal":0x536267,
"Gunmetal Beige":0x908982,
"Gunmetal Green":0x777648,
"Gunmetal Grey":0x808c8c,
"Gunny Sack":0xdcd3bc,
"Guns N' Roses":0xff0077,
"Gunsmoke":0x7a7c76,
"Guo Tie Dumpling":0xbd7e08,
"Guppie Green":0x00ff7f,
"Guppy Violet":0xae5883,
"Gurkha":0x989171,
"Gustav":0xa49691,
"Gusto Gold":0xf8ac1d,
"Gutsy Grape":0x705284,
"Guy":0x897a68,
"Gyoza Dumpling":0xdfb46f,
"Gypsum":0xeeede4,
"Gypsum Rose":0xe2c4af,
"Gypsum Sand":0xd6cfbf,
"Gypsy":0xe59368,
"Gypsy Canvas":0xb7a467,
"Gypsy Caravan":0xd1c8d7,
"Gypsy Dancer":0xc07c7b,
"Gypsy Jewels":0x613a57,
"Gypsy Magic":0x917d82,
"Gypsy Red":0xb6363b,
"Gypsy's Gown":0xa698a8,
"H₂O":0xbfe1e6,
"Habanero":0xf98513,
"Habanero Chile":0xb8473d,
"Habanero Gold":0xfed450,
"Habitat":0x897d6d,
"Hacienda":0x9e8022,
"Hacienda Blue":0x0087a8,
"Hacienda Tile":0xb86d64,
"Hacienda White":0xf0ede7,
"Haddock's Sweater":0x277aba,
"Hadfield Blue":0x1177ff,
"Hadopelagic Water":0x000022,
"Haggis":0xc3c7b2,
"Hailey Blue":0x2c75ff,
"Hailstorm":0xd0d1e1,
"Hailstorm Grey":0xbdbeb9,
"Hair Blonde":0xfdcfa1,
"Hair Brown":0x8b7859,
"Hair Ribbon":0x939cc9,
"Hairy Brown":0x734a12,
"Hairy Heath":0x633528,
"Haiti":0x2c2a35,
"Haitian Flower":0x97495a,
"Hakusai Green":0x88b378,
"Halakā Pīlā":0xf0e483,
"Halation":0xd1d1ce,
"Halayà Úbe":0x663854,
"Halcyon Green":0x9baaa2,
"Half Baked":0x558f93,
"Half Colonial White":0xf2e5bf,
"Half Dutch White":0xfbf0d6,
"Half Moon Bay Blush":0xcda894,
"Half Orc Highlight":0x976f3c,
"Half Pearl Lusta":0xf1ead7,
"Half Sea Fog":0xa9b8bb,
"Half Spanish White":0xe6dbc7,
"Half-Caff":0x604c3d,
"Half-Smoke":0xee8855,
"Halite Blue":0x09324a,
"Hallowed Hush":0xe2ebe5,
"Halloween Orange":0xeb6123,
"Halloween Punch":0xdd2211,
"Halo":0xe2c392,
"Halogen Blue":0xbdc6dc,
"Halt and Catch Fire":0xff6633,
"Halt Red":0xff004f,
"Hamilton Blue":0x8a99a4,
"Hammam Blue":0x65dcd6,
"Hammered Copper":0x834831,
"Hammered Gold":0xcb9d5e,
"Hammered Pewter":0x7e7567,
"Hammered Silver":0x978a7f,
"Hammerhead Shark":0x4e7496,
"Hammock":0x6d8687,
"Hampton":0xe8d4a2,
"Hampton Beach":0x9d603b,
"Hampton Green":0x4f604f,
"Hampton Surf":0x597681,
"Hamster Fur":0xa6814c,
"Hamster Habitat":0xc4d6af,
"Hamtaro Brown":0xb07426,
"Han Blue":0x446ccf,
"Han Purple":0x5218fa,
"Hanaasagi Blue":0x1d697c,
"Hanada Blue":0x044f67,
"Hanami Pink":0xf2abe1,
"Hancock":0x4d6968,
"Hand Sanitizer":0xceecee,
"Handmade Linen":0xddd6b7,
"Handmade Red":0xa87678,
"Handsome Hue":0x5286ba,
"Handwoven":0xbfa984,
"Hanging Gardens of Babylon":0x11aa44,
"Hannover Hills":0x685d4a,
"Hanover":0xdac5b1,
"Hanover Pewter":0x848472,
"Hansa Yellow":0xe9d66c,
"Hanuman Green":0x55ffaa,
"Hanyauku":0xe3d6c7,
"Happy":0xf8d664,
"Happy Camper":0x6b8350,
"Happy Days":0x506e82,
"Happy Daze":0xf7cf1b,
"Happy Face":0xffd10b,
"Happy Hippo":0x818581,
"Happy Piglets":0xf6cbca,
"Happy Prawn":0xffbe98,
"Happy Thoughts":0xd1dfeb,
"Happy Trails":0xb67a63,
"Happy Tune":0x96b957,
"Happy Yipee":0xffc217,
"Hapsburg Court":0xe2d4d6,
"Harā Green":0x55aa55,
"Harajuku Girl":0x504a6f,
"Harbor":0x5b909a,
"Harbor Blue":0x556699,
"Harbor Mist":0x88aaaa,
"Harbour":0x495867,
"Harbour Afternoon":0xe0e9f3,
"Harbour Blue":0x417491,
"Harbour Fog":0xafb1b4,
"Harbour Grey":0xa8c0bb,
"Harbour Light":0xd7e0e7,
"Harbour Mist":0xdae1e3,
"Harbour Mist Grey":0x778071,
"Harbour Rat":0x757d75,
"Harbour Sky":0x7eb6d0,
"Harbourmaster":0x4e536b,
"Hard Candy":0xffbbbb,
"Hard Coal":0x656464,
"Hardware":0x8b8372,
"Harem Silk":0x006383,
"Harissa Red":0xa52a2a,
"Harlequin":0x3fff00,
"Harlequin Green":0x46cb18,
"Harley Davidson Orange":0xc93413,
"Harlock's Cape":0xbb0000,
"Harmonic Tan":0xc1b287,
"Harmonious":0xafc195,
"Harmonious Gold":0xeacfa3,
"Harmonious Rose":0xf29cb7,
"Harold":0x6d6353,
"Harp":0xcbcec0,
"Harpoon":0x283b4c,
"Harpy Brown":0x493c2b,
"Harrison Grey":0x989b9e,
"Harrison Rust":0x9a5f3f,
"Harrow Gate":0xdbd4c7,
"Harrow's Gate":0x7e8e90,
"Harvard Crimson":0xc90016,
"Harvest at Dusk":0xcb862c,
"Harvest Blessing":0xba8e4e,
"Harvest Brown":0xb9a589,
"Harvest Dance":0xa5997c,
"Harvest Eve Gold":0xda9100,
"Harvest Gold":0xeab76a,
"Harvest Home":0xcbae84,
"Harvest Night":0x554488,
"Harvest Oak":0x65564f,
"Harvest Pumpkin":0xd56231,
"Harvest Time":0xcf875f,
"Harvest Wreath":0xf7d7c4,
"Harvester":0xedc38e,
"Hashibami Brown":0xbfa46f,
"Hashita Purple":0x8d608c,
"Hashut Copper":0xc9643b,
"Hassan II Mosque":0x009e6d,
"Hat Box Brown":0x8f775d,
"Hatching Chameleon":0xcfebde,
"Hatoba Pigeon":0x95859c,
"Hatoba-Nezumi Grey":0x9e8b8e,
"Haunted Dreams":0x333355,
"Haunted Hills":0x003311,
"Haunting Hue":0xd3e0ec,
"Haunting Melody":0x824855,
"Haute Couture":0xa0252a,
"Haute Pink":0xd899b1,
"Haute Red":0xa11729,
"Havana":0x3b2b2c,
"Havana Blue":0xa5dbe5,
"Havana Cigar":0xaf884a,
"Havana Coffee":0x554941,
"Havana Cream":0xf9e5c2,
"Havasu":0x007993,
"Havasupai Falls":0x0fafc6,
"Havelock Blue":0x5784c1,
"Haven":0xa3b48c,
"Hawaii Morning":0x00bbff,
"Hawaiian Breeze":0x75c7e0,
"Hawaiian Cinder":0x6f4542,
"Hawaiian Coconut":0x99522c,
"Hawaiian Cream":0xfae8b8,
"Hawaiian Ocean":0x008db9,
"Hawaiian Passion":0xffa03e,
"Hawaiian Pineapple":0xfdd773,
"Hawaiian Shell":0xf3dbd9,
"Hawaiian Sky":0x83a2bd,
"Hawaiian Sunset":0xbb5c14,
"Hawaiian Surf":0x0078a7,
"Hawaiian Vacation":0x77cabd,
"Hawk Grey":0x77757d,
"Hawk Turquoise":0x00756a,
"Hawk’s Eye":0x34363a,
"Hawkbit":0xfddb6d,
"Hawker's Gold":0xf4c26c,
"Hawkes Blue":0xd2daed,
"Hawkesbury":0x729183,
"Hawthorn Berry":0xcc1111,
"Hawthorn Blossom":0xeeffaa,
"Hawthorn Rose":0x884c5e,
"Hawthorne":0xced7c1,
"Hay":0xd3cca3,
"Hay Day":0xdacd81,
"Hay Wain":0xcdad59,
"Hay Yellow":0xc2a770,
"Hayden Valley":0x5f5d50,
"Hayloft":0xcdba96,
"Hayride":0xd4ac99,
"Haystack":0xf1e3c7,
"Haystacks":0xcfac47,
"Haze":0xc8c2c6,
"Haze Blue":0xb7c0be,
"Hazed Nuts":0xc39e6d,
"Hazel":0xae7250,
"Hazel Blush":0xeae2de,
"Hazel Gaze":0xb8bfb1,
"Hazel Woods":0x4a564d,
"Hazelnut":0xa8715a,
"Hazelnut Chocolate":0x7b3f00,
"Hazelnut Cream":0xe6dfcf,
"Hazelnut Milk":0xeeaa77,
"Hazelnut Turkish Delight":0xfce974,
"Hazelwood":0xfff3d5,
"Hazy Blue":0xbcc8cc,
"Hazy Daze":0xa5b8c5,
"Hazy Grove":0xf2f1dc,
"Hazy Mauve":0xc8c6ce,
"Hazy Moon":0xf1dca1,
"Hazy Rose":0xb39897,
"Hazy Skies":0xadbbc4,
"Hazy Sky":0xb7bdd6,
"Hazy Taupe":0xd5c3b5,
"Hazy Trail":0xdcdace,
"He Loves Me":0xe1dbe3,
"Hè Sè Brown":0x7f5e00,
"Head in the Clouds":0xd1dde1,
"Head in the Sand":0xebe2de,
"Healing Aloe":0xb9cab3,
"Healing Plant":0x6c7d42,
"Healing Retreat":0xbac2aa,
"Heart Gold":0x808000,
"Heart of Gold":0x9d7f4c,
"Heart Stone":0xede3df,
"Heart Throb":0xcb3d3c,
"Heart to Heart":0xd4a9c3,
"Heart's Content":0xe2b5bd,
"Heart's Desire":0xac3e5f,
"Heartbeat":0xaa0000,
"Heartbreaker":0xcc76a3,
"Heartfelt":0xffadc9,
"Hearth":0xe1cca6,
"Hearth Gold":0xa17135,
"Hearthstone":0xc7beb2,
"Heartless":0x623b70,
"Hearts of Palm":0xcfc291,
"Heartthrob":0xa82e33,
"Heartwood":0x6f4232,
"Hearty Hosta":0x96bf83,
"Hearty Orange":0xb44b34,
"Heat of Summer":0xe98d5b,
"Heat Signature":0xe3000e,
"Heat Wave":0xff7a00,
"Heath":0x4f2a2c,
"Heath Green":0x9acda9,
"Heath Grey":0xc9cbc2,
"Heath Spotted Orchid":0x9f5f9f,
"Heather":0xa484ac,
"Heather Berry":0xe75480,
"Heather Feather":0xc3adc5,
"Heather Field":0x909095,
"Heather Grey":0x9c9da4,
"Heather Hill":0xbbb0bb,
"Heather Moor":0x998e8f,
"Heather Plume":0xa39699,
"Heather Red Grey":0x988e94,
"Heather Rose":0xad6d7f,
"Heather Sachet":0x7b7173,
"Heather Violet":0xb18398,
"Heathered Grey":0xb6b095,
"Heating Lamp":0xee4422,
"Heaven Sent":0xeee1eb,
"Heaven Sent Storm":0xcad6de,
"Heavenly":0x7eb2c5,
"Heavenly Aromas":0xeedfd5,
"Heavenly Blue":0xa3bbcd,
"Heavenly Cocoa":0xbea79d,
"Heavenly Garden":0x93a394,
"Heavenly Haze":0xd8d5e3,
"Heavenly Pink":0xf4dede,
"Heavenly Sky":0x6b90b3,
"Heavenly Song":0xfbd9c6,
"Heavenly White":0xebe8e6,
"Heavy Black Green":0x3a514d,
"Heavy Blue Grey":0x9fabaf,
"Heavy Brown":0x73624a,
"Heavy Charcoal":0x565350,
"Heavy Cream":0xe8ddc6,
"Heavy Gluten":0xddccaa,
"Heavy Goldbrown":0xbaab74,
"Heavy Green":0x49583e,
"Heavy Grey":0x82868a,
"Heavy Hammock":0xbeb9a2,
"Heavy Heart":0x771122,
"Heavy Khaki":0x5e6a34,
"Heavy Metal":0x46473e,
"Heavy Metal Armor":0x888a8e,
"Heavy Ochre":0x9b753d,
"Heavy Orange":0xee4328,
"Heavy Rain":0x898a86,
"Heavy Red":0x9e1212,
"Heavy Siena":0x735848,
"Heavy Skintone":0x927a71,
"Heavy Sugar":0xeff5f1,
"Heavy Violet":0x4f566c,
"Heavy Warm Grey":0xbdb3a7,
"Hectorite":0xf0e4d2,
"Hedge Garden":0x00aa11,
"Hedge Green":0x768a75,
"Hedgehog Cactus Yellow Green":0xc4aa5e,
"Hedgehog Mushroom":0xfaf0da,
"Hēi Sè Black":0x142030,
"Heidelberg Red":0x960117,
"Heifer":0xc3bdb1,
"Heirloom":0xb67b71,
"Heirloom Apricot":0xf4bea6,
"Heirloom Hydrangea":0x327ccb,
"Heirloom Lace":0xf5e6d6,
"Heirloom Lilac":0x9d96b2,
"Heirloom Orchid":0xae9999,
"Heirloom Quilt":0xab979a,
"Heirloom Rose":0xd182a0,
"Heirloom Shade":0xdcd8d4,
"Heirloom Silver":0xb5b6ad,
"Heirloom Tomato":0x833633,
"Heisenberg Blue":0x70d4fb,
"Helen of Troy":0xc3b89f,
"Helena Rose":0xd28b72,
"Heliotrope":0xd94ff5,
"Heliotrope Grey":0xab98a9,
"Heliotrope Magenta":0xaa00bb,
"Heliotropic Mauve":0x9187bd,
"Helium":0xeae5d8,
"Hellebore":0x646944,
"Hellion Green":0x87c5ae,
"Hello Darkness My Old Friend":0x802280,
"Hello Fall":0x995533,
"Hello Spring":0x44dd66,
"Hello Summer":0x55bbff,
"Hello Winter":0x99ffee,
"Hello Yellow":0xffe59d,
"Helvetia Red":0xf00000,
"Hematite":0x5f615f,
"Hematitic Sand":0xdc8c59,
"Hemisphere":0x5285a4,
"Hemlock":0x69684b,
"Hemlock Bud":0xeceedf,
"Hemoglobin Red":0xc61a1b,
"Hemp":0x987d73,
"Hemp Fabric":0xb5ad88,
"Hemp Rope":0xb9a379,
"Hemp Tea":0xb5b35c,
"Hen of the Woods":0xeed9c4,
"Henna":0x7c423c,
"Henna Red":0x6e3530,
"Henna Shade":0xb3675d,
"Hep Green":0xc4b146,
"Hepatica":0xfbe5ea,
"Hephaestus":0xe1d4b6,
"Hephaestus Gold":0xff9911,
"Hera Blue":0x7777ee,
"Herald of Spring":0xa46366,
"Herald's Trumpet":0xce9f2f,
"Heraldic":0x444161,
"Herare White":0xe7e0d3,
"Herb Cornucopia":0x6e7357,
"Herb Garden":0xe9f3e1,
"Herb Robert":0xdda0df,
"Herbal":0x29ab87,
"Herbal Garden":0x9cad60,
"Herbal Mist":0xd2e6d3,
"Herbal Scent":0x8e9b7c,
"Herbal Tea":0xf9fee9,
"Herbal Vapors":0xddffcc,
"Herbal Wash":0xa49b82,
"Herbalist":0x969e86,
"Herbery Honey":0xeeee22,
"Herbivore":0x88ee77,
"Here Comes the Sun":0xfcdf63,
"Hereford Bull":0x5f3b36,
"Hereford Cow Brown":0x6c2e1f,
"Heritage":0xb0bacc,
"Heritage Blue":0x5d96bc,
"Heritage Oak":0x5c453d,
"Heritage Park":0x69756c,
"Heritage Taffeta":0x956f7b,
"Hermosa Pink":0x8a474c,
"Hero":0x005d6a,
"Heroic Blue":0x1166ff,
"Heron":0x62617e,
"Heron Plume":0xe5e1d8,
"Herring Silver":0xc6c8cf,
"Hesperide Apple Gold":0xffe296,
"Hestia Red":0xee2200,
"Hexed Lichen":0x6e0060,
"Hexos Palesun":0xfbff0a,
"Hey Blue!":0x16f8ff,
"Hi Def Lime":0xbbb465,
"Hibernate":0xaca69f,
"Hibernation":0x6f5166,
"Hibiscus":0xb6316c,
"Hibiscus Delight":0xfe9773,
"Hibiscus Flower":0xbc555e,
"Hibiscus Leaf":0x6e826e,
"Hibiscus Petal":0xedaaac,
"Hibiscus Pop":0xdd77dd,
"Hibiscus Punch":0x5c3d45,
"Hibiscus Red":0xa33737,
"Hickory":0xb7a28e,
"Hickory Branch":0xab8274,
"Hickory Cliff":0x7c6e6d,
"Hickory Grove":0x655341,
"Hickory Nut":0x78614c,
"Hickory Stick":0x997772,
"Hidcote":0x9c949b,
"Hidden Cottage":0x8d7f64,
"Hidden Cove":0xcec6bd,
"Hidden Creek":0xd5dae0,
"Hidden Depths":0x305451,
"Hidden Diary":0xede4cc,
"Hidden Forest":0x4f5a51,
"Hidden Glade":0x98ad8e,
"Hidden Hills":0xc5d2b1,
"Hidden Jade":0xebf1e2,
"Hidden Mask":0x96748a,
"Hidden Meadow":0xbbcc5a,
"Hidden Paradise":0x5e8b3d,
"Hidden Peak":0x727d7f,
"Hidden Sapphire":0x445771,
"Hidden Sea Glass":0x6fd1c9,
"Hidden Trail":0x5f5b4d,
"Hidden Treasure":0xa59074,
"Hidden Tribe":0xbb9900,
"Hidden Waters":0x225258,
"Hideaway":0xc8c0aa,
"Hideout":0x5386b7,
"Hierba Santa":0x77a373,
"High Altar":0x334f7b,
"High Blue":0x4ca8e0,
"High Chaparral":0x75603d,
"High Dive":0x59b9cc,
"High Drama":0x9a3843,
"High Elf Blue":0x8cbed6,
"High Forest Green":0x665d25,
"High Grass":0xbbdd00,
"High Hopes":0xdeeaaa,
"High Maintenance":0xd88cb5,
"High Noon":0xcfb999,
"High Plateau":0xe4b37a,
"High Point":0xbcd8d2,
"High Priest":0x643949,
"High Profile":0x005a85,
"High Rank":0x645453,
"High Reflective White":0xf7f7f1,
"High Rise":0xaeb2b5,
"High Risk Red":0xc71f2d,
"High Salute":0x445056,
"High Sierra":0xcedee2,
"High Society":0xcab7c0,
"High Speed Access":0xbdbebf,
"High Strung":0xac9825,
"High Style":0xa8b1d7,
"High Style Beige":0xe4d7c3,
"High Tea":0x7f6f57,
"High Tea Green":0x567063,
"High Voltage":0xeeff11,
"Highball":0x928c3c,
"Highland":0x7a9461,
"Highland Green":0x305144,
"Highland Ridge":0x8f714b,
"Highland Thistle":0xb9a1ae,
"Highlander":0x3a533d,
"Highlands Moss":0x445500,
"Highlands Twilight":0x484a80,
"Highlight":0xeef0de,
"Highlight Gold":0xdfc16d,
"Highlighter":0xffe536,
"Highlighter Blue":0x3aafdc,
"Highlighter Green":0x1bfc06,
"Highlighter Lavender":0x85569c,
"Highlighter Lilac":0xd72e83,
"Highlighter Orange":0xf39539,
"Highlighter Pink":0xea5a79,
"Highlighter Red":0xe94f58,
"Highlighter Turquoise":0x009e6c,
"Highlighter Yellow":0xf1e740,
"Highway":0xbdb388,
"Highway to Hell":0xcd1102,
"Hihada Brown":0x752e23,
"Hiker's Delight":0xd2b395,
"Hiking Boots":0x5e5440,
"Hiking Trail":0xa99170,
"Hill Giant":0xe0eedf,
"Hillary":0xa7a07e,
"Hills of Ireland":0x417b42,
"Hillsbrad Grass":0x7fa91f,
"Hillside Green":0x8f9783,
"Hillside View":0x8da090,
"Hilltop":0x587366,
"Hilo Bay":0x768aa1,
"Himalaya":0x736330,
"Himalaya Blue":0xaecde0,
"Himalaya Peaks":0xe2eaf0,
"Himalaya Sky":0x7695c2,
"Himalaya White Blue":0xb9dee9,
"Himalayan Balsam":0xff99cc,
"Himalayan Mist":0xe1f0ed,
"Himalayan Poppy":0xbec6d6,
"Himalayan Salt":0xc07765,
"Himawari Yellow":0xfcc800,
"Hindsight":0xbdc9e3,
"Hindu Lotus":0x8e8062,
"Hinoki":0xf8ddb7,
"Hinomaru Red":0xbc002d,
"Hint of Blue":0xcee1f2,
"Hint of Green":0xdfeade,
"Hint of Mauve":0xe1dbd5,
"Hint of Mint":0xdff1d6,
"Hint of Orange":0xf8e6d9,
"Hint of Pink":0xf1e4e1,
"Hint of Red":0xf6dfe0,
"Hint of Vanilla":0xeee8dc,
"Hint of Violet":0xd2d5e1,
"Hint of Yellow":0xfaf1cd,
"Hinterland":0x616c51,
"Hinterlands Green":0x304112,
"Hinting Blue":0xced9dd,
"Hip Hop":0xe4e8a7,
"Hip Waders":0x746a51,
"Hippie Blue":0x49889a,
"Hippie Green":0x608a5a,
"Hippie Pink":0xab495c,
"Hippie Trail":0xc6aa2b,
"Hippogriff Brown":0x5c3c0d,
"Hippolyta":0xcfc294,
"Hippy":0xeae583,
"Hipster":0xf2f1d9,
"Hipster Hippo":0xbfb3ab,
"Hipster Salmon":0xfd7c6e,
"Hipsterfication":0x88513e,
"Hiroshima Aquamarine":0x7fffd4,
"His Eyes":0x9bb9e1,
"Hisoku Blue":0xabced8,
"Historic Cream":0xfdf3e3,
"Historic Shade":0xada791,
"Historic Town":0xa18a64,
"Historic White":0xebe6d7,
"Historical Grey":0xa7a699,
"Historical Ruins":0xbfb9a7,
"Hisui Kingfisher":0x38b48b,
"Hit Grey":0xa1adb5,
"Hit Pink":0xfda470,
"Hitchcock Milk":0xeeffa9,
"Hitching Post":0xc48d69,
"Hitsujiyama Pink":0xee66ff,
"Hive":0xffff77,
"Hobgoblin":0x01ad8f,
"Hockham Green":0x59685f,
"Hoeth Blue":0x57a9d4,
"Hog Bristle":0xdcd1bb,
"Hog-Maw":0xfbe8e4,
"Hog's Pudding":0xdad5c7,
"Hokey Pokey":0xbb8e34,
"Hoki":0x647d86,
"Hokkaido Lavender":0x7736d9,
"Holbein Blue Grey":0x547d86,
"Hold Your Horses":0x705446,
"Hole In One":0x4aae97,
"Holenso":0x598069,
"Holiday":0x81c3b4,
"Holiday Blue":0x32bcd1,
"Holiday Camp":0x6d9e7a,
"Holiday Road":0xb1d1e2,
"Holiday Turquoise":0x8ac6bd,
"Holland Red":0xcb4543,
"Holland Tile":0xdd9789,
"Holland Tulip":0xf89851,
"Hollandaise":0xffee44,
"Hollow Knight":0x330055,
"Holly":0x25342b,
"Holly Berry":0xb44e5d,
"Holly Bush":0x355d51,
"Holly Fern":0x8cb299,
"Holly Glen":0xa2b7b5,
"Holly Green":0x0f9d76,
"Holly Jolly Christmas":0xb50729,
"Holly Leaf":0x2e5a50,
"Hollyhock":0x823270,
"Hollyhock Bloom":0xb7737d,
"Hollyhock Blossom Pink":0xbd79a5,
"Hollyhock Pink":0xc2a1b5,
"Hollywood Asparagus":0xdee7d4,
"Hollywood Cerise":0xf400a0,
"Hollywood Golden Age":0xecd8b1,
"Hollywood Starlet":0xf2d082,
"Holy Crow":0x332f2c,
"Holy Grail":0xe8d720,
"Holy Water":0x466e77,
"Holy White":0xf5f5dc,
"Homburg Gray":0x666d69,
"Home Body":0xf3d2b2,
"Home Brew":0x897b66,
"Home Plate":0xf7eedb,
"Home Song":0xf2eec7,
"Home Sweet Home":0x9b7e65,
"Homebush":0x726e69,
"Homeland":0xb18d75,
"Homeopathic":0x5f7c47,
"Homeopathic Blue":0xdbe7e3,
"Homeopathic Green":0xe1ebd8,
"Homeopathic Lavender":0xe5e0ec,
"Homeopathic Lilac":0xe1e0eb,
"Homeopathic Lime":0xe9f6e2,
"Homeopathic Mint":0xe5ead8,
"Homeopathic Orange":0xf2e6e1,
"Homeopathic Red":0xecdbe0,
"Homeopathic Rose":0xe8dbdd,
"Homeopathic Yellow":0xede7d7,
"Homestead":0xac8674,
"Homestead Brown":0x6f5f52,
"Homestead Red":0x986e6e,
"Homeworld":0x2299dd,
"Honed Soapstone":0x9d9887,
"Honed Steel":0x867c83,
"Honest":0x9bb8e2,
"Honest Blue":0x5a839e,
"Honesty":0xdfebe9,
"Honey":0xba9238,
"Honey and Thyme":0xaaaa00,
"Honey Baked Ham":0xffaa99,
"Honey Bear":0xe8c281,
"Honey Bee":0xfcdfa4,
"Honey Beehive":0xd39f5f,
"Honey Bees":0xfbd682,
"Honey Beige":0xf3e2c6,
"Honey Bird":0xffd28d,
"Honey Blush":0xf5cf9b,
"Honey Bunny":0xdbb881,
"Honey Butter":0xf5d29b,
"Honey Carrot Cake":0xff9955,
"Honey Chili":0x883344,
"Honey Cream":0xfae8ca,
"Honey Crusted Chicken":0xffbb55,
"Honey Do":0xededc7,
"Honey Flower":0x5c3c6d,
"Honey Fungus":0xd18e54,
"Honey Garlic Beef":0x884422,
"Honey Ginger":0xa86217,
"Honey Glow":0xe8b447,
"Honey Gold":0xd1a054,
"Honey Graham":0xbc886a,
"Honey Grove":0xdcb149,
"Honey Haven":0xbc9263,
"Honey Lime Chicken":0xddccbb,
"Honey Locust":0xffc367,
"Honey Mist":0xe5d9b2,
"Honey Moth":0xfbeccc,
"Honey Mustard":0xb68f52,
"Honey N Cream":0xf1dcb7,
"Honey Nectar":0xf1dda2,
"Honey Nougat":0xe0bb96,
"Honey Oat Bread":0xfaeed9,
"Honey Peach":0xdcbd9e,
"Honey Pink":0xcc99aa,
"Honey Pot":0xffc863,
"Honey Robber":0xdfbb86,
"Honey Tea":0xd8be89,
"Honey Teriyaki":0xee6611,
"Honey Tone":0xf8dc9b,
"Honey Wax":0xffaa22,
"Honey Yellow":0xca9456,
"Honey Yellow Green":0x937016,
"Honey Yogurt Popsicles":0xf3f0d9,
"Honeycomb":0xddaa11,
"Honeycomb Yellow":0xde9c52,
"Honeydew":0xf0fff0,
"Honeydew Melon":0xe6eccc,
"Honeydew Peel":0xd4fb79,
"Honeypot":0xf6deb3,
"Honeysuckle":0xe8ed69,
"Honeysuckle Blast":0xb3833f,
"Honeysuckle Vine":0xfbf1c8,
"Honeysuckle White":0xf8ecd3,
"Honeysweet":0xe9cfc8,
"Hóng Bǎo Shū Red":0xe02006,
"Hong Kong Mist":0x948e90,
"Hong Kong Skyline":0x676e7a,
"Hong Kong Taxi":0xa8102a,
"Hóng Lóu Mèng Red":0xcf3f4f,
"Hóng Sè Red":0xff0809,
"Hóng Zōng Brown":0x564a33,
"Honied White":0xfcefd1,
"Honky Tonk Blue":0x446a8d,
"Honolulu Blue":0x007fbf,
"Honorable Blue":0x164576,
"Hooked Mimosa":0xffc9c4,
"Hooker's Green":0x49796b,
"Hooloovoo Blue":0x4455ff,
"Hopbush":0xcd6d93,
"Hope":0xe581a0,
"Hope Chest":0x875942,
"Hopeful":0xf2d4e2,
"Hopeful Blue":0xa2b9bf,
"Hopeful Dream":0x95a9cd,
"Hopi Blue Corn":0x174871,
"Hopi Moccasin":0xffe4b5,
"Hopsack":0x9e8163,
"Hopscotch":0xafbb42,
"Horchata":0xf2e9d9,
"Horenso Green":0x789b73,
"Horizon":0x648894,
"Horizon Blue":0x289dbe,
"Horizon Glow":0xad7171,
"Horizon Grey":0x9ca9aa,
"Horizon Haze":0x80c1e2,
"Horizon Island":0xcdd4c6,
"Horizon Sky":0xc2c3d3,
"Hormagaunt Purple":0x51576f,
"Horn of Plenty":0xbba46d,
"Hornblende":0x332222,
"Hornblende Green":0x234e4d,
"Horned Frog":0xc2ae87,
"Horned Lizard":0xe8ead5,
"Hornet Nest":0xd5dfd3,
"Hornet Sting":0xff0033,
"Hornet Yellow":0xa67c08,
"Horror Snob":0xd34d4d,
"Horse Liver":0x543d37,
"Horseradish":0xe6dfc4,
"Horseradish Cream":0xeeeadd,
"Horseradish Yellow":0xffdea9,
"Horses Neck":0x6d562c,
"Horsetail":0x3d5d42,
"Hortensia":0x553b50,
"Hosanna":0xdbb8bf,
"Hospital Green":0x9be5aa,
"Hosta Flower":0xdcdde7,
"Hostaleaf":0x475a56,
"Hot":0xac4362,
"Hot and Spicy":0xb35547,
"Hot Aquarelle Pink":0xffb3de,
"Hot Beach":0xfff6d9,
"Hot Bolognese":0xcc5511,
"Hot Butter":0xe69d00,
"Hot Cacao":0xa5694f,
"Hot Calypso":0xfa8d7c,
"Hot Chili":0xad756b,
"Hot Chilli":0xb7513a,
"Hot Chocolate":0x683b39,
"Hot Cinnamon":0xd1691c,
"Hot Cocoa":0x806257,
"Hot Coral":0xf35b53,
"Hot Cuba":0xbb0033,
"Hot Curry":0x815b28,
"Hot Desert":0xeae4da,
"Hot Dog Relish":0x717c3e,
"Hot Embers":0xf55931,
"Hot Fever":0xd40301,
"Hot Flamingo":0xb35966,
"Hot Ginger":0xa36736,
"Hot Gossip":0xe07c89,
"Hot Green":0x25ff29,
"Hot Hazel":0xdd6622,
"Hot Hibiscus":0xbb2244,
"Hot Jazz":0xbc3033,
"Hot Lava":0xaa0033,
"Hot Lips":0xc9312b,
"Hot Magenta":0xff00cc,
"Hot Mustard":0x735c12,
"Hot Orange":0xf4893d,
"Hot Pepper Green":0x598039,
"Hot Pink":0xff028d,
"Hot Purple":0xcb00f5,
"Hot Sand":0xccaa00,
"Hot Sauce":0xab4f41,
"Hot Sauna":0x3f3f75,
"Hot Spice":0xcc2211,
"Hot Spot":0xffe597,
"Hot Stone":0xaba89e,
"Hot Sun":0xf9b82b,
"Hot Toddy":0xa7752c,
"Hothouse Orchid":0x755468,
"Hotot Bunny":0xf1f3f2,
"Hotspot":0xff4433,
"Hotter Butter":0xe68a00,
"Hotter Than Hell":0xff4455,
"Hottest Of Pinks":0xff80ff,
"Hourglass":0xe5e0d5,
"House Martin Eggs":0xe2e0db,
"House Sparrow's Egg":0xd6d9dd,
"House Stark Grey":0x4d495b,
"Houseplant":0x58713f,
"How Handsome":0xa0aeb8,
"How Now":0x886150,
"Howdy Neighbor":0xf9e4c8,
"Howdy Partner":0xc6a698,
"Howling Coyote":0x9c7f5a,
"Hú Lán Blue":0x1dacd1,
"Huáng Dì Yellow":0xf8ff73,
"Huáng Jīn Zhōu Gold":0xfada6a,
"Huáng Sè Yellow":0xf0f20c,
"Hubbard Squash":0xe9bf8c,
"Hubert's Truck Green":0x559933,
"Huckleberry":0x5b4349,
"Huckleberry Brown":0x71563b,
"Hudson":0xeadbd2,
"Hudson Bee":0xfdef02,
"Huelveño Horizon":0x17a9e5,
"Hugh's Hue":0x9fa09f,
"Hugo":0xe6cfcc,
"Hūi Sè Grey":0xc1c6d3,
"Hula Girl":0x929264,
"Hulett Ore":0x726f6c,
"Hulk":0x008000,
"Hull Red":0x4d140b,
"Humble Blush":0xe3cdc2,
"Humble Gold":0xedc796,
"Humble Hippo":0xaaaa99,
"Humboldt Redwoods":0x1f6357,
"Humid Cave":0xc9ccd2,
"Hummingbird":0xceefe4,
"Hummingbird Green":0x5b724a,
"Hummus":0xeecc99,
"Humorous Green":0xc6b836,
"Humpback Whale":0x473b3b,
"Humus":0xb7a793,
"Hunky Hummingbird":0xbb11ff,
"Hunt Club":0x2a4f43,
"Hunt Club Brown":0x938370,
"Hunter Green":0x0b4008,
"Hunter's Hollow":0x989a8d,
"Hunter's Orange":0xdb472c,
"Huntington Garden":0x96a782,
"Huntington Woods":0x46554c,
"Hurricane":0x8b7e77,
"Hurricane Green Blue":0x254d54,
"Hurricane Haze":0xbdbbad,
"Hurricane Mist":0xebeee8,
"Hush":0xc4bdba,
"Hush Grey":0xe1ded8,
"Hush Pink":0xf8e9e2,
"Hush Puppy":0xe4b095,
"Hush White":0xe5dad4,
"Hush-A-Bye":0x5397b7,
"Hushed Auburn":0xa8857a,
"Hushed Green":0xd8e9e5,
"Hushed Violet":0xd1c0bf,
"Hushed White":0xf1f2e4,
"Husk":0xb2994b,
"Husky":0xe0ebfa,
"Husky Orange":0xbb613e,
"Hutchins Plaza":0xae957c,
"Hyacinth":0x936ca7,
"Hyacinth Arbor":0x6c6783,
"Hyacinth Dream":0x807388,
"Hyacinth Mauve":0x6f729f,
"Hyacinth Red":0xa75536,
"Hyacinth Tint":0xb9c4d3,
"Hyacinth Violet":0x8d4687,
"Hyacinth White Soft Blue":0xc1c7d7,
"Hybrid":0xd0cda9,
"Hydra":0x006995,
"Hydra Turquoise":0x007a73,
"Hydrangea":0x849bcc,
"Hydrangea Blossom":0xa6aebe,
"Hydrangea Bouquet":0xcaa6a9,
"Hydrangea Floret":0xe6eae0,
"Hydrangea Pink":0xe7b6c8,
"Hydrangea Purple":0xcaa0ff,
"Hydrargyrum":0x9b9b9b,
"Hydro":0x426972,
"Hydrogen Blue":0x33476d,
"Hydrology":0x89acac,
"Hydroport":0x5e9ca1,
"Hygge Green":0xe0e1d8,
"Hygiene Green":0x5dbcb4,
"Hyper Blue":0x015f97,
"Hyper Green":0x55ff00,
"Hyper Light Drifter":0xeddbda,
"Hypnotic":0x687783,
"Hypnotic Sea":0x00787f,
"Hypnotism":0x32584c,
"Hypothalamus Grey":0x415d66,
"Hyssop":0x6d4976,
"I Heart Potion":0xa97fb1,
"I Love To Boogie":0xffa917,
"I Miss You":0xdddbc5,
"I Pink I Can":0xd47f8d,
"I R Dark Green":0x404034,
"I'm a Local":0xebbf5c,
"Ibex Brown":0x482400,
"Ibis":0xf4b3c2,
"Ibis Mouse":0xe4d2d8,
"Ibis Rose":0xca628f,
"Ibis White":0xf2ece6,
"Ibis Wing":0xf58f84,
"Ibiza Blue":0x007cb7,
"Ice":0xd6fffa,
"Ice Age":0xc6e4e9,
"Ice Ballet":0xeadee8,
"Ice Blue":0x739bd0,
"Ice Blue Grey":0x717787,
"Ice Bomb":0xcce2dd,
"Ice Boutique Turquoise":0xa2cdcb,
"Ice Breaker":0xd4e7e7,
"Ice Cap Green":0xb9e7dd,
"Ice Castle":0xd5edfb,
"Ice Cave":0xa0beda,
"Ice Climber":0x25e2cd,
"Ice Cold":0xd2eaf1,
"Ice Cold Green":0xd9ebac,
"Ice Cold Stare":0xb1d1fc,
"Ice Cream Cone":0xe3d0bf,
"Ice Cream Parlour":0xf7d3ad,
"Ice Crystal Blue":0xa6e3e0,
"Ice Cube":0xafe3d6,
"Ice Dagger":0xcee5df,
"Ice Dark Turquoise":0x005456,
"Ice Dream":0xeaebe1,
"Ice Drop":0xd3e2ee,
"Ice Effect":0xbbeeff,
"Ice Fishing":0xdcecf5,
"Ice Floe":0xd8e7e1,
"Ice Flow":0xc6d2d2,
"Ice Flower":0xc3e7ec,
"Ice Folly":0xdbece9,
"Ice Glow":0xffffe9,
"Ice Green":0x87d8c3,
"Ice Grey":0xcac7c4,
"Ice Gull Grey Blue":0x9bb2ba,
"Ice Hot Pink":0xe4bdc2,
"Ice Ice Baby":0x00ffdd,
"Ice Lemon":0xfffbc1,
"Ice Mauve":0xc9c2dd,
"Ice Mist":0xb6dbbf,
"Ice Pack":0xa5dbe3,
"Ice Palace":0xe2e4d7,
"Ice Plant":0xcf7ead,
"Ice Rink":0xbbddee,
"Ice Sculpture":0xe1e6e5,
"Ice Shard Soft Blue":0xc1dee2,
"Ice Temple":0x11ffee,
"Ice Water Green":0xcdebe1,
"Ice Yellow":0xfefecd,
"Ice-Cold White":0xdff0e2,
"Iceberg":0xdae4ee,
"Iceberg Green":0x8c9c92,
"Iced Aniseed":0xcbd3c3,
"Iced Apricot":0xefd6c0,
"Iced Aqua":0xabd3db,
"Iced Avocado":0xc8e4b9,
"Iced Cappuccino":0x9c8866,
"Iced Celery":0xe5e9b7,
"Iced Cherry":0xe8c7bf,
"Iced Coffee":0xb18f6a,
"Iced Copper":0xd0ae9a,
"Iced Espresso":0x5a4a42,
"Iced Green Apple":0xecebc9,
"Iced Lavender":0xc2c7db,
"Iced Mauve":0xe8dce3,
"Iced Mocha":0xa3846c,
"Iced Orchid":0x8e7d89,
"Iced Slate":0xd6dcd7,
"Iced Tea":0xb87253,
"Iced Tulip":0xafa9af,
"Iced Vovo":0xe1a4b2,
"Iced Watermelon":0xd1afb7,
"Iceland Green":0x008b52,
"Iceland Poppy":0xf4963a,
"Icelandic":0xdae4ec,
"Icelandic Blue":0xa9adc2,
"Icelandic Water":0x0011ff,
"Icelandic Winds":0xd7deeb,
"Icelandic Winter":0xd9e7e3,
"Icepick":0xdadcd0,
"Icewind Dale":0xe8ecee,
"Icicle":0xdde7df,
"Icicle Mint":0xcfe8e6,
"Icicles":0xbcc5c9,
"Icing Flower":0xd5b7cb,
"Icing Rose":0xf5eee7,
"Icky Green":0x8fae22,
"Icterine":0xfcf75e,
"Icy":0xbbc7d2,
"Icy Bay":0xe0e5e2,
"Icy Brook":0xc1cad9,
"Icy Lavender":0xe2e2ed,
"Icy Lemonade":0xf4e8b2,
"Icy Life":0x55ffee,
"Icy Lilac":0xe6e9f9,
"Icy Morn":0xb0d3d1,
"Icy Teal":0xd6dfe8,
"Icy Tundra":0xf7f5ec,
"Icy Water":0xbce2e8,
"Icy Waterfall":0xc0d2d0,
"Icy Wind":0xd3f1ee,
"Identity":0x7890ac,
"Idol":0x645a8b,
"Idyllic Isle":0x94c8d2,
"Idyllic Pink":0xc89eb7,
"Igloo":0xfdfcfa,
"Igloo Blue":0xc9e5eb,
"Iguaçuense Waterfall":0x2e776d,
"Iguana":0x818455,
"Iguana Green":0x71bc77,
"Ikkonzome Pink":0xf08f90,
"Illicit Darkness":0x00022e,
"Illicit Green":0x56fca2,
"Illicit Pink":0xff5ccd,
"Illicit Purple":0xbf77f6,
"Illuminated":0xf9e5d8,
"Illuminati Green":0x419168,
"Illuminating":0xeeee77,
"Illuminating Emerald":0x319177,
"Illuminating Experience":0xdee4e0,
"Illusion":0xef95ae,
"Illusion Blue":0xc9d3dc,
"Illusionist":0x574f64,
"Illusive Dream":0xe1d5c2,
"Illusive Green":0x92948d,
"Illustrious Indigo":0x5533bb,
"Ilvaite Black":0x330011,
"Imagery":0x7a6e70,
"Imaginary Mauve":0x89687d,
"Imagination":0xdfe0ee,
"Imagine":0xaf9468,
"Imagine That":0x947c98,
"Imam Ali Gold":0xfae199,
"Imayou Pink":0xd0576b,
"Immaculate Iguana":0xaacc00,
"Immersed":0x204f54,
"Immortal":0xc0a9cc,
"Immortal Indigo":0xd8b7cf,
"Immortality":0x945b7f,
"Immortelle Yellow":0xd4a207,
"Impala":0xf8ce97,
"Impatiens Petal":0xf1d2d7,
"Impatiens Pink":0xffc4bc,
"Impatient Heart":0xc47d7c,
"Impatient Pink":0xdb7b97,
"Imperial":0x602f6b,
"Imperial Blue":0x002395,
"Imperial Dynasty":0x33746b,
"Imperial Grey":0x676a6a,
"Imperial Ivory":0xf1e8d2,
"Imperial Jewel":0x693e42,
"Imperial Palace":0x604e7a,
"Imperial Palm":0x596458,
"Imperial Primer":0x21303e,
"Imperial Purple":0x542c5d,
"Imperial Red":0xec2938,
"Impetuous":0xe4d68c,
"Impression of Obscurity":0x1a2578,
"Impressionist Blue":0xa7cac9,
"Impressionist Sky":0xb9cee0,
"Impressive Ivory":0xf4dec3,
"Improbable":0x6e7376,
"Impromptu":0x705f63,
"Impulse":0x005b87,
"Impulsive Purple":0x624977,
"Impure White":0xf5e7e3,
"Imrik Blue":0x67aed0,
"In A Pickle":0x978c59,
"In for a Penny":0xee8877,
"In Good Taste":0xb6d4a0,
"In the Blue":0x9eb0bb,
"In the Buff":0xd6cbbf,
"In the Hills":0xaea69b,
"In the Moment":0x859893,
"In the Navy":0x283849,
"In the Pink":0xf4c4d0,
"In the Red":0xff2233,
"In the Shadows":0xcbc4c0,
"In The Slip":0xe2c3cf,
"In the Spotlight":0xede6ed,
"In the Tropics":0xa3bc3a,
"In the Woods":0x72786f,
"Inca Gold":0xbb7a2c,
"Inca Temple":0x8c7b6c,
"Inca Yellow":0xffd301,
"Incan Treasure":0xf9ddc4,
"Incandescence":0xffbb22,
"Incarnadine":0xaa0022,
"Incense":0xaf9a7e,
"Inchworm":0xb2ec5d,
"Incision":0xff0022,
"Incognito":0x8e8e82,
"Incredible White":0xe3ded7,
"Incremental Blue":0x123456,
"Incubi Darkness":0x0b474a,
"Incubus":0x772222,
"Independence":0x4c516d,
"Independent Gold":0xd2ba83,
"India Blue":0x008a8e,
"India Green":0x138808,
"India Ink":0x3c3d4c,
"India Trade":0xe0a362,
"Indian Brass":0xa5823d,
"Indian Clay":0xf2d0c0,
"Indian Dance":0xf49476,
"Indian Green":0x91955f,
"Indian Ink":0x3c3f4a,
"Indian Khaki":0xd3b09c,
"Indian Maize":0xe4c14d,
"Indian Mesa":0xd5a193,
"Indian Muslin":0xeae3d8,
"Indian Ocean":0x86b7a1,
"Indian Paintbrush":0xfa9761,
"Indian Pale Ale":0xd5bc26,
"Indian Peafowl":0x0044aa,
"Indian Pink":0xad5b78,
"Indian Princess":0xda846d,
"Indian Red":0x850e04,
"Indian Reed":0x9f7060,
"Indian Silk":0x8a5773,
"Indian Spice":0xae8845,
"Indian Summer":0xa85143,
"Indian Sunset":0xd98a7d,
"Indian Teal":0x3c586b,
"Indian White":0xefdac2,
"Indian Yellow":0xe3a857,
"Indiana Clay":0xe88a5b,
"Indica":0x588c3a,
"Indifferent":0x9892b8,
"Indigo":0x4b0082,
"Indigo Batik":0x4467a7,
"Indigo Black":0x002e51,
"Indigo Blue":0x3a18b1,
"Indigo Bunting":0x006ca9,
"Indigo Carmine":0x006ec7,
"Indigo Child":0xa09fcc,
"Indigo Dye":0x00416c,
"Indigo Hamlet":0x1f4788,
"Indigo Ink":0x474a4d,
"Indigo Ink Brown":0x393432,
"Indigo Iron":0x393f4c,
"Indigo Light":0x5d76cb,
"Indigo Mouse":0x6c848d,
"Indigo Navy Blue":0x4c5e87,
"Indigo Night":0x324680,
"Indigo Purple":0x660099,
"Indigo Red":0x695a78,
"Indigo Sloth":0x1f0954,
"Indigo White":0xebf6f7,
"Indiscreet":0xac3b3b,
"Individual White":0xd4cdca,
"Indiviolet Sunset":0x6611aa,
"Indochine":0x9c5b34,
"Indocile Indochine":0xb96b00,
"Indolence":0xa29dad,
"Indonesian Jungle":0x008c69,
"Indonesian Rattan":0xd1b272,
"Indulgence":0x533d47,
"Indulgent":0x66565f,
"Indulgent Mocha":0xd1c5b7,
"Industrial Age":0xaeadad,
"Industrial Black":0x322b26,
"Industrial Blue":0x00898c,
"Industrial Green":0x114400,
"Industrial Grey":0x5b5a57,
"Industrial Revolution":0x737373,
"Industrial Rose":0xe09887,
"Industrial Strength":0x877a65,
"Industrial Turquoise":0x008a70,
"Ineffable Forest":0x4f9153,
"Ineffable Green":0x63f7b4,
"Ineffable Ice Cap":0xcaede4,
"Ineffable Linen":0xe6e1c7,
"Ineffable Magenta":0xcc99cc,
"Infamous":0x777985,
"Infatuation":0xf0d5ea,
"Inferno":0xda5736,
"Infinite Deep Sea":0x435a6f,
"Infinitesimal Blue":0xbddde1,
"Infinitesimal Green":0xd7e4cc,
"Infinity":0x222831,
"Infinity and Beyond":0x6e7e99,
"Informal Ivory":0xf1e7d0,
"Informative Pink":0xfe85ab,
"Infra Red":0xfe486c,
"Infra-White":0xffccee,
"Infrared Burn":0xdd3333,
"Infrared Flush":0xcc3344,
"Infrared Gloze":0xcc3355,
"Infrared Tang":0xdd2244,
"Infusion":0xc8d0ca,
"Inglenook Olive":0xaaa380,
"Inheritance":0xd7ae77,
"Ink Black":0x252024,
"Ink Blotch":0x00608b,
"Ink Blue":0x0b5369,
"Inked":0x3b5066,
"Inked Silk":0xd9dce4,
"Inkjet":0x44556b,
"Inkwell":0x31363a,
"Inky Blue":0x4e7287,
"Inky Storm":0x535266,
"Inland":0x606b54,
"Inlet Harbor":0x3f586e,
"Inner Cervela":0xbbaa7e,
"Inner Child":0xf1bdb2,
"Inner Journey":0x6d69a1,
"Inner Space":0x285b5f,
"Inner Touch":0xbbafba,
"Inness Sage":0x959272,
"Innisfree Garden":0x229900,
"Innocence":0xebd1cf,
"Innocent Pink":0x856f79,
"Innuendo":0xa4b0c4,
"Inoffensive Blue":0x114477,
"Inside":0x221122,
"Inside Passage":0xe0cfb5,
"Insightful Rose":0xc9b0ab,
"Insignia Blue":0x2f3e55,
"Insignia White":0xecf3f9,
"Inspiration Peak":0x4fa183,
"Inspired Lilac":0xdfd9e4,
"Instant":0xd9cec7,
"Instant Classic":0xe3dac6,
"Instant Noodles":0xf4d493,
"Instant Orange":0xff8d28,
"Instant Relief":0xede7d2,
"Instigate":0xada7c8,
"Integra":0x405e95,
"Integrity":0x233e57,
"Intellectual":0x3f414c,
"Intellectual Gray":0xa8a093,
"Intense Brown":0x7f5400,
"Intense Green":0x123328,
"Intense Jade":0x68c89d,
"Intense Mauve":0x682d63,
"Intense Passion":0xdf3163,
"Intense Purple":0x4d4a6f,
"Intense Teal":0x00978c,
"Intense Yellow":0xe19c35,
"Inter-Galactic Blue":0xafe0ef,
"Interactive Cream":0xe4caad,
"Intercoastal Grey":0xa8b5bc,
"Interdimensional Blue":0x360ccc,
"Interdimensional Portal":0xd6e6e6,
"Interesting Aqua":0x9bafb2,
"Interface Tan":0xc1a392,
"Intergalactic":0x4d516c,
"Intergalactic Cowboy":0x222266,
"Intergalactic Ray":0x573935,
"Interior Green":0x536437,
"Interlude":0x564355,
"Intermediate Blue":0x56626e,
"Intermediate Green":0x137730,
"International":0x3762a5,
"International Blue":0x002fa7,
"International Klein Blue":0x002fa6,
"International Orange":0xba160c,
"Interstellar Blue":0x001155,
"Intimate Journal":0xccbb99,
"Intimate White":0xf0e1d8,
"Into the Stratosphere":0x425267,
"Intoxicate":0x11bb55,
"Intoxication":0xa1ac4d,
"Intrepid Grey":0xe0e2e0,
"Intricate Ivory":0xedddca,
"Intrigue":0x635951,
"Intrigue Red":0xb24648,
"Introspective":0x6d6053,
"Intuitive":0xcfc6bc,
"Inuit Blue":0xd8e4e7,
"Inuit White":0xd1cdd0,
"Inventive Orange":0xe89d6f,
"Inverness":0x576238,
"Inverness Grey":0xdce3e2,
"Invigorate":0xe47237,
"Invigorating":0xf1eab4,
"Invitation Gold":0xa6773f,
"Inviting Gesture":0xcdc29d,
"Inviting Ivory":0xf2d5b0,
"Inviting Veranda":0xb9c4bc,
"Iolite":0x707bb4,
"Ionian":0x368976,
"Ionic Ivory":0xe7dfc5,
"Ionic Sky":0xd0ede9,
"Ionized-air Glow":0x55ddff,
"Iqaluit Ice":0x93cfe3,
"Ireland Green":0x006c2e,
"Iridescent":0x3a5b52,
"Iridescent Green":0x48c072,
"Iridescent Peacock":0x00707d,
"Iridescent Purple":0x966fd6,
"Iridescent Red":0xcc4e5c,
"Iridescent Turquoise":0x7bfdc7,
"Iris":0x5a4fcf,
"Iris Bloom":0x5b609e,
"Iris Blue":0x03b4c8,
"Iris Eyes":0x767694,
"Iris Ice":0xe0e3ef,
"Iris Isle":0xe8e5ec,
"Iris Mauve":0xb39b94,
"Iris Orchid":0xa767a2,
"Iris Petal":0x6b6273,
"Iris Pink":0xcab9be,
"Irish Beauty":0x007f59,
"Irish Charm":0x69905b,
"Irish Clover":0x53734c,
"Irish Coffee":0x62422b,
"Irish Cream":0xe9dbbe,
"Irish Folklore":0xd3e3bf,
"Irish Green":0x019529,
"Irish Hedge":0x7cb386,
"Irish Jig":0x66cc11,
"Irish Linen":0xeee4e0,
"Irish Mist":0xe7e5db,
"Irish Moor":0xb5c0b3,
"Irogon Blue":0x9dacb5,
"Iroko":0x433120,
"Iron":0x5e5e5e,
"Iron Creek":0x50676b,
"Iron Earth":0x8aa1a6,
"Iron Fist":0xcbcdcd,
"Iron Fixture":0x5d5b5b,
"Iron Flint":0x6e3b31,
"Iron Gate":0x4e5055,
"Iron Grey":0x7c7f7c,
"Iron Head":0x344d56,
"Iron Maiden":0xd6d1dc,
"Iron Mountain":0x757574,
"Iron Ore":0xaf5b46,
"Iron Oxide":0x835949,
"Iron River":0x4d504b,
"Iron Wood":0xa0a6a8,
"Iron-ic":0x6a6b67,
"Ironbreaker":0x887f85,
"Ironbreaker Metal":0xa1a6a9,
"Ironclad":0x615c55,
"Ironside Grey":0x706e66,
"Ironstone":0x865040,
"Ironwood":0xa19583,
"Irradiant Iris":0xdadee6,
"Irradiated Green":0xaaff55,
"Irresistible":0xb3446c,
"Irresistible Beige":0xe6ddc6,
"Irrigation":0x786c57,
"Irrigo Purple":0x9955ff,
"Irritated Ibis":0xee1122,
"Is It Cold":0x0022ff,
"Isabella's Aqua":0x9bd8c4,
"Isabelline":0xf4f0ec,
"Ishtar":0x484450,
"Islamic Green":0x009900,
"Island Aqua":0x2bb9af,
"Island Breeze":0x8adacf,
"Island Coral":0xd8877a,
"Island Dream":0x139ba2,
"Island Embrace":0xded9b4,
"Island Girl":0xffb59a,
"Island Green":0x2bae66,
"Island Hopping":0xf6e3d6,
"Island Light":0xa7c9eb,
"Island Lush":0x008292,
"Island Moment":0x3fb2a8,
"Island Monkey":0xad4e1a,
"Island Oasis":0x88d9d8,
"Island Palm":0x6c7e71,
"Island Paradise":0x95dee3,
"Island Sea":0x81d7d0,
"Island Spice":0xf8eddb,
"Island View":0xc3ddee,
"Isle of Capri":0x0099c9,
"Isle of Dreams":0xbcccb5,
"Isle of Pines":0x3e6655,
"Isle of Sand":0xf9dd13,
"Isle Royale":0x80d7cf,
"Isolation":0x494d55,
"Isotonic Water":0xddff55,
"Issey-San":0xcfdac3,
"It Works":0xaf8a5b,
"It's a Girl":0xde95ae,
"It's A Girl!":0xffdae2,
"It's My Party":0xcc7365,
"It's Your Mauve":0xbc989e,
"Italian Basil":0x5f6957,
"Italian Buckthorn":0x6b8c23,
"Italian Clay":0xd79979,
"Italian Fitch":0xd0c8e6,
"Italian Grape":0x413d4b,
"Italian Ice":0xe2e0d3,
"Italian Lace":0xede9d4,
"Italian Olive":0x807243,
"Italian Plum":0x533146,
"Italian Roast":0x221111,
"Italian Sky Blue":0xb2fcff,
"Italian Straw":0xe7d1a1,
"Italian Villa":0xad5d5d,
"Italiano Rose":0xd16169,
"Ivalo River":0xcce5e8,
"Ivoire":0xe4ceac,
"Ivory":0xfffff0,
"Ivory Charm":0xfff6da,
"Ivory Coast":0xfaf5de,
"Ivory Cream":0xdac0a7,
"Ivory Invitation":0xfcefd6,
"Ivory Keys":0xf8f7e6,
"Ivory Lace":0xece2cc,
"Ivory Lashes":0xe6e6d8,
"Ivory Memories":0xe6ddcd,
"Ivory Mist":0xefeade,
"Ivory Oats":0xf9e4c1,
"Ivory Palace":0xeeeadc,
"Ivory Paper":0xe6deca,
"Ivory Parchment":0xefe3ca,
"Ivory Ridge":0xd9c9b8,
"Ivory Steam":0xf0eada,
"Ivory Stone":0xeee1cc,
"Ivory Tassel":0xf8ead8,
"Ivory Tower":0xfbf3f1,
"Ivy":0x226c63,
"Ivy Enchantment":0x93a272,
"Ivy Garden":0x818068,
"Ivy Green":0x585442,
"Ivy League":0x007958,
"Ivy Topiary":0x67614f,
"Ivy Wreath":0x708d76,
"Iwai Brown":0x6b6f59,
"Iwaicha Brown":0x5e5545,
"Iyanden Darksun":0xa59a59,
"Izmir Pink":0xceb0b5,
"Izmir Purple":0x4d426e,
"J's Big Heart":0xa06856,
"Jabłoński Brown":0xad6d68,
"Jabłoński Grey":0x536871,
"Jacaranda":0xf9d7ee,
"Jacaranda Jazz":0x6c70a9,
"Jacaranda Light":0xa8acb7,
"Jacaranda Pink":0xc760ff,
"Jacarta":0x440044,
"Jacey's Favorite":0xbcaccd,
"Jack and Coke":0x920f0e,
"Jack Bone":0x869f69,
"Jack Frost":0xdae6e3,
"Jack Rabbit":0xc0b2b1,
"Jack-o":0xfb9902,
"Jack-O-Lantern":0xd37a51,
"Jackal":0xa9a093,
"Jackfruit":0xf7c680,
"Jacko Bean":0x413628,
"Jackpot":0xd19431,
"Jackson Antique":0xc3bda9,
"Jacksons Purple":0x3d3f7d,
"Jacobean Lace":0xe4ccb0,
"Jacqueline":0x5d4e50,
"Jacuzzi":0x007cac,
"Jade":0x00a86b,
"Jade Bracelet":0xc2d7ad,
"Jade Cream":0x60b892,
"Jade Dragon":0x6aa193,
"Jade Dust":0xceddda,
"Jade Glass":0x00ced1,
"Jade Gravel":0x0abab5,
"Jade Green":0x779977,
"Jade Jewel":0x247e81,
"Jade Light Green":0xc1cab7,
"Jade Lime":0xa1ca7b,
"Jade Mist":0xd6e9d7,
"Jade Mountain":0x34c2a7,
"Jade Mussel Green":0x166a45,
"Jade Orchid":0x00aaaa,
"Jade Powder":0x2baf6a,
"Jade Shard":0x017b92,
"Jade Spell":0xc1e5d5,
"Jade Stone Green":0x74bb83,
"Jade Tinge":0xbbccbc,
"Jaded":0x0092a1,
"Jaded Clouds":0xaeddd3,
"Jaded Ginger":0xcc7766,
"Jadeite":0x38c6a1,
"Jadesheen":0x77a276,
"Jadite":0x61826c,
"Jaffa":0xe27945,
"Jaffa Orange":0xd86d39,
"Jagdwurst":0xffcccb,
"Jagged Ice":0xcae7e2,
"Jagger":0x3f2e4c,
"Jaguar":0x29292f,
"Jaguar Rose":0xf1b3b6,
"Jaipur Pink":0xd0417e,
"Jakarta":0xefddc3,
"Jakarta Skyline":0x3d325d,
"Jalapeño":0x9a8d3f,
"Jalapeño Bouquet":0x576648,
"Jalapeño Red":0xb2103c,
"Jam Session":0xd4cfd6,
"Jama Masjid Taupe":0xb38b6d,
"Jamaica Bay":0x95cbc4,
"Jamaican Dream":0x04627a,
"Jamaican Jade":0x64d1be,
"Jamaican Sea":0x26a5ba,
"Jambalaya":0xf7b572,
"James Blonde":0xf2e3b5,
"Janemba Red":0xff2211,
"Janey's Party":0xceb5c8,
"Janitor":0x2266cc,
"Janna":0xf4ebd3,
"January Blue":0x00a1b9,
"January Dawn":0xdfe2e5,
"January Frost":0x99c1dc,
"January Garnet":0x7b4141,
"Japan Blush":0xddd6f3,
"Japanese Bonsai":0x829f96,
"Japanese Carmine":0x9f2832,
"Japanese Coral":0xc47a88,
"Japanese Cypress":0x965036,
"Japanese Fern":0xb5b94c,
"Japanese Horseradish":0xa8bf93,
"Japanese Indigo":0x264348,
"Japanese Iris":0x7f5d3b,
"Japanese Kimono":0xcc6358,
"Japanese Koi":0xdb7842,
"Japanese Laurel":0x2f7532,
"Japanese Maple":0x780109,
"Japanese Poet":0xc4bab7,
"Japanese Rose Garden":0xe4b6c4,
"Japanese Sable":0x313739,
"Japanese Violet":0x5b3256,
"Japanese Wax Tree":0xb77b57,
"Japanese White":0xeee6d9,
"Japanese Wineberry":0x522c35,
"Japanese Yew":0xd8a373,
"Japonica":0xce7259,
"Jardin":0xbdd0ab,
"Jardin De Hierbas":0xc6caa7,
"Jargon Jade":0x53a38f,
"Jarrah":0x827058,
"Jasmine":0xfff4bb,
"Jasmine Flower":0xf4e8e1,
"Jasmine Green":0x7ec845,
"Jasmine Hollow":0x7e7468,
"Jasper":0xd73b3e,
"Jasper Cane":0xe7c89f,
"Jasper Green":0x57605a,
"Jasper Orange":0xde8f4e,
"Jasper Park":0x4a6558,
"Jasper Stone":0x8d9e97,
"Java":0x259797,
"Jay Bird":0x50859e,
"Jay Wing Feathers":0x7994b5,
"Jazlyn":0x464152,
"Jazz":0x5f2c2f,
"Jazz Age Blues":0x3b4a6c,
"Jazz Age Coral":0xf1bfb1,
"Jazz Blue":0x1a6a9f,
"Jazz Tune":0x9892a8,
"Jazzberry Jam":0x674247,
"Jazzercise":0xb6e12a,
"Jazzy":0xb61c50,
"Jazzy Jade":0x55ddcc,
"Jealous Jellyfish":0xbb0099,
"Jealousy":0x7fab60,
"Jean Jacket Blue":0x7b90a2,
"Jeans Indigo":0x6d8994,
"Jedi Night":0x041108,
"Jefferson Cream":0xf1e4c8,
"Jelly Bean":0x44798e,
"Jelly Berry":0xee1177,
"Jelly Slug":0xde6646,
"Jelly Yogurt":0xede6d9,
"Jellybean Pink":0x9b6575,
"Jellyfish Blue":0x95cad0,
"Jellyfish Sting":0xee6688,
"Jemima":0xf6d67f,
"Jerboa":0xdeb887,
"Jericho Jade":0x4d8681,
"Jersey Cream":0xf5debb,
"Jess":0x25b387,
"Jester Red":0x9e1030,
"Jet":0x343434,
"Jet Black":0x2d2c2f,
"Jet d'Eau":0xd1eaec,
"Jet Fuel":0x575654,
"Jet Grey":0x9d9a9a,
"Jet Set":0x262c2a,
"Jet Ski":0x5492af,
"Jet Stream":0xbbd0c9,
"Jet White":0xf2ede2,
"Jetski Race":0x005d96,
"Jetstream":0xb0d2d6,
"Jewel":0x136843,
"Jewel Caterpillar":0xd374d5,
"Jewel Cave":0x3c4173,
"Jewel Weed":0x46a795,
"Jewellery White":0xced6e6,
"Jewett White":0xe6ddca,
"Jigglypuff":0xffaaff,
"Jimbaran Bay":0x3d5d64,
"Jīn Huáng Gold":0xf5d565,
"Jīn Sè Gold":0xa5a502,
"Jīn Zōng Gold":0x8e7618,
"Jinza Safflower":0xee827c,
"Jinzamomi Pink":0xf7665a,
"Jitterbug":0xbac08a,
"Jitterbug Jade":0x019d6e,
"Jitterbug Lure":0x8db0ad,
"Jittery Jade":0x77eebb,
"Job's Tears":0x005b7a,
"Jocose Jade":0x77cc99,
"Jocular Green":0xcce2ca,
"Jodhpur Blue":0x9bd7e9,
"Jodhpur Tan":0xdad1c8,
"Jodhpurs":0xebdcb6,
"Jogging Path":0xc0b9a9,
"John Lemon":0xeeff22,
"Joie De Vivre":0xbc86af,
"Jojoba":0xdabe81,
"Jokaero Orange":0xea5505,
"Joker's Smile":0xd70141,
"Jolly Green":0x5e774a,
"Jolly Jade":0x77ccbb,
"Jonquil":0xeef293,
"Jonquil Trail":0xf7d395,
"Jordan Jazz":0x037a3b,
"Jordy Blue":0x7aaae0,
"Josephine":0xd3c3be,
"Joshua Tree":0x7fb377,
"Journal White":0xe6d3b2,
"Journey to the Sky":0xcdeced,
"Journey's End":0xbac9d4,
"Joust Blue":0x55aaff,
"Jovial":0xeeb9a7,
"Jovial Jade":0x88ddaa,
"Joyful":0xf6eec0,
"Joyful Lilac":0xe4d4e2,
"Joyful Orange":0xfa9335,
"Joyful Poppy":0xebada5,
"Joyful Ruby":0x503136,
"Joyful Tears":0x006669,
"Joyous":0xffeeb0,
"Joyous Song":0x5b365e,
"Jú Huáng Tangerine":0xf9900f,
"Jube":0x4b373c,
"Jube Green":0x78cf86,
"Jubilant Jade":0x44aa77,
"Jubilation":0xfbdd24,
"Jubilee":0x7e6099,
"Jubilee Grey":0x7c7379,
"Judah Silk":0x473739,
"Judge Grey":0x5d5346,
"Jugendstil Green":0xc3c8b3,
"Jugendstil Pink":0x9d6375,
"Jugendstil Turquoise":0x5f9b9c,
"Juggernaut":0x255367,
"Juice Violet":0x442238,
"Juicy Details":0xd9787c,
"Juicy Fig":0x7d6c4a,
"Juicy Jackfruit":0xeedd33,
"Juicy Lime":0xb1cf5d,
"Juicy Mango":0xffd08d,
"Juicy Passionfruit":0xf18870,
"Julep":0x57aa80,
"Julep Green":0xc7dbd9,
"Jules":0xa73940,
"July":0x8bd2e3,
"July Ruby":0x773b4a,
"Jumbo":0x878785,
"June":0x9bc4d4,
"June Berry":0x9b96b6,
"June Bud":0xbdda57,
"June Bug":0x264a48,
"June Bugs":0xbb6633,
"June Day":0xffe182,
"June Vision":0xf1f1da,
"Juneberry":0x775496,
"Jungle":0x00a466,
"Jungle Adventure":0x446d46,
"Jungle Book Green":0x366c4e,
"Jungle Camouflage":0x53665a,
"Jungle Civilization":0x69673a,
"Jungle Cloak":0x686959,
"Jungle Cover":0x565042,
"Jungle Expedition":0xb49356,
"Jungle Green":0x048243,
"Jungle Juice":0xa4c161,
"Jungle Khaki":0xc7bea7,
"Jungle King":0x4f4d32,
"Jungle Mist":0xb0c4c4,
"Jungle Moss":0xbdc3ac,
"Jungle Noises":0x36716f,
"Jungle Trail":0x6d6f42,
"Juniper":0x74918e,
"Juniper Ash":0x798884,
"Juniper Berries":0x547174,
"Juniper Berry":0xb9b3c2,
"Juniper Berry Blue":0x3f626e,
"Juniper Breeze":0xd9e0d8,
"Juniper Green":0x567f69,
"Juniper Oil":0x6b8b75,
"Junket":0xfbecd3,
"Junkrat":0x998778,
"Jupiter":0xe1e1e2,
"Jupiter Brown":0xac8181,
"Jurassic Gold":0xe7aa56,
"Jurassic Park":0x3c663e,
"Just a Fairytale":0x6c5d97,
"Just a Little":0xdbe0d6,
"Just A Tease":0xfbd6d2,
"Just About Green":0xe2e7d3,
"Just About White":0xe8e8e0,
"Just Blush":0xfab4a4,
"Just Gorgeous":0xd6c4c1,
"Just Peachy":0xf8c275,
"Just Perfect":0xeaecd3,
"Just Pink Enough":0xffebee,
"Just Right":0xdcbfac,
"Just Rosey":0xc4a295,
"Justice":0x606b8e,
"Jute":0xad9773,
"Jute Brown":0x815d40,
"Juzcar Blue":0xa1d5f1,
"Kā Fēi Sè Brown":0x736354,
"Kabacha Brown":0xb14a30,
"Kabalite Green":0x038c67,
"Kabocha Green":0x044a05,
"Kabul":0x6c5e53,
"Kacey's Pink":0xe94b7e,
"Kachi Indigo":0x393e4f,
"Kaffee":0x816d5a,
"Kaffir Lime":0xb9ab85,
"Kahili":0xb7bfb0,
"Kahlua Milk":0xbab099,
"Kahu Blue":0x0093d6,
"Kaitoke Green":0x245336,
"Kakadu Trail":0x7d806e,
"Kākāriki Green":0x298256,
"Kakitsubata Blue":0x3e62ad,
"Kālā Black":0x201819,
"Kala Namak":0x46444c,
"Kalahari Sunset":0x9f5440,
"Kalamata":0x5f5b4c,
"Kale":0x5a7247,
"Kale Green":0x4f6a56,
"Kaleidoscope":0x8da8be,
"Kali Blue":0x00505a,
"Kalish Violet":0x552288,
"Kalliene Yellow":0xb59808,
"Kaltes Klares Wasser":0x0ffef9,
"Kamenozoki Grey":0xc6c2b6,
"Kamut":0xcca483,
"Kanafeh":0xdd8833,
"Kandinsky Turquoise":0x2d8284,
"Kangaroo":0xc5c3b0,
"Kangaroo Fur":0xc4ad92,
"Kangaroo Paw":0xdecac5,
"Kangaroo Pouch":0xbda289,
"Kangaroo Tan":0xe4d7ce,
"Kansas Grain":0xfee7cb,
"Kantor Blue":0x001146,
"Kanzō Orange":0xff8936,
"Kaolin":0xad7d40,
"Kappa Green":0xc5ded1,
"Kara Cha Brown":0x783c1d,
"Karacha Red":0xb35c44,
"Karak Stone":0xbb9662,
"Karaka":0x2d2d24,
"Karaka Orange":0xf04925,
"Karakurenai Red":0xc91f37,
"Kariyasu Green":0x6e7955,
"Karma":0xb2a484,
"Karma Chameleon":0x9f78a9,
"Karry":0xfedcc1,
"Kashmir":0x6f8d6a,
"Kashmir Blue":0x576d8e,
"Kashmir Pink":0xe9c8c3,
"Kasugai Peach":0xf3dfd5,
"Kathleen's Garden":0x8fa099,
"Kathmandu":0xad9a5d,
"Katsura":0xc9e3cc,
"Katy Berry":0xaa0077,
"Katydid":0x66bc91,
"Kauai":0x5ac7ac,
"Kawaii":0xeaabbc,
"Kazakhstan Yellow":0xfec50c,
"Keel Joy":0xd49595,
"Keemun":0xa49463,
"Keen Green":0x226600,
"Keepsake":0xc0ced6,
"Keepsake Lilac":0xc0a5ae,
"Keepsake Rose":0xb08693,
"Keese Blue":0x0000bc,
"Kefir":0xd5d5ce,
"Kelley Green":0x02ab2e,
"Kellie Belle":0xdec7cf,
"Kelly Green":0x339c5e,
"Kelly's Flower":0xbabd6c,
"Kelp":0x4d503c,
"Kelp Brown":0x716246,
"Kelp Forest":0x448811,
"Kelp'thar Forest Blue":0x0092ae,
"Kemp Kelly":0x437b48,
"Ken Masters Red":0xec2c25,
"Kendal Green":0x547867,
"Kendall Rose":0xf7cccd,
"Kenny's Kiss":0xd45871,
"Kenpō Brown":0x543f32,
"Kenpōzome Black":0x2e211b,
"Kentucky":0x6395bf,
"Kentucky Blue":0xa5b3cc,
"Kentucky Bluegrass":0x22aabb,
"Kenya":0xcca179,
"Kenyan Copper":0x6c322e,
"Kenyan Sand":0xbb8800,
"Keppel":0x5fb69c,
"Kermit Green":0x5cb200,
"Kernel":0xecb976,
"Kerr's Pink Potato":0xb57281,
"Keshizumi Cinder":0x524e4d,
"Kestrel White":0xe0d6c8,
"Ketchup":0x9a382d,
"Kettle Black":0x131313,
"Kettle Corn":0xf6e2bd,
"Kettle Drum":0x9bcb96,
"Kettleman":0x606061,
"Key Keeper":0xecd1a5,
"Key Largo":0x7fb6a4,
"Key Lime":0xaeff6e,
"Key Lime Pie":0xbfc921,
"Key Lime Water":0xe8f48c,
"Key to the City":0xbb9b7c,
"Key West Zenith":0x759fc1,
"Keystone":0xb39372,
"Keystone Gray":0x9e9284,
"Keystone Grey":0xb6bbb2,
"Khaki":0xc3b091,
"Khaki Brown":0x954e2a,
"Khaki Core":0xfbe4af,
"Khaki Green":0x728639,
"Khaki Shade":0xd4c5ac,
"Khardic Flesh":0xb16840,
"Khemri Brown":0x76664c,
"Khmer Curry":0xee5555,
"Khorne Red":0x6a0001,
"Kickstart Purple":0x7777cc,
"Kid Gloves":0xb6aeae,
"Kid Icarus":0xa81000,
"Kid's Stuff":0xed8732,
"Kidnapper":0xbfc0ab,
"Kihada Yellow":0xfef263,
"Kikorangi Blue":0x2e4ebf,
"Kikuchiba Gold":0xe29c45,
"Kikyō Purple":0x5d3f6a,
"Kilauea Lava":0x843d38,
"Kilim Beige":0xd7c5ae,
"Kilimanjaro":0x3a3532,
"Kilkenny":0x498555,
"Killarney":0x49764f,
"Killer Fog":0xc9d2d1,
"Kiln Dried":0xa89887,
"Kimberley Sea":0x386b7d,
"Kimberley Tree":0xb8c1b1,
"Kimberlite":0x696fa5,
"Kimberly":0x695d87,
"Kimchi":0xed4b00,
"Kimirucha Brown":0x896c39,
"Kimono":0x6d86b6,
"Kimono Grey":0x3d4c51,
"Kimono Violet":0x75769b,
"Kin Gold":0xf39800,
"Kincha Brown":0xc66b27,
"Kind Green":0xaac2b3,
"Kind Magenta":0xff1dce,
"Kinder":0xb8bfca,
"Kindleflame":0xe9967a,
"Kindling":0x7a7068,
"Kindness":0xd4b2c0,
"King Creek Falls":0x5f686f,
"King Ghidorah":0xaa9977,
"King Kong":0x161410,
"King Lime":0xadd900,
"King Lizard":0x77dd22,
"King Nacho":0xffb800,
"King Neptune":0x7794c0,
"King of Waves":0xc6dce7,
"King Salmon":0xd88668,
"King Tide":0x2a7279,
"King Triton":0x3c85be,
"King's Cloak":0xc48692,
"King's Court":0x706d5e,
"King's Ransom":0xb59d77,
"King's Robe":0x6274ab,
"Kingdom Gold":0xd1a436,
"Kingdom's Keys":0xe9cfb7,
"Kingfisher":0x3a5760,
"Kingfisher Blue":0x006491,
"Kingfisher Bright":0x096872,
"Kingfisher Daisy":0x583580,
"Kingfisher Grey":0x7e969f,
"Kingfisher Sheen":0x007fa2,
"Kingfisher Turquoise":0x7ab6b6,
"Kings Yellow":0xead665,
"Kingston":0xd4dcd3,
"Kingston Aqua":0x8fbcc4,
"Kinky Koala":0xbb00bb,
"Kinky Pinky":0xee55cc,
"Kinlock":0x7f7793,
"Kinsusutake Brown":0x7d4e2d,
"Kir Royale Rose":0xb45877,
"Kirby":0xd74894,
"Kirchner Green":0x5c6116,
"Kiri Mist":0xc5c5d3,
"Kiriume Red":0x8b352d,
"Kirsch":0xb2132b,
"Kirsch Red":0x974953,
"Kislev Flesh":0xefcdcb,
"Kismet":0xa18ab7,
"Kiss":0xd28ca7,
"Kiss A Frog":0xbec187,
"Kiss and Tell":0xd86773,
"Kiss Candy":0xaa854a,
"Kiss Good Night":0xe5c8d9,
"Kiss Me Kate":0xe7eeec,
"Kissable":0xfd8f79,
"Kissed by Mist":0xfcccf5,
"Kitchen Blue":0x8ab5bd,
"Kite Brown":0x95483f,
"Kitsilano Cookie":0xd0c8b0,
"Kitsurubami Brown":0xbb8141,
"Kitten's Paw":0xdaa89b,
"Kittiwake Gull":0xccccbb,
"Kiwi":0x7aab55,
"Kiwi Fruit":0x9daa4d,
"Kiwi Green":0x8ee53f,
"Kiwi Ice Cream Green":0xe5e7a7,
"Kiwi Kiss":0xeef9c1,
"Kiwi Pulp":0x9cef43,
"Kiwi Sorbet Green":0xdee8be,
"Kiwi Squeeze":0xd1edcd,
"Kiwikiwi Grey":0x909495,
"Klimt Green":0x3fa282,
"Knapsack":0x95896c,
"Knarloc Green":0x4b5b40,
"Knight Elf":0x926cac,
"Knight Rider":0x0f0707,
"Knight's Armor":0x5c5d5d,
"Knight's Tale":0xaa91ae,
"Knighthood":0x3c3f52,
"Knightley Straw":0xedcc99,
"Knit Cardigan":0x6d6c5f,
"Knitting Needles":0xc3c1bc,
"Knock On Wood":0x9f9b84,
"Knockout Orange":0xe16f3e,
"Knot":0x988266,
"Knotweed":0x837f67,
"Koala Bear":0xbdb7a3,
"Kōbai Red":0xdb5a6b,
"Kobe":0x882d17,
"Kobi":0xe093ab,
"Kobicha":0x6b4423,
"Kobold Skin":0xf0d2cf,
"Kobra Khan":0x00aa22,
"Kodama White":0xe8f5fc,
"Koeksister":0xe97551,
"Kofta Brown":0x883322,
"Köfte Brown":0x773644,
"Kogane Gold":0xe5b321,
"Kohaku Amber":0xca6924,
"Kohlrabi Green":0xd9d9b1,
"Koi":0xd15837,
"Koi Pond":0x797f63,
"Koji Orange":0xf6ad49,
"Koke Moss":0x8b7d3a,
"Kokiake Brown":0x7b3b3a,
"Kokimurasaki Purple":0x3a243b,
"Kokoda":0x7b785a,
"Kokushoku Black":0x171412,
"Kolibri Blue":0x00477a,
"Komatsuna Green":0x7b8d42,
"Kombu":0x7e726d,
"Kombu Green":0x3a4032,
"Kombucha":0xd89f66,
"Kommando Khaki":0x9d907e,
"Komodo Dragon":0xb38052,
"Komorebi":0xbbc5b2,
"Kon":0x192236,
"Kona":0x574b50,
"Konjō Blue":0x003171,
"Konkikyō Blue":0x191f45,
"Koopa Green Shell":0x58d854,
"Kopi Luwak":0x833d3e,
"Kōrainando Green":0x203838,
"Koral Kicks":0xf2d1c3,
"Korean Mint":0x5d7d61,
"Korichnewyi Brown":0x8d4512,
"Korila":0xd7e9c8,
"Korma":0x804e2c,
"Koromiko":0xfeb552,
"Kōrozen":0x592b1f,
"Kosher Khaki":0x888877,
"Kournikova":0xf9d054,
"Kōwhai Yellow":0xe1b029,
"Kowloon":0xe1d956,
"Kraft Paper":0xd5b59c,
"Krasnyi Red":0xeb2e28,
"Kremlin Red":0x633639,
"Krieg Khaki":0xc0bd81,
"Krishna Blue":0x01abfd,
"Krypton":0xb8c0c3,
"KSU Purple":0x512888,
"KU Crimson":0xe8000d,
"Kuchinashi Yellow":0xffdb4f,
"Kul Sharif Blue":0x87d3f8,
"Kumera":0x886221,
"Kumquat":0xfbaa4c,
"Kundalini Bliss":0xd2ccda,
"Kung Fu":0x643b42,
"Kurenai Red":0xd7003a,
"Kuretake Black Manga":0x001122,
"Kuri Black":0x554738,
"Kuro Brown":0x583822,
"Kuro Green":0x1b2b1b,
"Kurobeni":0x23191e,
"Kuroi Black":0x14151d,
"Kurumizome Brown":0x9f7462,
"Kuta Surf":0x5789a5,
"Kuwanomi Purple":0x55295b,
"Kuwazome Red":0x59292c,
"Kvass":0xc7610f,
"Kyo Purple":0x9d5b8b,
"Kyoto":0xbee3ea,
"Kyoto House":0x503000,
"Kyoto Pearl":0xdfd6d1,
"Kyuri Green":0x4b5d16,
"La Grange":0x7a7a60,
"Là Jiāo Hóng Red":0xfc2647,
"La Luna":0xffffe5,
"La Luna Amarilla":0xfddfa0,
"La Minute":0xf5e5dc,
"La Palma":0x428929,
"La Paz Siesta":0xc1e5ea,
"La Pineta":0x577e88,
"La Rioja":0xbac00e,
"La Salle Green":0x087830,
"La Terra":0xea936e,
"LA Vibes":0xeeccdd,
"La Vie en Rose":0xd2a5a3,
"La-De-Dah":0xc3b1be,
"Labrador":0xf2ecd9,
"Labradorite":0x657b83,
"Labradorite Green":0x547d80,
"Labyrinth Walk":0xc9a487,
"Lace Cap":0xebeaed,
"Lace Veil":0xecebea,
"Lace Wisteria":0xc2bbc0,
"Laced Green":0xccee99,
"Lacewing":0xd7e3ca,
"Lacey":0xcaaeab,
"Lacquer Green":0x1b322c,
"Lacquer Mauve":0xf0cfe1,
"Lacquered Licorice":0x383838,
"Lacrosse":0x2e5c58,
"Lacustral":0x19504c,
"Lacy Mist":0xa78490,
"Laddu Orange":0xff8e13,
"Ladoga Bottom":0xd9ded8,
"Lady Anne":0xfde2de,
"Lady Banksia":0xfde5a7,
"Lady Fern":0x8fa174,
"Lady Fingers":0xccbbc0,
"Lady Flower":0xd0a4ae,
"Lady Guinevere":0xcaa09e,
"Lady in Red":0xb34b47,
"Lady Luck":0x47613c,
"Lady Nicole":0xd6d6cd,
"Lady of the Sea":0x0000cc,
"Lady Pink":0xf3d2cf,
"Lady?S Cushions Pink":0xc99bb0,
"Lady's Slipper":0xe3e3ea,
"Ladylike":0xffc3bf,
"Lager":0xf6f513,
"Lagoon":0x4d9e9a,
"Lagoon Blue":0x80a4b1,
"Lagoon Mirror":0xeaedee,
"Lagoon Moss":0x8b7e64,
"Lagoon Rock":0x43bcbe,
"Lagoona Teal":0x76c6d3,
"Laguna Beach":0xe9d7c0,
"Laguna Blue":0x5a7490,
"Lahar":0x5f5855,
"Lahmian Medium":0xe2dad1,
"Lahn Yellow":0xfff80a,
"Laid Back Grey":0xb3afa7,
"Laird":0x79853c,
"Lake Baikal":0x155084,
"Lake Blue":0x008c96,
"Lake Green":0x2e8b57,
"Lake Lucerne":0x689db7,
"Lake Placid":0xaeb9bc,
"Lake Red":0xb74a70,
"Lake Reflection":0x9dd8db,
"Lake Retba Pink":0xee55ee,
"Lake Stream":0x3e6b83,
"Lake Tahoe Turquoise":0x34b1b2,
"Lake Thun":0x44bbdd,
"Lake View":0x2e4967,
"Lake Water":0x86aba5,
"Lake Winnipeg":0x80a1b0,
"Lakelike":0x306f73,
"Lakeshore":0x5b96a2,
"Lakeside":0xadb8c0,
"Lakeside Mist":0xd7eeef,
"Lakeside Pine":0x566552,
"Lakeview":0x819aa0,
"Lakeville":0x6c849b,
"Laksa":0xe6bf95,
"Lāl Red":0xd85525,
"Lama":0xe0bb95,
"Lamb Chop":0x82502c,
"Lamb's Ears":0xc8ccbc,
"Lamb's Wool":0xffffe3,
"Lambent Lagoon":0x3b5b92,
"Lambs Wool":0xe6d1b2,
"Lambskin":0xebdcca,
"Lamenters Yellow":0xfffeb6,
"Lamina":0xbbd9bc,
"Laminated Wood":0x948c7e,
"Lamp Post":0x4a4f55,
"Lamplit":0xe4af65,
"Lampoon":0x805557,
"Lán Sè Blue":0x4d4dff,
"Land Before Time":0xbfbead,
"Land Light":0xdfcaaa,
"Land of Trees":0xe0d5b9,
"Land Rush Bone":0xc9bba1,
"Landing":0xeee1d9,
"Landjäger":0xaf403c,
"Landmark":0x746854,
"Landmark Brown":0x756657,
"Langdon Dove":0xb5ab9a,
"Langoustine":0xdc5226,
"Langoustino":0xca6c56,
"Languid Blue":0xa4b7bd,
"Languid Lavender":0xd6cadd,
"Lannister Red":0xcd0101,
"Lantana":0xda7e7a,
"Lantana Lime":0xd7eccd,
"Lantern Light":0xf6ebb9,
"Lanyard":0xc09972,
"Lap Dog":0xa6927f,
"Lap of Luxury":0x515366,
"Lap Pool Blue":0x98bbb7,
"Lapis Blue":0x004b8d,
"Lapis Jewel":0x165d95,
"Lapis Lazuli":0x26619c,
"Lapis Lazuli Blue":0x215f96,
"Lapwing Grey Green":0x7a7562,
"Larb Gai":0xdfc6aa,
"Larch Bolete":0xffaa77,
"Larchmere":0x70baa7,
"Laredo Road":0xc7994f,
"Large Wild Convolvulus":0xe4e2d6,
"Largest Black Slug":0x551f2f,
"Larimar Blue":0x1d78ab,
"Larimar Green":0x93d3bc,
"Lark":0xb89b72,
"Lark Green":0x8ac1a1,
"Larkspur":0x3c7d90,
"Larkspur Blue":0x20aeb1,
"Larkspur Bouquet":0x798bbd,
"Larkspur Bud":0xb7c0ea,
"Larkspur Violet":0x928aae,
"Las Palmas":0xc6da36,
"Laser":0xc6a95e,
"Laser Lemon":0xffff66,
"Last Light Blue":0x475f94,
"Last of Lettuce":0xaadd66,
"Last Straw":0xe3dbcd,
"Last Warning":0xd30f3f,
"Lasting Impression":0xb36663,
"Lasting Lime":0x88ff00,
"Lasting Thoughts":0xd4e6b1,
"Later Gator":0x008a51,
"Latigo Bay":0x379190,
"Latin Charm":0x292e44,
"Latte":0xc5a582,
"Latte Froth":0xf3f0e8,
"Lattice":0xcecec6,
"Lattice Work":0xb9e1c2,
"Laudable Lime":0x8cbf6f,
"Laughing Jack":0xc9c3d2,
"Laughing Orange":0xf49807,
"Launderette Blue":0xc0e7eb,
"Laundry Blue":0xa2adb3,
"Laundry White":0xf6f7f1,
"Laura":0xa6979a,
"Laura Potato":0x800008,
"Laurel":0x6e8d71,
"Laurel Garland":0x68705c,
"Laurel Green":0xa9ba9d,
"Laurel Grey":0xaaaca2,
"Laurel Leaf":0x969b8b,
"Laurel Mist":0xacb5a1,
"Laurel Nut Brown":0x55403e,
"Laurel Oak":0x918c7e,
"Laurel Pink":0xf7e1dc,
"Laurel Tree":0x889779,
"Laurel Woods":0x44493d,
"Laurel Wreath":0x52a786,
"Lauren's Lace":0xefeae7,
"Lauren's Surprise":0xd5e5e7,
"Lauriston Stone":0x868172,
"Lava":0xcf1020,
"Lava Black":0x352f36,
"Lava Core":0x764031,
"Lava Geyser":0xdbd0ce,
"Lava Grey":0x5e686d,
"Lava Lamp":0xeb7135,
"Lava Pit":0xe46f34,
"Lava Stone":0x3c4151,
"Lavenbrun":0xaf9894,
"Lavendaire":0x8f818b,
"Lavendar Wisp":0xe9ebee,
"Lavender":0xb56edc,
"Lavender Ash":0x9998a7,
"Lavender Aura":0x9f99aa,
"Lavender Bikini":0xe5d9da,
"Lavender Blessing":0xd3b8c5,
"Lavender Bliss":0xcec3dd,
"Lavender Blossom":0xb57edc,
"Lavender Blossom Grey":0x8c8da1,
"Lavender Blue":0xccccff,
"Lavender Blue Shadow":0x8b88f8,
"Lavender Blush":0xfff0f5,
"Lavender Bonnet":0x9994c0,
"Lavender Bouquet":0xc7c2d0,
"Lavender Breeze":0xe4e1e3,
"Lavender Candy":0xfcb4d5,
"Lavender Cloud":0xb8abb1,
"Lavender Cream":0xc79fef,
"Lavender Crystal":0x936a98,
"Lavender Dream":0xb4aecc,
"Lavender Dust":0xc4c3d0,
"Lavender Earl":0xaf92bd,
"Lavender Elan":0x9d9399,
"Lavender Elegance":0x786c75,
"Lavender Essence":0xdfdad9,
"Lavender Fog":0xd2c4d6,
"Lavender Fragrance":0xddbbff,
"Lavender Frost":0xbdabbe,
"Lavender Grey":0xbdbbd7,
"Lavender Haze":0xd3d0dd,
"Lavender Herb":0xb18eaa,
"Lavender Honor":0xc0c2d2,
"Lavender Illusion":0xa99ba7,
"Lavender Indigo":0x9457eb,
"Lavender Lace":0xdfdde0,
"Lavender Lake":0xa198a2,
"Lavender Leaf Green":0x8c9180,
"Lavender Lily":0xa5969c,
"Lavender Lustre":0x8c9cc1,
"Lavender Magenta":0xee82ed,
"Lavender Mauve":0x687698,
"Lavender Memory":0xd3d3e2,
"Lavender Mist":0xe5e5fa,
"Lavender Mosaic":0x857e86,
"Lavender Oil":0xc0c0ca,
"Lavender Pearl":0xede5e8,
"Lavender Phlox":0xa6badf,
"Lavender Pillow":0xc5b9d3,
"Lavender Pink":0xdd85d7,
"Lavender Pizzazz":0xe9e2e5,
"Lavender Princess":0xe9d2ef,
"Lavender Purple":0x967bb6,
"Lavender Quartz":0xbd88ab,
"Lavender Rose":0xfba0e3,
"Lavender Sachet":0xbec2da,
"Lavender Savor":0xeeddff,
"Lavender Scent":0xbfacb1,
"Lavender Sky":0xdbd7f2,
"Lavender Soap":0xf1bfe2,
"Lavender Sparkle":0xcfcedc,
"Lavender Spectacle":0x9392ad,
"Lavender Steel":0xc6cbdb,
"Lavender Suede":0xb4a5a0,
"Lavender Sweater":0xbd83be,
"Lavender Syrup":0xe6e6f1,
"Lavender Tea":0xd783ff,
"Lavender Tonic":0xccbbff,
"Lavender Twilight":0xe7dfe3,
"Lavender Veil":0xd9bbd3,
"Lavender Violet":0x767ba5,
"Lavender Vista":0xe3d7e5,
"Lavender Wash":0xaab0d4,
"Lavender Water":0xd2c9df,
"Lavendula":0xbca4cb,
"Lavish Gold":0xa38154,
"Lavish Lavender":0xc2aec3,
"Lavish Lemon":0xf9efca,
"Lavish Lime":0xb0c175,
"Lavish Spending":0x8469bc,
"Lawn Green":0x4da409,
"Lawn Party":0x5eb56a,
"Layers of Ocean":0x5c7186,
"Laylock":0xab9ba5,
"Lazurite Blue":0x174c60,
"Lazy Afternoon":0x97928b,
"Lazy Caterpillar":0xe2e5c7,
"Lazy Daisy":0xf6eba1,
"Lazy Day":0x95aed1,
"Lazy Gray":0xbec1c3,
"Lazy Lavender":0xa3a0b3,
"Lazy Lichen":0x6e6e5c,
"Lazy Lizard":0x9c9c4b,
"Lazy Shell Red":0xcc0011,
"Lazy Summer Day":0xfef3c3,
"Lazy Sunday":0xcad3e7,
"Le Corbusier Crush":0xbf4e46,
"Le Luxe":0x5e6869,
"Le Max":0x85b2a1,
"Lead":0x212121,
"Lead Cast":0x6c809c,
"Lead Glass":0xfffae5,
"Lead Grey":0x8a7963,
"Lead Ore":0x99aabb,
"Leadbelcher":0xcacacb,
"Leadbelcher Metal":0x888d8f,
"Leaf":0x71aa34,
"Leaf Bud":0xeff19d,
"Leaf Green":0x5ca904,
"Leaf Print":0xe1d38e,
"Leaf Tea":0x697d4c,
"Leaf Yellow":0xe9d79e,
"Leaflet":0x8b987b,
"Leafy":0x679b6a,
"Leafy Lemon":0xc0f000,
"Leafy Seadragon":0xb6c406,
"Leamington Spa":0xa0b7a8,
"Leap of Faith":0xc4d3e3,
"Leapfrog":0x41a94f,
"Leather":0x906a54,
"Leather Bound":0x916e52,
"Leather Brown":0x97572b,
"Leather Chair":0xa3754c,
"Leather Clutch":0x744e42,
"Leather Loafers":0x867354,
"Leather Satchel":0x7c4f3a,
"Leather Tan":0xa48454,
"Leather Work":0x8a6347,
"Leaves of Spring":0xc5e6cc,
"Lebanon Cedar":0x3c341f,
"LeChuck's Beard":0x3c351f,
"LED Blue":0x0066a3,
"LED Green":0xd8cb32,
"Leek":0x98d98e,
"Leek Blossom Pink":0xbca3b8,
"Leek Green":0x979c84,
"Leek Powder":0xb7b17a,
"Leek Soup":0x7a9c58,
"Leek White":0xcedcca,
"Leery Lemon":0xf5c71a,
"Legacy":0x5e5a67,
"Legal Eagle":0x6d758f,
"Legal Ribbon":0x6f434a,
"Legendary":0xc6baaf,
"Legendary Grey":0x787976,
"Legendary Lilac":0xad969d,
"Legendary Purple":0x4e4e63,
"Legendary Sword":0x7f8384,
"Legion Blue":0x1f495b,
"Lei Flower":0xd87b6a,
"Leisure":0xc19634,
"Leisure Blue":0x6a8ea1,
"Leisure Green":0x438261,
"Leisure Time":0x758c8f,
"Lemon":0xfff700,
"Lemon Appeal":0xefe4ae,
"Lemon Balm":0xe5d9b6,
"Lemon Balm Green":0x005228,
"Lemon Bar":0xcea02f,
"Lemon Blast":0xfcecad,
"Lemon Bubble":0xfcebbf,
"Lemon Bundt Cake":0xfef59f,
"Lemon Burst":0xfed67e,
"Lemon Caipirinha":0xf7de9d,
"Lemon Candy":0xfae8ab,
"Lemon Chiffon":0xfffacd,
"Lemon Chiffon Pie":0xfff7c4,
"Lemon Chrome":0xffc300,
"Lemon Cream":0xfee193,
"Lemon Curd":0xffee11,
"Lemon Curry":0xcda323,
"Lemon Delicious":0xfce699,
"Lemon Dream":0xeea300,
"Lemon Drizzle":0xfee483,
"Lemon Drop":0xfdd878,
"Lemon Drops":0xffe49d,
"Lemon Essence":0xe2ae4d,
"Lemon Filling":0xf9e4a6,
"Lemon Flesh":0xf0e891,
"Lemon Gate":0x96fbc4,
"Lemon Gelato":0xf8ec9e,
"Lemon Ginger":0x968428,
"Lemon Glacier":0xfdff00,
"Lemon Grass":0x999a86,
"Lemon Green":0xadf802,
"Lemon Ice":0xfffee6,
"Lemon Ice Yellow":0xf6e2a7,
"Lemon Icing":0xf6ebc8,
"Lemon Juice":0xffffec,
"Lemon Lily":0xfaf4d9,
"Lemon Lime":0xbffe28,
"Lemon Lime Mojito":0xcbba61,
"Lemon Meringue":0xf6e199,
"Lemon Pearl":0xf9f1db,
"Lemon Peel":0xffed80,
"Lemon Pepper":0xebeca7,
"Lemon Pie":0xf1ff62,
"Lemon Poppy":0xe1ae58,
"Lemon Popsicle":0xfaf2d1,
"Lemon Pound Cake":0xffdd93,
"Lemon Punch":0xfecf24,
"Lemon Rose":0xfbe9ac,
"Lemon Sachet":0xfaf0cf,
"Lemon Sherbet":0xf1ffa8,
"Lemon Slice":0xfffba8,
"Lemon Soap":0xfffcc4,
"Lemon Sorbet":0xfffac0,
"Lemon Sorbet Yellow":0xdcc68e,
"Lemon Souffle":0xffe8ad,
"Lemon Splash":0xf9f6de,
"Lemon Sponge Cake":0xf7f0e1,
"Lemon Stick":0xfbf7e0,
"Lemon Sugar":0xf0f6dd,
"Lemon Surprise":0xe1bc5c,
"Lemon Tart":0xffdd66,
"Lemon Tint":0xfcf3cb,
"Lemon Twist":0xfed95d,
"Lemon Verbena":0xf3e779,
"Lemon Whip":0xffe6ba,
"Lemon Whisper":0xffb10d,
"Lemon White":0xfbf6e0,
"Lemon Zest":0xf9d857,
"Lemonade":0xf0e79d,
"Lemonade Stand":0xf2ca3b,
"Lemongrass":0xc5a658,
"Lemonwood Place":0xf9f3d7,
"Lemur":0x695f4f,
"Lemures":0xbfb9d4,
"Lens Flare Blue":0xcee2e2,
"Lens Flare Green":0xb0ff9d,
"Lens Flare Pink":0xe4cbff,
"Lenticular Ore":0x6fb5a8,
"Lentil":0xdcc8b0,
"Lentil Sprout":0xaba44d,
"Lenurple":0xba93d8,
"Leopard":0xd09800,
"Lepidolite Purple":0x947e94,
"Leprechaun":0x29906d,
"Leprechaun Green":0x395549,
"Leprous Brown":0xd99631,
"Lepton Gold":0xd0a000,
"Leroy":0x71635a,
"Les Cavaliers Beach":0x0f63b3,
"Less Brown":0x756761,
"Less Traveled":0x5d6957,
"Lester":0xafd1c4,
"Let It Rain":0xb6b8bd,
"Let It Ring":0xcfae74,
"Let it Snow":0xd8f1f4,
"Lethal Lime":0x88ff11,
"Leticiaz":0x95be76,
"Letter Grey":0x8f8f8b,
"Letter Jacket":0xb8860b,
"Lettuce Alone":0xcedda2,
"Lettuce Green":0xbed38e,
"Lettuce Mound":0x92a772,
"Leukocyte White":0xf2f1ed,
"Level Up":0x468741,
"Leverkaas":0xedcdc2,
"Leviathan Purple Wash":0x8b2a98,
"Lewisham":0x675a49,
"Lexaloffle Green":0x00e436,
"Lexington Blue":0x7d9294,
"Liaison":0x8c3f52,
"Lián Hóng Lotus Pink":0xf075e6,
"Liberace":0xccb8d2,
"Liberal Lilac":0x9955bb,
"Liberalist":0x0c4792,
"Liberated Lime":0xd8ddcc,
"Liberator Gold":0xe8c447,
"Liberia":0xefe2db,
"Liberty":0x4d448a,
"Liberty Bell Grey":0x696b6d,
"Liberty Blue":0x0e1531,
"Liberty Green":0x16a74e,
"Liberty Grey":0xafbfc9,
"Library Leather":0x68554e,
"Library Oak":0x8f7459,
"Library Pewter":0x7f7263,
"Library Red":0x5b3530,
"Lich Grey":0xa9a694,
"Liche Purple":0x730061,
"Lichen":0x9bc2b1,
"Lichen Blue":0x5d89b3,
"Lichen Green":0x9da693,
"Lichtenstein Yellow":0xfdff38,
"Lick and Kiss":0xee5577,
"Lickedy Lick":0xb4496c,
"Lickety Split":0xc3d997,
"Licorice":0x1a1110,
"Licorice Stick":0xb53e3d,
"Liddell":0xc99c59,
"Liebermann Green":0x92b498,
"Life Aquatic":0xa2b0a8,
"Life at Sea":0xafc9dc,
"Life Force":0x6fb7e0,
"Life Is a Peach":0xe5cdbe,
"Life Is Good":0xe19b42,
"Life Lesson":0xc5cabe,
"Lifeboat Blue":0x81b6bc,
"Lifeguard":0xe50000,
"Lifeless Planet":0xe6d699,
"Lifeline":0x990033,
"Ligado":0xcdd6c2,
"Light Aluminium":0xc3c5c5,
"Light Amber Orange":0xed9a76,
"Light Amourette":0xd4d3e0,
"Light Angel Kiss":0xdad4e4,
"Light Angora Blue":0xc9d4e1,
"Light Apricot":0xf2dad6,
"Light Aroma":0xdecfd2,
"Light Ash Brown":0xc2a487,
"Light Bassinet":0xded0d8,
"Light Bathing":0xabd5dc,
"Light Beige":0xe5deca,
"Light Birch Green":0x9db567,
"Light Bleaches":0xd5d4d0,
"Light Blond":0xe8d3af,
"Light Blossom Time":0xecddd6,
"Light Blue":0xadd8e6,
"Light Blue Cloud":0xd2d3e1,
"Light Blue Glint":0xa8d3e1,
"Light Blue Grey":0xb7c9e2,
"Light Blue Sloth":0xc6dde4,
"Light Blue Veil":0xc0d8eb,
"Light Bluish Water":0xa4dbe4,
"Light Blush":0xe9c4cc,
"Light Bobby Blue":0xadd2e3,
"Light Breeze":0xcfe0f2,
"Light Bright Spark":0x94d0e9,
"Light Brown":0xb5651d,
"Light Brume":0xd6d5d2,
"Light Budgie Blue":0x9ed6e8,
"Light Bunny Soft":0xdeced1,
"Light Cameo Blue":0xc6d4e1,
"Light Candela":0xc9d2df,
"Light Capri Green":0x8bd4c3,
"Light Caramel":0xa38a83,
"Light Cargo River":0xdbd9c9,
"Light Carob":0xf9dbcf,
"Light Carolina":0xd8f3d7,
"Light Carrot Flower":0xd8decf,
"Light Celery Stick":0xd8f2dc,
"Light Chamois Beige":0xd1c6be,
"Light Chiffon":0xf4e7e5,
"Light Chintz":0xe0d5c9,
"Light Christobel":0xdfd3ca,
"Light Cipollino":0xd5dad1,
"Light Continental Waters":0xafd5d8,
"Light Copper":0xc48f4b,
"Light Corn":0xf3e2d1,
"Light Corn Yellow":0xe0c3a2,
"Light Cornflower Blue":0x93ccea,
"Light Crushed Almond":0xddd7d1,
"Light Cuddle":0xcbd7ed,
"Light Curd":0xf9e9c9,
"Light Cyan":0xe0ffff,
"Light Daly Waters":0xc2e4e7,
"Light Dante Peak":0xc6dedf,
"Light Daydreamer":0xe2d9d2,
"Light Dedication":0xfce9d5,
"Light Delphin":0x9ed1e3,
"Light Deluxe Days":0xa4d4ec,
"Light Detroit":0xcddbdc,
"Light Dewpoint":0xc4dadd,
"Light Drizzle":0xa7aea5,
"Light Dry Lichen":0xd4e3d7,
"Light Duck Egg Cream":0xd5ebdd,
"Light Easter Rabbit":0xd4ced1,
"Light Eggshell Pink":0xd9d2c9,
"Light Ellen":0xead5c7,
"Light Elusive Dream":0xd8cdd3,
"Light Enchanted":0xd6eadb,
"Light Fairy Pink":0xf3ded7,
"Light Favourite Lady":0xead3e0,
"Light Feather Green":0xd3d9c5,
"Light Featherbed":0xc1d8eb,
"Light Fern Green":0xe6e6d0,
"Light First Love":0xfce6db,
"Light Flamingo Pink":0xe7d1dd,
"Light French Gray":0xc2c0bb,
"Light French Grey":0xc9cfcc,
"Light Fresh Lime":0xe2f4d7,
"Light Freshman":0xecf4d2,
"Light Frost":0xede8d7,
"Light Frosty Dawn":0xd7efd5,
"Light Frozen Frappe":0xe6d2dc,
"Light Gentle Calm":0xd2d9cd,
"Light Ghosting":0xd7d3ca,
"Light Ginger Yellow":0xf7d28c,
"Light Glaze":0xc0b5aa,
"Light Granite":0xe2ddcf,
"Light Green":0x76ff7b,
"Light Green Alabaster":0xd5d8c9,
"Light Green Ash":0xd7ddcd,
"Light Green Glint":0xe5f4d5,
"Light Green Veil":0xe8f4d2,
"Light Green Wash":0xd4e6d9,
"Light Greenette":0xe2f0d2,
"Light Gregorio Garden":0xd7d4e4,
"Light Grey":0xd8dcd6,
"Light Hindsight":0xcdd6ea,
"Light Hint Of Lavender":0xdccfce,
"Light Hog Bristle":0xe5ddcb,
"Light Horizon Sky":0xd0d2de,
"Light Iced Aniseed":0xd8ded0,
"Light Iced Lavender":0xd0d4e3,
"Light Imagine":0xaed4d8,
"Light Incense":0xefdcbe,
"Light Instant":0xe2d9d4,
"Light Issey-San":0xdbe4d1,
"Light Jellyfish Blue":0xacd6db,
"Light Katsura":0xd6ead8,
"Light Khaki":0x998d7c,
"Light Kiri Mist":0xd3d2dd,
"Light Lamb's Ears":0xd6d9cb,
"Light Lavender":0xefc0fe,
"Light Lavender Blush":0xe3d2cf,
"Light Lavender Water":0xddd6e7,
"Light Lichen":0xbfb6a9,
"Light Ligado":0xd9e0d0,
"Light Light Blush":0xeed2d7,
"Light Light Lichen":0xd3e7dc,
"Light Lilac":0xdcc6d2,
"Light Lime Sherbet":0xd8e6ce,
"Light Limed White":0xdbd5ce,
"Light Limpid Light":0xdad1d7,
"Light Lip Gloss":0xe7d9d4,
"Light Livingstone":0xd8d7ca,
"Light Lost Lace":0xd1f0dd,
"Light Lunette":0xdcd5d3,
"Light Magnolia Rose":0xdbd5da,
"Light Mahogany":0x9b8b7c,
"Light Maiden's Blush":0xf6ddce,
"Light Male":0xe3dbd0,
"Light Marsh Fog":0xd3e1d3,
"Light Marshmallow Magic":0xf4dddb,
"Light Martian Moon":0xd1efdd,
"Light Mauve":0xc292a1,
"Light Meadow Lane":0xcee1d9,
"Light Mint":0xb6ffbb,
"Light Mint Green":0xa6fbb2,
"Light Mist":0xdce1d5,
"Light Mocha":0xb18673,
"Light Modesty":0xded5e2,
"Light Morality":0xc4d9eb,
"Light Mosque":0xd8cdd0,
"Light Mulberry":0xd1cae1,
"Light Mystified":0xd6e4d4,
"Light Naked Pink":0xe2d4e1,
"Light Nougat":0xfbe6c7,
"Light Nursery":0xf4dcdc,
"Light Nut Milk":0xe3d8d4,
"Light Oak":0xd2b183,
"Light Oak Brown":0xaf855c,
"Light of New Hope":0xeaf3d0,
"Light Olive":0xacbf69,
"Light Opale":0xc1e8ea,
"Light Opus":0xdad7e8,
"Light Orchid":0xe6a8d7,
"Light Orchid Haze":0xd6cdd0,
"Light Oriental Blush":0xe1d4e8,
"Light Otto Ice":0xcde7dd,
"Light Pale Icelandish":0xccdfdc,
"Light Pale Lilac":0xced5e4,
"Light Pale Pearl":0xd4cbce,
"Light Pale Tendril":0xdbdacb,
"Light Pastel Green":0xb2fba5,
"Light Pax":0xd5d3e3,
"Light Peach Rose":0xffe6d8,
"Light Pearl Ash":0xdcd6d1,
"Light Pearl Soft Blue":0xbec8d8,
"Light Pecan Pine":0xf1eae2,
"Light Pelican Bill":0xe1ced4,
"Light Penna":0xc8d4e7,
"Light Pensive":0xd0d0d7,
"Light Periwinkle":0xc1c6fc,
"Light Perk Up":0xe0d5cd,
"Light Petite Pink":0xf0d7d7,
"Light Pianissimo":0xecdbd6,
"Light Picnic Bay":0xcde5de,
"Light Pink":0xffd1df,
"Light Pink Clay":0xfedfdc,
"Light Pink Linen":0xddced1,
"Light Pink Pandora":0xe9d3d5,
"Light Pink Polar":0xd8c9cc,
"Light Pink Tone":0xfad9da,
"Light Pistachio Tang":0xe2dec8,
"Light Placid Blue":0xc8d8e8,
"Light Pollinate":0xebe1cb,
"Light Poolside":0xbee0e2,
"Light Porcelain":0xe7dad7,
"Light Powder Blue":0xc4d9ef,
"Light Powdered Granite":0xd1d6eb,
"Light Pre School":0xc5d0d9,
"Light Pretty Pale":0xead4e0,
"Light Puffball":0xd9ced5,
"Light Pumpkin Brown":0xc2a585,
"Light Pure Blue":0xc2d2d8,
"Light Purity":0xe0d5e9,
"Light Quaver":0xcdded7,
"Light Quilt":0xfde1d4,
"Light Radar":0xc6d5ea,
"Light Rattan":0xd1c1aa,
"Light Raw Cotton":0xecdfca,
"Light Red":0xf3d3d9,
"Light Relax":0xcaddde,
"Light Ridge Light":0xc3d5e5,
"Light Roast":0x615544,
"Light Rose":0xf4d4d6,
"Light Rose Beige":0xf9ebe4,
"Light Rose Romantic":0xf3dcd8,
"Light Saffron Orange":0xffcca5,
"Light Sage":0xb3b0a3,
"Light Salome":0xccf1e3,
"Light Salt Spray":0xbbd3da,
"Light Sandbank":0xdedcc6,
"Light Sandy Day":0xe1dacf,
"Light Sea Breeze":0xb7cdd9,
"Light Sea Cliff":0xb9d4e7,
"Light Sea Spray":0xabd6de,
"Light Sea-Foam":0xa0febf,
"Light Seafoam Green":0xa7ffb5,
"Light Security":0xe0e9d0,
"Light Shell Haven":0xf1e8ce,
"Light Shell Tint":0xfce0d6,
"Light Shetland Lace":0xe7dccf,
"Light Shimmer":0xa3d4ef,
"Light Short Phase":0xcbe8df,
"Light Shutterbug":0xcef2e4,
"Light Silver Grass":0xd4dbd1,
"Light Silverton":0xcee3d9,
"Light Sky Babe":0xa1d0e2,
"Light Sky Bus":0xafcfe0,
"Light Sky Chase":0xbad7dc,
"Light Skyway":0xc2e3e8,
"Light Slipper Satin":0xcfd1d8,
"Light Soft Celadon":0xcedcd4,
"Light Soft Fresco":0xcfe0d7,
"Light Soft Kind":0xdcddcc,
"Light Spearmint Ice":0xcfded7,
"Light Spirit":0xc3cad3,
"Light Spirited":0xd8eee7,
"Light Sprig Muslin":0xe0cfd2,
"Light Spring Burst":0xd6e8d5,
"Light Sprinkle":0xe3e3d7,
"Light Stargate":0xc7d2dd,
"Light Starlight":0xcbd0d7,
"Light Stately Frills":0xd2ccd1,
"Light Steel Blue":0xb0c4de,
"Light Stone":0xdcd1cc,
"Light Subpoena":0xe4dad3,
"Light Supernova":0xcde5e2,
"Light Tactile":0xdeedd4,
"Light Taupe":0xb19d8d,
"Light Taupe White":0xd5d0cb,
"Light Teal":0xb1ccc5,
"Light Template":0xbbd6ea,
"Light Terracotta":0xdf9b81,
"Light Thought":0xe2d8d4,
"Light Tidal Foam":0xbcd6e9,
"Light Time Travel":0xc5d2df,
"Light Tinge Of Mauve":0xdfd2d9,
"Light Tip Toes":0xe1d0d8,
"Light Tomato":0xd0756f,
"Light Topaz Ochre":0xb08971,
"Light Topaz Soft Blue":0xb5cdd7,
"Light Touch":0xf5ecdf,
"Light Turquoise":0x7ef4cc,
"Light Vandamint":0xbfe7ea,
"Light Vanilla Ice":0xb8ced9,
"Light Vanilla Quake":0xd8d5d0,
"Light Violet":0xd6b4fc,
"Light Vision":0xdcd9eb,
"Light Wallis":0xd4ccce,
"Light Washed Blue":0xacdce7,
"Light Water Wash":0xbfd5eb,
"Light Water Wings":0xc2f0e6,
"Light Watermark":0xb7dadd,
"Light Watermelon Milk":0xe6dad6,
"Light Wavecrest":0xb5d1df,
"Light Weathered Hide":0xe0d4d0,
"Light Whimsy":0x99d0e7,
"Light White Box":0xcedcd6,
"Light Year":0xbfbfb4,
"Light Yellow":0xfffe7a,
"Light Yellowish Green":0xc2ff89,
"Light Youth":0xead7d5,
"Light Zen":0xd1dbd2,
"Lighter Green":0x75fd63,
"Lighter Mint":0xdfebdd,
"Lighter Purple":0xa55af4,
"Lightest Sky":0xe4eadf,
"Lighthearted":0xf7e0e1,
"Lighthearted Pink":0xedd5dd,
"Lighthearted Rose":0xc7a1a9,
"Lighthouse":0xf3f4f4,
"Lighthouse Glow":0xf8d568,
"Lighthouse View":0xd9dcd5,
"Lightish Blue":0x3d7afd,
"Lightish Green":0x61e160,
"Lightish Purple":0xa552e6,
"Lightish Red":0xfe2f4a,
"Lightning Bolt":0xe5ebe6,
"Lightning Bolt Blue":0x93b9df,
"Lightning Bug":0xefde74,
"Lightning White":0xf8edd1,
"Lightning Yellow":0xf7a233,
"Lights of Shibuya":0xf8f2de,
"Lights Out":0x3d474b,
"Lightsaber Blue":0x15f2fd,
"Lightweight Beige":0xf6e5c5,
"Lignum Vitœ Foliage":0x67765b,
"Ligonier Tan":0xd2b18f,
"Likeable Sand":0xd1b7a8,
"Lilac":0xcea2fd,
"Lilac Ash":0xd7cdcd,
"Lilac Bisque":0xc6cde0,
"Lilac Bloom":0xafabb8,
"Lilac Blossom":0x9a93a9,
"Lilac Blue":0x8293ac,
"Lilac Breeze":0xb3a0c9,
"Lilac Bush":0x9470c4,
"Lilac Champagne":0xdfe1e6,
"Lilac Chiffon":0xde9bc4,
"Lilac Cotton Candy":0xcdd7ec,
"Lilac Crystal":0xcbc5d9,
"Lilac Fields":0x8f939d,
"Lilac Flare":0xb2badb,
"Lilac Fluff":0xc8a4bf,
"Lilac Frost":0xe8deea,
"Lilac Geode":0xbb88ff,
"Lilac Grey":0x9896a4,
"Lilac Haze":0xd5b6d4,
"Lilac Hint":0xd0d0da,
"Lilac Intuition":0x9a7ea7,
"Lilac Light":0xd7c1ba,
"Lilac Lotion":0xff3388,
"Lilac Lust":0xc3b9d8,
"Lilac Luster":0xae98aa,
"Lilac Marble":0xc3babf,
"Lilac Mauve":0xd6d0d6,
"Lilac Mist":0xe4e4e7,
"Lilac Murmur":0xe5e6ea,
"Lilac Paradise":0xdcbbba,
"Lilac Pink":0xc09dc8,
"Lilac Purple":0xa183c0,
"Lilac Rose":0xbd4275,
"Lilac Sachet":0xabb6d7,
"Lilac Scent Soft Blue":0x9eabd0,
"Lilac Smoke":0xb6a3a0,
"Lilac Snow":0xe0c7d7,
"Lilac Spring":0x8822cc,
"Lilac Suede":0xba9b97,
"Lilac Tan":0xd4c7c4,
"Lilac Time":0xa4abbf,
"Lilac Violet":0x754a80,
"Lilacs in Spring":0xe9cfe5,
"Lilas":0xb88995,
"Lilás":0xcc99ff,
"Liliac":0xc48efd,
"Lilliputian Lime":0x88dd55,
"Lilting Laughter":0xfcebd8,
"Lily":0xc19fb3,
"Lily Green":0xc5cf98,
"Lily Lavender":0xe6e6e8,
"Lily Legs":0xeec7d6,
"Lily of the Nile":0x9191bb,
"Lily of The Valley White":0xe2e3d6,
"Lily Pad":0x818f84,
"Lily Pads":0x6db083,
"Lily Pond":0xdeead8,
"Lily Pond Blue":0x55707f,
"Lily Scent Green":0xe6e6bc,
"Lily The Pink":0xf5dee2,
"Lily White":0xf0e7d3,
"Lilylock":0xe0e1c1,
"Lima":0xa9f971,
"Lima Bean":0xe1d590,
"Lima Bean Green":0x88be69,
"Lima Green":0xb1b787,
"Lima Sombrio":0x7aac21,
"Limbert Leather":0x988870,
"Lime":0xaaff32,
"Lime Acid":0xafff01,
"Lime Blossom":0xf4f2d3,
"Lime Bright":0xf1e4b0,
"Lime Cake":0xdae3d0,
"Lime Candy Pearl":0xaaff00,
"Lime Chalk":0xe5ddc8,
"Lime Coco Cake":0xe6efcc,
"Lime Cream":0xd7e8bc,
"Lime Daiquiri":0xdde6d7,
"Lime Dream":0xc2ecbc,
"Lime Fizz":0xcfe838,
"Lime Flip":0xd2e3cc,
"Lime Glow":0xe1ecd9,
"Lime Granita":0xdce1b8,
"Lime Green":0x9fc131,
"Lime Hawk Moth":0xcdaea5,
"Lime Ice":0xd1dd86,
"Lime Jelly":0xe3ff00,
"Lime Juice":0xe7e4d3,
"Lime Juice Green":0xe5e896,
"Lime Lightning":0xbefd73,
"Lime Lizard":0xabd35d,
"Lime Lollipop":0xb4bd7a,
"Lime Meringue":0xe6ecd6,
"Lime Mist":0xddffaa,
"Lime Parfait":0x95c577,
"Lime Peel":0xc6c191,
"Lime Pink":0xb6848c,
"Lime Pop":0xcccb2f,
"Lime Popsicle":0xc0db3a,
"Lime Punch":0xc0d725,
"Lime Rasp":0xb5ce08,
"Lime Rickey":0xafb96a,
"Lime Sherbet":0xcdd78a,
"Lime Shot":0x1df914,
"Lime Slice":0xf0fded,
"Lime Soap":0x7af9ab,
"Lime Sorbet":0xbee5be,
"Lime Sorbet Green":0xc6cd7d,
"Lime Splash":0xcfdb8d,
"Lime Spritz":0xdae1cf,
"Lime Taffy":0xbad1b5,
"Lime Time":0xebe734,
"Lime Tree":0xd8d06b,
"Lime Twist":0xc6d624,
"Lime Wash":0xdfe3d0,
"Lime Yellow":0xd0fe1d,
"Lime Zest":0xddff00,
"Limeade":0x5f9727,
"Limed Ash":0x747d63,
"Limed Oak":0xac8a56,
"Limed Spruce":0x394851,
"Limed White":0xcfc9c0,
"Limelight":0xf0e87d,
"Limeño Limón":0xf8b109,
"Limerick":0x76857b,
"Limescent":0xe0d4b7,
"Limesicle":0xf2eabf,
"Limestone":0xdcd8c7,
"Limestone Green":0xa5af9d,
"Limestone Mauve":0xd6d7db,
"Limestone Quarry":0xf9f6db,
"Limestone Slate":0xc5e0bd,
"Limetta":0x8e9a21,
"Limewash":0xdbd5cb,
"Limited Lime":0xeaecb9,
"Limitless":0xf0ddb8,
"Limo-Scene":0x4b4950,
"Limoge Pink":0xf3e0db,
"Limoges":0x243f6c,
"Limón Fresco":0xcebc55,
"Limonana":0x11dd66,
"Limoncello":0xbfff00,
"Limone":0xd6c443,
"Limonite":0xbe7f51,
"Limonite Brown":0x4b4433,
"Limousine Grey Blue":0x535f62,
"Limousine Leather":0x3b3c3b,
"Limpet Shell":0x98ddde,
"Limpid Light":0xcdc2ca,
"Limuyi Yellow":0xfefc7e,
"Lincoln Green":0x195905,
"Lincolnshire Sausage":0xe3e6da,
"Linden Green":0xc4bf71,
"Linden Spear":0x8e9985,
"Linderhof Garden":0x229922,
"Lindworm Green":0x172808,
"Line Dried Sheets":0xf5eded,
"Lineage":0x4c3430,
"Linear":0x164975,
"Linen":0xfaf0e6,
"Linen Grey":0x466163,
"Linen Ruffle":0xefebe3,
"Linen White":0xe9dcd1,
"Lingering Lilac":0xe6def0,
"Lingonberry":0xff255c,
"Lingonberry Punch":0xa95657,
"Lingonberry Red":0xce4458,
"Link":0x778290,
"Link Gray":0x7f7e72,
"Link Green":0x01a049,
"Link to the Past":0xd2b48c,
"Link Water":0xc7cdd8,
"Link's Awakening":0x3eaf76,
"Linnet":0xc3bcb3,
"Linnet Egg Red":0xffccdd,
"Linoleum Blue":0x427c9d,
"Linoleum Green":0x3aa372,
"Linseed":0xb0a895,
"Lint":0xb6ba99,
"Lion":0xc19a62,
"Lion Cub":0xf9cda4,
"Lion King":0xdd9933,
"Lion Mane":0xba8e4f,
"Lion of Menecrates":0xeeaa66,
"Lion's Lair":0x81522e,
"Lion's Mane":0xe8af49,
"Lion's Mane Blonde":0x946b41,
"Lioness":0xe0af47,
"Lionfish Red":0xe03c28,
"Lionhead":0xd5b60a,
"Lionheart":0xcc2222,
"Lip Gloss":0xdfcdc7,
"Lippie":0xd16a68,
"Lips of Apricot":0xfbceb1,
"Lipstick":0xc95b83,
"Lipstick Pink":0xbd7f8a,
"Lipstick Red":0xc0022f,
"Liqueur Red":0x61394b,
"Liquid Blue":0x55b7ce,
"Liquid Gold":0xfdc675,
"Liquid Green Stuff":0x3b7a5f,
"Liquid Lime":0xcdf80c,
"Liquid Mercury":0x757a80,
"Liquid Nitrogen":0xf3f3f4,
"Liquorice":0x0a0502,
"Liquorice Black":0x352d32,
"Liquorice Green":0x2a4041,
"Liquorice Red":0x740900,
"Liquorice Root":0x222200,
"Lira":0xe2c28d,
"Lisbon Brown":0x423921,
"Lisbon Lemon":0xfffb00,
"Liselotte Syrup":0xdd5511,
"Liseran Purple":0xde6fa1,
"Lit":0xfffed8,
"Lit'L Buoy Blew":0xd6e8e1,
"Lite Cocoa":0xb59a8d,
"Lite Lavender":0xe0dadf,
"Lithic Sand":0x53626e,
"Litmus":0x9895c5,
"Little Baby Girl":0xf8b9d4,
"Little Bear":0x604b42,
"Little Beaux Blue":0xb6d3c5,
"Little Black Dress":0x43484b,
"Little Blue Box":0x8ac5ba,
"Little Blue Heron":0x3c4378,
"Little Bow Pink":0xd37c99,
"Little Boy Blu":0xc7d8db,
"Little Boy Blue":0x6ca0dc,
"Little Dipper":0xe4e6ea,
"Little Dove":0xebe0ce,
"Little Lamb":0xeae6d7,
"Little League":0x6a9a8e,
"Little Lilac":0xe0d8df,
"Little Mermaid":0x2d454a,
"Little Pinky":0xf4efed,
"Little Pond":0xa6d1eb,
"Little Princess":0xe6aac1,
"Little Red Corvette":0xe50102,
"Little Smile":0xf8d0e8,
"Little Sun Dress":0xf7c85f,
"Little Theater":0x73778f,
"Little Touch":0xe7cfe8,
"Little Valley":0xa4a191,
"Live Jazz":0x87819b,
"Liveable Green":0xcecebd,
"Liveliness":0xffdfb9,
"Lively Coral":0xe67c7a,
"Lively Ivy":0xb3ae87,
"Lively Laugh":0xe1dd8e,
"Lively Lavender":0x816f7a,
"Lively Light":0xa18899,
"Lively Lilac":0x9096b7,
"Lively Tune":0xc8d8e5,
"Lively White":0xf7f3e0,
"Lively Yellow":0xffe9b1,
"Liver":0x534b4f,
"Liver Brown":0x513e32,
"Liver Chestnut":0x987456,
"Livery Green":0xa8d275,
"Livid":0x6688cc,
"Livid Brown":0x312a29,
"Livid Lime":0xb8e100,
"Living Coral":0xff6f61,
"Living Large":0xc87163,
"Living Stream":0x37708c,
"Livingston":0xa39880,
"Livingstone":0xcbcbbb,
"Lizard":0x71643e,
"Lizard Belly":0xcccc33,
"Lizard Breath":0xedbb32,
"Lizard Brown":0x795419,
"Lizard Green":0x81826e,
"Lizard Legs":0x7f6944,
"Llama Wool":0x917864,
"Loafer":0xdbd9c2,
"Lobaria Lichen":0x9fc8b2,
"Lobby Lilac":0xa780b2,
"Lobelia":0x7498be,
"Loblolly":0xb3bbb7,
"Lobster":0xbb240c,
"Lobster Bisque":0xdd9289,
"Lobster Brown":0xa73836,
"Lobster Butter Sauce":0xcc8811,
"Local Curry":0xcb9e34,
"Loch Blue":0x609795,
"Loch Modan Moss":0xdfe5bf,
"Loch Ness":0x5f6db0,
"Lochinvar":0x489084,
"Lochmara":0x316ea0,
"Lockhart":0xbe9aa2,
"Locomotion":0x988171,
"Locust":0xa2a580,
"Loden Frost":0x788f74,
"Loden Green":0x6e7153,
"Loden Purple":0x553a76,
"Loden Yellow":0xb68b13,
"Lodgepole Pines":0xaca690,
"Loft Light":0xdccab7,
"Loft Space":0xcbcecd,
"Log Cabin":0x705a46,
"Logan":0x9d9cb4,
"Loganberry":0x5a4769,
"Loggia":0xc4b7a5,
"Loggia Lights":0xe1ebde,
"Lol Yellow":0xe7cd8b,
"Lola":0xb9acbb,
"Lolita":0xbf2735,
"Lollipop":0xcc1c3b,
"Lolly":0xfd978f,
"Lolly Ice":0xa6dad0,
"London Fog":0xa29e92,
"London Grey":0x666677,
"London Hue":0xae94ab,
"London Rain":0x0055bb,
"London Road":0x7f878a,
"London Square":0x7f909d,
"Lone Pine":0x575a44,
"Lone Star":0xc09458,
"Lonely Road":0x947754,
"Lonestar":0x522426,
"Long Beach":0xfaefdf,
"Long Forgotten Purple":0xa1759c,
"Long Island Sound":0x95d0fc,
"Long Lake":0x68757e,
"Long Spring":0xc97586,
"Long-Haul Flight":0x002277,
"Longan's Kernel":0x442117,
"Longbeard Grey":0xceceaf,
"Longboat":0x60513a,
"Longfellow":0x90b1a3,
"Longlure Frogfish":0xebd84b,
"Longmeadow":0x77928a,
"Loofah":0xe3d3b5,
"Look At Me!":0xa67e4b,
"Look at the Bright Side":0xfebf01,
"Looking Glass":0x888786,
"Loom of Fate":0x454151,
"Loon Turquoise":0x2e6676,
"Looney Blue":0x11ffff,
"Loophole":0xcbc0b3,
"Loose Leather":0x84613d,
"Loquat Brown":0xae7c4f,
"Lord Baltimore":0xb76764,
"Lords of the Night":0x664488,
"Loren Forest":0x50702d,
"Lorian":0x8ebcbd,
"Lorna":0x658477,
"Lost at Sea":0x8d9ca7,
"Lost Atlantis":0x5f7388,
"Lost Canyon":0x998e7a,
"Lost Golfer":0x74af54,
"Lost in Heaven":0x002489,
"Lost in Istanbul":0xdee8e1,
"Lost in the Woods":0x014426,
"Lost Lace":0xc2ebd1,
"Lost Lake":0xb5adb5,
"Lost Lavender Somewhere":0x8d828c,
"Lost Love":0xe5d7d4,
"Lost River":0x08457e,
"Lost Soul Grey":0x929591,
"Lost Summit":0x887a6e,
"Lothern Blue":0x6699cc,
"Lotion":0xfefdfa,
"Lots of Bubbles":0xe5ecb7,
"Lottery Winnings":0x768371,
"Lotti Red":0xe40046,
"Lotus":0x8b504b,
"Lotus Flower":0xf4f0da,
"Lotus Leaf":0x93a79e,
"Lotus Petal":0xf2e9dc,
"Lotus Pod":0xe7d7c2,
"Lotus Red":0xd1717b,
"Loud Lime":0x88ff22,
"Louisiana Mud":0x655856,
"Loulou":0x4c3347,
"Lounge Green":0x8ba97f,
"Lounge Leather":0x563e31,
"Lounge Violet":0x5e336d,
"Louvre":0xddc3a4,
"Lovable":0xc87570,
"Lovage Green":0x98b1a6,
"Love Affair":0xffbec8,
"Love at First Sight":0xe5a5b1,
"Love Bird":0xba5b6a,
"Love In A Mist":0xe1b9c2,
"Love Juice":0xcc1155,
"Love Letter":0xe4658e,
"Love Poem":0xa06582,
"Love Potion":0xc01352,
"Love Priestess":0xbb55cc,
"Love Red":0xff496c,
"Love Spell":0xf8b4c4,
"Love-Struck Chinchilla":0xaeaeb7,
"Loveable":0xf0c1c6,
"Lovebirds":0xc76a77,
"Lovecloud":0xeebbee,
"Loveliest Leaves":0xa69a5c,
"Lovelight":0xf7d6d8,
"Lovely Euphoric Delight":0xffeeff,
"Lovely Harmony":0xf4dbdc,
"Lovely Lavender":0xd6d2dd,
"Lovely Lemonade":0xe9dd22,
"Lovely Lilac":0xa7b0cc,
"Lovely Linen":0xdbceac,
"Lovely Pink":0xd8bfd4,
"Lover's Hideaway":0xd0c6b5,
"Lover's Kiss":0x8f3b3d,
"Lover's Knot":0xf2dbdb,
"Lover's Leap":0x957e68,
"Lover's Retreat":0xf4ced8,
"Lover's Tryst":0xb48ca3,
"Lower Green":0xe0efe3,
"Lower Lavender":0xdcdfef,
"Lower Lilac":0xe2d6d8,
"Lower Lime":0xe6f1de,
"Lower Linen":0xe0dcd8,
"Lower Lip":0xf7468a,
"Loyal":0xd2e1f0,
"Loyal Blue":0x01455e,
"Loyalty":0x4e6175,
"Lǜ Sè Green":0x02c14d,
"Luau Green":0x989746,
"Lucario Blue":0x0b83b5,
"Lucea":0x7cafe1,
"Lucent Lime":0x00ff33,
"Lucent Yellow":0xe4d0a5,
"Lucerne":0x77b87c,
"Lucid Blue":0x7e8d9f,
"Lucidity":0x1e4469,
"Lucinda":0xa6bbb7,
"Lucius Lilac":0xbaa2ce,
"Luck of the Irish":0x547839,
"Lucky":0xab9a1c,
"Lucky Bamboo":0x93834b,
"Lucky Clover":0x008400,
"Lucky Day":0x929a7d,
"Lucky Dog":0xd3c8ba,
"Lucky Duck":0xf4ecd7,
"Lucky Green":0x238652,
"Lucky Lime":0x9acd32,
"Lucky Lobster":0xcc3322,
"Lucky Orange":0xff7700,
"Lucky Penny":0xbc6f37,
"Lucky Point":0x292d4f,
"Lucky Potato":0xefead8,
"Lucky Shamrock":0x487a7b,
"Ludicrous Lemming":0xbb8877,
"Lugganath Orange":0xf7a58b,
"Luigi":0x4cbb17,
"Lull Wind":0xc3d5e8,
"Lullaby":0xcbd4d4,
"Lumber":0xffe4cd,
"Lumberjack":0x9d4542,
"Luminary":0xfffeed,
"Luminary Green":0xe3eaa5,
"Luminescent Blue":0xa4dde9,
"Luminescent Green":0x769c18,
"Luminescent Lime":0xb9ff66,
"Luminescent Pink":0xf984ef,
"Luminescent Sky":0xcafffb,
"Luminous Light":0xbbaeb9,
"Luminous Pink":0xdc6c84,
"Luminous Yellow":0xfee37f,
"Lump of Coal":0x4e5154,
"Luna Light":0xc2ceca,
"Luna Moon":0xeceae1,
"Luna Moona":0x70c1c9,
"Luna Pier":0x414d62,
"Lunar Basalt":0x686b67,
"Lunar Base":0x878786,
"Lunar Dust":0xccccdd,
"Lunar Eclipse":0x415053,
"Lunar Federation":0x868381,
"Lunar Green":0x4e5541,
"Lunar Lander":0xdece9e,
"Lunar Landing":0xd2cfc1,
"Lunar Launch Site":0x938673,
"Lunar Light":0x9b959c,
"Lunar Lite":0xe0ddd8,
"Lunar Outpost":0x828287,
"Lunar Rays":0xcaced2,
"Lunar Rock":0xc5c5c5,
"Lunar Shadow":0x707685,
"Lunar Surface":0xb6b9b6,
"Lunar Tide":0x6f968b,
"Lunaria":0xf7e7cd,
"Lunatic Lynx":0xddaa88,
"Lunatic Sky Dancer":0x76fda8,
"Lunch Box":0xf2ca95,
"Lunette":0xd0c8c6,
"Lupin Grey":0xd1e0e9,
"Lupine":0xbe9cc1,
"Lupine Blue":0x6a96ba,
"Lurid Lettuce":0xb4f319,
"Lurid Pink":0xff33ee,
"Lurid Red":0xff4400,
"Luscious":0x903d49,
"Luscious Lavender":0x696987,
"Luscious Leek":0xbbcc22,
"Luscious Lemon":0xeebd6a,
"Luscious Lemongrass":0x517933,
"Luscious Lime":0x91a673,
"Luscious Lobster":0xc5847c,
"Luscious Purple":0x605c71,
"Lush":0xc5bda0,
"Lush Aqua":0x004466,
"Lush Bamboo":0xafbb33,
"Lush Garden":0x008811,
"Lush Grass":0x445243,
"Lush Green":0xbbee00,
"Lush Greenery":0x7ff23e,
"Lush Honeycomb":0xfca81b,
"Lush Hosta":0x6c765c,
"Lush Life":0xe9f6e0,
"Lush Lilac":0x9d7eb7,
"Lush Mauve":0xa091b7,
"Lush Meadow":0x006e51,
"Lush Plains":0x22bb22,
"Lush Un'goro Crater":0x54a64d,
"Lust":0xe62020,
"Lust Priestess":0xbb3388,
"Luster Green":0xbece61,
"Luster White":0xf4f1ec,
"Lustful Wishes":0xcc4499,
"Lustrian Undergrowth":0x415a09,
"Lustrous Yellow":0xe6da78,
"Lusty Lavender":0x8d5eb7,
"Lusty Lips":0xd5174e,
"Lusty Lizard":0x00bb11,
"Lusty Orange":0xefafa7,
"Lusty Red":0xb1383d,
"Lusty-Gallant":0xffcccc,
"Luxe Blue":0x516582,
"Luxe Lilac":0xa8a3b1,
"Luxor Blue":0xbde9e5,
"Luxor Gold":0xab8d3f,
"Luxurious Lime":0x88ee22,
"Luxurious Red":0x863a42,
"Luxury":0x818eb1,
"Lviv Blue":0x384172,
"Lvivian Rain":0x0182cc,
"Lyceum (Was Lycra Strip)":0xadcf43,
"Lychee":0xba0b32,
"Lychee Pulp":0xf7f2da,
"Lye":0x9e9478,
"Lye Tinted":0x7f6b5d,
"Lyman Camellia":0xe5c7b9,
"Lynch":0x697d89,
"Lynx":0x604d47,
"Lynx Screen Blue":0x2cb1eb,
"Lynx White":0xf7f7f7,
"Lyons Blue":0x005871,
"Lyrebird":0x0087ad,
"Lyric Blue":0x728791,
"Lythrum":0x72696f,
"M. Bison":0xb4023d,
"Mā White":0xf4f7fd,
"Maastricht Blue":0x001c3d,
"Mabel":0xcbe8e8,
"Mac N Cheese":0xe4b070,
"Macabre":0x880033,
"Macadamia":0xe4cfb6,
"Macadamia Beige":0xf7dfba,
"Macadamia Brown":0xbba791,
"Macadamia Nut":0xeee3dd,
"Macaroni":0xf3d085,
"Macaroni and Cheese":0xffb97b,
"Macaroon":0xb38b71,
"Macaroon Cream":0xfee8d6,
"Macaroon Rose":0xf75280,
"Macau":0x46c299,
"Macaw":0xffbd24,
"Macaw Green":0x9bb53e,
"Macchiato":0x928168,
"Macharius Solar Orange":0xdd4400,
"Machine Green":0xa6a23f,
"Machine Gun Metal":0x454545,
"Machine Oil":0xf1e782,
"Machinery":0x9999aa,
"Machu Picchu Gardens":0x99bb33,
"Mack Creek":0xbfae5b,
"MacKintosh Midnight":0x41434e,
"Macquarie":0x007d82,
"Macragge Blue":0x004577,
"Maculata Bark":0xada5a3,
"Mad For Mango":0xf8a200,
"Madagascar":0x9d8544,
"Madagascar Pink":0xd194a1,
"Madam Butterfly":0x7ca7cb,
"Madame Mauve":0xb5adb4,
"Madang":0xb7e3a8,
"Madder":0x754c50,
"Madder Blue":0xb5b6ce,
"Madder Brown":0x6a3331,
"Madder Lake":0xcc3336,
"Madder Magenta":0x80496e,
"Madder Orange":0xf1beb0,
"Madder Red":0xb7282e,
"Madder Rose":0xeebbcb,
"Made of Steel":0x5b686f,
"Madeira Brown":0x8f4826,
"Mademoiselle Pink":0xf504c9,
"Madera":0xeed09d,
"Madison":0x2d3c54,
"Madison Avenue":0x3d3e3e,
"Madonna":0x3f4250,
"Madonna Blue":0x71b5d1,
"Madonna Lily":0xeee6db,
"Madras":0x473e23,
"Madras Blue":0x9ac3da,
"Madrid Beige":0xecbf9f,
"Madrileño Maroon":0x8f003a,
"Magenta":0xff00ff,
"Magenta Affair":0xaa44dd,
"Magenta Crayon":0xff55a3,
"Magenta Dye":0xca1f7b,
"Magenta Elephant":0xde0170,
"Magenta Haze":0x9d446e,
"Magenta Ink":0x513d3c,
"Magenta Pink":0xcc338b,
"Magenta Purple":0x6b264b,
"Magenta Red":0x913977,
"Magenta Red Lips":0x62416d,
"Magenta Stream":0xfa5ff7,
"Magenta Twilight":0xbb989f,
"Magenta Violet":0x6c5389,
"Magentarama":0xcf3476,
"Magentella":0xd521b8,
"Magentle":0xaa11aa,
"Maggie's Magic":0xddeee2,
"Magic":0x656b78,
"Magic Blade":0x44dd00,
"Magic Blue":0x3e8baa,
"Magic Carpet":0x9488be,
"Magic Dust":0x817c85,
"Magic Fountain":0x1f75ff,
"Magic Gem":0x8e7282,
"Magic Ink":0x0247fe,
"Magic Lamp":0xc2a260,
"Magic Magenta":0x7f4774,
"Magic Malt":0xa5887e,
"Magic Melon":0xde9851,
"Magic Metal":0x3f3925,
"Magic Mint":0xaaf0d1,
"Magic Moment":0x757caf,
"Magic Moments":0xe9dbe0,
"Magic Mountain":0x717462,
"Magic Night":0x3a3b5b,
"Magic Potion":0xff4466,
"Magic Sage":0x598556,
"Magic Sail":0xe0d2ba,
"Magic Scent":0xccc9d7,
"Magic Spell":0x544f66,
"Magic Wand":0xc3d9e4,
"Magic Whale":0x17034a,
"Magical":0xc1ceda,
"Magical Malachite":0x22cc88,
"Magical Mauve":0xbaa3a9,
"Magical Melon":0xe9e9d0,
"Magical Merlin":0x3d8ed0,
"Magical Moonlight":0xf0eeeb,
"Magical Stardust":0xeaeadb,
"Magma":0xff4e01,
"Magna Cum Laude":0xdd0066,
"Magnesia Bay":0x64bfdc,
"Magnesium":0xc1c2c3,
"Magnet":0x4d4b4f,
"Magnetic Blue":0x054c8a,
"Magnetic Gray":0xb2b5af,
"Magnetic Green":0x2b6867,
"Magnetic Grey":0x838789,
"Magnetic Magic":0x3fbbb2,
"Magnetos":0xbf3cff,
"Magnificence":0x7f556f,
"Magnificent Magenta":0xee22aa,
"Magnitude":0xae8d7b,
"Magnolia":0xfff9e4,
"Magnolia Blossom":0xf4e7ce,
"Magnolia Petal":0xf7eee3,
"Magnolia Pink":0xecb9b3,
"Magnolia Spray":0xf6e6cb,
"Magnolia Spring":0xf4f2e7,
"Magnolia White":0xd8bfc8,
"Magnus Blue":0x003686,
"Magos":0x69475a,
"Maharaja":0x3f354f,
"Mahogany":0xc04000,
"Mahogany Brown":0x812308,
"Mahogany Cherry":0x82495a,
"Mahogany Finish":0xaa5511,
"Mahogany Rose":0xc5a193,
"Mahogany Spice":0x5b4646,
"Mahonia Berry Blue":0x62788e,
"Mai Tai":0xa56531,
"Maiden Hair":0xf5e9ca,
"Maiden Mist":0xb9c0c0,
"Maiden of the Mist":0xefdceb,
"Maiden Pink":0xff2feb,
"Maiden Voyage":0x8ac7d4,
"Maiden's Blush":0xf3d3bf,
"Maidenhair Fern":0x44764a,
"Maiko":0xd8baa6,
"Main Mast Gold":0xb79400,
"Maine-Anjou Cattle":0xa95249,
"Mainsail":0xd9dfe2,
"Maire":0x2a2922,
"Maison Blanche":0xdfd2bf,
"Maison De Campagne":0xbb9b7d,
"Maison Verte":0xe5f0d9,
"Maize":0xf4d054,
"Maizena":0xfbec5e,
"Majestic":0x5d4250,
"Majestic Blue":0x3f425c,
"Majestic Eggplant":0x443388,
"Majestic Magenta":0xee4488,
"Majestic Magic":0x555570,
"Majestic Mount":0x7c8091,
"Majestic Mountain":0x447788,
"Majestic Orchid":0x8d576d,
"Majestic Plum":0x806173,
"Majestic Purple":0x65608c,
"Majestic Violet":0x9d9ac4,
"Majesty":0x593761,
"Majin Bū Pink":0xffaacc,
"Majolica Blue":0x274357,
"Majolica Earthenware":0x976352,
"Majolica Green":0xaeb08f,
"Majolica Mauve":0xa08990,
"Major Blue":0x289ec4,
"Major Brown":0x5b5149,
"Major Tom":0x001177,
"Majorca Blue":0x4a9c95,
"Majorelle Blue":0x6050dc,
"Majorelle Gardens":0x337766,
"Makara":0x695f50,
"Make-Up Blue":0x335f8d,
"Makin it Rain":0x88bb55,
"Mako":0x505555,
"Makore Veneer Red":0x6e2f2c,
"Malabar":0xcfbea9,
"Malachite":0x0bda51,
"Malachite Blue Turquoise":0x0e4f4f,
"Malachite Green":0x004e00,
"Malaga":0x9f5069,
"Malarca":0x6e7d6e,
"Malaysian Mist":0xb8d1d0,
"Maldives":0x00bbdd,
"Male":0xd6cec3,
"Male Betta":0x347699,
"Malibu":0x66b7e1,
"Malibu Beige":0xc9c0b1,
"Malibu Blue":0x008cc1,
"Malibu Coast":0xe7cfc2,
"Malibu Dune":0xe7ceb5,
"Malibu Peach":0xfdc8b3,
"Malibu Sun":0xfff2d9,
"Mallard":0x254855,
"Mallard Blue":0x3a5c6e,
"Mallard Green":0x478865,
"Mallard Lake":0x91b9c2,
"Mallard's Egg":0xf8f2d8,
"Mallardish":0x3a4531,
"Mallorca Blue":0x517b95,
"Malmö FF":0xa7d7ff,
"Malt":0xddcfbc,
"Malt Shake":0xbba87f,
"Malta":0xa59784,
"Malted":0xdbc8c0,
"Malted Milk":0xe8d9ce,
"Malted Mint":0xbfd6c8,
"Malted Mint Madness":0x11ddaa,
"Mama Africa":0x551111,
"Mama Racoon":0x594f40,
"Mamala Bay":0x005e8c,
"Mamba":0x766d7c,
"Mamba Green":0x77ad3b,
"Mamey":0xeba180,
"Mamie Pink":0xee82ee,
"Mammary Red":0xb00b1e,
"Mammoth Mountain":0x3b6a7a,
"Mammoth Wool":0x995522,
"Man Cave":0x816045,
"Man Friday":0x3c4c5d,
"Mana":0xb09737,
"Mana Tree":0x4f7942,
"Manakin":0x94bbda,
"Manatee":0x8d90a1,
"Manchester":0x65916d,
"Manchester Brown":0x504440,
"Manchester Nights":0x992222,
"Mandalay":0xb57b2e,
"Mandalay Road":0xa05f45,
"Mandarin":0xf37a48,
"Mandarin Essence":0xee9944,
"Mandarin Jelly":0xff8800,
"Mandarin Orange":0xec6a37,
"Mandarin Peel":0xff9f00,
"Mandarin Red":0xe74a33,
"Mandarin Sorbet":0xffae42,
"Mandarin Sugar":0xf6e7e1,
"Mandarin Tusk":0xd8d4d3,
"Mandrake":0x8889a0,
"Mandu Dumpling":0xc6c0a6,
"Mandy":0xcd525b,
"Mandys Pink":0xf5b799,
"Mangala Pink":0xe781a6,
"Manganese Black":0x202f4b,
"Manganese Red":0xe52b50,
"Mångata":0x9dbcd4,
"Mango":0xffa62b,
"Mango Brown":0xbb8434,
"Mango Cheesecake":0xfbedda,
"Mango Green":0x96ff00,
"Mango Loco":0xfeb81c,
"Mango Madness":0xfd8c23,
"Mango Margarita":0xf7b74e,
"Mango Mojito":0xd69c2f,
"Mango Nectar":0xffd49d,
"Mango Orange":0xff8b58,
"Mango Salsa":0xffb066,
"Mango Squash":0x8e6c39,
"Mango Tango":0xff8243,
"Mangosteen":0x383e5d,
"Mangosteen Violet":0x3a2732,
"Mangrove":0x757461,
"Mangrove Leaf":0x607c3d,
"Mangu Black":0x292938,
"Mangy Moose":0xb2896c,
"Manhattan":0xe2af80,
"Manhattan Blue":0x404457,
"Manhattan Mist":0xcccfcf,
"Mani":0x97908e,
"Maniac Green":0x009000,
"Maniac Mansion":0x004058,
"Manifest":0x899888,
"Manila":0xe7c9a9,
"Manila Tint":0xffe2a7,
"Manitou Blue":0x5b92a2,
"Mannequin":0xeedfdd,
"Mannequin Cream":0xf6e5ce,
"Mannered Gold":0xc19763,
"Manor House":0x665d57,
"Mantella Frog":0xffbb00,
"Manticore Brown":0x957840,
"Manticore Wing":0xdd7711,
"Mantis":0x74c365,
"Mantle":0x96a793,
"Mantra":0xdce2df,
"Manually Pressed Grapes":0x881144,
"Manure":0xad900d,
"Manuscript":0xd1c9ba,
"Manuscript Ink":0x827e71,
"Manz":0xe4db55,
"Manzanilla Olive":0x9e8f6b,
"Maple":0xb88e72,
"Maple Beige":0xfad0a1,
"Maple Brown Sugar":0xa38e6f,
"Maple Elixir":0xf6d193,
"Maple Glaze":0xa76944,
"Maple Leaf":0xd17b41,
"Maple Pecan":0xe3d1bb,
"Maple Red":0xbf514e,
"Maple Sugar":0xc9a38d,
"Maple Syrup":0xbb9351,
"Maple Syrup Brown":0xc88554,
"Maple View":0xb49161,
"Maraschino":0xff2600,
"Marble Dust":0xf3e5cb,
"Marble Garden":0x646255,
"Marble Green":0x8f9f97,
"Marble Green-Grey":0x85928f,
"Marble Red":0xa9606e,
"Marble White":0xf2f0e6,
"March Green":0xd4cc00,
"March Hare Orange":0xff750f,
"March Pink":0x9a7276,
"March Tulip Green":0xd4c978,
"March Wind":0xbab9b6,
"March Yellow":0xf1d48a,
"Mardi Gras":0x880085,
"Marea Baja":0x2e5464,
"Marfil":0xf9ecda,
"Margarine":0xf2d930,
"Margarita":0xb5c38e,
"Mariana Trench":0x445956,
"Marigold":0xfcc006,
"Marigold Yellow":0xfbe870,
"Marilyn Monroe":0xe7c3ac,
"Marina":0x4f84c4,
"Marina Isle":0xb1c8bf,
"Marine":0x042e60,
"Marine Blue":0x01386a,
"Marine Green":0x40a48e,
"Marine Grey":0xa5b2aa,
"Marine Ink":0x6384b8,
"Marine Layer":0xa5b4b6,
"Marine Magic":0x515e62,
"Marine Teal":0x008384,
"Marine Tinge":0x33a3b3,
"Marine Wonder":0x1f7073,
"Mariner":0x42639f,
"Mario":0xe4000f,
"Marionberry":0x380282,
"Maritime":0xbdcfea,
"Maritime Blue":0x27293d,
"Maritime Soft Blue":0x69b8c0,
"Maritime White":0xe5e6e0,
"Marjoram":0xbfcba2,
"Marker Blue":0x00869a,
"Marker Green":0x9daf00,
"Marker Pink":0xe3969b,
"Market Melon":0xfbb377,
"Marlin":0x515b87,
"Marlin Green":0x41a1aa,
"Marmalade":0xc16512,
"Marmalade Glaze":0xc27545,
"Marmot":0x928475,
"Maroon":0x800000,
"Maroon Flush":0xc32249,
"Maroon Light":0xbf3160,
"Maroon Oak":0x520c17,
"Marooned":0x86cdab,
"Marquee White":0xf5ead6,
"Marquis Orange":0xd2783a,
"Marrakech Brown":0x91734c,
"Marrakesh Red":0x783b3c,
"Marrett Apple":0xcacaa3,
"Marron":0x6e4c4b,
"Marron Canela":0xa7735a,
"Marrs Green":0x008c8c,
"Mars":0xad6242,
"Mars Red":0xbc2731,
"Marsala":0x964f4c,
"Marseilles":0xb7bbbb,
"Marsh":0x5c5337,
"Marsh Creek":0x6b8781,
"Marsh Fern":0xb6ca90,
"Marsh Field":0xd4c477,
"Marsh Fog":0xc6d8c7,
"Marsh Grass":0x82763d,
"Marsh Marigold":0xffef17,
"Marsh Mix":0x5a653a,
"Marsh Orchid":0xc4a3bf,
"Marshal Blue":0x3e4355,
"Marshland":0x2b2e26,
"Marshmallow":0xf0eee4,
"Marshmallow Cream":0xf3e0d6,
"Marshmallow Fluff":0xfaf3de,
"Marshmallow Magic":0xefd2d0,
"Marshmallow Mist":0xe0caaa,
"Marshmallow Rose":0xf7e5e6,
"Marshmallow Whip":0xf9efe0,
"Marshy Green":0x8e712e,
"Marshy Habitat":0xb8aea2,
"Marsupilami":0xfdf200,
"Martian":0xaea132,
"Martian Colony":0xe5750f,
"Martian Green":0x136c51,
"Martian Haze":0xadeace,
"Martian Ironcrust":0xb7410e,
"Martian Ironearth":0xc15a4b,
"Martian Moon":0xc3e9d3,
"Martica":0xf4e5b7,
"Martina Olive":0x8e8e41,
"Martini":0xb7a8a3,
"Martini East":0xce8c8d,
"Martini Olive":0xcdc796,
"Martinique":0x3c3748,
"Marvellous":0x6a7fb4,
"Marvelous Magic":0xe1c6d6,
"Mary Blue":0x006a77,
"Mary Poppins":0xd1b5ca,
"Mary Rose":0xd7b1b0,
"Mary's Garden":0x69913d,
"Mary's Rose":0xf7d1d4,
"Marzena Dream":0xa6d0ec,
"Marzipan":0xebc881,
"Marzipan Pink":0xeebabc,
"Marzipan White":0xebe5d8,
"Masala":0x57534b,
"Masala Chai":0xeeccaa,
"Mascarpone":0xece6d4,
"Mask":0xab878d,
"Masked Mauve":0xc6b2be,
"Masoho Red":0xd57c6b,
"Master":0x3a4b61,
"Master Chief":0x507d2a,
"Master Key":0xddcc88,
"Master Round Yellow":0xe78303,
"Master Sword Blue":0x00ffee,
"Masterpiece":0xa1a2ab,
"Masuhana Blue":0x4d646c,
"Mat Dazzle Rose":0xff48d0,
"Mata Hari":0x544859,
"Matador's Cape":0xcf6e66,
"Match Head":0xd63756,
"Match Strike":0xffaa44,
"Matcha Picchu":0x99bb00,
"Matcha Powder":0xa0d404,
"Mate Tea":0x7bb18d,
"Matisse":0x365c7d,
"Matriarch":0x7e6884,
"Matrix":0x8e4d45,
"Matsuba Green":0x454d32,
"Matt Black":0x151515,
"Matt Blue":0x2c6fbb,
"Matt Demon":0xdd4433,
"Matt Green":0x39ad48,
"Matt Lilac":0xdec6d3,
"Matt Pink":0xffb6c1,
"Matt Purple":0x9370db,
"Matt Sage":0xb2b9a5,
"Matt White":0xffffd4,
"Mattar Paneer":0x884433,
"Matte Blue":0x8fb0ce,
"Matte Carmine":0xa06570,
"Matte Grey":0xb4a8a4,
"Matte Jade Green":0xb5cbbd,
"Matte Olive":0x998f7f,
"Matte Sage Green":0x8a9381,
"Matterhorn":0x524b4b,
"Matterhorn Snow":0xe0fefe,
"Mature":0xc4afb3,
"Mature Cognac":0x9a463d,
"Mature Grape":0x5f3f54,
"Maud":0x988286,
"Maui":0x21a5be,
"Maui Blue":0x52a2b4,
"Maui Mai Tai":0xb66044,
"Maui Mist":0xeef2f3,
"Mauve":0xe0b0ff,
"Mauve Aquarelle":0xe3d2db,
"Mauve Brown":0x62595f,
"Mauve Chalk":0xe5d0cf,
"Mauve Day":0xac8c8c,
"Mauve Finery":0xcbb8c0,
"Mauve Glow":0xd18489,
"Mauve It":0xbb4466,
"Mauve Jazz":0x908186,
"Mauve Madness":0xaa7982,
"Mauve Magic":0xbf91b2,
"Mauve Melody":0xa69f9a,
"Mauve Mist":0xc49bd4,
"Mauve Mole":0x7d716e,
"Mauve Morn":0xecd6d6,
"Mauve Morning":0xd9d0cf,
"Mauve Musk":0xa98ca1,
"Mauve Muslin":0xb59ead,
"Mauve Mystery":0x685c61,
"Mauve Mystique":0xbb4477,
"Mauve Nymph":0xc0ada6,
"Mauve Orchid":0xb58299,
"Mauve Organdie":0xd9c4d0,
"Mauve Pansy":0xbebbc0,
"Mauve Seductress":0xbb7788,
"Mauve Shadows":0xb598a3,
"Mauve Stone":0xc4bab6,
"Mauve Taupe":0x915f6d,
"Mauve Tinge":0xe7e1e1,
"Mauve White":0xdee3e4,
"Mauve Wine":0x5b3644,
"Mauve Wisp":0xeadde1,
"Mauve-a-Lish":0x90686c,
"Mauvelous":0xd6b3c0,
"Mauverine":0x9d8888,
"Mauvette":0xc4b2a9,
"Mauvewood":0xa75d67,
"Mauvey Nude":0xbb8899,
"Mauvey Pink":0x8c8188,
"Maverick":0xc8b1c0,
"Mawmaw's Pearls":0xefe9dd,
"Maxi Teal":0x017478,
"Maximum Blue":0x47abcc,
"Maximum Blue Green":0x30bfbf,
"Maximum Blue Purple":0xacace6,
"Maximum Green":0x5e8c31,
"Maximum Green Yellow":0xd9e650,
"Maximum Mocha":0x6b4a40,
"Maximum Orange":0xff5b00,
"Maximum Purple":0x733380,
"Maximum Red":0xd92121,
"Maximum Red Purple":0xa63a79,
"Maximum Yellow":0xfafa37,
"Maximum Yellow Red":0xf2ba49,
"May Apple":0x92d599,
"May Green":0x4c9141,
"May Mist":0xa19fc8,
"May Sun":0xfaead0,
"Maya Blue":0x73c2fb,
"Maya Green":0x98d2d9,
"Mayan Blue":0x006b6c,
"Mayan Chocolate":0x655046,
"Mayan Gold":0xb68c37,
"Mayan Red":0x6c4a43,
"Mayan Ruins":0x7d6950,
"Mayan Treasure":0xce9844,
"Maybe Maui":0xf6d48d,
"Maybe Mushroom":0xe2d8cb,
"Maybeck Muslin":0xeddfc9,
"Mayfair White":0xe6f0de,
"Mayfly":0x65663f,
"Maypole":0xbee8d3,
"Mazarine Blue":0x273c76,
"Maze":0x5c5638,
"Mazzone":0xb0907c,
"Mazzy Star":0xbf5bb0,
"McKenzie":0x8c6338,
"McNuke":0x33ff11,
"Mead":0xffc878,
"Meadow":0x8bba94,
"Meadow Blossom Blue":0x7ab2d4,
"Meadow Flower":0x987184,
"Meadow Glen":0xccd1b2,
"Meadow Grass":0xc1d6b1,
"Meadow Green":0x739957,
"Meadow Lane":0xc0d7cd,
"Meadow Light":0xdfe9de,
"Meadow Mauve":0xa9568c,
"Meadow Mist":0xd3dec4,
"Meadow Phlox":0xa8afc7,
"Meadow Trail":0x8d8168,
"Meadow Violet":0x764f82,
"Meadow Yellow":0xf7da90,
"Meadowbrook":0x60a0a3,
"Meadowland":0x807a55,
"Meadowlark":0xead94e,
"Meadowood":0x9da28e,
"Meadowsweet Mist":0xd4e3e2,
"Meander":0x8f8c79,
"Meander Blue":0xbedbd8,
"Meat":0xf08080,
"Meat Brown":0xe5b73b,
"Meatbun":0xf8eed3,
"Meatloaf":0x663311,
"Mecca Gold":0xc89134,
"Mecca Orange":0xbd5745,
"Mecca Red":0x663f3f,
"Mech Suit":0xbbdddd,
"Mecha Grey":0x8d847f,
"Mechagodzilla":0xdedce2,
"Mechanicus Standard Grey":0x3d4b4d,
"Mechrite Red":0xa31713,
"Medal Bronze":0x977547,
"Medallion":0xc3a679,
"Medical Mask":0x95cce4,
"Medici Blue":0x104773,
"Medici Ivory":0xf3e9d7,
"Medicine Man":0x69556d,
"Medicine Wheel":0x99a28c,
"Medieval":0x696db0,
"Medieval Blue":0x29304e,
"Medieval Cobblestone":0x878573,
"Medieval Forest":0x007e6b,
"Medieval Gold":0xac7f48,
"Medieval Wine":0x8c7d88,
"Meditation":0xa9ac9d,
"Meditation Time":0xa7a987,
"Meditative":0x96aab0,
"Mediterranea":0x32575d,
"Mediterranean":0x60797d,
"Mediterranean Blue":0x0090a8,
"Mediterranean Charm":0xa1cfec,
"Mediterranean Cove":0x007b84,
"Mediterranean Green":0xe0e9d3,
"Mediterranean Mist":0xbce9d6,
"Mediterranean Sea":0x1e8cab,
"Mediterranean Swirl":0x2999a2,
"Medium Aquamarine":0x66ddaa,
"Medium Black":0x444443,
"Medium Blue":0x0000cd,
"Medium Brown":0x7f5112,
"Medium Candy Apple Red":0xe2062c,
"Medium Carmine":0xaf4035,
"Medium Champagne":0xf3e5ac,
"Medium Electric Blue":0x035096,
"Medium Goldenrod":0xeaeaae,
"Medium Green":0x3c824e,
"Medium Grey":0x7d7f7c,
"Medium Grey Green":0x4d6b53,
"Medium Gunship Grey":0x3f4952,
"Medium Jungle Green":0x1c352d,
"Medium Lavender Magenta":0xdda0fd,
"Medium Orchid":0xba55d3,
"Medium Persian Blue":0x0067a5,
"Medium Pink":0xf36196,
"Medium Purple":0x9e43a2,
"Medium Red Violet":0xbb3385,
"Medium Roast":0x3c2005,
"Medium Ruby":0xaa4069,
"Medium Scarlet":0xfc2847,
"Medium Sea Green":0x3cb371,
"Medium Sky Blue":0x80daeb,
"Medium Slate Blue":0x7b68ee,
"Medium Spring Bud":0xc9dc87,
"Medium Spring Green":0x00fa9a,
"Medium Taupe":0x674c47,
"Medium Terracotta":0xdc9d8b,
"Medium Turquoise":0x48d1cc,
"Medium Tuscan Red":0x794431,
"Medium Vermilion":0xd9603b,
"Medium Violet Red":0xc71585,
"Medium Wood":0xa68064,
"Medlar":0xd5d7bf,
"Medusa Green":0x998800,
"Medusa's Snakes":0x777711,
"Mee-hua Sunset":0xee7700,
"Meek Moss Green":0x869f98,
"Meerkat":0xa46f44,
"Meetinghouse Blue":0x739dad,
"Mega Blue":0x366fa6,
"Mega Greige":0xada295,
"Mega Magenta":0xd767ad,
"Mega Metal Mecha":0xdfcbcf,
"Mega Metal Phoenix":0xc6ccd4,
"Megadrive Screen":0x4a40ad,
"Megaman":0x3cbcfc,
"Megaman Helmet":0x0058f8,
"Méi Gūi Hóng Red":0xfe023c,
"Méi Gūi Zǐ Purple":0xe03fd8,
"Méi Hēi Coal":0x123120,
"Meissen Blue":0x007fb9,
"Melancholia":0x12390d,
"Melancholic Macaw":0xaa1133,
"Melancholic Sea":0x53778f,
"Melancholy":0xdd8899,
"Mélange Green":0xc4c476,
"Melanie":0xe0b7c2,
"Melanite Black Green":0x282e27,
"Melanzane":0x342931,
"Melbourne":0x4c7c4b,
"Melbourne Cup":0x45c3ad,
"Melissa":0xb5d96b,
"Mella Yella":0xf0dda2,
"Mellifluous Blue":0xc9e1e0,
"Mellow Apricot":0xf8b878,
"Mellow Blue":0xd7e2dd,
"Mellow Buff":0xd8b998,
"Mellow Coral":0xe0897e,
"Mellow Flower":0xf1dfe9,
"Mellow Glow":0xffcfad,
"Mellow Green":0xd5d593,
"Mellow Mango":0xcc4400,
"Mellow Mauve":0x996378,
"Mellow Melon":0xee2266,
"Mellow Mint":0xddedbd,
"Mellow Mood":0xb1b7a1,
"Mellow Rose":0xd9a6a1,
"Mellow Yellow":0xf8de7f,
"Melmac Silver":0xb6b2a1,
"Melodic White":0xeee8e8,
"Melodious":0x7bb5ae,
"Melody":0xbecbd7,
"Melon":0xff7855,
"Melon Baby":0xf47869,
"Melon Balls":0xf2bd85,
"Melon Green":0x74ac8d,
"Melon Ice":0xf4d9c8,
"Melon Melody":0xf9c291,
"Melón Meloso":0xf2b88c,
"Melon Mist":0xe88092,
"Melon Orange":0xf08f48,
"Melon Pink":0xf1d4c4,
"Melon Red":0xf69268,
"Melon Seed":0x332c22,
"Melon Sorbet":0xf8b797,
"Melon Sprinkle":0xffcd9d,
"Melon Tint":0xf8e7d4,
"Melon Twist":0xaa6864,
"Melon Water":0xfdbcb4,
"Melrose":0xc3b9dd,
"Melt Ice":0xb4cbe3,
"Melt with You":0xe3cfab,
"Melted Butter":0xffcf53,
"Melted Chocolate":0x785f4c,
"Melted Copper":0xce8544,
"Melted Ice Cream":0xdcb7a6,
"Melted Marshmallow":0xfee2cc,
"Melted Wax":0xf6e6c5,
"Melting Glacier":0xe9f9f5,
"Melting Ice":0xcae1d9,
"Melting Icicles":0xecebe4,
"Melting Moment":0xbba2b6,
"Melting Point":0xcbe1e4,
"Melting Snowman":0xdae5e0,
"Melting Violet":0xd4b8bf,
"Meltwater":0x79c0cc,
"Melville":0x95a99e,
"Memoir":0xecf0da,
"Memorable Rose":0xcf8a8d,
"Memories":0xe8deda,
"Memorize":0x9197a4,
"Memory Lane":0xc7d1db,
"Memphis Green":0x5e9d7b,
"Men Brown":0x5e5239,
"Mendocino Hills":0x837a64,
"Menoth White Base":0xf3e8b8,
"Menoth White Highlight":0xf0f1ce,
"Mental Floss":0xdeb4c5,
"Mental Note":0xeaeede,
"Menthol":0xc1f9a2,
"Menthol Green":0x9cd2b4,
"Mephiston Red":0x9a1115,
"Mercer Charcoal":0xaca495,
"Merchant Marine Blue":0x0343df,
"Mercurial":0xb6b0a9,
"Mercury":0xebebeb,
"Mercury Mist":0x89c8c3,
"Merguez":0x650021,
"Meridian Star":0x7bc8b2,
"Merin's Fire":0xff9408,
"Meringue":0xf3e4b3,
"Meringue Tips":0xc2a080,
"Merino":0xe1dbd0,
"Merino Wool":0xcfc1ae,
"Meristem":0xaae1ce,
"Merlin":0x4f4e48,
"Merlin's Beard":0xefe2d9,
"Merlin's Choice":0x9f8898,
"Merlin's Cloak":0x89556e,
"Merlot":0x730039,
"Merlot Fields":0x712735,
"Mermaid":0x817a65,
"Mermaid Blues":0x004477,
"Mermaid Harbor":0x00776f,
"Mermaid Net":0x22cccc,
"Mermaid Sea":0x297f6d,
"Mermaid Song":0x25ae8e,
"Mermaid Tears":0xd9e6a6,
"Mermaid Treasure":0x1fafb4,
"Mermaid's Cove":0x8aa786,
"Mermaid's Kiss":0x59c8a5,
"Mermaid's Tail":0x337b35,
"Merry Music":0xced3c1,
"Merry Pink":0xeac8da,
"Merrylyn":0xa5d0af,
"Mesa":0xbca177,
"Mesa Beige":0xf2ebd6,
"Mesa Peach":0xc19180,
"Mesa Pink":0xddb1a8,
"Mesa Red":0x92555b,
"Mesa Rose":0xeeb5af,
"Mesa Sunrise":0xea8160,
"Mesa Tan":0xa78b71,
"Mesclun Green":0x9db682,
"Meški Black":0x1f0b1e,
"Mesmerize":0x8e9074,
"Mesquite Powder":0xe3c8b1,
"Message Green":0x37b8af,
"Messenger Bag":0x7d745e,
"Messinesi":0xfee2be,
"Metal":0xbabfbc,
"Metal Chi":0x9c9c9b,
"Metal Construction Green":0x2f2e1f,
"Metal Deluxe":0x244343,
"Metal Flake":0x838782,
"Metal Fringe":0x837e74,
"Metal Gear":0xa2c3db,
"Metal Grey":0x677986,
"Metal Petal":0xb090b2,
"Metal Spark":0xeeff99,
"Metalise":0x34373c,
"Metallic Blue":0x4f738e,
"Metallic Bronze":0x554a3c,
"Metallic Copper":0x6e3d34,
"Metallic Gold":0xd4af37,
"Metallic Green":0x24855b,
"Metallic Mist":0xcdccbe,
"Metallic Seaweed":0x0a7e8c,
"Metallic Sunburst":0x9c7c38,
"Meteor":0xbb7431,
"Meteor Shower":0x5533ff,
"Meteorite":0x4a3b6a,
"Meteorite Black Blue":0x414756,
"Meteorological":0x596d69,
"Methadone":0xcc2233,
"Methyl Blue":0x0074a8,
"Metro":0x828393,
"Metroid Red":0xf83800,
"Metropolis":0x61584f,
"Metropolis Mood":0x99a1a5,
"Mette Penne":0xf9e1d4,
"Mettwurst":0xdf7163,
"Mexican Chile":0xd16d76,
"Mexican Chocolate":0x6f5a48,
"Mexican Milk":0xffb9b2,
"Mexican Moonlight":0xc99387,
"Mexican Mudkip":0xfcd8dc,
"Mexican Pink":0xe4007c,
"Mexican Purple":0x5a3c55,
"Mexican Red":0x9b3d3d,
"Mexican Red Papaya":0xc6452f,
"Mexican Sand":0xaf9781,
"Mexican Sand Dollar":0xdad4c5,
"Mexican Silver":0xcecec8,
"Mexican Spirit":0xd68339,
"Mexican Standoff":0xec9f76,
"Mǐ Bái Beige":0xdad7ad,
"Mì Chéng Honey":0xe8af45,
"Miami Jade":0x17917f,
"Miami Marmalade":0xf7931a,
"Miami Spice":0x907a6e,
"Miami Stucco":0xf5d5b8,
"Miami Weiss":0xede4d3,
"Miami White":0xccccee,
"Mica Creek":0x70828f,
"Micaceous Green":0xc5dacc,
"Micaceous Light Grey":0xcdc7bd,
"Microchip":0xbabcc0,
"Micropolis":0x556e6b,
"MicroProse Red":0xee172b,
"Microwave Blue":0x2d5254,
"Mid Blue":0x276ab3,
"Mid Century":0x553333,
"Mid Century Furniture":0xae5c1b,
"Mid Cypress":0x779781,
"Mid Green":0x50a747,
"Mid Grey":0x5f5f6e,
"Mid Spring Morning":0xcff7ef,
"Mid Tan":0xc4915e,
"Mid-century Gem":0x81b39c,
"Midas Finger Gold":0xf6b404,
"Midas Touch":0xe8bd45,
"Midday":0xf7d78a,
"Midday Sun":0xffe1a3,
"Middle Blue":0x7ed4e6,
"Middle Blue Green":0x8dd9cc,
"Middle Blue Purple":0x8b72be,
"Middle Ditch":0x7c6942,
"Middle Green":0x4d8c57,
"Middle Green Yellow":0xacbf60,
"Middle Purple":0xd982b5,
"Middle Red":0xe58e73,
"Middle Red Purple":0x210837,
"Middle Safflower":0xc85179,
"Middle Yellow":0xffeb00,
"Middle Yellow Red":0xecb176,
"Middle-Earth":0xa2948d,
"Middlestone":0xc7ab84,
"Middy's Purple":0xaa8ed6,
"Midnight":0x03012d,
"Midnight Badger":0x585960,
"Midnight Blue":0x020035,
"Midnight Blush":0x979fbf,
"Midnight Brown":0x706048,
"Midnight Clover":0x3c574e,
"Midnight Dream":0x394857,
"Midnight Dreams":0x002233,
"Midnight Escape":0x403c40,
"Midnight Express":0x21263a,
"Midnight Garden":0x637057,
"Midnight Green":0x004953,
"Midnight Grey":0x666a6d,
"Midnight Haze":0x3e505f,
"Midnight Hour":0x3b484f,
"Midnight in NY":0x4e5a59,
"Midnight in Saigon":0xdd8866,
"Midnight in the Tropics":0x435964,
"Midnight in Tokyo":0x000088,
"Midnight Magic":0x46474a,
"Midnight Melancholia":0x002266,
"Midnight Merlot":0x880044,
"Midnight Mosaic":0x3d5267,
"Midnight Moss":0x242e28,
"Midnight Navy":0x34414e,
"Midnight Pearl":0x5f6c74,
"Midnight Purple":0x280137,
"Midnight Sea":0x565b8d,
"Midnight Show":0x546473,
"Midnight Sky":0x424753,
"Midnight Spruce":0x555b53,
"Midnight Sun":0x4e5a6d,
"Midnight Violet":0x6a75ad,
"Midori":0x2a603b,
"Midori Green":0x3eb370,
"Midsummer":0xf6d9a9,
"Midsummer Dream":0xb7a5ad,
"Midsummer Gold":0xeab034,
"Midsummer Nights":0x0011ee,
"Midsummer's Dream":0xb4d0d9,
"Midtown":0xb5a18a,
"Midwinter Fire":0xdd1100,
"Midwinter Mist":0xa5d4dc,
"Mighty Mauve":0x8f7f85,
"Mighty Midnight":0x000133,
"Migol Blue":0x283482,
"Mikado":0x3f3623,
"Mikado Yellow":0xffc40c,
"Mikan Orange":0xf08300,
"Mike Wazowski Green":0x11ee55,
"Milady":0xeee1dc,
"Milan":0xf6f493,
"Milano":0xc1a181,
"Milano Red":0x9e3332,
"Mild Blue":0xcbd5db,
"Mild Blue Yonder":0xa2add0,
"Mild Evergreen":0x8ebbac,
"Mild Green":0x789885,
"Mild Mint":0xdce6e3,
"Mild Orange":0xf3bb93,
"Mildura":0x667960,
"Miles":0x829ba0,
"Milestone":0x7f848a,
"Militant Vegan":0x229955,
"Military Green":0x667c3e,
"Military Olive":0x63563b,
"Milk":0xfdfff5,
"Milk and Cookies":0xe9e1df,
"Milk Blue":0xdce3e7,
"Milk Brownie Dough":0x8f7265,
"Milk Chocolate":0x7f4e1e,
"Milk Coffee Brown":0x966f5d,
"Milk Froth":0xffeecc,
"Milk Glass":0xfaf7f0,
"Milk Mustache":0xfaf3e6,
"Milk Paint":0xefe9d9,
"Milk Punch":0xfff4d3,
"Milk Quartz":0xf5deae,
"Milk Star White":0xf5ede2,
"Milk Thistle":0x9e9b88,
"Milk Tooth":0xfaebd7,
"Milk White":0xdcd9cd,
"Milkshake Pink":0xf0cdd2,
"Milkweed":0xe3e8d9,
"Milkweed Pod":0x95987e,
"Milkwort Red":0x916981,
"Milky":0xe2dcd4,
"Milky Aquamarine":0x038487,
"Milky Blue":0x72a8ba,
"Milky Green":0xcfdbd1,
"Milky Maize":0xf9d9a0,
"Milky Skies":0xc3b1af,
"Milky Way":0xe8f4f7,
"Milky Way Galaxy":0xfaefd5,
"Milky Yellow":0xf8dd74,
"Mill Creek":0x876e59,
"Millbrook":0x595648,
"Mille-Feuille":0xefc87d,
"Millennium Silver":0x8c9595,
"Millionaire":0xb6843c,
"Millstream":0xb9d4de,
"Milly Green":0x99bd91,
"Milpa":0x689663,
"Milton":0xb4b498,
"Milvus Milvus Orange":0xbb7722,
"Mimesia Blue":0x2269ca,
"Mimi Pink":0xffdae9,
"Mimolette Orange":0xee8811,
"Mimosa":0xf5e9d5,
"Mimosa Yellow":0xdfc633,
"Minced Ginger":0xbdb387,
"Mincemeat":0xb66a3c,
"Mindaro":0xdaea6f,
"Mindful Gray":0xbdb5ad,
"Mine Rock":0x8e8583,
"Mine Shaft":0x373e41,
"Mined Coal":0x6c6b65,
"Miner's Dust":0xd3cec5,
"Mineral":0xd7d1c5,
"Mineral Beige":0xd8c49f,
"Mineral Blue":0x6d9192,
"Mineral Brown":0x4d3f33,
"Mineral Deposit":0xabb0ac,
"Mineral Glow":0xfce8ce,
"Mineral Gray":0x515763,
"Mineral Green":0x506355,
"Mineral Grey":0xb2b6ac,
"Mineral Red":0xb35457,
"Mineral Spring":0xedf2ec,
"Mineral Umber":0xb18b32,
"Mineral Water":0xdfebd6,
"Mineral White":0xdce5d9,
"Mineral Yellow":0xd39c43,
"Minerva":0xb5deda,
"Minestrone":0xc72616,
"Ming":0x407577,
"Ming Green":0x3aa278,
"Mini Bay":0x8aadcf,
"Mini Blue":0x96d7db,
"Mini Cake":0xfbf6de,
"Mini Green":0x9fc5aa,
"Miniature Posey":0xe5beba,
"Minified Ballerina Blue":0xd3dfea,
"Minified Blue":0xb3dbea,
"Minified Blush":0xf2dde1,
"Minified Cinnamon":0xded9db,
"Minified Green":0xdde8e0,
"Minified Jade":0xc1e3e9,
"Minified Lime":0xebf5de,
"Minified Magenta":0xe6dfe8,
"Minified Malachite":0xddf3e5,
"Minified Maroon":0xe5dbda,
"Minified Mauve":0xe0dce4,
"Minified Mint":0xe4ebdc,
"Minified Moss":0xe3e8db,
"Minified Mustard":0xe9e6d4,
"Minified Purple":0xe1dee7,
"Minified Yellow":0xf4ebd4,
"Minimal":0xf3eecd,
"Minimal Grey":0x948d99,
"Minimal Rose":0xf2cfe0,
"Minimalist":0xcabead,
"Minimalistic":0xe9ece5,
"Minimum Beige":0xe8d3ba,
"Minion Yellow":0xfed55d,
"Mink":0x8a7561,
"Mink Brown":0x67594c,
"Mink Haze":0xc5b29f,
"Minnesota April":0x9b9fb5,
"Minor Blue":0xb7dfe8,
"Minotaur Red":0x734b42,
"Minotaurus Brown":0x882211,
"Minsk":0x3e3267,
"Minstrel of the Woods":0x118800,
"Minstrel Rose":0xc89697,
"Mint":0x3eb489,
"Mint Blossom Rose":0xd7c2ce,
"Mint Blue":0xbce0df,
"Mint Bonbon Green":0x7db6a8,
"Mint Chiffon":0xe6fdf1,
"Mint Circle":0xa9ceaa,
"Mint Cocktail Green":0xb8e2b0,
"Mint Cold Green":0x6cbba0,
"Mint Condition":0xdffbf3,
"Mint Cream":0xf5fffa,
"Mint Emulsion":0xdfeadb,
"Mint Fizz":0xe6f3e7,
"Mint Flash":0xdcf4e6,
"Mint Frappe":0xd0ebc8,
"Mint Gloss":0xc8f3cd,
"Mint Grasshopper":0xe2f0e0,
"Mint Green":0x487d49,
"Mint Hint":0xecf4e2,
"Mint Ice":0xbde8d8,
"Mint Ice Cream":0x98cdb5,
"Mint Ice Green":0xc9caa1,
"Mint Jelly":0x45cea2,
"Mint Julep":0xdef0a3,
"Mint Leaf":0x00b694,
"Mint Leaves":0x6a7d4e,
"Mint Macaron":0xafeeee,
"Mint Majesty":0x7dd7c0,
"Mint Morning":0x00ddcc,
"Mint Mousse":0xb4ccbd,
"Mint Parfait":0xbbe6bb,
"Mint Shake":0xdaeed3,
"Mint Smoothie":0xc5e6d1,
"Mint Soap":0xcbd5b1,
"Mint Sprig":0x009c6e,
"Mint Tea":0xafeee1,
"Mint Tonic":0x99eeaa,
"Mint Tulip":0xc6eadd,
"Mint Twist":0x98cbba,
"Mint Wafer":0xdce5d8,
"Mint Zest":0xcfecee,
"Mint-o-licious":0xb6e9c8,
"Mintage":0x78bfb2,
"Minted":0xe0ead8,
"Minted Blue":0x26a6be,
"Minted Blueberry Lemonade":0xb32651,
"Minted Ice":0xd8f3eb,
"Minted Lemon":0xc1c6a8,
"Mintie":0xabf4d2,
"Mintos":0x80d9cc,
"Minty Fresh":0xd2f2e7,
"Minty Frosting":0xdbe8cf,
"Minty Green":0x0bf77d,
"Minty Paradise":0x00ffbb,
"Minuet":0xa5b6cf,
"Minuet Rose":0xb38081,
"Minuet White":0xe8e6e7,
"Minuette":0xd47791,
"Minute Mauve":0xcfc9c8,
"Mirabella":0x886793,
"Mirabelle Yellow":0xf3be67,
"Miracle":0x898696,
"Miracle Bay":0x799292,
"Miracle Elixir":0x617ba6,
"Mirador":0xbcdccd,
"Mirage":0x373f43,
"Mirage Blue":0x636c77,
"Mirage Grey":0xabafae,
"Mirage Lake":0x4f938f,
"Mirage White":0xf5f4e6,
"Miranda's Spike":0x614251,
"Mirror Ball":0xd6d4d7,
"Mirror Lake":0x7aa8cb,
"Mirror Mirror":0xa8b0b2,
"Mirrored Willow":0x8e876e,
"Mischief Maker":0x954738,
"Mischief Mouse":0xb7bab9,
"Mischievous":0xdff2dd,
"Mischka":0xa5a9b2,
"Missed":0xeff0c0,
"Missing Link":0x6f5d57,
"Mission Bay Blue":0x9ba9ab,
"Mission Brown":0x775c47,
"Mission Control":0x818387,
"Mission Courtyard":0xf3d1b3,
"Mission Gold":0xb78d61,
"Mission Hills":0xb29c7f,
"Mission Jewel":0x456252,
"Mission Stone":0xdac5b6,
"Mission Tan":0xdac6a8,
"Mission Tile":0x874c3e,
"Mission Trail":0x857a64,
"Mission White":0xe2d8c2,
"Mission Wildflower":0x9e5566,
"Mississippi Mud":0x99886f,
"Mississippi River":0x3b638c,
"Missouri Mud":0xa6a19b,
"Mist Green":0xaacebc,
"Mist Grey":0xc4c4bc,
"Mist of Green":0xe3f1eb,
"Mist Spirit":0xe4ebe7,
"Mist Yellow":0xf8eed6,
"Misted Eve":0xa2b7cf,
"Misted Fern":0xe1ecd1,
"Misted Yellow":0xdab965,
"Mistletoe":0x8aa282,
"Mistletoe Kiss":0x98b489,
"Mistral":0xb8bfcc,
"Misty":0xcdd2d2,
"Misty Afternoon":0xc6dcc7,
"Misty Aqua":0xbcdbdb,
"Misty Beach Cattle":0xf1eedf,
"Misty Bead":0xd2d59b,
"Misty Blue":0xbfcdcc,
"Misty Blush":0xddc9c6,
"Misty Coast":0xd5d9d3,
"Misty Dawn":0xe4e5e0,
"Misty Grape":0x65434d,
"Misty Hillside":0xdce5cc,
"Misty Isle":0xc5e4dc,
"Misty Jade":0xbcd9c8,
"Misty Lake":0xc2d5c4,
"Misty Lavender":0xdbd9e1,
"Misty Lawn":0xdffae1,
"Misty Lilac":0xbcb4c4,
"Misty Meadow":0xbec0b0,
"Misty Moonstone":0xe5e0cc,
"Misty Moor":0x718981,
"Misty Morn":0xe7e1e3,
"Misty Morning":0xb2c8bd,
"Misty Moss":0xbbb477,
"Misty Mustard":0xf7ebd1,
"Misty Rose":0xffe4e1,
"Misty Surf":0xb5c8c9,
"Misty Valley":0xbdc389,
"Misty Violet":0xdbd7e4,
"Mitchell Blue":0x0d789f,
"Mithril":0x878787,
"Mithril Silver":0xbbbbc1,
"Mix Or Match":0xccccba,
"Mixed Berries":0x96819a,
"Mixed Berry Jam":0x6a4652,
"Mixed Fruit":0xf9bab2,
"Mixed Veggies":0x719166,
"Miyamoto Red":0xe4030f,
"Miyazaki Verdant":0x6fea3e,
"Mizu":0x70c1e0,
"Mizu Cyan":0xa7dbed,
"Mizuasagi Green":0x749f8d,
"Moat":0x3e6a6b,
"Mobster":0x605a67,
"Moby Dick":0xdde8ed,
"Moccasin":0xfbebd6,
"Mocha":0x9d7651,
"Mocha Accent":0x8d8171,
"Mocha Bisque":0x8c543a,
"Mocha Black":0x6f5b52,
"Mocha Brown":0x6b565e,
"Mocha Foam":0xbba28e,
"Mocha Glow":0x773322,
"Mocha Ice":0xdfd2ca,
"Mocha Latte":0x82715f,
"Mocha Light":0xd7cfc2,
"Mocha Magic":0x88796d,
"Mocha Mousse":0xa47864,
"Mocha Tan":0xac9680,
"Mocha Wisp":0x918278,
"Mochaccino":0x945200,
"Mochachino":0xbeaf93,
"Mochito":0x8efa00,
"Mock Orange":0xffa368,
"Mod Orange":0xd8583c,
"Modal":0x31a6d1,
"Modal Blue":0x40a6ac,
"Mode Beige":0x96711f,
"Moderate White":0xe9decf,
"Modern Blue":0xbad1e9,
"Modern Gray":0xd5cec2,
"Modern History":0xbea27d,
"Modern Ivory":0xf5ecdc,
"Modern Lavender":0xa8aab3,
"Modern Mint":0x88a395,
"Modern Mocha":0x9d8376,
"Modern Monument":0xd6d6d1,
"Modern Zen":0xe0deb2,
"Moderne Class":0x745b49,
"Modest Mauve":0x838492,
"Modest Violet":0xe9e4ef,
"Modest White":0xe6ddd4,
"Modestly Peach":0xeea59d,
"Modesty":0xd4c7d9,
"Modish Moss":0xc3b68b,
"Moegi Green":0xf19172,
"Moelleux Au Chocolat":0x553311,
"Moenkopi Soil":0xc8a692,
"Mogwa-Cheong Yellow":0xddcc00,
"Mohair Mauve":0xbfa59e,
"Mohair Pink":0xa78594,
"Mohair Soft Blue Grey":0x97b2b7,
"Mohalla":0xa79b7e,
"Moire":0xbeadb0,
"Moire Satin":0x665d63,
"Moist Gold":0xdbdb70,
"Moist Silver":0xe0e7dd,
"Moisty Mire":0x004422,
"Mojave Desert":0xc7b595,
"Mojave Dusk":0xb99178,
"Mojave Gold":0xbf9c65,
"Mojave Sunset":0xaa6a53,
"Mojito":0xe4f3e0,
"Mojo":0x97463c,
"Molasses":0x574a47,
"Molasses Cookie":0x8b714b,
"Moldy Ochre":0xd5a300,
"Mole":0x392d2b,
"Mole Grey":0x938f8a,
"Moleskin":0xb0a196,
"Molly Green":0xe3efe3,
"Molly Robins":0x4d8b72,
"Molten Bronze":0xc69c04,
"Molten Core":0xff5800,
"Molten Ice":0xe1ede6,
"Molten Lava":0xb5332e,
"Molten Lead":0x686a69,
"Mom's Apple Pie":0xeab781,
"Mom's Love":0xffd4bb,
"Momentum":0x746f5c,
"Momo Peach":0xf47983,
"Momoshio Brown":0x542d24,
"Mona Lisa":0xff9889,
"Monaco":0xabd4e6,
"Monaco Blue":0x274374,
"Monarch":0x6b252c,
"Monarch Gold":0xb7813c,
"Monarch Migration":0xbf764c,
"Monarch Orange":0xefa06b,
"Monarch Wing":0xff8d25,
"Monarch's Cocoon":0x8cb293,
"Monarchist":0x4b62d2,
"Monarchy":0x9093ad,
"Monastery Mantle":0x41363a,
"Monastic":0xaba9d2,
"Monastir":0xb78999,
"Moncur":0x9bb9ae,
"Mondo":0x554d42,
"Mondrian Blue":0x0f478c,
"Monet":0xc3cfdc,
"Monet Lily":0xcdd7e6,
"Monet Magic":0xc1acc3,
"Monet Moonrise":0xeef0d1,
"Monet's Lavender":0xdde0ea,
"Money":0x7b9a6d,
"Money Banks":0xaabe49,
"Money Tree":0xc9937a,
"Mongolian Plateau":0x777700,
"Mongoose":0xa58b6f,
"Monk's Cloth":0x6e6355,
"Monkey Island":0x553b39,
"Monkey Madness":0x63584c,
"Monks Robe":0x704822,
"Monogram":0x595747,
"Monologue":0xa1bcd8,
"Monorail Silver":0xb8bcbb,
"Monroe Kiss":0xdec1b8,
"Monsoon":0x7a7679,
"Monstera Deliciosa":0x75bf0a,
"Monstrous Green":0x22cc11,
"Mont Blanc":0x9eb6d8,
"Mont Blanc Peak":0xf2e7e7,
"Montage":0x8190a4,
"Montana":0x393b3c,
"Montana Grape":0x6c5971,
"Montana Sky":0x6ab0b9,
"Montauk Sands":0xbbad9e,
"Monte Carlo":0x7ac5b4,
"Montecito":0xb6a180,
"Montego Bay":0x3fbabd,
"Monterey Brown":0x946e5c,
"Monterey Chestnut":0x7d4235,
"Montezuma":0xd2cdb6,
"Montezuma Gold":0xeecc44,
"Montezuma Hills":0xa6b2a4,
"Montezuma's Castle":0xd9ad9e,
"Montreux Blue":0x5879a2,
"Montrose Rose":0x9d6a73,
"Monument":0x84898c,
"Monument Grey":0x7a807a,
"Monza":0xc7031e,
"Moo":0xfbe5bd,
"Mood Indigo":0x353a4c,
"Mood Lighting":0xffe7d5,
"Mood Mode":0x7f90cb,
"Moody Black":0x49555d,
"Moody Blue":0x8378c7,
"Moody Blues":0x586e75,
"Mooloolaba":0xc7b8a9,
"Moon Base":0x7d7d77,
"Moon Buggy":0xc7bdc1,
"Moon Dance":0xfaefbe,
"Moon Drop":0xddd5c9,
"Moon Dust":0xe0e6f0,
"Moon Glass":0xbcd1c7,
"Moon Glow":0xf5f3ce,
"Moon Goddess":0xcfc7d5,
"Moon Jellyfish":0x8eb8ce,
"Moon Lily":0xe6e6e7,
"Moon Mist":0xcecdb8,
"Moon Rise":0xf4f4e8,
"Moon Rock":0x958b84,
"Moon Rose":0xb9aba5,
"Moon Shell":0xe9e3d8,
"Moon Valley":0xfcf1de,
"Moon White":0xeaf4fc,
"Moon Yellow":0xf0c420,
"Moonbeam":0xcdc6bd,
"Moondance":0xe5decc,
"Moondoggie":0xf3debf,
"Moonglade Water":0x65ffff,
"Moonglow":0xf8e4c4,
"Moonless Night":0x2f2d30,
"Moonlight":0xf6eed5,
"Moonlight Blue":0x506886,
"Moonlight Green":0xd2e8d8,
"Moonlight Jade":0xc7e5df,
"Moonlight Melody":0xaf73b0,
"Moonlight White":0xf9f0de,
"Moonlight Yellow":0xe1c38b,
"Moonlit Beach":0xf9f0e6,
"Moonlit Mauve":0xd28fb0,
"Moonlit Ocean":0x293b4d,
"Moonlit Orchid":0x949194,
"Moonlit Pool":0x205a61,
"Moonlit Snow":0xeaeeec,
"Moonmist":0xc9d9e0,
"Moonquake":0x8d9596,
"Moonraker":0xc0b2d7,
"Moonrose":0xa53f48,
"Moonscape":0x725f69,
"Moonshade":0x5a6e9c,
"Moonshadow":0x9845b0,
"Moonstone":0x3aa8c1,
"Moonstone Blue":0x73a9c2,
"Moonstruck":0xfcf0c2,
"Moonwalk":0xbebec4,
"Moonwort":0xa5ae9f,
"Moor Oak Grey":0x6a584d,
"Moor Pond Green":0x3c6461,
"Moorland":0xa6ab9b,
"Moorland Heather":0xcc94be,
"Moorstone":0xcfd1ca,
"Moose Fur":0x725440,
"Moose Trail":0x6b5445,
"Moosewood":0x5d5744,
"Moot Green":0xa2db10,
"Moping Green":0x00ee33,
"Morado Purple":0x9955cc,
"Morality":0xb4cde5,
"Morass":0x726138,
"Moray":0xc8bd6a,
"Moray Eel":0x00a78b,
"Mordant Blue":0x2a6671,
"Mordant Red 19":0xae0c00,
"Mordian Blue":0x2f5684,
"More Maple":0xd0ab70,
"More Melon":0xe0e3c8,
"More Mint":0xe6e8c5,
"More Than A Week":0x8d8d8d,
"Morel":0x685c53,
"Morganite":0xdfcdc6,
"Morning at Sea":0x82979b,
"Morning Blue":0x8da399,
"Morning Blush":0xf9e8df,
"Morning Bread":0xe7e6de,
"Morning Breeze":0xd5e3de,
"Morning Calm":0xceeeef,
"Morning Dew":0xb0b9ac,
"Morning Dew White":0xc6dbd6,
"Morning Fog":0xd0dbd7,
"Morning Forest":0x6dae81,
"Morning Frost":0xebf4df,
"Morning Glory":0x9ed1d3,
"Morning Glory Pink":0xca99b7,
"Morning Glow":0xeef0d6,
"Morning Green":0x89bab2,
"Morning Haze":0xe0e8ed,
"Morning Light Wave":0xe0efe9,
"Morning Mist":0xe5edf1,
"Morning Mist Grey":0xada7b9,
"Morning Moon":0xf7eecf,
"Morning Moor":0xdad6ae,
"Morning Parlor":0xacc0bd,
"Morning Rush":0xdee4dc,
"Morning Shine":0xf8eaed,
"Morning Sigh":0xfce9de,
"Morning Sky":0xc7ecea,
"Morning Snow":0xf5f4ed,
"Morning Song":0xe4ece9,
"Morning Sun":0xf3e6ce,
"Morning Sunlight":0xfdefcc,
"Morning Tea":0xcabd94,
"Morning Wheat":0xe7d2a9,
"Morning Zen":0xcbcdb9,
"Morning's Egg":0xd9be77,
"Morningside":0xf3e2df,
"Mornington":0xdcc6b9,
"Moroccan Blue":0x0f4e67,
"Moroccan Blunt":0x75583d,
"Moroccan Brown":0x7c726c,
"Moroccan Dusk":0x6b5e5d,
"Moroccan Henna":0x6e5043,
"Moroccan Leather":0x6d4444,
"Moroccan Moonlight":0xeae0d4,
"Moroccan Ruby":0x8d504b,
"Moroccan Sky":0xbf7756,
"Moroccan Spice":0x8f623b,
"Morocco":0xb67267,
"Morocco Brown":0x442d21,
"Morocco Red":0x96453b,
"Morocco Sand":0xece3cc,
"Morris Artichoke":0x8cb295,
"Morris Leaf":0xc2d3af,
"Morris Room Grey":0xada193,
"Morro Bay":0x546b78,
"Morrow White":0xfcfccf,
"Mortar":0x565051,
"Mortar Grey":0x9e9f9e,
"Mosaic Blue":0x00758f,
"Mosaic Green":0x599f68,
"Mosaic Tile":0x1c6b69,
"Moscow Midnight":0x204652,
"Moscow Mule":0xeecc77,
"Moscow Papyrus":0x937c00,
"Moselle Green":0x2e4e36,
"Mosque":0x005f5b,
"Moss":0x009051,
"Moss Beach":0x6b7061,
"Moss Brown":0x715b2e,
"Moss Cottage":0x42544c,
"Moss Covered":0x7a7e66,
"Moss Glen":0x4a473f,
"Moss Green":0x638b27,
"Moss Grey":0xafab97,
"Moss Ink":0xc7cac1,
"Moss Island":0xc8c6b4,
"Moss Landing":0x6d7e40,
"Moss Mist":0xdee1d3,
"Moss Point Green":0x7e8d60,
"Moss Print":0xafb796,
"Moss Ring":0x729067,
"Moss Rock":0x5e5b4d,
"Moss Rose":0x8f6d6b,
"Moss Stone":0xb4a54b,
"Moss Vale":0x38614c,
"Mossa":0xb4c2b6,
"Mosslands":0x779966,
"Mossleaf":0x8c9d8f,
"Mosstone":0x858961,
"Mossy":0x857349,
"Mossy Bank":0x8b8770,
"Mossy Bench":0x83a28f,
"Mossy Bronze":0x525f48,
"Mossy Cavern":0xa4a97b,
"Mossy Gold":0x9c9273,
"Mossy Green":0x5a7c46,
"Mossy Oak":0x848178,
"Mossy Pavement":0x908c7e,
"Mossy Rock":0xa9965d,
"Mossy Shade":0x7e6c44,
"Mossy Statue":0x828e74,
"Mossy White":0xe7f2de,
"Mossy Woods":0x7a9703,
"Mostly Metal":0x575e5f,
"Mote of Dust":0xc1c1c5,
"Moth":0xd2cbaf,
"Moth Green":0x007700,
"Moth Grey":0xdad3cb,
"Moth Mist":0xedebde,
"Moth Orchid":0xc875c4,
"Moth Pink":0xcfbdba,
"Moth Wing":0xccbca9,
"Moth's Wing":0xedf1db,
"Mother Earth":0x849c8d,
"Mother Lode":0xa28761,
"Mother Nature":0xbde1c4,
"Mother of Pearl":0xe9d4c3,
"Mother-Of-Pearl Green":0x8fd89f,
"Mother-Of-Pearl Pink":0xd1c4c6,
"Mother-Of-Pearl Silver":0xccd6e6,
"Motherland":0xbcb667,
"Mothra Wing":0xeedd82,
"Mothy":0xcebbb3,
"Motto":0x917c6f,
"Mount Eden":0xe7efe0,
"Mount Etna":0x3d484c,
"Mount Hyjal":0x3d703e,
"Mount Olive":0x716646,
"Mount Olympus":0xd4ffff,
"Mount Sterling":0xcad3d4,
"Mount Tam":0x7c7b6a,
"Mountain Air":0xe6e0e0,
"Mountain Ash":0xcc7700,
"Mountain Blueberry":0x3c4b6c,
"Mountain Bluebird":0x4c98c2,
"Mountain Crystal Silver":0xe2efe8,
"Mountain Dew":0xcfe2e0,
"Mountain Elk":0x867965,
"Mountain Falls":0xbdcac0,
"Mountain Fern":0x94b491,
"Mountain Fig":0x383c49,
"Mountain Flower Mauve":0x6c71a6,
"Mountain Fog":0xf4dbc7,
"Mountain Forest":0x4d663e,
"Mountain Green":0xb2b599,
"Mountain Grey":0xe8e3db,
"Mountain Haze":0x6c6e7e,
"Mountain Heather":0xeedae6,
"Mountain Lake":0x2d5975,
"Mountain Lake Azure":0x4cbca7,
"Mountain Lake Blue":0x85d4d4,
"Mountain Lake Green":0x75b996,
"Mountain Laurel":0xf4c8d5,
"Mountain Lichen":0xa7ae9e,
"Mountain Main":0x8db8d0,
"Mountain Maize":0xefcc7c,
"Mountain Meadow":0x30ba8f,
"Mountain Meadow Green":0x418638,
"Mountain Mint":0xa7e0c2,
"Mountain Mist":0xa09f9c,
"Mountain Morn":0xd4dcd1,
"Mountain Moss":0x94a293,
"Mountain Pass":0x5c6a6a,
"Mountain Pine":0x3b5257,
"Mountain Range Blue":0x53b8c9,
"Mountain Range Green":0x283123,
"Mountain Ridge":0x75665e,
"Mountain Road":0x868578,
"Mountain Sage":0xa3aa8c,
"Mountain Shade":0xb1ab9a,
"Mountain Spring":0xd9e1c1,
"Mountain Stream":0x96afb7,
"Mountain Trail":0x615742,
"Mountain View":0x2e3d30,
"Mountain's Majesty":0xd8d0e3,
"Mountbatten Pink":0x997a8d,
"Mourn Mountain Snow":0xe9eaeb,
"Mournfang Brown":0x6f5749,
"Mourning Dove":0x94908b,
"Mourning Violet":0x474354,
"Mouse Catcher":0x9e928f,
"Mouse Nose":0xffe5b4,
"Mouse Tail":0x727664,
"Mouse Trap":0xbeb1b0,
"Moussaka":0x6d2a13,
"Mousy Brown":0x5c4939,
"Mousy Indigo":0x5c544e,
"Moutarde de Bénichon":0xbf9005,
"Move Mint":0x4effcd,
"Mover & Shaker":0x9cce9e,
"Mover and Shaker":0x855d44,
"Movie Magic":0xb2bfd5,
"Movie Star":0xc52033,
"Mow the Lawn":0xa9b49a,
"Mown Grass":0x627948,
"Mown Hay":0xe6d3bb,
"Moxie":0xe5dad8,
"Mozart":0x485480,
"Mozzarella Covered Chorizo":0xe39b7a,
"Mr Frosty":0xa3c5db,
"Mr Mustard":0xe4b857,
"Mr. Glass":0xc0d5ef,
"Ms. Pac-Man Kiss":0xff00aa,
"MSU Green":0x18453b,
"Mt Burleigh":0x597766,
"Mt. Hood White":0xe7e9e6,
"Mt. Rushmore":0x7f8181,
"Mǔ Lì Bái Oyster":0xf1f2d3,
"Mud":0x70543e,
"Mud Ball":0x966544,
"Mud Bath":0x7c6841,
"Mud Berry":0xd0c8c4,
"Mud Brown":0x60460f,
"Mud Green":0x606602,
"Mud House":0x847146,
"Mud Pack":0x9d9588,
"Mud Pink":0xdcc0c3,
"Mud Pots":0xb6b5b1,
"Mud Puddle":0x9d958b,
"Mud Room":0x60584b,
"Mud Yellow":0xc18136,
"Mud-Dell":0xa08b76,
"Mudbrick":0xa46960,
"Muddled Basil":0x5a5243,
"Muddy Brown":0x886806,
"Muddy Green":0x657432,
"Muddy Mauve":0xe4b3cc,
"Muddy Olive":0x4b5d46,
"Muddy Quicksand":0xc3988b,
"Muddy River":0x715d3d,
"Muddy Rose":0xe2beb4,
"Muddy Waters":0xa9844f,
"Muddy Yellow":0xbfac05,
"Mudra":0xb8d0da,
"Mudskipper":0x897a69,
"Mudslide":0x84735f,
"Mudstone":0x84846f,
"Muesli":0x9e7e53,
"Muffin Magic":0xf9ddc7,
"Muffin Mix":0xf5e0d0,
"Mughal Green":0x448800,
"Mukluks":0xa38961,
"Mulberry":0x920a4e,
"Mulberry Brown":0x956f29,
"Mulberry Bush":0xad6ea0,
"Mulberry Mauve Black":0x463f60,
"Mulberry Mix":0x9f556c,
"Mulberry Purple":0x493c62,
"Mulberry Silk":0x94766c,
"Mulberry Stain":0xc6babe,
"Mulberry Thorn":0xc57f2e,
"Mulberry Wine":0x997c85,
"Mulberry Wood":0x5c0536,
"Mulberry Yogurt":0xc54b8c,
"Mulch":0x433937,
"Mule":0x827b77,
"Mule Fawn":0x884f40,
"Mulgore Mustard":0xc2b332,
"Mulled Cider":0xa18162,
"Mulled Grape":0x675a74,
"Mulled Wine":0x524d5b,
"Mulled Wine Red":0x3b2932,
"Mullen Pink":0xca4042,
"Mulling Spice":0xc18654,
"Multnomah Falls":0xccd0dd,
"Mulu Frog":0x55bb00,
"Mummy's Tomb":0x828e84,
"Munch On Melon":0xf23e67,
"Munchkin":0x9bb139,
"Munsell Blue":0x0093af,
"Munsell Yellow":0xefcc00,
"Muntok White Pepper":0xd2a172,
"Murano Soft Blue":0xc5d6ee,
"Murasaki":0x4f284b,
"Murasaki Purple":0x884898,
"Murdoch":0x5b8d6b,
"Murex":0x847eb1,
"Murky Green":0x6c7a0e,
"Murmur":0xd2d8d2,
"Murray Red":0x6b3c39,
"Muscat Blanc":0xebe2cf,
"Muscat Grape":0x5e5067,
"Muscatel":0x7b6a68,
"Muscovado Sugar":0x9b6957,
"Muse":0xa5857f,
"Museum":0x685951,
"Mushiao Green":0x2d4436,
"Mushroom":0xbdaca3,
"Mushroom Basket":0x977a76,
"Mushroom Bisque":0xcab49b,
"Mushroom Brown":0x906e58,
"Mushroom Risotto":0xdbd0ca,
"Mushroom White":0xf0e1cd,
"Musical Mist":0xf8eae6,
"Musk":0xcca195,
"Musk Deer":0x7e5b58,
"Musk Dusk":0xcfbfb9,
"Musk Memory":0x774548,
"Musket":0x7d6d39,
"Muskmelon":0xec935e,
"Muskrat":0x7e6f4f,
"Muslin":0xd3d1c4,
"Muslin Tint":0xe0cdb1,
"Mussel Green":0x24342a,
"Mussel White":0xf0e2de,
"Mustang":0x5e4a47,
"Mustard":0xceb301,
"Mustard Brown":0xac7e04,
"Mustard Crusted Salmon":0xef8144,
"Mustard Field":0xd8b076,
"Mustard Flower":0xd2bd0a,
"Mustard Gold":0xb08e51,
"Mustard Green":0xa8b504,
"Mustard Magic":0x857139,
"Mustard Musketeers":0xd5a129,
"Mustard Oil":0xd5bd66,
"Mustard On Toast":0xddcc33,
"Mustard Sauce":0xedbd68,
"Mustard Seed":0xc69f26,
"Mustard Seed Beige":0xc5a574,
"Mustard Yellow":0xe1ad01,
"Mutabilis":0xc29594,
"Muted Berry":0x91788c,
"Muted Blue":0x3b719f,
"Muted Clay":0xd29380,
"Muted Green":0x5fa052,
"Muted Lime":0xd1c87c,
"Muted Mauve":0xb3a9a3,
"Muted Mulberry":0x66626d,
"Muted Pink":0xd1768f,
"Muted Purple":0x805b87,
"Muted Sage":0x93907e,
"MVS Red":0xee0000,
"My Fair Lady":0xf3c4c2,
"My Love":0xe1c6a8,
"My Pink":0xd68b80,
"My Place or Yours?":0x4f434e,
"My Sin":0xfdae45,
"My Sweetheart":0xf8e7df,
"Mykonos":0x387abe,
"Mykonos Blue":0x005780,
"Myoga Purple":0xe0218a,
"Myrtle":0x21421e,
"Myrtle Deep Green":0x00524c,
"Myrtle Green":0x317873,
"Myrtle Pepper":0xb77961,
"Myself":0x8e6f76,
"Mystere":0x98817c,
"Mysteria":0x826f7a,
"Mysterioso":0x46394b,
"Mysterious":0x535e63,
"Mysterious Blue":0x3e7a85,
"Mysterious Mauve":0xa6a3a9,
"Mysterious Moss":0x6f6a52,
"Mysterious Night":0x5c6070,
"Mystery":0xa4cdcc,
"Mystic":0xd8ddda,
"Mystic Blue":0x48a8d0,
"Mystic Fog":0xeae9e1,
"Mystic Green":0xd8f878,
"Mystic Harbor":0xd2e4ee,
"Mystic Iris":0x8596d2,
"Mystic Light":0xdde5ec,
"Mystic Magenta":0xe02e82,
"Mystic Maroon":0xad4379,
"Mystic Mauve":0xdbb7ba,
"Mystic Melon":0xedebb4,
"Mystic Opal":0xfbddbe,
"Mystic Pool":0xd5dde2,
"Mystic Red":0xff5500,
"Mystic River":0xb7cae0,
"Mystic Tulip":0xf9b3a3,
"Mystic Turquoise":0x00877b,
"Mystical":0x5f4e72,
"Mystical Mist":0xe5e2e3,
"Mystical Purple":0x745d83,
"Mystical Sea":0xdce3d1,
"Mystical Shade":0x4c5364,
"Mystical Trip":0x7a6a75,
"Mystification":0x2a4071,
"Mystified":0xc9dbc7,
"Mystique":0xa598a0,
"Myth":0x657175,
"Mythic Forest":0x4a686c,
"Mythical":0x7e778e,
"Mythical Blue":0x93a8a7,
"Mythical Forest":0x398467,
"Mythical Orange":0xff7f49,
"Nacre":0xe8e2d4,
"Nadeshiko Pink":0xf6adc6,
"Nadia":0xafc9c0,
"Naga Morich":0xc90406,
"Naga Viper Pepper":0xed292b,
"Naggaroth Night":0x3d3354,
"Nǎi Yóu Sè Cream":0xfdedc3,
"Nail Polish Pink":0xbd4e84,
"Nairobi Dusk":0xd9a787,
"Naive Peach":0xfce7d3,
"Nakabeni Pink":0xc93756,
"Naked Lady":0xd6b3a9,
"Naked Light":0xe9b6c1,
"Naked Pink":0xd8c6d6,
"Naked Rose":0xebb5b3,
"Namakabe Brown":0x785e49,
"Namara Grey":0x7b7c7d,
"Namaste":0xbdd8c0,
"Namibia":0x7c6d61,
"Nana":0xa08da7,
"Nancy":0x57b8dc,
"Nandi Bear":0x8f423d,
"Nandor":0x4e5d4e,
"Nankeen":0xb89e82,
"Nano White":0xf2f0ea,
"Nanohanacha Gold":0xe3b130,
"Nantucket Dune":0xd0bfaa,
"Nantucket Mist":0xcabfbf,
"Nantucket Sands":0xb4a89a,
"Napa":0xa39a87,
"Napa Grape":0x5b5162,
"Napa Harvest":0x534853,
"Napa Sunset":0xcd915c,
"Napa Wine":0x5d4149,
"Napa Winery":0x6a5c7d,
"Napery":0xefddc1,
"Napier Green":0x2a8000,
"Naples Yellow":0xfada5f,
"Napoleon":0x404149,
"Nārangī Orange":0xff8050,
"Narcissus":0xc39449,
"Narcomedusae":0xe6e3d8,
"Nârenji Orange":0xffc14b,
"Narvik":0xe9e6dc,
"Narwhal Grey":0x080813,
"Nasake":0x746062,
"Nashi Pear Beige":0xedd4b1,
"Nasturtium":0xfe6347,
"Nasturtium Flower":0xe64d1d,
"Nasturtium Leaf":0x87b369,
"Nasturtium Shoot":0x869f49,
"Nasty Green":0x70b23f,
"Nasu Purple":0x5d21d0,
"Nataneyu Gold":0xa17917,
"Natchez":0xba9f95,
"Natchez Moss":0xb1a76f,
"National Anthem":0x3f6f98,
"Native Berry":0xdc6b67,
"Native Flora":0x9aa099,
"Native Hue of Resolution":0xd33300,
"Native Soil":0x887b69,
"Nato Blue":0x153043,
"NATO Olive":0x555548,
"Natrolite":0xebbc71,
"Natural":0xaa907d,
"Natural Almond":0xded2bb,
"Natural Bark":0x6d574d,
"Natural Bridge":0xa29171,
"Natural Candy Pink":0xe4717a,
"Natural Chamois":0xbba88b,
"Natural Choice":0xe3ded0,
"Natural Copper":0x8b655a,
"Natural Green":0xbccd91,
"Natural Grey":0xc4c0bb,
"Natural Indigo":0x003740,
"Natural Instinct Green":0x017374,
"Natural Leather":0xa80e00,
"Natural Light":0xf1ebc8,
"Natural Linen":0xecdfcf,
"Natural Pumice":0x4a4a43,
"Natural Radiance":0xe7dcc1,
"Natural Rice Beige":0xdcc39f,
"Natural Silk Grey":0xd3c5c0,
"Natural Spring":0xaa838b,
"Natural Steel":0x8a8287,
"Natural Stone":0xaea295,
"Natural Tan":0xdcd2c3,
"Natural Twine":0xdbc39b,
"Natural Whisper":0xf0e8cf,
"Natural White":0xfbede2,
"Natural Wool":0xfff6d7,
"Natural Yellow":0xeed88b,
"Natural Youth":0xd7e5b4,
"Naturale":0xf1e0cf,
"Naturalism":0x68685d,
"Naturalist Grey":0x8b8c83,
"Naturally Calm":0xced0d9,
"Nature":0xbfd5b3,
"Nature Apricot":0xfeb7a5,
"Nature Green":0x7daf94,
"Nature Retreat":0x7b8787,
"Nature Spirits":0xc8c8b4,
"Nature Surrounds":0x52634b,
"Nature Trail":0xe6d7bb,
"Nature's Delight":0xa6d292,
"Nature's Gate":0x666a60,
"Nature's Gift":0x99a399,
"Nature's Reflection":0xc5d4cd,
"Nature's Strength":0x117733,
"Naturel":0xcbc0ad,
"Naughty Hottie":0xba403a,
"Naughty Marietta":0xe3ccdc,
"Nauseous Blue":0x483d8b,
"Nautical":0x2e4a7d,
"Nautical Blue":0x1a5091,
"Nautical Star":0xaab5b7,
"Nautilus":0x273c5a,
"Navagio Bay":0x3183a0,
"Navajo":0xefdcc3,
"Navajo Turquoise":0x007c78,
"Navajo White":0xffdead,
"Naval":0x41729f,
"Naval Passage":0x386782,
"Navel":0xec8430,
"Navigate":0x008583,
"Navigator":0x5d83ab,
"Navy":0x01153e,
"Navy Black":0x263032,
"Navy Blazer":0x282d3c,
"Navy Blue":0x000080,
"Navy Cosmos":0x503b53,
"Navy Damask":0x425166,
"Navy Dark Blue":0x004c6a,
"Navy Green":0x35530a,
"Navy Peony":0x223a5e,
"Navy Purple":0x9556eb,
"Navy Teal":0x20576e,
"Navy Trim":0x203462,
"Neapolitan":0x9b7a78,
"Neapolitan Blue":0x4d7faa,
"Near Moon":0x5ee7df,
"Nearly Brown":0xa88e76,
"Nearly Peach":0xefded1,
"Nearsighted":0xc8d5dd,
"Nebula":0xa104c3,
"Nebula Outpost":0x922b9c,
"Nebulas Blue":0x2d62a3,
"Nebulous":0xc4b9b8,
"Nebulous White":0xdedfdc,
"Necklace Pearl":0xf6eeed,
"Necron Compound":0x828b8e,
"Necrotic Flesh":0x9faf6c,
"Nectar of the Gods":0x513439,
"Nectar Red":0x7f4c64,
"Nectarina":0xd38d72,
"Nectarine":0xff8656,
"Nectarous Nectarine":0xdd5566,
"Needlepoint Navy":0x546670,
"Nefarious Blue":0xc5ced8,
"Nefarious Mauve":0xe6d1dc,
"Negishi Green":0x938b4b,
"Negroni":0xeec7a2,
"Neighborly Peach":0xf3c1a3,
"Nelson's Milk Snake":0x933d41,
"Neo Mint":0xaaffcc,
"Neo Tokyo Grey":0xbec0c2,
"Neon Blue":0x04d9ff,
"Neon Boneyard":0xdfc5fe,
"Neon Carrot":0xff9933,
"Neon Fuchsia":0xfe4164,
"Neon Green":0x39ff14,
"Neon Light":0xffdf5e,
"Neon Pink":0xfe019a,
"Neon Purple":0xbc13fe,
"Neon Red":0xff073a,
"Neon Violet":0x674876,
"Neon Yellow":0xcfff04,
"Nepal":0x93aab9,
"Nephrite":0x6d9288,
"Neptune":0x007dac,
"Neptune Blue":0x2e5d9d,
"Neptune Green":0x7fbb9e,
"Neptune's Wrath":0x11425d,
"Nereus":0x4c793c,
"Nero":0x252525,
"Nero's Green":0x318181,
"Nervous Neon Pink":0xff6ec7,
"Nervy Hue":0xd7c65b,
"Nessie":0x716748,
"Nesting Dove":0xeeeada,
"Net Worker":0xb6a194,
"Netherworld":0x881111,
"Netsuke":0xe0cfb0,
"Nettle":0xbbac7d,
"Nettle Green":0x364c2e,
"Nettle Rash":0xe4f7e7,
"Network Gray":0xa0a5a7,
"Neutral Buff":0x9d928f,
"Neutral Green":0xaaa583,
"Neutral Grey":0x8e918f,
"Neutral Ground":0xe2daca,
"Neutral Peach":0xffe6c3,
"Neutral Valley":0x8b694d,
"Neutrino Blue":0x01248f,
"Nevada":0x666f6f,
"Nevada Morning":0xffd5a7,
"Nevada Sand":0xead5b9,
"Nevada Sky":0xa1d9e7,
"Never Cry Wolf":0x6e6455,
"Never Forget":0xa67283,
"Nevergreen":0x666556,
"Neverland":0x9ce5d6,
"Nevermind Nirvana":0x7bc8f6,
"New Age Blue":0x496ead,
"New Amber":0x6d3b24,
"New Bamboo":0xadac84,
"New Brick":0x934c3d,
"New Brick Red":0xcb4154,
"New Bulgarian Rose":0x482427,
"New Car":0x214fc6,
"New Chestnut":0xa28367,
"New Clay":0xefc1b5,
"New Colonial Yellow":0xd9ad7f,
"New Cork":0xb89b6b,
"New Cream":0xede0c0,
"New England Brick":0xad7065,
"New England Roast":0xaa7755,
"New Fawn":0xc9a171,
"New Foliage":0xc2bc90,
"New Forest":0x47514d,
"New Frond":0xbacca0,
"New Gold":0xead151,
"New Green":0xb5ac31,
"New Harvest Moon":0xeddfc7,
"New Hope":0xe2efc2,
"New House White":0xf1ede7,
"New Hunter":0x4a5f58,
"New Kenyan Copper":0x7c1c05,
"New Khaki":0xd9c7aa,
"New Life":0x7c916e,
"New Limerick":0x9dc209,
"New Love":0xc6bbdb,
"New Moss":0xc6d6c7,
"New Navy Blue":0x3b4a55,
"New Neutral":0xbec0aa,
"New Orleans":0xe4c385,
"New Penny":0xa27d66,
"New Roof":0x875251,
"New Shoot":0x869e3e,
"New Sled":0x933c3c,
"New Steel":0x738595,
"New Violet":0xd6c1dd,
"New Wave Green":0x11ff11,
"New Wave Pink":0xff22ff,
"New Wheat":0xd7b57f,
"New Wool":0xd6c3b9,
"New Yellow":0xe8c247,
"New York Pink":0xdd8374,
"New Youth":0xf0e1df,
"Newbury Moss":0x616550,
"Newburyport":0x445a79,
"Newman's Eye":0xb2c7e1,
"Newmarket Sausage":0xeae2dc,
"Newport Blue":0x1c8ac9,
"Newport Indigo":0x313d6c,
"Newsprint":0x756f6d,
"Niagara":0x29a98b,
"Niagara Falls":0xcbe3ee,
"Niagara Mist":0xc5e8ee,
"Niblet Green":0x7dc734,
"Nice Blue":0x107ab0,
"Nice Cream":0xfaecd1,
"Nice White":0xe6ddd5,
"Niche":0x65758f,
"Nick's Nook":0x909062,
"Nickel":0x929292,
"Nickel Ore Green":0x537e7e,
"Nicotine Gold":0xeebb33,
"Niebla Azul":0xb6c3c4,
"Nifty Turquoise":0x019187,
"Night Black":0x312f36,
"Night Bloom":0x613e3d,
"Night Blooming Jasmine":0xf9f7ec,
"Night Blue":0x040348,
"Night Brown":0x44281b,
"Night Brown Black":0x322d25,
"Night Club":0x494b4e,
"Night Dive":0x003355,
"Night Flight":0x434d5c,
"Night Fog":0x2d1962,
"Night Green":0x302f27,
"Night Grey":0x45444d,
"Night Gull Grey":0x615d5c,
"Night in the Woods":0x443300,
"Night Kite":0x005572,
"Night Market":0x4c6177,
"Night Mauve":0x5d3b41,
"Night Mission":0x5e5c50,
"Night Mode":0x234e86,
"Night Music":0x9c96af,
"Night Night":0x4f4f5e,
"Night Out":0x656a6e,
"Night Owl":0x5d7b89,
"Night Pearl":0x11ffbb,
"Night Red":0x3c2727,
"Night Rendezvous":0x66787e,
"Night Rider":0x332e2e,
"Night Romance":0x715055,
"Night Rose":0xb0807a,
"Night Shadz":0xa23d54,
"Night Shift":0x2a5c6a,
"Night Sky":0x2a2a35,
"Night Snow":0xaaccff,
"Night Tan":0xab967b,
"Night Thistle":0x6b7ba7,
"Night Tide":0x455360,
"Night Turquoise":0x003833,
"Night Watch":0x3c4f4e,
"Night White":0xe1e1dd,
"Night Wind":0xd7e2db,
"Night Wizard":0x313740,
"Nightfall":0x43535e,
"Nightfall in Suburbia":0x0011dd,
"Nighthawk":0x615452,
"Nightingale":0x5c4827,
"Nightingale Grey":0xbaaea3,
"Nightlife":0x27426b,
"Nightly Aurora":0x9beec1,
"Nightly Blade":0x5a7d9a,
"Nightly Escapade":0x0433ff,
"Nightly Expedition":0x221188,
"Nightly Ivy":0x444940,
"Nightly Silhouette":0x4f5b93,
"Nightly Violet":0x784384,
"Nightly Woods":0x013220,
"Nightmare":0x112211,
"Nightshade":0x3c464b,
"Nightshade Berries":0x1b1811,
"Nightshade Blue":0x293135,
"Nightshade Purple":0x535872,
"Nightshade Violet":0xa383ac,
"Nightshadow Blue":0x4e5368,
"Nihilakh Oxide":0xa0d6b4,
"Nīlā Blue":0x0055ff,
"Nile":0xb4bb85,
"Nile Blue":0x253f4e,
"Nile Clay":0x8b8174,
"Nile Green":0xa7c796,
"Nile Reed":0x968f5f,
"Nile River":0x9ab6a9,
"Nile Sand":0xbbad94,
"Nile Stone":0x61c9c1,
"Nilla Vanilla":0xf1ebe0,
"Nimbus Blue":0x4422ff,
"Nimbus Cloud":0xd5d5d8,
"Nina":0xf5e3ea,
"Nine Iron":0x46434a,
"Níng Méng Huáng Lemon":0xffef19,
"Ninja":0x020308,
"Ninja Turtle":0x94b1a9,
"Ninjin Orange":0xe5aa70,
"Nipple":0xbb7777,
"Nippon":0xbc002c,
"Nirvana":0xa2919b,
"Nirvana Jewel":0x64a5ad,
"Nisemurasaki Purple":0x43242a,
"Níu Zǎi Sè Denim":0x056eee,
"No More Drama":0xa33f40,
"No Need to Blush":0xffd6dd,
"No Way Rosé":0xfbaa95,
"No$GMB Yellow":0xf8e888,
"Nobel":0xa99d9d,
"Nobility Blue":0x414969,
"Noble Blue":0x697991,
"Noble Blush":0xe8b9b2,
"Noble Cause Purple":0x7e1e9c,
"Noble Crown":0x8d755d,
"Noble Fir":0x5a736d,
"Noble Grey":0xc1beb9,
"Noble Honor":0x69354f,
"Noble Knight":0x394d78,
"Noble Lilac":0xb28392,
"Noble Plum":0x871f78,
"Noble Purple":0xafb1c5,
"Noble Robe":0x807070,
"Noble Silver":0x73777f,
"Noble Tone":0x884967,
"Noblesse":0x524b50,
"Noctis":0x646b77,
"Nocturnal Flight":0x675754,
"Nocturnal Rose":0xcc6699,
"Nocturnal Sea":0x0e6071,
"Nocturne":0x7a4b56,
"Nocturne Blue":0x344d58,
"Nocturne Shade":0x356fad,
"Noghrei Silver":0xbdbebd,
"Nomad":0xa19986,
"Nomad Grey":0x7e736f,
"Nomadic":0xaf9479,
"Nomadic Desert":0xc7b198,
"Nomadic Dream":0xdbdedb,
"Nomadic Taupe":0xd2c6ae,
"Nomadic Travels":0xe0c997,
"Nominee":0x357567,
"Non Skid Grey":0x8a8daa,
"Non-Photo Blue":0xa4dded,
"Non-Stop Orange":0xdd8811,
"Nonchalant White":0xdeddd1,
"Nonpareil Apple":0xc1a65c,
"Noodle Arms":0xf5ddc4,
"Noodles":0xf9e3b4,
"Nor'wester":0x99a9ad,
"Nora's Forest":0x003333,
"Nordic":0x1d393c,
"Nordic Breeze":0xd3dde7,
"Nordic Grass Green":0x1fab58,
"Nordic Noir":0x003344,
"Nordland Blue":0x7e95ab,
"Nordland Light Blue":0x96aec5,
"Norfolk Green":0x2e4b3c,
"Norfolk Sky":0x6cbae7,
"Nori Green":0x112a12,
"Nori Seaweed Green":0x464826,
"Norman Shaw Goldspar":0xe9c68e,
"Norse Blue":0x4ca5c7,
"North Atlantic":0x536d70,
"North Beach Blue":0x849c9d,
"North Cape Grey":0x7a9595,
"North Grey":0x6a7777,
"North Island":0xbcb6b4,
"North Rim":0xd8a892,
"North Sea":0x316c6b,
"North Sea Blue":0x343c4c,
"North Star":0xf2dea4,
"North Star Blue":0x223399,
"North Texas Green":0x059033,
"North Wind":0x48bdc1,
"North Woods":0x555a51,
"Northampton Trees":0x767962,
"Northeast Trail":0x948666,
"Northern Barrens Dust":0xde743c,
"Northern Beach":0xe9dad2,
"Northern Exposure":0xbfc7d4,
"Northern Glen":0x536255,
"Northern Landscape":0xc5c1a3,
"Northern Light Grey":0xa7aeb4,
"Northern Lights":0xe6f0ea,
"Northern Pond":0xa3b9cd,
"Northern Sky":0x8daccc,
"Northern Star":0xffffea,
"Northern Territory":0x5e463c,
"Northgate Green":0xaaa388,
"Northpointe":0x9e9181,
"Northrend":0xb9f2ff,
"Norway":0xa4b88f,
"Norwegian Blue":0x78888e,
"Norwich Green":0xacb597,
"Nosegay":0xffe6ec,
"Nosferatu":0xa9a8a8,
"Noshime Flower":0x426579,
"Nostalgia":0xd6b8bd,
"Nostalgia Rose":0xa4777e,
"Nostalgic":0x666c7e,
"Nostalgic Evening":0x47626f,
"Not a Cloud in Sight":0x85c8d3,
"Not My Fault":0x7e7d78,
"Not So Innocent":0x6a6968,
"Not Yo Cheese":0xffc12c,
"Notable Hue":0x8ba7bb,
"Notebook Paper":0xe8ebe6,
"Notes of Plum":0x770f05,
"Noteworthy":0xd9bacc,
"Nothing Less":0xf2deb9,
"Notice Me":0xba8686,
"Notorious":0xbda998,
"Notorious Neanderthal":0x664400,
"Nottingham Forest":0x585d4e,
"Nougat":0xb69885,
"Nougat Brown":0x7c503f,
"Nouveau Copper":0xa05b42,
"Nouveau Rose":0x996872,
"Nouveau-Riche":0xffbb77,
"Nouvelle White":0xe1dcda,
"Novel Lilac":0xc2a4c2,
"Novelle Peach":0xe7cfbd,
"Novelty Navy":0x515b62,
"November":0xbe7767,
"November Gold":0xf6b265,
"November Green":0x767764,
"November Leaf":0xf1b690,
"November Pink":0xede6e8,
"November Skies":0x7cafb9,
"November Storms":0x423f3b,
"Noxious":0x89a203,
"Nuance":0xe2e0d6,
"Nuclear Blast":0xbbff00,
"Nuclear Fallout":0xaa9900,
"Nuclear Mango":0xee9933,
"Nuclear Meltdown":0x44ee00,
"Nuclear Throne":0x00de00,
"Nuclear Waste":0x7cfc00,
"Nude":0xf2d3bc,
"Nude Flamingo":0xe58f7c,
"Nude Lips":0xb5948d,
"Nugget":0xbc9229,
"Nugget Gold":0xc89720,
"Nuisette":0xb48395,
"Nuit Blanche":0x1e488f,
"Nuln Oil":0x14100e,
"Nuln Oil Gloss":0x171310,
"Numbers":0x929bac,
"Numero Uno":0xe2e6de,
"Nurgle's Rot":0x9b8f22,
"Nurgling Green":0xb8cc82,
"Nursery":0xefd0d2,
"Nursery Green":0xedf0de,
"Nursery Pink":0xf4d8e8,
"Nurture":0xd7dcd5,
"Nurture Green":0x98b092,
"Nurturing":0xa1a97b,
"Nurude Brown":0x9d896c,
"Nut":0x9e8a6d,
"Nut Brown":0x86695e,
"Nut Cracker":0x816c5b,
"Nut Flavor":0xd7bea4,
"Nut Milk":0xd9ccc8,
"Nut Oil":0x775d38,
"Nuthatch":0x8e725f,
"Nuthatch Back":0x445599,
"Nutmeg":0x7e4a3b,
"Nutmeg Frost":0xecd9ca,
"Nutmeg Glow":0xd8b691,
"Nutmeg Wood Finish":0x683600,
"Nutria":0x75663e,
"Nutria Fur Brown":0x514035,
"Nutshell":0xa9856b,
"Nutter Butter":0xf7d4c6,
"Nutty Beige":0xd4bca3,
"Nutty Brown":0x8a6f44,
"Nyanza":0xe9ffdb,
"NYC Taxi":0xf7b731,
"Nyctophobia Blue":0x4d587a,
"Nylon":0xe9e3cb,
"Nymph Green":0xaec2a5,
"Nymph's Delight":0x7b6c8e,
"Nymphaeaceae":0xcee0e3,
"Nypd":0x5f6e77,
"O Fortuna":0xe1b8b5,
"O Tannenbaum":0x005522,
"O'Brien Orange":0xf3a347,
"O'grady Green":0x58ac8f,
"O'Neal Green":0x395643,
"Oak Barrel":0x715636,
"Oak Brown":0xa18d80,
"Oak Buff":0xcf9c63,
"Oak Creek":0x5d504a,
"Oak Harbour":0xcdb386,
"Oak Plank":0x5d4f39,
"Oak Ridge":0xc0b0ab,
"Oak Shaving":0xeed8c2,
"Oak Tone":0xd0c7b6,
"Oakley Apricot":0xe0b695,
"Oakmoss":0x6d7244,
"Oakwood":0xbda58b,
"Oakwood Brown":0x8f716e,
"Oarsman Blue":0x648d95,
"Oasis":0x0092a3,
"Oasis Sand":0xfcedc5,
"Oasis Spring":0x47a3c6,
"Oasis Stream":0xa2ebd8,
"Oat Cake":0xe1cab3,
"Oat Field":0xc0ad89,
"Oat Flour":0xf7e4cd,
"Oat Milk":0xdedacd,
"Oat Straw":0xf1d694,
"Oath":0x4a465a,
"Oatmeal":0xcbc3b4,
"Oatmeal Bath":0xddc7a2,
"Oatmeal Biscuit":0xb7a86d,
"Oatmeal Cookie":0xeadac6,
"Obi Lilac":0xb0a3b6,
"Object of Desire":0xb7a8a8,
"Objectivity":0xbbc6de,
"Obligation":0x54645c,
"Oblivion":0x000435,
"Obscure Ochre":0x88654e,
"Obscure Ogre":0x771908,
"Obscure Olive":0x4a5d23,
"Obscure Orange":0xbb5500,
"Obscure Orchid":0x9d0759,
"Observatory":0x008f70,
"Obsession":0xae9550,
"Obsidian":0x445055,
"Obsidian Brown":0x523e35,
"Obsidian Lava Black":0x382b46,
"Obsidian Red":0x372a38,
"Obsidian Shard":0x060313,
"Obsidian Shell":0x441166,
"Obsidian Stone":0x3c3f40,
"Obstinate Orange":0xd7552a,
"Obtrusive Orange":0xffb077,
"Ocean":0x005493,
"Ocean Abyss":0x221166,
"Ocean Air":0xdae4ed,
"Ocean Blue":0x009dc4,
"Ocean Boat Blue":0x0077be,
"Ocean Boulevard":0xa4c8c8,
"Ocean Breeze":0xd3e5eb,
"Ocean Bubble":0x8cadcd,
"Ocean Call":0x2b6c8e,
"Ocean City":0x7896ba,
"Ocean Crest":0xd6dddd,
"Ocean Cruise":0x9cd4e1,
"Ocean Current":0x537783,
"Ocean Depths":0x006175,
"Ocean Dream":0xd4dde2,
"Ocean Drive":0xb0bec5,
"Ocean Droplet":0xafc3bc,
"Ocean Foam":0xcac8b4,
"Ocean Frigate":0x7a7878,
"Ocean Front":0xb8e3ed,
"Ocean Green":0x3d9973,
"Ocean Kiss":0xa4c3c5,
"Ocean Liner":0x189086,
"Ocean Melody":0x7d999f,
"Ocean Mirage":0x00748f,
"Ocean Night":0x637195,
"Ocean Oasis":0x006c68,
"Ocean Pearl":0xd3cfbd,
"Ocean Ridge":0x7594b3,
"Ocean Sand":0xe4d5cd,
"Ocean Shadow":0x5b7886,
"Ocean Spray":0x005379,
"Ocean Storm":0x3f677e,
"Ocean Surf":0x79a2bd,
"Ocean Swell":0x727c7e,
"Ocean Trapeze":0x2e526a,
"Ocean Trip":0x62aeba,
"Ocean Tropic":0x67a6d4,
"Ocean View":0x729bb3,
"Ocean Wave":0x8ec5b6,
"Ocean Weed":0x6c6541,
"Oceanic":0x4f6d82,
"Oceanic Climate":0xbbc8c9,
"Oceano":0x9ad6e5,
"Oceanside":0x015a6b,
"Oceanus":0x90aba8,
"Ocelot":0xf1e2c9,
"Ocher":0xbf9b0c,
"Ochre":0xcc7722,
"Ochre Brown":0x9f7b3e,
"Ochre Maroon":0xcc7733,
"Ochre Revival":0xeec987,
"Ochre Spice":0xe96d03,
"Ochre Yellow":0xefcc83,
"Octagon Ocean":0x085b73,
"Octarine":0xccdd00,
"Octavius":0x37393e,
"October":0xc67533,
"October Bounty":0xe3c6a3,
"October Harvest":0xd1bb98,
"October Haze":0xf8ac8c,
"October Leaves":0x855743,
"October Sky":0x8fa2a2,
"Odd Pea Pod":0x357911,
"Ode to Green":0xb6e5d6,
"Ode to Joy":0x9d404a,
"Ode to Purple":0xa798c2,
"Odious Orange":0xffdfbf,
"Odyssey":0x374a5a,
"Odyssey Grey":0x434452,
"Odyssey Lilac":0xd5c6cc,
"Odyssey Plum":0xe1c2c5,
"Off Blue":0x5684ae,
"Off Broadway":0x433f3d,
"Off Green":0x6ba353,
"Off Shore":0xd1cccb,
"Off the Grid":0x9f9049,
"Off The Grid":0xb8aea4,
"Off White":0xffffe4,
"Off Yellow":0xf1f33f,
"Off-Road Green":0x003723,
"Offbeat":0xd6d0c6,
"Offbeat Green":0x9c8b1f,
"Office Blue Green":0x006c65,
"Office Green":0x00800f,
"Office Grey":0x635d54,
"Office Neon Light":0xff2277,
"Official Violet":0x2e4182,
"Offshore Mist":0xcad8d8,
"Often Orange":0xff714e,
"Ogen Melon":0xd7b235,
"Ogre Odor":0xfd5240,
"Ogryn Camo":0x9da94b,
"Ogryn Flesh Wash":0xd1a14e,
"Oh Boy!":0xbbdaf8,
"Oh Dahling":0xedeec5,
"Oh My Gold":0xeebb55,
"Oh Pistachio":0xabca99,
"Oh So Pretty":0xeac7cb,
"Oil":0x313330,
"Oil Blue":0x658c88,
"Oil Green":0x80856d,
"Oil Of Lavender":0xc7bebe,
"Oil on Fire":0xff5511,
"Oil Rush":0x333144,
"Oil Slick":0x031602,
"Oil Yellow":0xc4a647,
"Oilcloth Green":0x83ba8e,
"Oiled Teak":0x6c5a51,
"Oiled Up Kardashian":0x996644,
"Oilseed Crops":0xc2be0e,
"Oily Steel":0x99aaaa,
"Oitake Green":0x5e644f,
"OK Corral":0xd07360,
"Oklahoma Wheat":0xf5e0ba,
"Okra":0xfdefe9,
"Okroshka":0x40533d,
"Old Amethyst":0x87868f,
"Old Army Helmet":0x616652,
"Old Asparagus":0x929000,
"Old Bamboo":0x769164,
"Old Benchmark":0x029386,
"Old Bone":0xdbc2ab,
"Old Boot":0x7c644b,
"Old Botanical Garden":0x5e624a,
"Old Brick":0x8a3335,
"Old Brown Crayon":0x330000,
"Old Burgundy":0x43302e,
"Old Celadon":0xa8a89d,
"Old Chalk":0xe3d6e9,
"Old Cheddar":0xdd6644,
"Old Coffee":0x704241,
"Old Copper":0x73503b,
"Old Cumin":0x784430,
"Old Doeskin":0xbdab9b,
"Old Driftwood":0x97694f,
"Old Eggplant":0x614051,
"Old Eggshell":0xcdc4ba,
"Old Faithful":0x82a2be,
"Old Fashioned Pink":0xf4c6cc,
"Old Fashioned Purple":0x73486b,
"Old Flame":0xf2b7b5,
"Old Four Leaf Clover":0x757d43,
"Old Geranium":0xc66787,
"Old Glory Blue":0x002868,
"Old Glory Red":0xbf0a30,
"Old Gold":0xcfb53b,
"Old Green":0x839573,
"Old Grey Mare":0xb4b6ad,
"Old Gungeon Red":0x0063ec,
"Old Heart":0xe66a77,
"Old Heliotrope":0x563c5c,
"Old Ivory":0xffffcb,
"Old Kitchen White":0xeff5dc,
"Old Lace":0xfdf5e6,
"Old Laser Lemon":0xfdfc74,
"Old Lavender":0x796878,
"Old Leather":0xa88b66,
"Old Lime":0xaec571,
"Old Mahogany":0x4a0100,
"Old Mandarin":0x8e2323,
"Old Map":0xd5c9bc,
"Old Mauve":0x673147,
"Old Mill":0x343b4e,
"Old Mill Blue":0x6e6f82,
"Old Mission Pink":0xd8c2ca,
"Old Money":0x2c5c4f,
"Old Moss Green":0x867e36,
"Old Nan Yarn":0x5e5896,
"Old Pearls":0xf6ebd7,
"Old Pink":0xc77986,
"Old Porch":0x745947,
"Old Prune":0x8272a4,
"Old Red Crest":0xd8cbcf,
"Old Rose":0xc08081,
"Old Ruin":0x917b53,
"Old School":0x353c3d,
"Old Silver":0x848482,
"Old Trail":0xbb8811,
"Old Treasure Chest":0x544333,
"Old Truck":0x0a888a,
"Old Vine":0x687760,
"Old Whiskey":0xddaa55,
"Old Willow Leaf":0x756947,
"Old Wine":0x90091f,
"Old World":0xb2b7d1,
"Old Yella":0xfeed9a,
"Old Yellow Bricks":0xece6d7,
"Olde World Gold":0x8f6c3e,
"Olden Amber":0xeeb76b,
"Ole Pink":0xebd5cc,
"Ole Yeller":0xc79e5f,
"Oleander":0xf2ccc5,
"Oleander Pink":0xf85898,
"Oliva Oscuro":0x665439,
"Olive":0x808010,
"Olive Bark":0x5f5537,
"Olive Branch":0x646a45,
"Olive Bread":0xc3bebb,
"Olive Brown":0x645403,
"Olive Chutney":0xa6997a,
"Olive Conquering White":0xe4e5d8,
"Olive Court":0x5f5d48,
"Olive Creed":0xe8ecc0,
"Olive Drab":0x6f7632,
"Olive Gold":0xbfac8b,
"Olive Green":0x677a04,
"Olive Grey":0xafa78d,
"Olive Grove":0x716a4d,
"Olive Haze":0x888064,
"Olive Hint":0xc9bd88,
"Olive It":0xaeab9a,
"Olive Leaf":0x4e4b35,
"Olive Leaf Tea":0x78866b,
"Olive Martini":0xced2ab,
"Olive Night":0x535040,
"Olive Ochre":0x837752,
"Olive Oil":0xbab86c,
"Olive Paste":0x83826d,
"Olive Pit":0xa9a491,
"Olive Reserve":0xa4a84d,
"Olive Sand":0x9abf8d,
"Olive Sapling":0x7f7452,
"Olive Shade":0x7d7248,
"Olive Shadow":0x706041,
"Olive Soap":0x97a49a,
"Olive Sprig":0xacaf95,
"Olive Tint":0xefebd7,
"Olive Tree":0xaba77c,
"Olive Wood":0x756244,
"Olive Yellow":0xc2b709,
"Olivenite":0x333311,
"Olivetone":0x747028,
"Olivia":0x996622,
"Olivine":0x9ab973,
"Olivine Basalt":0x655867,
"Olivine Grey":0x928e7c,
"Olm Pink":0xffe6e2,
"Olympia Ivy":0x5a6647,
"Olympian Blue":0x1a4c8b,
"Olympic Bronze":0x9a724a,
"Olympic Range":0x424c44,
"Olympus White":0xd4d8d7,
"Ombre Blue":0x434854,
"Ombre Grey":0x848998,
"Omphalodes":0xb5cedf,
"On Cloud Nine":0xc2e7e8,
"On Location":0xd4c6dc,
"On the Avenue":0x948776,
"On the Nile":0xb29aa7,
"On the Rocks":0xd0cec8,
"Onahau":0xc2e6ec,
"Once in a Blue Moon":0x0044bb,
"One Minute to Midnight":0x003388,
"One to Remember":0xdcbdad,
"One Year of Rain":0x29465b,
"Onion":0x48412b,
"Onion Powder":0xece2d4,
"Onion Seedling":0x47885e,
"Onion Skin":0xeeeddf,
"Onion Skin Blue":0x4c5692,
"Onion White":0xe2d5c2,
"Online":0xb0b5b5,
"Online Lime":0x44883c,
"Only Natural":0xe1bc99,
"Only Oatmeal":0xd4cdb5,
"Only Olive":0xcbccb5,
"Only Yesterday":0xf4d1b9,
"Onsen":0x66eebb,
"Ontario Violet":0x777cb0,
"Onyx":0x464544,
"Onyx Heart":0x353839,
"Ooid Sand":0xc2beb6,
"Opal":0xaee0e4,
"Opal Blue":0xc3ddd6,
"Opal Cream":0xfceece,
"Opal Fire":0xe49c86,
"Opal Flame":0xe95c4b,
"Opal Green":0x157954,
"Opal Grey":0xa49e9e,
"Opal Silk":0x9db9b2,
"Opal Turquoise":0x96d1c3,
"Opal Violet":0x7e8fbb,
"Opal Waters":0xb1c6d1,
"Opalescent":0x3c94c1,
"Opalescent Coral":0xffd2a9,
"Opaline":0xc1d1c4,
"Opaline Green":0xa3c57d,
"Opaline Pink":0xc6a0ab,
"Open Air":0xc7dfe0,
"Open Canyon":0xbba990,
"Open Range":0x91876b,
"Open Seas":0x83afbc,
"Open Sesame":0xf8e2a9,
"Opera":0x816575,
"Opera Blue":0x453e6e,
"Opera Glass":0xe5f1eb,
"Opera Glasses":0x365360,
"Opera Mauve":0xb784a7,
"Opera Red":0xff1b2d,
"Operetta Mauve":0x3a284c,
"Opium":0x987e7e,
"Opium Mauve":0x735362,
"Optimist Gold":0xe9ab51,
"Optimistic Yellow":0xf5e1a6,
"Optimum Blue":0x465a7f,
"Opulent":0xd5892f,
"Opulent Blue":0x0055ee,
"Opulent Green":0x103222,
"Opulent Lime":0x88dd11,
"Opulent Mauve":0x462343,
"Opulent Opal":0xf2ebea,
"Opulent Ostrich":0x775577,
"Opulent Purple":0x673362,
"Opulent Turquoise":0x88ddcc,
"Opulent Violet":0xa09ec6,
"Opus":0xcecae1,
"Opus Magnum":0xe3e1ed,
"Oracle":0x395555,
"Orange":0xffa500,
"Orange Aura":0xff9682,
"Orange Avant-Garde":0xff8822,
"Orange Ballad":0xb56d41,
"Orange Bell Pepper":0xff8844,
"Orange Blast":0xf5c99b,
"Orange Brown":0xb16002,
"Orange Burst":0xff6e3a,
"Orange Chalk":0xfad48b,
"Orange Chiffon":0xf9aa7d,
"Orange Chocolate":0xf3c775,
"Orange Clay":0xe6a57f,
"Orange Coloured White":0xfbebcf,
"Orange Com":0xda321c,
"Orange Confection":0xf4e3d2,
"Orange Crush":0xee7733,
"Orange Danger":0xdd6600,
"Orange Daylily":0xeb7d5d,
"Orange Delight":0xffc355,
"Orange Drop":0xe18e3f,
"Orange Essential":0xd1907c,
"Orange Fire":0xffaf6b,
"Orange Flambe":0xa96f55,
"Orange Glass":0xffca7d,
"Orange Glow":0xffe2bd,
"Orange Gluttony":0xee7722,
"Orange Grove":0xfbaf8d,
"Orange Hibiscus":0xff9a45,
"Orange Ice":0xffdec1,
"Orange Jelly":0xfac205,
"Orange Jewel":0xff9731,
"Orange Juice":0xff7f00,
"Orange Keeper":0xca5333,
"Orange Lily":0xbe7249,
"Orange Liqueur":0xedaa80,
"Orange Maple":0xd3a083,
"Orange Marmalade":0xfaac72,
"Orange Ochre":0xdc793a,
"Orange Outburst":0xdd7700,
"Orange Peel":0xffa000,
"Orange Pepper":0xdf7500,
"Orange Piñata":0xff6611,
"Orange Pink":0xff6f52,
"Orange Poppy":0xe68750,
"Orange Popsicle":0xff7913,
"Orange Red":0xfe4401,
"Orange Roughy":0xa85335,
"Orange Rust":0xc25a3c,
"Orange Salmonberry":0xf0b073,
"Orange Satisfaction":0xdd9900,
"Orange Sherbet":0xfec49b,
"Orange Shimmer":0xe2d6bd,
"Orange Shot":0xdd7744,
"Orange Soda":0xfa5b3d,
"Orange Spice":0xfea060,
"Orange Squash":0xc27635,
"Orange Tea Rose":0xff8379,
"Orange Tiger":0xf96714,
"Orange Vermillion":0xbc5339,
"Orange White":0xeae3cd,
"Orange Wood":0xb74923,
"Orange Yellow":0xfdb915,
"Orange you Happy?":0xfd7f22,
"Orange Zest":0xf07227,
"Orangeade":0xe2552c,
"Orangealicious":0xee5511,
"Orangeville":0xe57059,
"Orangina":0xfec615,
"Orangish":0xfd8d49,
"Orangish Brown":0xb25f03,
"Orangish Red":0xf43605,
"Oranzhewyi Orange":0xee6237,
"Orb of Discord":0x772299,
"Orb of Harmony":0xeedd44,
"Orbital":0x6d83bb,
"Orbital Kingdom":0x220088,
"Orca White":0xd0ccc9,
"Orchard Plum":0x9a858c,
"Orchid":0x7a81ff,
"Orchid Bloom":0xc5aecf,
"Orchid Blossom":0xe4e1e4,
"Orchid Bouquet":0xd1acce,
"Orchid Dottyback":0xaa55aa,
"Orchid Ecstasy":0xbb4488,
"Orchid Fragrance":0xc9c1d0,
"Orchid Grey":0x5e5871,
"Orchid Haze":0xb0879b,
"Orchid Hue":0xe5e999,
"Orchid Hush":0xcec3d2,
"Orchid Ice":0xe0d0db,
"Orchid Kiss":0xac74a4,
"Orchid Lane":0xe5dde7,
"Orchid Lei":0x9c4a7d,
"Orchid Mist":0xe8e6e8,
"Orchid Orange":0xffa180,
"Orchid Orchestra":0x876281,
"Orchid Petal":0xbfb4cb,
"Orchid Pink":0xf3bbca,
"Orchid Red":0xad878d,
"Orchid Rose":0xe9d1da,
"Orchid Shadow":0xcbc5c2,
"Orchid Smoke":0xd294aa,
"Orchid Tint":0xdbd2db,
"Orchid Whisper":0xdde0e8,
"Orchid White":0xf1ebd9,
"Orchilla":0x938ea9,
"Ordain":0x998188,
"Order Green":0x1a4c32,
"Ore Bluish Black":0x1c3339,
"Ore Mountains Green":0x2b6551,
"Orecchiette":0xfaeecb,
"Oregano":0x7f8353,
"Oregano Green":0x4da241,
"Oregano Spice":0x8d8764,
"Oregon":0x9b4703,
"Oregon Grape":0x49354e,
"Oregon Hazel":0x916238,
"Oregon Trail":0xefb91b,
"Orenju Ogon Koi":0xffcda8,
"Orestes":0x9e9b85,
"Organic":0x747261,
"Organic Bamboo":0xe1cda4,
"Organic Fiber":0xfeede0,
"Organic Field":0xc6c2ab,
"Organic Green":0x7fac6e,
"Organic Matter":0xa99e54,
"Organza":0xffdea6,
"Organza Green":0xbbccbd,
"Organza Peach":0xfbeeda,
"Organza Violet":0x7391cc,
"Orient":0x255b77,
"Orient Blue":0x47457a,
"Orient Green":0x77997d,
"Orient Mosaic Green":0x7cb8a1,
"Orient Pink":0x8f415f,
"Orient Yellow":0xf7b969,
"Oriental Blush":0xd7c6e1,
"Oriental Eggplant":0x533e4f,
"Oriental Herbs":0x118822,
"Oriental Olive":0x445533,
"Oriental Pink":0xc28e88,
"Oriental Ruby":0xce536b,
"Oriental Silk":0xefe5d6,
"Oriental Spice":0x8b5131,
"Origami":0xece0c6,
"Origami White":0xe5e2da,
"Original White":0xf0e5d3,
"Orinoco":0xd2d3b3,
"Oriole Yellow":0xf6d576,
"Orioles":0xee8962,
"Orioles Orange":0xfb4f14,
"Orion Blue":0x3e4f5c,
"Orion Grey":0x535558,
"Orka Black":0x27221f,
"Orkhide Shade":0x3e5755,
"Orko":0xd91407,
"Orlean's Tune":0xb8995b,
"Orleans Tune":0x97d5e7,
"Ornamental Turquoise":0x00867d,
"Ornate":0x806d95,
"Ornery Tangerine":0xf77d25,
"Oro":0xc29436,
"Orochimaru":0xd9d8da,
"Orpiment Orange":0xd17c3f,
"Orpiment Yellow":0xf9c89b,
"Orpington Chicken":0xbe855e,
"Orzo Pasta":0xf9eacc,
"Osage Orange":0xf4a045,
"Osiris":0x5b5a4d,
"Oslo Blue":0xa6bdbe,
"Oslo Grey":0x878d91,
"Osprey":0x63564b,
"Osprey Nest":0xccbab1,
"Osso Bucco":0xad9769,
"Ostrich":0xe9e3d5,
"Ostrich Egg":0xdcd0bb,
"Ostrich Tail":0xeadfe6,
"Oswego Tea":0x665d59,
"Ōtan Red":0xff4e20,
"Otis Madeira":0x633d38,
"Ottawa Falls":0x00a78d,
"Otter":0x7f674f,
"Otter Brown":0x654320,
"Otter Creek":0x3f5a5d,
"Otter Tail":0x938577,
"Otto Ice":0xbedfd3,
"Ottoman":0xd3dbcb,
"Ottoman Red":0xee2222,
"OU Crimson Red":0x990000,
"Oubliette":0x4f4944,
"Ouni Red":0xee7948,
"Out of Blue":0xc0f7db,
"Out of Plumb":0x9c909c,
"Out of the Blue":0x1199ee,
"Outback":0xc9a375,
"Outback Brown":0x7e5d47,
"Outdoor Cafe":0x8d745e,
"Outdoor Land":0xa07d5e,
"Outdoor Oasis":0x6e6f4d,
"Outer Boundary":0x654846,
"Outer Reef":0x2a6295,
"Outer Rim":0x221177,
"Outer Space":0x414a4c,
"Outerbanks":0xb7a48b,
"Outerspace":0x314e64,
"Outgoing Orange":0xe6955f,
"Outlawed Orange":0xb67350,
"Outrageous":0x824438,
"Outrageous Green":0x8ab733,
"Outrageous Orange":0xff6e4a,
"Outrigger":0x82714d,
"Ovation":0x9eb2b9,
"Over the Taupe":0xb09d8a,
"Overboard":0x005555,
"Overcast":0x73a3d0,
"Overcast Day":0x8f99a2,
"Overcast Night":0x42426f,
"Overcast Sky":0xa7b8c4,
"Overdue Blue":0x4400ff,
"Overdue Grey":0xc7c3be,
"Overexposed Shot":0xeff4dc,
"Overgrown":0x88dd00,
"Overgrown Citadel":0x888844,
"Overgrown Trees":0x6b6048,
"Overgrown Trellis":0x6a8988,
"Overgrowth":0x88cc33,
"Overjoy":0xeec25f,
"Overnight Oats":0xfbf0db,
"Overt Green":0x97a554,
"Overtake":0x33557f,
"Overtone":0xa4e3b3,
"Ovoid Fruit":0x8c7e49,
"Owl Manner Malt":0xc0af87,
"Owlet":0x90845f,
"Oxalis":0xc1e28a,
"Oxblood":0x800020,
"Oxblood Red":0x71383f,
"Oxford":0xb1bbc5,
"Oxford Blue":0x002147,
"Oxford Brick":0x743b39,
"Oxford Brown":0x504139,
"Oxford Sausage":0xdb7192,
"Oxford Street":0xbda07f,
"Oxford Tan":0xb8a99a,
"Oxide":0xbf7657,
"Oxley":0x6d9a78,
"Oxygen Blue":0x92b6d5,
"Oyster":0xe3d3bf,
"Oyster Bar":0xdbd0bb,
"Oyster Bay":0x71818c,
"Oyster Catch":0x4a4c45,
"Oyster Cracker":0xf4f0d2,
"Oyster Grey":0xcbc1ae,
"Oyster Haze":0xe4ded2,
"Oyster Linen":0xb1ab96,
"Oyster Mushroom":0xc3c6c8,
"Oyster Pink":0xd4b5b0,
"Oyster White":0xd2caaf,
"Ozone":0x8b95a2,
"Ozone Blue":0xc7d3e0,
"Pa Red":0x5e3a39,
"Paarl":0x864b36,
"Pablo":0x7a715c,
"Pac-Man":0xffe737,
"Paccheri":0xecdfad,
"Pacer White":0xe5ddd0,
"Pachyderm":0x8f989d,
"Pacific":0x1f595c,
"Pacific Bliss":0x96acb8,
"Pacific Blue":0x1ca9c9,
"Pacific Blues":0x4470b0,
"Pacific Bluffs":0xc3a285,
"Pacific Breeze":0xc1dbe7,
"Pacific Bridge":0x0052cc,
"Pacific Coast":0x5480ac,
"Pacific Depths":0x004488,
"Pacific Fog":0xdcdcd5,
"Pacific Harbour":0x77b9db,
"Pacific Line":0x2d3544,
"Pacific Mist":0xcdd5d3,
"Pacific Ocean":0x92cbf1,
"Pacific Palisade":0x69a4b9,
"Pacific Panorama":0xc0d6ea,
"Pacific Pearl":0xe8eae6,
"Pacific Pine":0x546b45,
"Pacific Queen":0x026b5d,
"Pacific Sand":0xf1ebcd,
"Pacific Sea Teal":0x3e8083,
"Pacific Spirit":0x3c4a56,
"Pacific Storm":0x035453,
"Pacifica":0x4e77a3,
"Pacifika":0x778120,
"Packing Paper":0xba9b5d,
"Paco":0x4f4037,
"Padded Leaf":0x859e94,
"Paddle Wheel":0x88724d,
"Paddy":0xda9585,
"Paddy Field":0x99bb44,
"Padua":0x7eb394,
"Paella":0xdcc61f,
"Paella Natural White":0xe1d7c2,
"Pageant Green":0x99dac5,
"Pageant Song":0xb6c3d1,
"Pagoda":0x127e93,
"Pagoda Blue":0x1a7f8e,
"Paid In Full":0x8c8e65,
"Painite":0x6b4947,
"Paint the Sky":0x11eeff,
"Painted Bark":0x5f3d32,
"Painted Clay":0xeb8f6f,
"Painted Desert":0xbeb8b6,
"Painted Leather":0x6d544f,
"Painted Pony":0xbb9471,
"Painted Sea":0x008595,
"Painted Skies":0xb28774,
"Painted Turtle":0x56745f,
"Painter's Canvas":0xf9f2de,
"Painter's White":0xf2ebdd,
"Paisley":0x726f7e,
"Paisley Purple":0x8b79b1,
"Pakistan Green":0x006600,
"Palace Blue":0x346cb0,
"Palace Green":0x426255,
"Palace Purple":0x68457a,
"Palace Red":0x752745,
"Palace Rose":0xf8cad5,
"Palais White":0xf4f0e5,
"Palak Paneer":0x888811,
"Palatial":0xeedcd1,
"Palatial White":0xf9f2e4,
"Palatinate Blue":0x273be2,
"Palatinate Purple":0x682860,
"Palatine":0xc9c7b6,
"Pale":0xfff9d0,
"Pale Ale":0xfef068,
"Pale Aqua":0xbcd4e1,
"Pale Bamboo":0xc9bfa8,
"Pale Beige":0xccc7b1,
"Pale Berries":0xe2ccc7,
"Pale Berry":0xe39e9c,
"Pale Beryl":0x98ded9,
"Pale Blackish Purple":0x4a475c,
"Pale Blossom":0xfde1f0,
"Pale Blue":0xd0fefe,
"Pale Blue Grey":0xa2adb1,
"Pale Blush":0xe4bfb3,
"Pale Brown":0xb1916e,
"Pale Bud":0xeeebe8,
"Pale Cashmere":0xe8dfd5,
"Pale Celadon":0xc9cbbe,
"Pale Celery":0xe9e9c7,
"Pale Cerulean":0x9bc4e2,
"Pale Chamois":0xefe5d7,
"Pale Cherry Blossom":0xfdeff2,
"Pale Chestnut":0xddadaf,
"Pale Cloud":0xdadee9,
"Pale Coral":0xf0d0b4,
"Pale Cornflower":0xced9e1,
"Pale Cucumber":0xd6d5bc,
"Pale Daffodil":0xfde89a,
"Pale Dogwood":0xecccc1,
"Pale Egg":0xfde8d0,
"Pale Flower":0x698aab,
"Pale Gingersnap":0xeaddca,
"Pale Gold":0xfdde6c,
"Pale Grape":0xc0a2c7,
"Pale Green":0x69b076,
"Pale Green Grey":0x96907e,
"Pale Green Tea":0xe2e2d2,
"Pale Grey":0xfdfdfe,
"Pale Grey Blue":0xd4e2eb,
"Pale Grey Magenta":0xe7d8ea,
"Pale Honey":0xf5d6aa,
"Pale Icelandish":0xbdd4d1,
"Pale Iris":0x8895c5,
"Pale Ivy":0xd4cfb2,
"Pale Jade":0x77c3b4,
"Pale Jasper":0xfed6cc,
"Pale Khaki":0x998877,
"Pale Lavender":0xdcd0ff,
"Pale Leaf":0xbdcaa8,
"Pale Lichen":0xd8d4bf,
"Pale Light Green":0xb1fc99,
"Pale Lilac":0xe1c6cc,
"Pale Lily":0xf3ece7,
"Pale Lime Green":0xb1ff65,
"Pale Lime Yellow":0xdfe69f,
"Pale Loden":0xccd2ca,
"Pale Lychee":0xc4acb2,
"Pale Marigold":0xffbb44,
"Pale Mauve":0xc6a4a4,
"Pale Mint":0xaac2a1,
"Pale Moss":0xdcc797,
"Pale Moss Green":0xd0dbc4,
"Pale Mountain Lake Turquoise":0xbae1d3,
"Pale Narcissus":0xfaf5e2,
"Pale Olive":0xd3c7a1,
"Pale Orchid":0xdedbe5,
"Pale Orchid Petal":0xf6e2ec,
"Pale Organza":0xfdebbc,
"Pale Oyster":0x9c8d72,
"Pale Palomino":0xe5dbca,
"Pale Parchment":0xd1c3ad,
"Pale Parsnip":0xe3d8bf,
"Pale Pastel":0x9adedb,
"Pale Peach":0xffe5ad,
"Pale Pearl":0xfff2de,
"Pale Periwinkle":0xc8d2e2,
"Pale Persimmon":0xd4acad,
"Pale Petticoat":0xba9ba5,
"Pale Petunia":0xf8c0c7,
"Pale Phthalo Blue":0xccd5ff,
"Pale Pink":0xefcddb,
"Pale Pistachio":0xe3e7d1,
"Pale Poppy":0xbca8ad,
"Pale Primrose":0xeec8d3,
"Pale Purple":0xb790d4,
"Pale Quartz":0xefeada,
"Pale Rebelka Jakub":0xebebd7,
"Pale Robin Egg Blue":0x96ded1,
"Pale Rose":0xefd6da,
"Pale Sage":0xacbda1,
"Pale Sagebrush":0xd3d1b9,
"Pale Sand":0xe5d5ba,
"Pale Seafoam":0xc3e7e8,
"Pale Shale":0xcacfdc,
"Pale Shrimp":0xf8dbd6,
"Pale Sienna":0xdfc7bc,
"Pale Sky":0xbdf6fe,
"Pale Spring Bud":0xecebbd,
"Pale Spring Morning":0xb3be98,
"Pale Starlet":0xe4ded8,
"Pale Sunshine":0xf2c880,
"Pale Taupe":0xbc987e,
"Pale Teal":0x82cbb2,
"Pale Tendril":0xcecdbb,
"Pale Terra":0xeaaa96,
"Pale Turquoise":0xa5fbd5,
"Pale Verdigris":0x6f9892,
"Pale View":0xf4f2e2,
"Pale Violet":0xc6c3d6,
"Pale Vista":0xd8dece,
"Pale Wheat":0xd9c29f,
"Pale Willow":0x89ab98,
"Pale Wisteria":0xbbc8e6,
"Pale Wood":0xead2a2,
"Palest of Lemon":0xf4eed1,
"Palisade":0xc3b497,
"Palisade Orchid":0xaf8ea5,
"Palish Peach":0xf7ece1,
"Pallasite Blue":0x314a4e,
"Pallid Blue":0xb3cdd4,
"Pallid Flesh":0xf3dfdb,
"Pallid Green":0xc1e0c1,
"Pallid Light Green":0xcbdcb7,
"Pallid Orange":0xfcb99d,
"Pallid Wych Flesh":0xcdcebe,
"Palm":0xafaf5e,
"Palm Breeze":0xdbe2c9,
"Palm Desert":0x85775f,
"Palm Frond":0xaead5b,
"Palm Green":0x20392c,
"Palm Heart Cream":0xddd8c2,
"Palm Lane":0x7a7363,
"Palm Leaf":0x36482f,
"Palm Springs Splash":0x20887a,
"Palm Sugar Yellow":0xedd69d,
"Palm Tree":0x74b560,
"Palmerin":0x577063,
"Palmetto":0x6d9a9b,
"Palmetto Bluff":0xceb993,
"Palmito":0xeaeacf,
"Palo Verde":0x5f6356,
"Paloma":0x9f9c99,
"Paloma Tan":0xe9b679,
"Palomino":0xbb7744,
"Palomino Gold":0xdaae00,
"Palomino Mane":0xe6d6ba,
"Palomino Pony":0x837871,
"Palomino Tan":0xc2aa8d,
"Pampas":0xeae4dc,
"Pampered Princess":0xf5eaeb,
"Pan Tostado":0xe8be99,
"Panache":0xebf7e4,
"Panache Pink":0xedc9d5,
"Panama Rose":0xc6577c,
"Pancake":0xf7d788,
"Pancake Mix":0xd7bfa6,
"Pancakes":0xf5ddd8,
"Pancho":0xdfb992,
"Pancotto Pugliese":0xbfdb89,
"Panda":0x544f3a,
"Panda Black":0x3c4748,
"Panda White":0xeae2d4,
"Pandanus":0x616c44,
"Pandora":0x71689a,
"Pandora Grey":0xe3d4cf,
"Pandora's Box":0xfedbb7,
"Panela":0x9b5227,
"Pango Black":0x4e4f6a,
"Pani Puri":0xf4aa53,
"Pannikin":0x7895cc,
"Panorama":0x327a88,
"Panorama Blue":0x35bdc8,
"Pansy":0xf75394,
"Pansy Garden":0x7f8fca,
"Pansy Petal":0x5f4561,
"Pansy Posy":0xbca3b4,
"Pansy Purple":0x78184a,
"Pantomime":0xadafba,
"Paolo Veronese Green":0x009b7d,
"Paparazzi":0x5a4a64,
"Paparazzi Flash":0xc6cbd1,
"Papaya":0xfea166,
"Papaya Punch":0xfca289,
"Papaya Sorbet":0xffeac5,
"Papaya Whip":0xffd1af,
"Papaya Yellow Green":0xbea932,
"Paper Brown":0xd7ac7f,
"Paper Daisy":0xf0e5c7,
"Paper Dog":0xd6c5a9,
"Paper Elephant":0xc5d0e6,
"Paper Goat":0xb1a99f,
"Paper Heart":0xf7dbc7,
"Paper Hearts":0xcc4466,
"Paper Lamb":0xf2ebe1,
"Paper Lantern":0xf2e0c4,
"Paper Plane":0xf1ece0,
"Paper Sack":0xb4a07a,
"Paper Tiger":0xfdf1af,
"Paper White":0xeef0f3,
"Paperboy's Lawn":0x249148,
"Paperwhite":0xf6efdf,
"Papier Blanc":0xefeadc,
"Papilio Argeotus":0x8590ae,
"Pappardelle Noodle":0xf9ebcc,
"Paprika":0x7c2d37,
"Papyrus":0x999911,
"Papyrus Map":0xc0ac92,
"Papyrus Paper":0xf5edd6,
"Par Four":0x507069,
"Par Four Green":0x3f8f45,
"Parachute":0xbeb755,
"Parachute Purple":0x392852,
"Parachute Silk":0xffe2b5,
"Parachuting":0x00589b,
"Paradise":0xdef1ea,
"Paradise Bird":0xff8c55,
"Paradise City":0x5f7475,
"Paradise Found":0x83988c,
"Paradise Grape":0x746565,
"Paradise Green":0xb2e79f,
"Paradise Island":0x5aa7a0,
"Paradise Landscape":0x009494,
"Paradise of Greenery":0x398749,
"Paradise Palms":0x006622,
"Paradise Pink":0xe4445e,
"Paradise Sky":0x66c6d0,
"Paradiso":0x488084,
"Parador Inn":0xa99a8a,
"Parador Stone":0x908d86,
"Parakeet":0x78ae48,
"Parakeet Blue":0x7eb6ff,
"Parakeet Green":0x1aa36d,
"Parakeet Pete":0xcbd3c6,
"Paramount":0x5b6161,
"Parasailing":0x00736c,
"Parasite Brown":0x914b13,
"Parasol":0xe9dfde,
"Parauri Brown":0x824a53,
"Parchment":0xfefcaf,
"Parchment Paper":0xf0e7d8,
"Parchment White":0xf9eae5,
"Parfait":0xc8a6a1,
"Parfait d'Amour":0x734f96,
"Parfait Pink":0xe9c3cf,
"Paris":0x91a7bc,
"Paris Blue":0xb7dded,
"Paris Creek":0x888873,
"Paris Daisy":0xfbeb50,
"Paris Green":0x50c87c,
"Paris M":0x312760,
"Paris Paving":0x737274,
"Paris Pink":0xda6d91,
"Paris White":0xbfcdc0,
"Parisian Blue":0x4f7ca4,
"Parisian Cafè":0xa49085,
"Parisian Cashmere":0xd1c7b8,
"Parisian Green":0x6b9c42,
"Parisian Night":0x323441,
"Parisian Patina":0x7d9b89,
"Parisian Violet":0x787093,
"Park Avenue":0x465048,
"Park Bench":0x537f6c,
"Park Green Flat":0x88c9a6,
"Park Picnic":0x428f46,
"Parkview":0x46483e,
"Parkwater":0x477bbd,
"Parlor Rose":0xbaa1b2,
"Parlour Blue":0x465f7e,
"Parlour Red":0xa12d5d,
"Parma Grey":0x806e85,
"Parma Mauve":0x5f5680,
"Parma Plum Red":0x5e3958,
"Parma Violet":0x55455a,
"Parmentier":0x887cab,
"Parmesan":0xffffdd,
"Parrot Green":0x8db051,
"Parrot Pink":0xd998a0,
"Parrot Tulip":0xeebfd5,
"Parsley":0x305d35,
"Parsley Green":0x5a9f4d,
"Parsley Sprig":0x3d7049,
"Parsnip":0xd6c69a,
"Partial Pink":0xffedf8,
"Particle Cannon":0xdef3e6,
"Particle Ioniser Red":0xcb3215,
"Particular Mint":0xd0d2c5,
"Partly Cloudy":0x9dbbcd,
"Partridge":0x844c44,
"Partridge Grey":0x919098,
"Partridge Knoll":0xa9875b,
"Party Hat":0xcac1e2,
"Party Pig":0xee99ff,
"Party Time":0xd0252f,
"Partytime":0xe3a9c4,
"Pasadena Rose":0xa84a49,
"Paseo Verde":0x929178,
"Pasha Brown":0xc3b7a4,
"Paspalum Grass":0xb9bd97,
"Pass Time Blue":0x5d98b3,
"Passion Flower":0x6d5698,
"Passion Fruit":0x907895,
"Passion Fruit Punch":0xe8aa9d,
"Passion Plum":0x9c5f77,
"Passion Potion":0xe398af,
"Passion Razz":0x59355e,
"Passionate Blue":0x1f3465,
"Passionate Blueberry":0x334159,
"Passionate Pause":0xedefcb,
"Passionate Pink":0xdd00cc,
"Passionate Plum":0x753a58,
"Passionate Purple":0x882299,
"Passionfruit Mauve":0x513e49,
"Passive":0xcbccc9,
"Passive Pink":0xdba29e,
"Passive Royal":0x795365,
"Pasta":0xf7dfaf,
"Pasta Rasta":0xeec474,
"Pastel Blue":0xa2bffe,
"Pastel Brown":0x836953,
"Pastel China":0xf0e4e0,
"Pastel Day":0xdfd8e1,
"Pastel Green":0x77dd77,
"Pastel Grey":0xcfcfc4,
"Pastel Grey Green":0xbccbb9,
"Pastel Jade":0xd2f0e0,
"Pastel Lavender":0xd8a1c4,
"Pastel Lilac":0xbdb0d0,
"Pastel Magenta":0xf49ac2,
"Pastel Mint":0xcef0cc,
"Pastel Mint Green":0xadd0b3,
"Pastel Orange":0xff964f,
"Pastel Parchment":0xe5d9d3,
"Pastel Pea":0xbee7a5,
"Pastel Peach":0xf1caad,
"Pastel Pink":0xdea5a4,
"Pastel Purple":0xb39eb5,
"Pastel Red":0xff6961,
"Pastel Rose Tan":0xe9d1bf,
"Pastel Sand":0xd5c6b4,
"Pastel Smirk":0xdeece1,
"Pastel Turquoise":0x99c5c4,
"Pastel Violet":0xcb99c9,
"Pastel Yellow":0xfdfd96,
"Pastoral":0xedfad9,
"Pastry":0xf8deb8,
"Pastry Dough":0xfaedd5,
"Pastry Shell":0xbd8c66,
"Pasture Green":0x506351,
"Patch of Land":0x225511,
"Patches":0x8a7d6b,
"Patchwork Pink":0xc4a89e,
"Patchwork Plum":0x7e696a,
"Paternoster":0xc7c7c6,
"Path to the Sky":0xc4eee8,
"Pathway":0xdbd6d2,
"Patience":0xe6ddd6,
"Patient White":0xede2de,
"Patina":0x639283,
"Patina Creek":0xb6c4bd,
"Patina Green":0xb9eab3,
"Patina Violet":0x695a67,
"Patio Green":0x3f5a50,
"Patio Stone":0x6b655b,
"Patriarch":0x800070,
"Patrice":0x8cd9a1,
"Patrician Purple":0x6c4e79,
"Patrinia Flowers":0xd9b611,
"Patrinia Scabiosaefolia":0xf2f2b0,
"Patriot Blue":0x363756,
"Pattens Blue":0xd3e5ef,
"Pattipan":0xbcc6b1,
"Paua":0x2a2551,
"Paua Shell":0x245056,
"Pauley":0x629191,
"Pauper":0x343445,
"Paved Path":0x828782,
"Pavement":0x524d50,
"Pavestone":0xc9c4ba,
"Pavilion":0xbebf84,
"Pavilion Beige":0xc5b6a4,
"Pavilion Peach":0xdf9c45,
"Pavillion":0xede4d4,
"Paving Stone":0xa8a498,
"Paving Stones":0xcbccc4,
"Pavlova":0xbaab87,
"Paw Paw":0xfbd49c,
"Paw Print":0x827a6d,
"Pawn Broker":0x473430,
"Pax":0xc8c6da,
"Payne's Grey":0x536878,
"PCB Green":0x002d04,
"Pea":0xa4bf20,
"Pea Aubergine Green":0x7c9865,
"Pea Case":0x709d3d,
"Pea Green":0x8eab12,
"Pea Soup":0x929901,
"Pea Soup Green":0x94a617,
"Peabody":0x3f7074,
"Peace":0xa2b2bd,
"Peace N Quiet":0xcacfe0,
"Peace of Mind":0xc1875f,
"Peace River":0xa8bfcc,
"Peace Yellow":0xeecf9e,
"Peaceable Kingdom":0xddccac,
"Peaceful Blue":0x9ab6c0,
"Peaceful Glade":0x878e83,
"Peaceful Night":0xd6e7e3,
"Peaceful Pastures":0x94d8ac,
"Peaceful Peach":0xffddcd,
"Peaceful Purple":0x660088,
"Peaceful Rain":0xf1fbf1,
"Peaceful River":0x47a0d2,
"Peach":0xffb07c,
"Peach A La Mode":0xefc9aa,
"Peach Amber":0xfb9f93,
"Peach Ash":0xefc4bb,
"Peach Beauty":0xe7c3ab,
"Peach Beige":0xd3a297,
"Peach Bellini":0xfedcad,
"Peach Bloom":0xd99b7c,
"Peach Blossom":0xde8286,
"Peach Blossom Red":0xeecfbf,
"Peach Blush":0xe4ccc6,
"Peach Breeze":0xffece5,
"Peach Brick":0xe5ccbd,
"Peach Bud":0xfdb2ab,
"Peach Buff":0xcc99bb,
"Peach Burst":0xf39998,
"Peach Butter":0xffac3a,
"Peach Caramel":0xc5733d,
"Peach Cider":0xffd9aa,
"Peach Cloud":0xfce2d8,
"Peach Cobbler":0xffb181,
"Peach Crayon":0xffcba7,
"Peach Cream":0xfff0db,
"Peach Crème Brûlée":0xffe19d,
"Peach Damask":0xf6c4a6,
"Peach Darling":0xefcdb4,
"Peach Dip":0xf4debf,
"Peach Dust":0xf0d8cc,
"Peach Echo":0xf7786b,
"Peach Everlasting":0xf4e2d4,
"Peach Fade":0xfce9d6,
"Peach Fizz":0xffa883,
"Peach Flower":0xe198b4,
"Peach Fury":0xf88435,
"Peach Fuzz":0xffc7b9,
"Peach Glow":0xffdcac,
"Peach Juice":0xffcfab,
"Peach Latte":0xe7c19f,
"Peach Macaron":0xc67464,
"Peach Melba":0xfbbdaf,
"Peach Mimosa":0xf4a28c,
"Peach Nectar":0xffb59b,
"Peach Nirvana":0xedb48f,
"Peach Nougat":0xe6af91,
"Peach of Mind":0xffe2b4,
"Peach Orange":0xffcc99,
"Peach Parfait":0xf8bfa8,
"Peach Patch":0xf3d5a1,
"Peach Pearl":0xffb2a5,
"Peach Pink":0xff9a8a,
"Peach Poppy":0xddaaaa,
"Peach Powder":0xe2bdb3,
"Peach Preserve":0xd29487,
"Peach Puff":0xffdab9,
"Peach Puree":0xefcfba,
"Peach Quartz":0xf5b895,
"Peach Red":0xf9cdc4,
"Peach Rose":0xf6e3d5,
"Peach Sachet":0xf6d9c9,
"Peach Schnapps":0xffdcd6,
"Peach Shortcake":0xf3dfd4,
"Peach Smoothie":0xffe5bd,
"Peach Souffle":0xecbcb2,
"Peach Surprise":0xf3e3d1,
"Peach Temptation":0xf2c5b2,
"Peach Tile":0xefa498,
"Peach Tone":0xf2e3dc,
"Peach Umbrella":0xf9e8ce,
"Peach Whip":0xdbbeb7,
"Peach Yellow":0xfadfad,
"Peachade":0xfadfc7,
"Peaches of Immortality":0xd98586,
"Peaches'n'Cream":0xeec9a6,
"Peachskin":0xdfb8b6,
"Peachtree":0xf3ddcd,
"Peachy Bon-Bon":0xffd2b9,
"Peachy Confection":0xd4a88d,
"Peachy Ethereal":0xfde0dc,
"Peachy Feeling":0xed8666,
"Peachy Keen":0xffdeda,
"Peachy Maroney":0xe8956b,
"Peachy Milk":0xf3e0d8,
"Peachy Pico":0xffccaa,
"Peachy Pinky":0xff775e,
"Peachy Sand":0xffdcb7,
"Peachy Scene":0xdd7755,
"Peachy Skin":0xf0cfa0,
"Peacoat":0x2b2e43,
"Peacock Blue":0x016795,
"Peacock Feather":0x12939a,
"Peacock Green":0x006a50,
"Peacock Plume":0x206d71,
"Peacock Pride":0x006663,
"Peacock Purple":0x513843,
"Peacock Silk":0x6da893,
"Peacock Tail":0x01636d,
"Peahen":0x719e8a,
"Peak Point":0x768083,
"Peak Season":0xffdfc9,
"Peanut":0x7a4434,
"Peanut Brittle":0xa6893a,
"Peanut Butter":0xbe893f,
"Peanut Butter Chicken":0xffb75f,
"Peanut Butter Crust":0xc8a38a,
"Peanut Butter Jelly":0xce4a2d,
"Peapod":0x82b185,
"Peapod Green":0x8e916d,
"Pear":0xd1e231,
"Pear Cactus":0x91af88,
"Pear Perfume":0xccdd99,
"Pear Sorbet":0xf3eac3,
"Pear Spritz":0xcbf85f,
"Pearl":0xeae0c8,
"Pearl Aqua":0x88d8c0,
"Pearl Ash":0xd0c9c3,
"Pearl Bay":0x7fc6cc,
"Pearl Blue":0x79b4c9,
"Pearl Blush":0xf4cec5,
"Pearl Brite":0xe6e6e3,
"Pearl Bush":0xded1c6,
"Pearl City":0xdce4e9,
"Pearl Drops":0xf0ebe4,
"Pearl Dust":0xefe5d9,
"Pearl Gray":0xcbcec5,
"Pearl Grey":0xb0b7be,
"Pearl Lusta":0xeae1c8,
"Pearl Necklace":0xfcf7eb,
"Pearl Onion":0xeeefe1,
"Pearl Oyster":0xddd6cb,
"Pearl Pebble":0xded7da,
"Pearl Rose":0xdfd3d4,
"Pearl Sugar":0xf4f1eb,
"Pearl Violet":0xe6e0e3,
"Pearl White":0xf3f2ed,
"Pearl Yellow":0xf1e3bc,
"Pearled Couscous":0xf2e9d5,
"Pearled Ivory":0xf0dfcc,
"Pearls & Lace":0xdcd0cb,
"Pearls and Lace":0xeee7dc,
"Pearly Flesh":0xf4e3df,
"Pearly Purple":0xb768a2,
"Pearly Putty":0xdbd3bd,
"Pearly Star":0xe4e4da,
"Pearly Swirly":0xeee9d8,
"Pearly White":0xfeefd3,
"Peas in a Pod":0x7b9459,
"Peas In A Pod":0xa9d689,
"Peas Please":0x8c7f3c,
"Peaslake":0x8caa95,
"Peat":0x766d52,
"Peat Brown":0x5a3d29,
"Peat Red Brown":0x6c5755,
"Peat Swamp Forest":0x988c75,
"Peaty Brown":0x552211,
"Pebble":0x9d9880,
"Pebble Beach":0x7f8285,
"Pebble Cream":0xf3e1ca,
"Pebble Path":0xd5bc94,
"Pebble Soft Blue White":0xd3d7dc,
"Pebble Stone":0xe0d9da,
"Pebble Walk":0xafb2a7,
"Pebblebrook":0xd8d0bc,
"Pebbled Courtyard":0xdecab9,
"Pebbled Path":0xa0968d,
"Pebbled Shore":0xdbd5ca,
"Pebbles":0xded8dc,
"Pecan":0xb17d64,
"Pecan Brown":0xa36e51,
"Pecan Sandie":0xf4decb,
"Pecan Veneer":0xe09f78,
"Peche":0xfddcb7,
"Pecos Spice":0xe1a080,
"Pedestrian Green":0x00bb22,
"Pedestrian Lemon":0xffff22,
"Pedestrian Red":0xcc1122,
"Pedigree":0x31646e,
"Pediment":0xd3ccc4,
"Peek a Blue":0xc5e1e1,
"Peekaboo":0xe6dee6,
"Peeled Asparagus":0x87a96b,
"Peeps":0xffcf38,
"Peevish Red":0xff2266,
"Pegasus":0xe8e9e4,
"Pegeen Peony":0xea9fb4,
"Pekin Chicken":0xf5d2ac,
"Pelagic":0x355d83,
"Pelati":0xff3333,
"Pelican":0xc1bcac,
"Pelican Bay":0x9eacb1,
"Pelican Bill":0xd7c0c7,
"Pelican Feather":0xe8c3c2,
"Pelican Pecker":0xfb9a30,
"Pelican Pink":0xe2a695,
"Pelican Tan":0xc8a481,
"Pelorus":0x2599b2,
"Pencil Eraser":0xdbb7bb,
"Pencil Lead":0x5c6274,
"Pencil Point":0x595d61,
"Pencil Sketch":0x999d9e,
"Pendula Garden":0x7b8267,
"Penelope":0xe3e3eb,
"Penelope Pink":0x9d6984,
"Peninsula":0x37799c,
"Penna":0xb9c8e0,
"Pennywise":0xa2583a,
"Pensive":0xc2c1cb,
"Pensive Pink":0xeab6ad,
"Pentagon":0x96ccd1,
"Pentalon":0xdbb2bc,
"Penthouse View":0xcabfb3,
"Penzance":0x627e75,
"Peony":0xed9ca8,
"Peony Blush":0xd8c1be,
"Peony Mauve":0x9f86b7,
"Peony Pink":0xe38c7f,
"Peony Prize":0xfaddd4,
"People's Choice":0xb6a8d0,
"Pepper Grass":0x7c9d47,
"Pepper Green":0x007d60,
"Pepper Jelly":0xcc2244,
"Pepper Mill":0x777568,
"Pepper Spice":0x8e7059,
"Pepper Sprout":0x7e9242,
"Pepperberry":0xc79d9b,
"Peppercorn":0x6c5656,
"Peppercorn Red":0x533d44,
"Peppercorn Rent":0x4f4337,
"Peppered Moss":0x807548,
"Peppered Pecan":0x957d6f,
"Peppergrass":0x767461,
"Peppermint":0xd7e7d0,
"Peppermint Bar":0x81bca8,
"Peppermint Fresh":0x64be9f,
"Peppermint Frosting":0xb8ffeb,
"Peppermint Patty":0xd1e6d5,
"Peppermint Pie":0xaac7c1,
"Peppermint Spray":0x90cbaa,
"Peppermint Stick":0xe8b9be,
"Peppermint Toad":0x009933,
"Peppermint Twist":0x96ced5,
"Pepperoncini":0xd8c553,
"Pepperoni":0xaa4400,
"Peppery":0x5b5752,
"Peppy":0x72d7b7,
"Peppy Peacock":0x55ccbb,
"Peppy Pineapple":0xffff44,
"Peptalk":0x0060a6,
"Pepto":0xe8a2b9,
"Pêra Rocha":0xa3ce27,
"Perano":0xacb9e8,
"Percale":0xf0e8dd,
"Perdu Pink":0xc1ada9,
"Perennial Blue":0xa4bbd3,
"Perennial Garden":0x87a56f,
"Perennial Gold":0xcaaf81,
"Perennial Green":0x47694f,
"Perennial Phlox":0xe6a7ac,
"Perfect Dark":0x313390,
"Perfect Greige":0xb7ab9f,
"Perfect Khaki":0xb2a492,
"Perfect Landing":0x9eb2c3,
"Perfect Ocean":0x3062a0,
"Perfect Pear":0xe9e8bb,
"Perfect Penny":0xa06a56,
"Perfect Periwinkle":0x6487b0,
"Perfect Pink":0xe5b3b2,
"Perfect Sky":0x4596cf,
"Perfect Solution":0xf2edd7,
"Perfect Storm":0x9598a1,
"Perfect Tan":0xcbac88,
"Perfect Taupe":0xb6aca0,
"Perfect White":0xf0eeee,
"Perfection":0xd9d6e5,
"Perfectly Purple":0x694878,
"Perfectly Purple Place":0xcc22aa,
"Perfume":0xc2a9db,
"Perfume Cloud":0xe2c9ce,
"Perfume Haze":0xf3e9f7,
"Pergament":0xbfa58a,
"Pergament Shreds":0xe4e0dc,
"Pergola Panorama":0xe1e9db,
"Peri Peri":0xc62d2c,
"Pericallis Hybrida":0x904fef,
"Peridot":0xe6e200,
"Periglacial Blue":0xacb6b2,
"Périgord Truffle":0x524a46,
"Periscope":0x52677b,
"Peristyle Brass":0xae905e,
"Periwinkle":0x8e82fe,
"Periwinkle Blossom":0x8b9ab9,
"Periwinkle Blue":0x8f99fb,
"Periwinkle Bud":0xb4c4de,
"Periwinkle Dusk":0x8d9db3,
"Periwinkle Grey":0xc3cde6,
"Periwinkle Powder":0xc5cbe1,
"Periwinkle Tint":0xd3ddd6,
"Perk Up":0xd6c7be,
"Perky":0x408e7c,
"Perky Tint":0xfbf4d3,
"Perky Yellow":0xf2ca83,
"Perle Noir":0x4f4d51,
"Permafrost":0x98eff9,
"Permanent Geranium Lake":0xe12c2c,
"Permanent Green":0x005437,
"Perpetual Purple":0x584d75,
"Perplexed":0xbdb3c3,
"Perrigloss Tan":0xddaa99,
"Perrywinkle":0x8f8ce7,
"Perseverance":0xacb3c7,
"Persian Bazaar":0xc5988c,
"Persian Belt":0x99ac4b,
"Persian Blinds":0xe3e1cc,
"Persian Blue":0x1c39bb,
"Persian Delight":0xefcada,
"Persian Fable":0xd4ebdd,
"Persian Flatbread":0xe1c7a8,
"Persian Gold":0x9b7939,
"Persian Green":0x00a693,
"Persian Indigo":0x32127a,
"Persian Jewel":0x6e81be,
"Persian Orange":0xd99058,
"Persian Pastel":0xaa9499,
"Persian Pink":0xf77fbe,
"Persian Plum":0x701c1c,
"Persian Plush":0x575b93,
"Persian Prince":0x38343e,
"Persian Red":0xcc3333,
"Persian Rose":0xfe28a2,
"Persian Violet":0x8c8eb2,
"Persicus":0xffb49b,
"Persimmon":0xe59b34,
"Persimmon Fade":0xf7bd8f,
"Persimmon Juice":0x934337,
"Persimmon Orange":0xf47327,
"Persimmon Red":0xa74e4a,
"Persimmon Varnish":0x9f563a,
"Perspective":0xcebeda,
"Persuasion":0xc4ae96,
"Peru":0xcd853f,
"Peruvian Lily":0xcd7db5,
"Peruvian Soil":0x733d1f,
"Peruvian Violet":0x7b7284,
"Pervenche":0x0099ee,
"Pestilence":0x9f8303,
"Pesto":0xc1b23e,
"Pesto Alla Genovese":0x558800,
"Pesto Calabrese":0xf49325,
"Pesto di Noce":0xb09d64,
"Pesto di Pistacchio":0xa7c437,
"Pesto di Rucola":0x748a35,
"Pesto Genovese":0x9dc249,
"Pesto Green":0x817553,
"Pesto Paste":0x898c66,
"Pesto Rosso":0xbb3333,
"Pestulance":0xaa9933,
"Petal Bloom":0xf7d5da,
"Petal Dust":0xf4dfcd,
"Petal Pink":0xf2e2e0,
"Petal Plush":0xddaaee,
"Petal Poise":0xf8e3ee,
"Petal Purple":0x53465d,
"Petal Tip":0xd9d9df,
"Petals Unfolding":0xf3bbc0,
"Peter Pan":0x19a700,
"Petit Four":0x87c2d4,
"Petite Orchid":0xda9790,
"Petite Pink":0xeacacb,
"Petite Purple":0xcfbbd8,
"Petrel":0x4076b4,
"Petrel Blue Grey":0xa0aebc,
"Petrichor":0x66cccc,
"Petrichor Brown":0x6a4345,
"Petrified":0x8b8680,
"Petrified Oak":0x8d7960,
"Petro Blue":0x2f5961,
"Petrol":0x005f6a,
"Petrol Green":0x549b8c,
"Petticoat":0xfecdac,
"Pettifers":0x228822,
"Pettingill Sage":0x88806a,
"Petula":0xffbab0,
"Petunia":0x4f3466,
"Petunia Patty":0x4b3c4b,
"Petunia Trail":0xb8b0cf,
"Pewter":0x91a092,
"Pewter Blue":0x8ba8b7,
"Pewter Cast":0x9b9893,
"Pewter Green":0x5e6259,
"Pewter Grey":0xa7a19e,
"Pewter Mug":0x8b8283,
"Pewter Patter":0xbab4a6,
"Pewter Ring":0x8a8886,
"Pewter Tankard":0xa39b90,
"Pewter Tray":0xbdc5c0,
"Pewter Vase":0xcececb,
"Peyote":0xc5bbae,
"Phantom":0x6e797b,
"Phantom Green":0xdce4d7,
"Phantom Hue":0x645d5e,
"Phantom Mist":0x4b4441,
"Phantom Ship":0x2f3434,
"Pharaoh Purple":0x636285,
"Pharaoh's Gem":0x007367,
"Pharaoh's Jade":0x83d1a9,
"Pharaoh's Seas":0x59bbc2,
"Pharlap":0x826663,
"Pharmaceutical Green":0x087e34,
"Pharmacy Green":0x005500,
"Phaser Beam":0xff4d00,
"Pheasant":0xc68463,
"Pheasant Brown":0x795435,
"Pheasant's Egg":0xe0dcd7,
"Phellodendron Amurense":0xf3c13a,
"Phelps Putty":0xc4bdad,
"Phenomenal Peach":0xffcba2,
"Phenomenal Pink":0xee55ff,
"Phenomenon":0x3e729b,
"Pheromone Purple":0x8822bb,
"Philanthropist Pink":0xe2d9dd,
"Philippine Blue":0x0038a7,
"Philippine Bronze":0x6e3a07,
"Philippine Brown":0x5d1916,
"Philippine Gold":0xb17304,
"Philippine Golden Yellow":0xeebb00,
"Philippine Green":0x008543,
"Philippine Orange":0xff7300,
"Philippine Pink":0xfa1a8e,
"Philippine Red":0xce1127,
"Philippine Violet":0x81007f,
"Philippine Yellow":0xfecb00,
"Philips Green":0x008f80,
"Philodendron":0x116356,
"Philosophically Speaking":0x4d483d,
"Phlox":0xdf00ff,
"Phlox Flower Violet":0x7f4f78,
"Phlox Pink":0xce5e9a,
"Phoenix Fossil":0xf8d99e,
"Phoenix Red":0xe2725b,
"Phoenix Rising":0xd2813a,
"Phoenix Villa":0xf7efde,
"Phosphor Green":0x00aa00,
"Phosphorescent Blue":0x11eeee,
"Phosphorescent Green":0x11ff00,
"Phosphorus":0xa5d0c6,
"Photo Grey":0xaead96,
"Photon Barrier":0x88ddee,
"Photon Projector":0x88eeff,
"Photon White":0xf8f8e8,
"PHP Purple":0x8892bf,
"Phthalo Blue":0x000f89,
"Phthalo Green":0x123524,
"Phuket Palette":0x0480bd,
"Physalis":0xef9548,
"Physalis Aquarelle":0xebe1d4,
"Physalis Peal":0xe1d8bb,
"Pianissimo":0xe6d0ca,
"Piano Black":0x17171a,
"Piano Brown":0x5c4c4a,
"Piano Grey Rose":0xcfc4c7,
"Piano Keys":0xeee5d4,
"Piano Mauve":0x9e8996,
"Picador":0x765c52,
"Picante":0x8d3f2d,
"Picasso":0xf8ea97,
"Picasso Lily":0x634878,
"Piccadilly Grey":0x625d5d,
"Piccolo":0x8bd2e2,
"Picholine":0x566955,
"Picket Fence":0xf3f2ea,
"Picket Fence White":0xebe7db,
"Pickford":0xc9f0d1,
"Pickle":0x85a16a,
"Pickle Juice":0xbba528,
"Pickled":0xb3a74b,
"Pickled Avocado":0x99bb11,
"Pickled Bean":0x6e4826,
"Pickled Beet":0x4d233d,
"Pickled Beets":0xaa0044,
"Pickled Bluewood":0x314459,
"Pickled Cucumber":0x94a135,
"Pickled Ginger":0xffdd55,
"Pickled Grape Leaves":0x775500,
"Pickled Lemon":0xddcc11,
"Pickled Limes":0xbbbb11,
"Pickled Okra":0x887647,
"Pickled Pineapple":0xeeff33,
"Pickled Pink":0xda467d,
"Pickled Plum":0x8e4785,
"Pickled Pork":0xddbbaa,
"Pickled Purple":0x8e7aa1,
"Pickled Radish":0xee1144,
"Pickled Salmon":0xff6655,
"Pickling Spice":0xcfd2b5,
"Picnic":0x99c285,
"Picnic Bay":0xbcdbd4,
"Picnic Day Sky":0x00ccee,
"Pico Earth":0xab5236,
"Pico Eggplant":0x7e2553,
"Pico Ivory":0xfff1e8,
"Pico Metal":0xc2c3c7,
"Pico Orange":0xffa300,
"Pico Sun":0xffec27,
"Pico Void":0x1d2b53,
"Pico-8 Pink":0xff77a8,
"Picton Blue":0x5ba0d0,
"Pictorial Carmine":0xc30b4e,
"Picture Book Green":0x00804c,
"Picture Perfect":0xfbf2d1,
"Pie Safe":0x877a64,
"Piece of Cake":0xede7c8,
"Pieces of Eight":0xffaf38,
"Pied Wagtail Grey":0xbebdc2,
"Piedmont":0xc2cec5,
"Piedra De Sol":0xeac185,
"Pier":0x88857d,
"Pier 17 Steel":0x647d8e,
"Piercing Pink":0xdd00ee,
"Piercing Red":0xdd1122,
"Piermont Stone Red":0x43232c,
"Piezo Blue":0xa1c8db,
"Pig Iron":0x484848,
"Pig Pink":0xfdd7e4,
"Pigeon":0xa9afaa,
"Pigeon Grey":0xc1b4a0,
"Pigeon Pink":0x9d857f,
"Pigeon Post":0xafbdd9,
"Piggy":0xef98aa,
"Piggy Bank":0xffccbb,
"Piggyback":0xf0dce3,
"Piglet":0xffc0c6,
"Pigment Indigo":0x4d0082,
"Pigskin Puffball":0xe8dad1,
"Pika Yellow":0xeee92d,
"Pikachu Chu":0xeede73,
"Pike Lake":0x6c7779,
"Pikkoro Green":0x15b01a,
"Pīlā Yellow":0xffff55,
"Pilot Blue":0x006981,
"Pilsener":0xf8f753,
"Piment Piquant":0xcc2200,
"Pimento":0xdc5d47,
"Pimento Grain Brown":0x6c5738,
"Pimlico":0xdf9e9d,
"Pimm's":0xc3585c,
"Pina":0xffd97a,
"Pina Colada":0xf4deb3,
"Pinafore Blue":0x7198c0,
"Pinata":0xc17a62,
"Pinball":0xd3d3d3,
"Pinch Me":0xc88ca4,
"Pinch of Pearl":0xfff8e3,
"Pinch of Pistachio":0xddddcc,
"Pinch Purple":0xb4abaf,
"Pincushion":0xac989c,
"Pindjur Red":0xbb4411,
"Pine":0x2b5d34,
"Pine Bark":0x827064,
"Pine Brook":0x5c7669,
"Pine Cone":0x645345,
"Pine Cone Brown":0x675850,
"Pine Cone Pass":0x5c6456,
"Pine Crush":0xb7b8a5,
"Pine Forest":0x415241,
"Pine Frost":0xdeeae0,
"Pine Garland":0x797e65,
"Pine Glade":0xbdc07e,
"Pine Grain":0xebc79e,
"Pine Green":0x0a481e,
"Pine Grove":0x213631,
"Pine Haven":0x486358,
"Pine Hutch":0xecdbd2,
"Pine Leaves":0x839b5c,
"Pine Mist":0xd5d8bc,
"Pine Mountain":0x5c685e,
"Pine Needle":0x334d41,
"Pine Nut":0xeadac2,
"Pine Ridge":0x6d9185,
"Pine Scent":0x4a6d42,
"Pine Strain":0xd5bfa5,
"Pine Trail":0x9c9f75,
"Pine Tree":0x2a2f23,
"Pine Water":0xe5e7d5,
"Pine Whisper":0xb3c6b9,
"Pineal Pink":0x786d72,
"Pineapple":0x563c0d,
"Pineapple Blossom":0xb4655c,
"Pineapple Cream":0xf2eac3,
"Pineapple Crush":0xedda8f,
"Pineapple Delight":0xf0e7a9,
"Pineapple Fizz":0xf9f0d6,
"Pineapple Juice":0xf8e87b,
"Pineapple Perfume":0xeeee88,
"Pineapple Sage":0x9c8f60,
"Pineapple Salmon":0xfd645f,
"Pineapple Slice":0xe7d391,
"Pineapple Soda":0xe4e5ce,
"Pineapple Sorbet":0xf7f4da,
"Pineapple Whip":0xead988,
"Pineberry":0xf0d6dd,
"Pinebrook":0x5d695a,
"Pinecone Hill":0x63695f,
"Pinecone Path":0x574745,
"Pinehurst":0x2b7b66,
"Pinetop":0x57593f,
"Piney Lake":0x006655,
"Píng Gǔo Lǜ Green":0x23c48b,
"Pink":0xffc0cb,
"Pink Abalone":0xe9b8a4,
"Pink Amour":0xf4e2e9,
"Pink and Sleek":0xffc3c6,
"Pink Apatite":0xd7b8ab,
"Pink Beach":0xf6c3a6,
"Pink Beauty":0xdca7c2,
"Pink Begonia":0xdd9cbd,
"Pink Bite":0xe936a7,
"Pink Bliss":0xe3abce,
"Pink Blossom":0xfbe9dd,
"Pink Blush":0xf4acb6,
"Pink Bonnet":0xdd77ee,
"Pink Booties":0xefe1e4,
"Pink Bubble Tea":0xfdbac4,
"Pink Cardoon":0xecc9ca,
"Pink Carnation":0xed7a9e,
"Pink Cattleya":0xffb2d0,
"Pink Chablis":0xf4ded9,
"Pink Chalk":0xf2a3bd,
"Pink Champagne":0xe8dfed,
"Pink Charge":0xdd66bb,
"Pink Chi":0xe4898a,
"Pink Chintz":0xefbecf,
"Pink Clay":0xffd5d1,
"Pink Clay Pot":0xd99294,
"Pink Condition":0xff99dd,
"Pink Cupcake":0xf5d0d6,
"Pink Currant":0xfed5e9,
"Pink Dahlia":0xb94c66,
"Pink Damask":0xd98580,
"Pink Dazzle":0xc97376,
"Pink Delight":0xff8ad8,
"Pink Diamond":0xfed0fc,
"Pink Diminishing":0xfff4f2,
"Pink Discord":0xb499a1,
"Pink Dogwood":0xf7d1d1,
"Pink Dream":0xfea5a2,
"Pink Duet":0xf8e7e4,
"Pink Dust":0xe4b5b2,
"Pink Dyed Blond":0xecdfd5,
"Pink Earth":0xb08272,
"Pink Elephant":0xf5d5cc,
"Pink Elephants":0xff99ee,
"Pink Emulsion":0xf2e4e2,
"Pink Eraser":0xf3a09a,
"Pink Explosion":0xf56f88,
"Pink Fetish":0xdd77ff,
"Pink Fever":0xcc55ff,
"Pink Fire":0xfc845d,
"Pink Flambe":0xd3507a,
"Pink Flamingo":0xff66ff,
"Pink Flare":0xd8b4b6,
"Pink Floyd":0xeb9a9d,
"Pink Fluorite":0xfbd3d9,
"Pink Frosting":0xf7d7e2,
"Pink Garnet":0xd2738f,
"Pink Gin":0xdfa3ba,
"Pink Ginger":0xcfa798,
"Pink Glamour":0xff787b,
"Pink Glitter":0xfddfda,
"Pink Glow":0xffece0,
"Pink Granite":0xa4877d,
"Pink Grapefruit":0xf3bac9,
"Pink Heath":0xf2bddf,
"Pink Horror":0x90305d,
"Pink Hydrangea":0xf8c1bb,
"Pink Ice":0xcf9fa9,
"Pink Icing":0xeea0a6,
"Pink Illusion":0xd8b8f8,
"Pink Ink":0xff1476,
"Pink Insanity":0xcc44ff,
"Pink Jazz":0x9e6b89,
"Pink Katydid":0xff55aa,
"Pink Kitsch":0xff22ee,
"Pink Lace":0xf6ccd7,
"Pink Lady":0xf3d7b6,
"Pink Lavender":0xd9afca,
"Pink Lemonade":0xffeaeb,
"Pink Lily":0xf8d0e7,
"Pink Linen":0xd2bfc4,
"Pink Lotus":0xfadbd7,
"Pink Makeup":0xfc80a5,
"Pink Manhattan":0xc16c7b,
"Pink Marble":0xe5d0ca,
"Pink Mimosa":0xf4b6a8,
"Pink Mirage":0xf4ede9,
"Pink Mist":0xe6bccd,
"Pink Moment":0xed9aab,
"Pink Moroccan":0xa98981,
"Pink Nectar":0xd8aab7,
"Pink Nudity":0xd6c3b7,
"Pink OCD":0x6844fc,
"Pink Orange":0xff9066,
"Pink Orchid":0xda70d6,
"Pink Orchid Mantis":0xfd82c3,
"Pink Orthoclase":0xaa98a9,
"Pink Overflow":0xff33ff,
"Pink Pail":0xeaced4,
"Pink Pampas":0xd1b6c3,
"Pink Pandora":0xe1c5c9,
"Pink Panther":0xff0090,
"Pink Papaya":0xd5877e,
"Pink Parade":0xb26ba2,
"Pink Parakeet":0xad546e,
"Pink Parfait":0xfaddd5,
"Pink Party":0xff55ee,
"Pink Peacock":0xc62168,
"Pink Pearl":0xe7accf,
"Pink Peony":0xe1bed9,
"Pink Pepper":0xc62d42,
"Pink Perfume":0xffdbe5,
"Pink Persimmon":0xffad97,
"Pink Petal":0xf6e6e2,
"Pink Piano":0xf62681,
"Pink Pieris":0xefc9b8,
"Pink Ping":0xee66ee,
"Pink Pleasure":0xffdfe5,
"Pink Plum":0xead2d2,
"Pink Poison":0xff007e,
"Pink Polar":0xccbabe,
"Pink Poppy":0x8e6e74,
"Pink Posey":0xeadee0,
"Pink Posies":0xefdbe2,
"Pink Potion":0xceaebb,
"Pink Power":0xd5b6cd,
"Pink Prestige":0xee99aa,
"Pink Pride":0xef1de7,
"Pink Prism":0xf3e6e4,
"Pink Proposal":0xf1e0e8,
"Pink Punch":0xd04a70,
"Pink Purple":0xdb4bda,
"Pink Pussycat":0xdc9f9f,
"Pink Quartz":0xffbbee,
"Pink Quince":0xab485b,
"Pink Raspberry":0x980036,
"Pink Red":0xf5054f,
"Pink Rose Bud":0xfeab9a,
"Pink Sachet":0xeebcb8,
"Pink Salt":0xf7cdc7,
"Pink Sand":0xdfb19b,
"Pink Sangria":0xf6dbd3,
"Pink Satin":0xffbbdd,
"Pink Scallop":0xf2e0d4,
"Pink Sea Salt":0xf6dacb,
"Pink Shade":0xcd7584,
"Pink Shadow":0xbb3377,
"Pink Sherbet":0xf780a1,
"Pink Shimmer":0xfde0da,
"Pink Slip":0xd58d8a,
"Pink Softness":0xdeb8bc,
"Pink Sparkle":0xffe9eb,
"Pink Spinel":0xe7c9ca,
"Pink Spyro":0xa328b3,
"Pink Stock":0xddabab,
"Pink Sugar":0xeeaaff,
"Pink Swan":0xbfb3b2,
"Pink Taffy":0xefbcb6,
"Pink Tease":0xff81c0,
"Pink Theory":0xffe6e4,
"Pink Tint":0xdbcbbd,
"Pink Touch":0xfae2d6,
"Pink Tulip":0x985672,
"Pink Tulle":0xdeb59a,
"Pink Tutu":0xf9e4e9,
"Pink Vibernum":0xf5e6e6,
"Pink Water":0xe0c9c4,
"Pink Wink":0xffaaee,
"Pink Wraith":0xddbbbb,
"Pink Yarrow":0xce3175,
"Pink Zest":0xf2d8cd,
"Pink-N-Purple":0x866180,
"Pinkadelic":0xcb5c5b,
"Pinkalicious":0xff99ff,
"Pinkathon":0xf1bdba,
"Pinkham":0xe8c5ae,
"Pinkish":0xd46a7e,
"Pinkish Brown":0xb17261,
"Pinkish Grey":0xc8aca9,
"Pinkish Orange":0xff724c,
"Pinkish Purple":0xd648d7,
"Pinkish Red":0xf10c45,
"Pinkish Tan":0xd99b82,
"Pinkman":0xdd11ff,
"Pinktone":0xf9ced1,
"Pinky":0xfc86aa,
"Pinky Beige":0xc9aa98,
"Pinky Promise":0xf5d1cf,
"Pinky Swear":0xeeaaee,
"Pinnacle":0xbeddd5,
"Pinot Noir":0x605258,
"Pinque":0xeca2ad,
"Pinwheel Geyser":0xd2dcde,
"Pinyon Pine":0x625a42,
"Pion Purple":0x480840,
"Pioneer Village":0xaa9076,
"Pipe":0x857165,
"Pipe Clay":0xcac7bc,
"Piper":0x9d5432,
"Pipitschah":0xf5e6c4,
"Pippin":0xfcdbd2,
"Piquant Green":0x769358,
"Piquant Pink":0xee00ee,
"Pirat's Wine":0x71424a,
"Pirate Black":0x363838,
"Pirate Gold":0xba782a,
"Pirate Plunder":0xb1905e,
"Pirate Silver":0x818988,
"Pirate's Haven":0x005176,
"Pirate's Hook":0xb08f42,
"Pirate's Trinket":0x716970,
"Pisco Sour":0xbeeb71,
"Pismo Dunes":0xf4d6a4,
"Pistachio":0x93c572,
"Pistachio Cream":0xd5e2e1,
"Pistachio Flour":0x4f8f00,
"Pistachio Green":0xa9d39e,
"Pistachio Ice Cream":0xa0b7ad,
"Pistachio Mousse":0xc0fa8b,
"Pistachio Pudding":0xc6d4ac,
"Pistachio Shell":0xd7cfbb,
"Pistachio Shortbread":0xc7bb73,
"Pistachio Tang":0xd7d2b8,
"Pistou Green":0x00bb55,
"Pit Stop":0x414958,
"Pita":0xf5e7d2,
"Pita Bread":0xdec8a6,
"Pitapat":0xedeb9a,
"Pitch":0x423937,
"Pitch Black":0x483c41,
"Pitch Green":0x283330,
"Pitch Mary Brown":0x5c4033,
"Pitch Pine":0x7c7766,
"Pitch-Black Forests":0x003322,
"Pitcher":0xb5d1be,
"Pitmaston Pear Yellow":0xd0a32e,
"Pitter Patter":0x9bc2bd,
"Pixel Bleeding":0xbb0022,
"Pixel Cream":0xf7d384,
"Pixel Nature":0x008751,
"Pixel White":0xdbdcdb,
"Pixelated Grass":0x009337,
"Pixie Green":0xbbcda5,
"Pixie Powder":0x391285,
"Pixie Violet":0xacb1d4,
"Pixie Wing":0xe9e6eb,
"Pixieland":0xb4a6c6,
"Pizazz":0xe57f3d,
"Pizazz Peach":0xf5c795,
"Pizza":0xbf8d3c,
"Pizza Pie":0xa06165,
"Place of Dust":0xc6c3c0,
"Placebo":0xe7e7e7,
"Placebo Blue":0xebf4fc,
"Placebo Fuchsia":0xf8ebfc,
"Placebo Green":0xebfcec,
"Placebo Lime":0xf6fceb,
"Placebo Magenta":0xfcebf4,
"Placebo Orange":0xfcf5eb,
"Placebo Pink":0xfcebfa,
"Placebo Purple":0xf0ebfc,
"Placebo Red":0xfcebeb,
"Placebo Sky":0xebfcfc,
"Placebo Turquoise":0xebfcf5,
"Placebo Yellow":0xfcfbeb,
"Placid Blue":0x8cadd3,
"Placid Sea":0x1cadba,
"Plague Brown":0xdfb900,
"Plaguelands Beige":0xab8d44,
"Plaguelands Hazel":0xad5f28,
"Plain and Simple":0xebf0d6,
"Plain Old Brown":0x905100,
"Plains":0xf5de85,
"Plane Brown":0x8a5024,
"Planet Earth":0xdaddc3,
"Planet Green":0x496a76,
"Planet of the Apes":0x883333,
"Planetarium":0x1c70ad,
"Planetary Silver":0xcccfcb,
"Plankton Green":0x00534c,
"Plant Green":0x777a44,
"Plantain":0x97943b,
"Plantain Chips":0xd6a550,
"Plantain Green":0x356554,
"Plantation":0x3e594c,
"Plantation Island":0x9b8a44,
"Plantation Shutters":0x6a5143,
"Planter":0x339900,
"Plasma Trail":0xd59cfc,
"Plaster":0xeaeaea,
"Plaster Cast":0xe1eaec,
"Plaster Mix":0xead1a6,
"Plastic Lime":0xeddc70,
"Plastic Lips":0xaa2266,
"Plastic Marble":0xffddcc,
"Plastic Pines":0x55aa11,
"Plastic Veggie":0x22ff22,
"Plasticine":0x4a623b,
"Plate Mail Metal":0x8c8589,
"Plateau":0xd3e7e5,
"Platinum":0xe5e4e2,
"Platinum Blonde":0xf0e8d7,
"Platinum Granite":0x807f7e,
"Platinum Grey":0x6a6d6f,
"Platinum Ogon Koi":0xece1d3,
"Platonic Blue":0x88ccff,
"Platoon Green":0x2a4845,
"Plaudit":0x39536c,
"Play 'til dawn":0xff8877,
"Play on Grey":0xbab6a9,
"Play School":0xce5924,
"Play Time":0xb39ba9,
"Playa Arenosa":0xdcc7b3,
"Playful Plum":0xba99a2,
"Playful Purple":0xbfb9d5,
"Playing Hooky":0x8b8c6b,
"Plaza Taupe":0xaea393,
"Pleasant Dream":0xa379aa,
"Pleasant Hill":0x4d5a4c,
"Pleasant Pomegranate":0xcc3300,
"Pleasant Purple":0x8833aa,
"Pleasant Stream":0x00a0a2,
"Pleasing Pink":0xf5cdd2,
"Pleasure":0x80385c,
"Pleated Mauve":0x858bc2,
"Plein Air":0xbfcad6,
"Ploughed Earth":0x6c6459,
"Plum":0x5a315d,
"Plum Blossom":0xf2a0a1,
"Plum Blossom Dye":0xb48a76,
"Plum Blue":0x4b6176,
"Plum Brown":0x4e4247,
"Plum Cake":0xd1bfdc,
"Plum Caspia":0x61224a,
"Plum Cheese":0x670728,
"Plum Crush":0x716063,
"Plum Dandy":0x8b6878,
"Plum Dust":0xaa4c8f,
"Plum Frost":0xb1a7b6,
"Plum Fuzz":0x313048,
"Plum Green":0x695c39,
"Plum Harvest":0x674555,
"Plum Haze":0x8b7574,
"Plum Highness":0x885577,
"Plum Island":0x463c4e,
"Plum Jam":0x624076,
"Plum Juice":0xdea1dd,
"Plum Kingdom":0xaa3377,
"Plum Kitten":0x625b5c,
"Plum Majesty":0x994548,
"Plum Mouse":0xc099a0,
"Plum Orbit":0x4e414b,
"Plum Paradise":0xaa1166,
"Plum Passion":0x9b4b80,
"Plum Perfect":0xaa1155,
"Plum Perfume":0xa489a3,
"Plum Pie":0x8e4585,
"Plum Point":0xd4bddf,
"Plum Power":0x7e5e8d,
"Plum Preserve":0x7c70aa,
"Plum Purple":0x580f41,
"Plum Raisin":0x644847,
"Plum Rich":0x64475e,
"Plum Royale":0x876c7a,
"Plum Sauce":0x6a3939,
"Plum Savor":0x915d88,
"Plum Shade":0x78738b,
"Plum Shadow":0x7c707c,
"Plum Skin":0x51304e,
"Plum Smoke":0x928e8e,
"Plum Swirl":0x957e8e,
"Plum Taupe":0xb6a19b,
"Plum Truffle":0x675657,
"Plum Wine":0x674550,
"Plum's the Word":0xdacee8,
"Plumage":0x00998c,
"Plumberry":0x735054,
"Plumburn":0x7d665f,
"Plume":0xa5cfd5,
"Plume Grass":0xd9d5c5,
"Plummy":0x675a75,
"Plumosa":0x64a281,
"Plumville":0x9e8185,
"Plunder":0x5072a9,
"Plunge":0x035568,
"Plunge Pool":0x656457,
"Plunging Waterfall":0x8cd4df,
"Plush":0x3b3549,
"Plush Purple":0x5d4a61,
"Plush Suede":0xb1928c,
"Plush Velvet":0x7e737d,
"Plushy Pink":0xeab7a8,
"Pluto":0x34acb1,
"Plutonium":0x35fa00,
"Pluviophile":0x66dddd,
"Plymouth Beige":0xddd3c2,
"Plymouth Green":0xb1b695,
"Plymouth Grey":0xb0b1ac,
"Plymouth Notch":0xcdb3ac,
"Poached Egg":0xf5d893,
"Poached Rainbow Trout":0xff8552,
"Poblano":0x077f1b,
"Pochard Duck Head":0xee9977,
"Pocket Lint":0xb5d5d7,
"Pocket Watch":0xc2a781,
"Poetic Green":0x00a844,
"Poetic License":0xe4e8e1,
"Poetic Light":0xe2ded8,
"Poetic Princess":0xf8e1e4,
"Poetic Yellow":0xfffed7,
"Poetry Mauve":0x886891,
"Poetry Plum":0x6f5c5f,
"Poetry Reading":0x9faec9,
"Pogo Sands":0xece4d2,
"Pohutukawa":0x651c26,
"Poinciana":0xca3422,
"Poinsettia":0xcb3441,
"Pointed Cabbage Green":0x859587,
"Pointed Fir":0x575d56,
"Pointed Rock":0x646767,
"Poise":0xa77693,
"Poised Peach":0xffa99d,
"Poised Taupe":0x8c7e78,
"Poison Green":0x40fd14,
"Poison Ivy":0x00ad43,
"Poison Purple":0x7f01fe,
"Poisonberry":0x73403e,
"Poisoning Green":0x66ff11,
"Poisonous":0x55ff11,
"Poisonous Apple":0x993333,
"Poisonous Dart":0x77ff66,
"Poisonous Ice Cream":0xd7d927,
"Poisonous Pesticide":0x32cd32,
"Poisonous Purple":0x2a0134,
"Poker Green":0x35654d,
"Polar":0xe5f2e7,
"Polar Bear":0xeae9e0,
"Polar Blue":0xb3e0e7,
"Polar Drift":0xccd5da,
"Polar Expedition":0xc9e7e3,
"Polar Fox":0xd2d0c9,
"Polar Ice":0x71a6d2,
"Polar Mist":0xadafbd,
"Polar Pond":0x6b7b7b,
"Polar Soft Blue":0xd0dcde,
"Polar White":0xe6efec,
"Polar Wind":0xb4dfed,
"Polaris":0xa0aead,
"Polaris Blue":0x6f8a8c,
"Polenta":0xefc47f,
"Police Blue":0x374f6b,
"Polignac":0xc28799,
"Polished":0xded8ce,
"Polished Apple":0x862a2e,
"Polished Aqua":0x77bcb6,
"Polished Bronze":0xcd7f32,
"Polished Brown":0x985538,
"Polished Concrete":0x9e9793,
"Polished Copper":0xb66325,
"Polished Cotton":0xc7d4d7,
"Polished Garnet":0x953640,
"Polished Gold":0xeeaa55,
"Polished Leather":0x4f4041,
"Polished Limestone":0xdcd5c8,
"Polished Mahogany":0x432722,
"Polished Marble":0xd0bc9d,
"Polished Metal":0x819ab1,
"Polished Pearl":0xf8edd3,
"Polished Pewter":0x9c9a99,
"Polished Pine":0x5da493,
"Polished Pink":0xfff2ef,
"Polished Rock":0xbcc3c2,
"Polished Silver":0xc5d1da,
"Polished Steel":0x6f828a,
"Polished Stone":0xbeb49e,
"Polite White":0xe9ddd4,
"Polka Dot Plum":0x5a4458,
"Polka Dot Skirt":0xfde2a0,
"Pollen":0xeeeeaa,
"Pollen Grains":0xf0c588,
"Pollen Powder":0xfbd187,
"Pollen Storm":0xb8a02a,
"Pollinate":0xe3d6bc,
"Pollination":0xeedd66,
"Polly":0xffcaa4,
"Polo Blue":0x8aa7cc,
"Polo Pony":0xd09258,
"Polo Tan":0xf4e5dd,
"Polvo de Oro":0xe8b87f,
"Polyanthus Narcissus":0xfeffcc,
"Polypropylene":0xeaeae8,
"Pomace Red":0x856f76,
"Pomegranate":0xc35550,
"Pomegranate Red":0xb53d45,
"Pomegranate Tea":0xab6f73,
"Pomelo Red":0xe38fac,
"Pomelo Sugar":0xfce8e3,
"Pomodoro":0xc30232,
"Pomodoro e Mozzarella":0xf2d4df,
"Pomp and Power":0x87608e,
"Pompadour":0x6a1f44,
"Pompeian Pink":0xc87763,
"Pompeian Red":0xa4292e,
"Pompeii Ash":0x6c757d,
"Pompeii Blue":0x004c71,
"Pompeii Red":0xd1462c,
"Pompeii Ruins":0x5e615b,
"Pompeius Blue":0x77a8ab,
"Pompelmo":0xff6666,
"Pomtini":0xca93c1,
"Ponceau":0xf75c75,
"Poncho":0xb49073,
"Pond Bath":0x00827f,
"Pond Blue":0x8bb6c6,
"Pond Green":0xa18e6b,
"Pond Moss":0x01796f,
"Pond Newt":0x486b67,
"Pond's Edge":0xb6c9b8,
"Ponder":0xb88f88,
"Ponderosa Pine":0x203b3d,
"Pondscape":0xd7efde,
"Pont Moss":0x5f9228,
"Pontoon":0x0c608e,
"Pony":0xc6aa81,
"Pony Express":0x726a60,
"Pony Tail":0xd2bc9b,
"Ponzu Brown":0x220000,
"Poodle Pink":0xeecee6,
"Poodle Skirt":0xffaebb,
"Poodle Skirt Peach":0xea927a,
"Pookie Bear":0x824b2e,
"Pool Bar":0x8fabbd,
"Pool Blue":0x67bcb3,
"Pool Floor":0x7daee1,
"Pool Green":0x00af9d,
"Pool Party":0xbee9e3,
"Pool Side":0xaad5d9,
"Pool Tide":0x70928e,
"Pool Tiles":0x89cff0,
"Pool Water":0x2188ff,
"Poolhouse":0x8095a0,
"Pop Shop":0x93d4c0,
"Popcorn":0xf8de8d,
"Popcorn Ball":0xfcebd1,
"Poplar":0xa29f46,
"Poplar Kitten":0xece9e9,
"Poplar White":0xdfe3d8,
"Poppy Crepe":0xfbe9d8,
"Poppy Flower":0xec5800,
"Poppy Glow":0xf18c49,
"Poppy Leaf":0x88a496,
"Poppy Petal":0xf6a08c,
"Poppy Pods":0x736157,
"Poppy Pompadour":0x6b3fa0,
"Poppy Power":0xed2939,
"Poppy Prose":0xae605b,
"Poppy Red":0xdc343b,
"Poppy Seed":0x4a4e54,
"Poppy Surprise":0xff5630,
"Poppy's Whiskers":0xccd7df,
"Popstar":0xbe4f62,
"Popular Gray":0xd4ccc3,
"Porcelain":0xdddcdb,
"Porcelain Basin":0xd9d0c4,
"Porcelain Blue":0x95c0cb,
"Porcelain Crab":0xe9b7a8,
"Porcelain Earth":0xeeffbb,
"Porcelain Figurines":0xa9998c,
"Porcelain Goldfish":0xe1dad9,
"Porcelain Green":0x108780,
"Porcelain Jasper":0xdfe2e4,
"Porcelain Mint":0xdbe7e1,
"Porcelain Mold":0xebe8e2,
"Porcelain Peach":0xf5d8ba,
"Porcelain Pink":0xecd9b9,
"Porcelain Rose":0xea6b6a,
"Porcelain Skin":0xffe7eb,
"Porcelain Tan":0xf7d8c4,
"Porcelain Yellow":0xfddda7,
"Porcellana":0xffbfab,
"Porch Ceiling":0xa4b3b9,
"Porch Song":0x566f8c,
"Porch Swing":0x597175,
"Porch Swing Beige":0xd2cabe,
"Porchetta Crust":0xaa8736,
"Porcini":0xcca580,
"Porcupine Needles":0x917a75,
"Pork Belly":0xf8e0e7,
"Porous Stone":0xd4cebf,
"Porpita Porpita":0x2792c3,
"Porpoise":0xdbdbda,
"Porpoise Fin":0xc8cbcd,
"Porpoise Place":0x076a7e,
"Porsche":0xdf9d5b,
"Port":0x663336,
"Port Au Prince":0x006a93,
"Port Glow":0x54383b,
"Port Gore":0x3b436c,
"Port Hope":0x54c3c1,
"Port Malmesbury":0x0e4d4e,
"Port Royale":0x502b33,
"Port Wine":0xa17a83,
"Port Wine Red":0x85707c,
"Port Wine Stain":0x85677b,
"Portabella":0x937b6a,
"Portabello":0x947a62,
"Portage":0x8b98d8,
"Portal Entrance":0xf8f6da,
"Portica":0xf0d555,
"Portico":0xbbab95,
"Portland Orange":0xff5a36,
"Portobello":0xa28c82,
"Portobello Mushroom":0x9d928a,
"Portofino":0xf4f09b,
"Portrait Pink":0xc6b4a9,
"Portrait Tone":0xc4957a,
"Portsmouth":0x768482,
"Portsmouth Bay":0xa1adad,
"Portsmouth Blue":0x5b7074,
"Portsmouth Olive":0x6b6b44,
"Portsmouth Spice":0xa75546,
"Portuguese Blue":0x3c5e95,
"Portuguese Dawn":0xc48f85,
"Portuguese Green":0x717910,
"Poseidon":0x123955,
"Poseidon Jr.":0x66eeee,
"Poseidon's Beard":0xd9d6c7,
"Poseidon's Territory":0x4400ee,
"Posey Blue":0xa5b4c6,
"Posies":0xdfbbd9,
"Positive Energy":0xe1e2cf,
"Positive Red":0xad2c34,
"Positively Palm":0x76745d,
"Positively Pink":0xe7bfb6,
"Possessed Plum":0x773355,
"Possessed Purple":0x881166,
"Possessed Red":0xc2264d,
"Possibly Pink":0xf3dace,
"Post Apocalyptic Cloud":0xc8cdd8,
"Post Boy":0x7a99ad,
"Post It":0x0074b4,
"Post Yellow":0xffee01,
"Poster Blue":0x134682,
"Poster Green":0x006b56,
"Poster Yellow":0xecc100,
"Postmodern Mauve":0xb39c8e,
"Posture & Pose":0xc7c4cd,
"Postwar Boom":0x466f97,
"Posy":0xf3e1d3,
"Posy Green":0x325b51,
"Posy Petal":0xf3879c,
"Pot Black":0x161616,
"Pot of Cream":0xf9f4e6,
"Potash":0xe07757,
"Potato Chip":0xfddc57,
"Potent Purple":0x462639,
"Potentially Purple":0xd5cde3,
"Potpourri":0xf1e0db,
"Potted Plant":0x9ecca7,
"Potter's Clay":0x9e4624,
"Potter's Pink":0xc2937b,
"Potters Pot":0x845c40,
"Pottery Blue":0x54a6c2,
"Pottery Clay":0xb9714a,
"Pottery Red":0xb05d59,
"Pottery Urn":0xaa866e,
"Pottery Wheel":0xcaac91,
"Potting Moss":0xa0a089,
"Potting Soil":0x54392d,
"Poudretteite Pink":0xe68e96,
"Pound Cake":0xfdf1c3,
"Pound Sterling":0x818081,
"Pouring Copper":0xfb9b82,
"Pout":0xe4ccc3,
"Pout Pink":0xff82ce,
"Pouty Purple":0xe7d7ef,
"Powder Ash":0xbcc9c2,
"Powder Blue":0xb0e0e6,
"Powder Cake":0xdfd7ca,
"Powder Dust":0xb7b7bc,
"Powder Lilac":0xbfc2ce,
"Powder Mill":0x9cb3b5,
"Powder Pink":0xfdd6e5,
"Powder Puff":0xffeff3,
"Powder Puff Pink":0xffcebe,
"Powder Red":0x95396a,
"Powder Room":0xa14d52,
"Powder Rose":0xf5b3bc,
"Powder Sand":0xf7f1dd,
"Powder Soft Blue":0xb9c9d7,
"Powder Viola":0xcbc2d3,
"Powder Viola White":0xd9d3e5,
"Powdered":0xf9f2e7,
"Powdered Allspice":0xc9ab9a,
"Powdered Blush":0xf8dcdb,
"Powdered Brick":0xac9b9b,
"Powdered Cocoa":0x341c02,
"Powdered Coffee":0xa0450e,
"Powdered Gold":0xe8d2b1,
"Powdered Granite":0xc3c9e6,
"Powdered Green Tea":0xc5c56a,
"Powdered Gum":0xa0b0a4,
"Powdered Peach":0xfde2d1,
"Powdered Petals":0xe3c7c6,
"Powdered Pool":0xc7d6d0,
"Powdered Snow":0xf8f4e6,
"Powdery Mist":0xe4e0eb,
"Power Grey":0xa2a4a6,
"Power Lunch":0xd4d1c7,
"Power Outage":0x332244,
"Power Peony":0xee5588,
"Powered Rock":0xbbb7ab,
"Powerful Mauve":0x4c3f5d,
"Powerful Violet":0x372252,
"Practical Beige":0xc9b29c,
"Practical Tan":0xe1cbb6,
"Practice Green":0x679a7c,
"Pragmatic":0xc2a593,
"Prairie Clay":0x935444,
"Prairie Denim":0x516678,
"Prairie Dog":0x937067,
"Prairie Dune":0xfbd5bd,
"Prairie Dusk":0xcec5ad,
"Prairie Dust":0xb9ab8f,
"Prairie Fire":0x996e5a,
"Prairie Grass":0xb1a38e,
"Prairie Green":0x50a400,
"Prairie Grove":0x8e7d5d,
"Prairie House":0xd3c9ad,
"Prairie Land":0xe2cc9c,
"Prairie Poppy":0xae5f55,
"Prairie Rose":0xf2c8be,
"Prairie Sage":0xb3a98c,
"Prairie Sand":0x883c32,
"Prairie Sky":0xc6d7e0,
"Prairie Sun":0xeea372,
"Prairie Sunset":0xffbb9e,
"Prairie Winds":0xe8e6d9,
"Praise Giving":0xb2b1ae,
"Praise of Shadow":0x221155,
"Praise the Sun":0xf3f4d9,
"Praline":0xad8b75,
"Prancer":0xc58380,
"Praxeti White":0x01b44c,
"Prayer Flag":0xd59c6a,
"Praying Mantis":0xa5be8f,
"Pre School":0xb5c2cd,
"Pre-Raphaelite":0x8b7f7a,
"Precious Blue":0x008389,
"Precious Copper":0x885522,
"Precious Dewdrop":0xf5f5e4,
"Precious Emerald":0x186e50,
"Precious Garnet":0xb7757c,
"Precious Nectar":0xffde9c,
"Precious Oxley":0x6d9a79,
"Precious Pearls":0xf1f0ef,
"Precious Peony":0xbd4048,
"Precious Persimmon":0xff7744,
"Precious Pink":0xf6b5b6,
"Precious Pumpkin":0xe16233,
"Precious Stone":0x328696,
"Precision":0x2c3944,
"Precocious Red":0xe8dee3,
"Predictable":0xe5dbcb,
"Prediction":0x6d6e7b,
"Prefect":0x5772b0,
"Prehistoric Meteor":0xee2211,
"Prehistoric Stone":0x9aa0a3,
"Prehnite Yellow":0xd0a700,
"Prelude":0xdfebee,
"Prelude to Pink":0xe1deda,
"Premium Pink":0xe6b6be,
"Preppy Rose":0xd1668f,
"Preservation Plum":0x665864,
"Preserve":0x4a3c50,
"Preserved Petals":0xb0655a,
"Presidential":0x3e4d59,
"Presidio Peach":0xec9580,
"Presidio Plaza":0xbb9174,
"Presley Purple":0x634875,
"Press Agent":0x606b77,
"Pressed Blossoms":0xc2968b,
"Pressed Flower":0xd492bd,
"Pressed Laser Lemon":0xfefe22,
"Pressing my Luck":0x00cc11,
"Prestige":0xb8a7a0,
"Prestige Blue":0x303742,
"Prestige Green":0x154647,
"Prestige Mauve":0x4c213d,
"Presumption":0x5e6277,
"Pretentious Peacock":0x4444ff,
"Pretty in Pink":0xfabfe4,
"Pretty in Plum":0xcc5588,
"Pretty Lady":0xc3a1b6,
"Pretty Maiden":0x849457,
"Pretty Pale":0xe3c6d6,
"Pretty Parasol":0xac5d3e,
"Pretty Pastry":0xdfcdb2,
"Pretty Petunia":0xd6b7e2,
"Pretty Pink":0xebb3b2,
"Pretty Please":0xffccc8,
"Pretty Posie":0xbcbde4,
"Pretty Primrose":0xf5a994,
"Pretty Puce":0x7b6065,
"Priceless Coral":0xe5a68d,
"Priceless Purple":0x46373f,
"Prickly Pear Cactus":0x69916e,
"Prim":0xe2cdd5,
"Primal":0xcba792,
"Primal Blue":0x0081b5,
"Primal Green":0x11875d,
"Primal Red":0xa92b4f,
"Primary Blue":0x0804f9,
"Primavera":0x6fa77a,
"Prime Blue":0x0064a1,
"Prime Merchandise":0x92b979,
"Prime Pink":0xff8d86,
"Prime Purple":0x656293,
"Primitive":0x685e4e,
"Primitive Green":0xded6ac,
"Primitive Plum":0x663c55,
"Primo":0x7cbc6c,
"Primrose":0xd6859f,
"Primrose Garden":0xf3949b,
"Primrose Path":0xffe262,
"Primrose Pink":0xeed4d9,
"Primrose White":0xece4d0,
"Primrose Yellow":0xf6d155,
"Primula":0xca9fa5,
"Prince":0x4b384c,
"Prince Charming":0xcc2277,
"Prince Grey":0xa0adac,
"Prince Paris":0x9d7957,
"Prince Royal":0x60606f,
"Princely":0x7d4961,
"Princely Violet":0x6d5c7b,
"Princess Blue":0x00539c,
"Princess Blue Feather":0xcceeee,
"Princess Bride":0xf4c1c1,
"Princess Elle":0xf6e9ea,
"Princess Irene":0xeadbde,
"Princess Ivory":0xfaead5,
"Princess Kate":0x6599a4,
"Princess Peach":0xf878f8,
"Princess Perfume":0xff85cf,
"Princess Pink":0xdfb5b0,
"Princeton Orange":0xff8f00,
"Priory":0x756f54,
"Priscilla":0xf1d3da,
"Prism":0xaadccd,
"Prism Pink":0xf0a1bf,
"Prism Violet":0x53357d,
"Prismarine":0x117777,
"Prismatic Pearl":0xeae8dd,
"Prismatic Springs":0x005c77,
"Prison Jumpsuit":0xfdaa48,
"Pristine":0xf2e8da,
"Pristine Petal":0xd5e1e0,
"Private Black":0x4c4949,
"Private Eye":0x006e89,
"Private Jet":0x889db2,
"Private Tone":0x845469,
"Privilege Green":0x7a8775,
"Privileged":0xf3ead7,
"Privileged Elite":0x597695,
"Prize Winning Orchid":0xcc9dc6,
"Professor Plum":0x393540,
"Profound Mauve":0x40243d,
"Prom":0xdaa5aa,
"Prom Corsage":0xe7c3e7,
"Promenade":0xf8f6df,
"Prominent Blue":0x2b7da6,
"Prominent Pink":0xda9ec5,
"Promise Keeping":0xafc7e8,
"Prompt":0x5e7fb5,
"Proper Gray":0xada8a5,
"Proper Purple":0x59476b,
"Proper Temperature":0xede5c7,
"Property":0x4b5667,
"Prophetess":0xbe8b8f,
"Prophetic Purple":0x624f59,
"Prophetic Sea":0x818b9c,
"Prosciutto":0xe0b4a4,
"Prosecco":0xfad6a5,
"Prospect":0x62584b,
"Prosperity":0x915f66,
"Protégé Bronze":0x66543e,
"Protein High":0xff8866,
"Proton Red":0x840804,
"Protoss Pylon":0x00aaff,
"Provence":0x658dc6,
"Provence Blue":0x8a9c99,
"Provence Creme":0xffedcb,
"Provence Violet":0x827191,
"Provincial Blue":0x5c798e,
"Provincial Pink":0xf6e3da,
"Prudence":0xd4c6db,
"Prune":0x701c11,
"Prune Plum":0x211640,
"Prune Purple":0x5c3a4d,
"Prunelle":0x220878,
"Prunus Avium":0xdd4492,
"Prussian Blue":0x003366,
"Prussian Nights":0x0b085f,
"Prussian Plum":0x6f4b5c,
"Psychedelic Purple":0xdd00ff,
"Psychic":0x625981,
"Pú Táo Zǐ Purple":0xce5dae,
"Puce":0xcc8899,
"Puddle":0xc8b69e,
"Puddle Jumper":0x6a8389,
"Pueblo":0x6e3326,
"Pueblo Rose":0xe9786e,
"Pueblo Sand":0xe7c3a4,
"Pueblo White":0xe5dfcd,
"Puerto Rico":0x59baa3,
"Puff Dragon":0x635940,
"Puff Pastry Yellow":0xfccf8b,
"Puffball":0xccbfc9,
"Puffball Vapour":0xe2dadf,
"Puffins Bill":0xe95c20,
"Puffy Little Cloud":0xd7edea,
"Puissant Purple":0x7722cc,
"Pulled Taffy":0xf1d6bc,
"Pullman Brown":0x644117,
"Pullman Green":0x3b331c,
"Pulp":0xe18289,
"Pulsating Blue":0x01678d,
"Puma":0x96711c,
"Pumice":0xbac0b4,
"Pumice Grey":0x807375,
"Pumice Stone":0xcac2b9,
"Pumpernickel Brown":0x6c462d,
"Pumpkin":0xff7518,
"Pumpkin Bread":0xd27d46,
"Pumpkin Butter":0xcba077,
"Pumpkin Choco":0x8d2d13,
"Pumpkin Cream":0xe6c8a9,
"Pumpkin Drizzle":0xb96846,
"Pumpkin Essence":0xf7dac0,
"Pumpkin Green":0x286848,
"Pumpkin Green Black":0x183425,
"Pumpkin Hue":0xf6a379,
"Pumpkin Mousse":0xf2c3a7,
"Pumpkin Orange":0xfb7d07,
"Pumpkin Patch":0xd59466,
"Pumpkin Pie":0xe99e56,
"Pumpkin Seed":0xfffdd8,
"Pumpkin Skin":0xb1610b,
"Pumpkin Soup":0xe17701,
"Pumpkin Spice":0xa05c17,
"Pumpkin Toast":0xde9456,
"Pumpkin Yellow":0xe99a10,
"Punch":0xdc4333,
"Punch of Pink":0xb68692,
"Punch of Yellow":0xecd086,
"Punch Out Glove":0x6888fc,
"Punchit Purple":0x56414d,
"Punctuate":0x856b71,
"Punga":0x534931,
"Punk Rock Pink":0x8811ff,
"Punk Rock Purple":0xbb11aa,
"Punky Pink":0xb2485b,
"Puppeteers":0x79ccb3,
"Puppy":0xbcaea0,
"Puppy Love":0xe2babf,
"Pure Apple":0x6ab54b,
"Pure Beige":0xe9d0c4,
"Pure Black":0x595652,
"Pure Blue":0x0203e2,
"Pure Cashmere":0xada396,
"Pure Cyan":0x36bfa8,
"Pure Earth":0xa79480,
"Pure Frost":0xfaeae1,
"Pure Hedonist":0xff2255,
"Pure Laughter":0xfdf5ca,
"Pure Light Blue":0x036c91,
"Pure Mauve":0x6f5390,
"Pure Passion":0xb40039,
"Pure Purple":0x751973,
"Pure Red":0xd22d1d,
"Pure Turquoise":0x7abec2,
"Pure White":0xf8f8f2,
"Pure Zeal":0x615753,
"Purebred":0x67707d,
"Pureed Pumpkin":0xc34121,
"Purehearted":0xe66771,
"Purification":0xc3dce9,
"Puritan Grey":0xa8b0ae,
"Purity":0xd7c9e3,
"Purple":0x800080,
"Purple Agate":0x988eb4,
"Purple Amethyst":0x9190ba,
"Purple Anemone":0x8866ff,
"Purple Anxiety":0xc20078,
"Purple Ash":0x8f8395,
"Purple Balance":0x9d9eb4,
"Purple Balloon":0x625b87,
"Purple Basil":0x5c4450,
"Purple Berry":0x4c4a74,
"Purple Blanket":0x4a455d,
"Purple Bloom":0x544258,
"Purple Blue":0x661aee,
"Purple Brown":0x673a3f,
"Purple Cabbage":0x3d34a5,
"Purple Chalk":0xc4adc9,
"Purple Climax":0x8800ff,
"Purple Comet":0x6e6970,
"Purple Corallite":0x5a4e8f,
"Purple Cort":0x593c50,
"Purple Cream":0xd7cbd7,
"Purple Crystal":0xe7e7eb,
"Purple Daze":0x63647e,
"Purple Door":0x331144,
"Purple Dove":0x98878c,
"Purple Dragon":0xc6bedd,
"Purple Dreamer":0x660066,
"Purple Dusk":0x7c6b76,
"Purple Emperor":0x6633bb,
"Purple Empire":0x5a4d55,
"Purple Emulsion":0xeadce2,
"Purple Essence":0xc2b1c8,
"Purple Feather":0x594670,
"Purple Gladiola":0xc1abd4,
"Purple Grapes":0x736993,
"Purple Grey":0x866f85,
"Purple Gumball":0x6a6283,
"Purple Gumdrop":0x7a596f,
"Purple Haze":0x807396,
"Purple Heart":0x69359c,
"Purple Heart Kiwi":0xcc2288,
"Purple Heather":0xbab8d3,
"Purple Hedonist":0xaa66ff,
"Purple Hepatica":0xccaaff,
"Purple Hollyhock":0xd96cad,
"Purple Honeycreeper":0x8855ff,
"Purple Hyacinth":0x6e8fc0,
"Purple Illusion":0xb8b8f8,
"Purple Illusionist":0xa675fe,
"Purple Impression":0x858fb1,
"Purple Ink":0x9a2ca0,
"Purple Kasbah":0x73626f,
"Purple Kite":0x512c31,
"Purple Kush":0xcc77cc,
"Purple Lepidolite":0xb88aac,
"Purple Magic":0x663271,
"Purple Mauve":0x9a8891,
"Purple Mountain Majesty":0x7a70a8,
"Purple Mountains Majesty":0x9678b6,
"Purple Mountains’ Majesty":0x9d81ba,
"Purple Mystery":0x815989,
"Purple Navy":0x4e5180,
"Purple Noir":0x322c56,
"Purple Odyssey":0x643e65,
"Purple Opulence":0x60569a,
"Purple Orchid":0xad4d8c,
"Purple Paradise":0x79669d,
"Purple Passage":0x645e77,
"Purple Passion":0x683d62,
"Purple Pennant":0x432c47,
"Purple People Eater":0x5b4763,
"Purple Peril":0x903f75,
"Purple Pink":0xc83cb9,
"Purple Pirate":0xbb00aa,
"Purple Pizzazz":0xfe4eda,
"Purple Pj's":0xc7cee8,
"Purple Plum":0x9c51b6,
"Purple Plumeria":0x473854,
"Purple Poodle":0xdab4cc,
"Purple Pool":0x4c4976,
"Purple Potion":0xaa00aa,
"Purple Premiere":0xb9a0d2,
"Purple Pride":0xa274b5,
"Purple Prince":0x5b4d54,
"Purple Prophet":0xbb9eca,
"Purple Prose":0x554348,
"Purple Protest":0x8822dd,
"Purple Punch":0x696374,
"Purple Purity":0xc9c6df,
"Purple Ragwort":0x8c8798,
"Purple Rain":0x7442c8,
"Purple Red":0x990147,
"Purple Reign":0x56456b,
"Purple Rhapsody":0x8278ad,
"Purple Rose":0xb09fca,
"Purple Rubiate":0x8b7880,
"Purple Sage":0x75697e,
"Purple Sand":0xc2b2f0,
"Purple Sapphire":0x6f4685,
"Purple Shade":0x4e2e53,
"Purple Shine":0xc8bad4,
"Purple Silhouette":0x776d90,
"Purple Sky":0x62547e,
"Purple Snail":0xcc69e4,
"Purple Sphinx":0x563948,
"Purple Spire":0x746f9d,
"Purple Spot":0x652dc1,
"Purple Springs":0xab9bbc,
"Purple Squid":0x845998,
"Purple Starburst":0xb16d90,
"Purple Statement":0x6e5755,
"Purple Statice":0xa885b5,
"Purple Stiletto":0x624154,
"Purple Stone":0x605467,
"Purple Surf":0x9b95a9,
"Purple Tanzanite":0x835995,
"Purple Taupe":0x50404d,
"Purple Thorn":0xf0b9be,
"Purple Tone Ink":0xa22da4,
"Purple Trinket":0x665261,
"Purple Urn Orchid":0xc364c5,
"Purple Vanity":0x9932cc,
"Purple Veil":0xd3d5e0,
"Purple Velvet":0x41354d,
"Purple Verbena":0x46354b,
"Purple Vision":0xa29cc8,
"Purple Void":0x442244,
"Purple White":0xd3c2cf,
"Purple Wine":0x8c3573,
"Purple Wineberry":0x5a395b,
"Purple Zergling":0xa15589,
"Purple's Baby Sister":0xeec3ee,
"Purplish":0x98568d,
"Purplish Blue":0x6140ef,
"Purplish Brown":0x6b4247,
"Purplish Grey":0x7a687f,
"Purplish Pink":0xdf4ec8,
"Purplish Red":0xb0054b,
"Purplish White":0xdfd3e3,
"Purplue":0x5e0dc2,
"Purposeful":0x776c76,
"Purpura":0x8d8485,
"Purpureus":0x9a4eae,
"Purpurite Red":0x864480,
"Purpurite Violet":0x57385e,
"Purri Sticks":0x898078,
"Purslane":0x879f6c,
"Pussy Foot":0xcebada,
"Pussywillow":0xb2ada4,
"Pussywillow Grey":0xaeaca1,
"Put on Ice":0xc8ddea,
"Putnam Plum":0x8d4362,
"Putrid Green":0x89a572,
"Putting Bench":0xf1e4c9,
"Putting Green":0x3a9234,
"Putty":0xcdae70,
"Putty Grey":0xbda89c,
"Putty Pearl":0xa99891,
"Putty Yellow":0x9d8e7f,
"Puturple":0xada2ce,
"Puyo Blob Green":0x55ff55,
"Pygmy Goat":0xd6d0cf,
"Pyjama Blue":0x6299aa,
"Pylon":0x9fbadf,
"Pyramid":0x9f7d4f,
"Pyramid Gold":0xe5b572,
"Pyrite Gold":0xac9362,
"Pyrite Green":0x3a6364,
"Pyrite Slate Green":0x867452,
"Python Blue":0x3776ab,
"Python Yellow":0xffd343,
"Qahvei Brown":0x7b5804,
"Qermez Red":0xcf3c71,
"Qiān Hūi Grey":0x89a0b0,
"Qing Dynasty Dragon":0x4455ee,
"Qing Dynasty Fire":0xdd2266,
"Qing Yellow":0xffcc66,
"Quack Quack":0xffe989,
"Quagmire Green":0x998811,
"Quail":0x98868c,
"Quail Ridge":0xaca397,
"Quail Valley":0xab9673,
"Quaint Peche":0xeacdc1,
"Quaking Grass":0xbbc6a4,
"Quantum Blue":0x6e799b,
"Quantum Green":0x7c948b,
"Quantum of Light":0x130173,
"Quark White":0xe7f1e6,
"Quarried Limestone":0xebe6d5,
"Quarry":0x98a0a5,
"Quarry Quartz":0xaf9a91,
"Quarter Pearl Lusta":0xf2eddd,
"Quarter Spanish White":0xebe2d2,
"Quarterdeck":0x1272a3,
"Quartersawn Oak":0x85695b,
"Quartz":0xd9d9f3,
"Quartz Green":0x6e7c45,
"Quartz Pink":0xefa6aa,
"Quartz Sand":0xa9aaab,
"Quartz Stone":0xe8e8e5,
"Quartz White":0xf3e8e1,
"Quartzite":0x232e26,
"Quarzo":0xc7d0da,
"Quaver":0xbed3cb,
"Queen Anne Lilac":0xc0b6b4,
"Queen Anne's Lace":0xf2eede,
"Queen Blue":0x436b95,
"Queen Conch Shell":0xe8bc95,
"Queen Lioness":0x77613d,
"Queen of Hearts":0x98333a,
"Queen of Sheba":0x817699,
"Queen of the Night":0x295776,
"Queen Palm":0xad9e4b,
"Queen Pink":0xe8ccd7,
"Queen Valley":0x6c7068,
"Queen's":0x7b6fa0,
"Queen's Honour":0x8b5776,
"Queen's Rose":0x753a40,
"Queen's Tart":0xd3bcc5,
"Queen's Violet":0xcdb9c4,
"Queenly":0xd3acce,
"Queenly Laugh":0xf9ecd0,
"Queer Blue":0x88ace0,
"Queer Purple":0xb36ff6,
"Quench Blue":0xb4e0e7,
"Quest":0xbdc1c1,
"Quest Gray":0xada5a5,
"Question Mark Block":0xef9a49,
"Quetzal Green":0x006865,
"Quibble":0xb393c0,
"Quiche Lorraine":0xfed56f,
"Quicksand":0xac9884,
"Quicksilver":0xa6a6a6,
"Quiet Bay":0x6597cc,
"Quiet Drizzle":0xb7d0c5,
"Quiet Green":0x9ebc97,
"Quiet Grey":0xb9babd,
"Quiet Harbour":0x5a789a,
"Quiet Moment":0x96aeb0,
"Quiet Night":0x3e8fbc,
"Quiet on the Set":0xe4e2dd,
"Quiet Peace":0x3a4a64,
"Quiet Pink":0xdba39a,
"Quiet Pond":0x94d8e2,
"Quiet Rain":0xe7efcf,
"Quiet Refuge":0xb69c97,
"Quiet Shade":0x66676d,
"Quiet Shore":0xf5ebd6,
"Quiet Splendor":0xfae6ca,
"Quiet Storm":0x2f596d,
"Quiet Teal":0xa9bab1,
"Quiet Time":0xb8bcb8,
"Quiet Veranda":0xebd2a7,
"Quiet Whisper":0xf1f3e8,
"Quietude":0xadbbb2,
"Quill Grey":0xcbc9c0,
"Quill Tip":0x2d3359,
"Quills of Terico":0x612741,
"Quilotoa Blue":0x7f9daf,
"Quilotoa Green":0x70a38d,
"Quilt":0xfcd9c6,
"Quilt Gold":0xeac365,
"Quinacridone Magenta":0x8e3a59,
"Quince":0xd4cb60,
"Quince Jelly":0xf89330,
"Quincy":0x6a5445,
"Quincy Granite":0xb5b5af,
"Quinoa":0xf9ecd1,
"Quinoline Yellow":0xf5e326,
"Quintana":0x008ca9,
"Quintessential":0xc2dbc6,
"Quite Coral":0xc76356,
"Quithayran Green":0x9be510,
"Quiver":0x886037,
"Quiver Tan":0x8e7f6a,
"Quixotic":0x948491,
"Quixotic Plum":0x4a4653,
"Rabbit":0x5f575c,
"Rabbit Paws":0x885d62,
"Rabbit-Ear Iris":0x491e3c,
"Raccoon Tail":0x735e56,
"Race Car Stripe":0xcf4944,
"Race the Sun":0xeef3d0,
"Race Track":0xcbbeb5,
"Rachel Pink":0xe8b9ae,
"Racing Green":0x014600,
"Racing Red":0xbd162c,
"Rackham Red":0xd6341e,
"Rackley":0x5d8aaa,
"Racoon Eyes":0x776a3c,
"Radar":0xb6c8e4,
"Radar Blip Green":0x96f97b,
"Radiance":0xbb9157,
"Radiant Dawn":0xece2ce,
"Radiant Glow":0xffeed2,
"Radiant Lilac":0xa489a0,
"Radiant Orchid":0xad5e99,
"Radiant Rose":0xeed5d4,
"Radiant Rouge":0xd7b1b2,
"Radiant Silver":0x8f979d,
"Radiant Sun":0xf0cc50,
"Radiant Sunrise":0xeebe1b,
"Radiant Yellow":0xfc9e21,
"Radiation Carrot":0xffa343,
"Radical Green":0x326a2b,
"Radical Red":0xff355e,
"Radicchio":0x745166,
"Radioactive":0x89fe05,
"Radioactive Eggplant":0xf9006f,
"Radioactive Green":0x2cfa1f,
"Radioactive Lilypad":0x66dd00,
"Radish":0xa42e41,
"Radish Lips":0xee3355,
"Radisson":0xe5e7e6,
"Radium":0x7fff00,
"Radler":0xffd15c,
"Radome Tan":0xf1c7a1,
"Raffia":0xdcc6a0,
"Raffia Cream":0xcda09a,
"Raffia Greige":0xb3a996,
"Raffia Light Grey":0xcbd9d8,
"Raffia Ribbon":0xcbb08c,
"Raffia White":0xeeeee3,
"Raffles Tan":0xca9a5d,
"Raftsman":0x3c5f9b,
"Rage":0xff1133,
"Rage of Quel'Danas":0xf32507,
"Ragin' Cajun":0x8d514c,
"Raging Bull":0xb54e45,
"Raging Leaf":0xdd5500,
"Raging Raisin":0xaa3333,
"Raging Sea":0x8d969e,
"Raging Tide":0x5187a0,
"Ragtime Blues":0x4a5e6c,
"Ragweed":0x7be892,
"Raichu Orange":0xf6ad3a,
"Raiden Blue":0x0056a8,
"Raiden's Fury":0xe34029,
"Railroad Ties":0x544540,
"Rain":0xabbebf,
"Rain Barrel":0x8b795f,
"Rain Boots":0x354d65,
"Rain Check":0xb6d5de,
"Rain Cloud":0x919fa1,
"Rain Dance":0xa9ccdb,
"Rain Drop":0xe7eee8,
"Rain Drum":0x5f4c40,
"Rain or Shine":0xb5dcea,
"Rain Shadow":0x677276,
"Rain Slicker":0xbca849,
"Rain Song":0xc5d5e9,
"Rain Storm":0x3e5964,
"Rain Washed":0xbed4d2,
"Rain Water":0xd6e5eb,
"Rainbow":0xf6bfbc,
"Rainbow Bright":0x2863ad,
"Rainbow Trout":0xff975c,
"Rainbow's Inner Rim":0xff09ff,
"Rainbow's Outer Rim":0xff0001,
"Raindance":0x819392,
"Raindrop":0x9ec6c6,
"Raindrops":0xece5e1,
"Rainee":0xb3c1b1,
"Rainford":0x759180,
"Rainforest":0x009a70,
"Rainforest Dew":0xe6dab1,
"Rainforest Fern":0xcec192,
"Rainforest Glow":0xb2c346,
"Rainforest Nights":0x002200,
"Rainforest Zipline":0x7f795f,
"Rainier Blue":0x558484,
"Rainmaker":0x485769,
"Rainmaster":0x9ca4a9,
"Rainsong":0xacbdb1,
"Rainstorm":0x244653,
"Rainwashed":0xc2cdc5,
"Rainwater":0x87d9d2,
"Rainy Afternoon":0x889a95,
"Rainy Day":0xcfc8bd,
"Rainy Grey":0xa5a5a5,
"Rainy Lake":0x3f6c8f,
"Rainy Morning":0x005566,
"Rainy Season":0xd1d8d6,
"Rainy Sidewalk":0x9bafbb,
"Rainy Week":0x99bbdd,
"Raisin":0x524144,
"Raisin Black":0x242124,
"Raisin in the Sun":0x78615c,
"Rajah":0xfbab60,
"Rajah Rose":0xe6d9e2,
"Raked Leaves":0x957d48,
"Rakuda Brown":0xbf794e,
"Rally Green":0x7ec083,
"Ramadi Grey":0xb7a9ac,
"Rambling Green":0x5a804f,
"Rambling Rose":0xd98899,
"Ramie":0xcdbda2,
"Ramjet":0x4c73af,
"Ramona":0x8f9a88,
"Rampant Rhubarb":0x603231,
"Rampart":0xbcb7b1,
"Ramsons":0x195456,
"Ranch Acres":0xf3e7cf,
"Ranch Brown":0x9e7454,
"Ranch House":0x7b645a,
"Ranch Mink":0x968379,
"Ranch Tan":0xc8b7a1,
"Rancho Verde":0xdfd8b3,
"Rand Moon":0xb7b7b4,
"Randall":0x756e60,
"Range Land":0x68bd56,
"Ranger Green":0x6a8472,
"Ranger Station":0x707651,
"Rangitoto":0x2e3222,
"Rangoon Green":0x2b2e25,
"Ranier White":0xf7ecd8,
"Ranunculus White":0xf5dde6,
"Rapakivi Granite":0xd28239,
"Rape Blossoms":0xffec47,
"Rapeseed":0xc19a13,
"Rapeseed Oil":0xa69425,
"Rapid Rock":0xa39281,
"Rapier Silver":0xd8dfda,
"Rapt":0x45363a,
"Rapture":0x114444,
"Rapture Blue":0xa7d6dd,
"Rapture Rose":0xd16277,
"Rapture's Light":0xf6f3e7,
"Rapunzel":0xf6d77f,
"Rapunzel Silver":0xd2d2d4,
"Rare Blue":0x0044ff,
"Rare Crystal":0xe1dee8,
"Rare Find":0xac8044,
"Rare Gray":0xa6a69b,
"Rare Happening":0x8daca0,
"Rare Orchid":0xdbdce2,
"Rare Red":0xdd1133,
"Rare Rhubarb":0xcc0022,
"Rare Turquoise":0x00748e,
"Rare White Jade":0xe8e9cc,
"Rare White Raven":0xe8dbdf,
"Rare Wind":0x55ffcc,
"Rare Wood":0x594c42,
"Rarified Air":0xe1e6e6,
"Raspberry":0xb00149,
"Raspberry Crush":0x875169,
"Raspberry Fool":0x8e3643,
"Raspberry Glace":0x915f6c,
"Raspberry Glaze":0xff77aa,
"Raspberry Ice":0xd9ccc7,
"Raspberry Ice Red":0x9f3753,
"Raspberry Jam":0xca3767,
"Raspberry Jelly Red":0x9b6287,
"Raspberry Kahlua":0xc9a196,
"Raspberry Leaf Green":0x044f3b,
"Raspberry Lemonade":0xe1aaaf,
"Raspberry Milk":0xebd2d1,
"Raspberry Mousse":0xe06f8b,
"Raspberry Parfait":0xb96482,
"Raspberry Patch":0xa34f66,
"Raspberry Pink":0xe25098,
"Raspberry Pudding":0x94435a,
"Raspberry Radiance":0x802a50,
"Raspberry Ripple":0xcd827d,
"Raspberry Rose":0xb3436c,
"Raspberry Smoothie":0xd0a1b4,
"Raspberry Sorbet":0xd2386c,
"Raspberry Truffle":0x8a5d55,
"Raspberry Whip":0xb3737f,
"Raspberry Wine":0xb63753,
"Raspberry Yogurt":0xe30b5d,
"Rat Brown":0x885f01,
"Rationality":0x6f6138,
"Ratskin Flesh":0xf7b273,
"Rattan":0xa58e61,
"Rattan Basket":0xa79069,
"Rattan Palm":0x8f876b,
"Rattlesnake":0x7f7667,
"Raucous Orange":0xc35530,
"Rave Raisin":0x54463f,
"Rave Red":0xa13b34,
"Rave Regatta":0x00619d,
"Raven":0x6f747b,
"Raven Black":0x3d3d3d,
"Raven Night":0x3b3f66,
"Raven's Banquet":0xbb2255,
"Raven's Coat":0x030205,
"Ravine":0xd3cec7,
"Ravioli al Limone":0xfade79,
"Ravishing Coral":0xe79580,
"Ravishing Rouge":0xbb2200,
"Raw Alabaster":0xf2eed3,
"Raw Amethyst":0x544173,
"Raw Cashew Nut":0xc8beb1,
"Raw Chocolate":0x662200,
"Raw Cinnabar":0x7d403b,
"Raw Copper":0xc46b51,
"Raw Cotton":0xe3d4bb,
"Raw Garnet Viola":0x8b6c7e,
"Raw Linen":0xcc8844,
"Raw Sienna":0x9a6200,
"Raw Sugar":0xd8cab2,
"Raw Sunset":0xf95d2d,
"Raw Umber":0xa75e09,
"Rawhide":0x865e49,
"Rawhide Canoe":0x7a643f,
"Ray of Light":0xfdf2c0,
"Rayo de Sol":0xf4c454,
"Razee":0x7197cb,
"Razzberries":0xd1768c,
"Razzberry Fizz":0xe1d5d4,
"Razzle Dazzle":0xba417b,
"Razzle Dazzle Rose":0xff33cc,
"Razzmatazz":0xe30b5c,
"Razzmatazz Lips":0xe3256b,
"Razzmic Berry":0x8d4e85,
"Rè Dài Chéng Orange":0xf08101,
"Reading Tea Leaves":0x7d5d5e,
"Ready Lawn":0x7ba570,
"Real Brown":0x563d2d,
"Real Cork":0xc1a17f,
"Real Mccoy":0x00577e,
"Real Raspberry":0xdd79a2,
"Real Red":0xa90308,
"Real Simple":0xccb896,
"Real Teal":0x405d73,
"Real Turquoise":0x008a4c,
"Realist Beige":0xd3c8bd,
"Really Light Green":0xe9eadb,
"Really Rain":0xe8ecdb,
"Really Teal":0x016367,
"Realm":0x796c70,
"Realm of the Underworld":0x114411,
"Rebecca Purple":0x663399,
"Rebel":0x453430,
"Rebel Red":0xcd4035,
"Rebel Rouser":0x9b7697,
"Rebellion Red":0xcc0404,
"Reboot":0x28a8cd,
"Rebounder":0xbad56b,
"Receding Night":0x4a4e5c,
"Reclaimed Wood":0xbab6ab,
"Reclining Green":0xb7d7bf,
"Recuperate":0xdecce4,
"Recycled":0xcdb6a0,
"Recycled Glass":0xb7c3b7,
"Red":0xff0000,
"Red Alert":0xff0f0f,
"Red Baron":0xbb0011,
"Red Bay":0x8e3738,
"Red Bean":0x3d0c02,
"Red Beech":0x7b3801,
"Red Bell Pepper":0xdd3300,
"Red Berry":0x701f28,
"Red Birch":0x9d2b22,
"Red Blood":0x660000,
"Red Blooded":0x8a3c38,
"Red Bluff":0x824e46,
"Red Brick":0x834841,
"Red Brown":0xa52a2f,
"Red Bud":0x962d49,
"Red Cabbage":0x534a77,
"Red Candle":0x833c3d,
"Red Card":0xff3322,
"Red Carpet":0xbc2026,
"Red Cedar":0xd87678,
"Red Cent":0xad654c,
"Red Chalk":0xed7777,
"Red Chipotle":0x834c3e,
"Red Clay":0x8f4b41,
"Red Clover":0xbb8580,
"Red Clown":0xd43e38,
"Red Contrast":0xb33234,
"Red Coral":0xc37469,
"Red Craft":0x91433e,
"Red Cray":0xe45e32,
"Red Crayon":0xee204d,
"Red Curry":0x8b5e52,
"Red Dahlia":0x7d2027,
"Red Damask":0xcb6f4a,
"Red Dead Redemption":0xbb012d,
"Red Devil":0x860111,
"Red Dit":0xff4500,
"Red Door":0xac0000,
"Red Dust":0xe8dedb,
"Red Earth":0xa2816e,
"Red Elegance":0x85464b,
"Red Emulsion":0xe9dbde,
"Red Endive":0x794d60,
"Red Epiphyllum":0xd00000,
"Red Flag":0xff2244,
"Red Gerbera":0xb07473,
"Red Gooseberry":0x604046,
"Red Gore":0xad1400,
"Red Gravel":0xb8866e,
"Red Grey":0x99686a,
"Red Gumball":0xac3a3e,
"Red Hawk":0x8a453b,
"Red Herring":0xdd1144,
"Red Hook":0x845544,
"Red Hot":0xdd0033,
"Red Hot Chili Pepper":0xdb1d27,
"Red Hot Jazz":0x773c31,
"Red Icon":0xc93543,
"Red Ink":0xac3235,
"Red Jalapeno":0xbf6153,
"Red Kite":0x913228,
"Red Knuckles":0xdd0011,
"Red Leather":0xab4d50,
"Red Leever":0x881400,
"Red Licorice":0xa83e4c,
"Red Light Neon":0xff0055,
"Red Lightning":0xd24b38,
"Red Lilac Purple":0xbfbac0,
"Red Mahogany":0x60373d,
"Red Mana":0xf95554,
"Red Mane":0x6d3d2a,
"Red Maple Leaf":0x834c4b,
"Red Menace":0xaa2121,
"Red Mull":0xff8888,
"Red Mulled Wine":0x880022,
"Red My Mind":0x994341,
"Red Obsession":0xb63731,
"Red Ochre":0x913832,
"Red October":0xfe2712,
"Red Octopus":0x773243,
"Red Onion":0x473442,
"Red Orange":0xff3f34,
"Red Orange Juice":0xff5349,
"Red Orpiment":0xcd6d57,
"Red Oxide":0x5d1f1e,
"Red Panda":0xc34b1b,
"Red Paracentrotus":0xbb0044,
"Red Pear":0x7b3539,
"Red Pegasus":0xdd0000,
"Red Pepper":0x7a3f38,
"Red Perfume":0xf6b894,
"Red Pigment":0xed1c24,
"Red Pines":0x72423f,
"Red Pink":0xfa2a55,
"Red Plum":0x7c2946,
"Red Potato":0x995d50,
"Red Potion":0xdd143d,
"Red Power":0xd63d3b,
"Red Prairie":0x8e3928,
"Red Prayer Flag":0xbb1100,
"Red Prickly Pear":0xd92849,
"Red Purple":0xe40078,
"Red Radish":0xee3344,
"Red Rampage":0xee3322,
"Red Red Red":0x91403d,
"Red Red Wine":0x814142,
"Red Remains":0xffe0de,
"Red Revival":0xa8453b,
"Red Ribbon":0xed0a3f,
"Red Riding Hood":0xfe2713,
"Red River":0xb95543,
"Red Robin":0x7d4138,
"Red Rock":0xa65052,
"Red Rock Falls":0xa27253,
"Red Rock Panorama":0xb29e9d,
"Red Rooster":0x7e5146,
"Red Rust":0x8a3319,
"Red Safflower":0xc53d43,
"Red Salsa":0xfd3a4a,
"Red Sandstorm":0xe5cac0,
"Red Savina Pepper":0xee0128,
"Red Shade Wash":0x862808,
"Red Shimmer":0xfee0da,
"Red Shrivel":0x874c62,
"Red Sparowes":0xc8756d,
"Red Stage":0xad522e,
"Red Stone":0x8d6b64,
"Red Stop":0xff2222,
"Red Tape":0xcc1133,
"Red Terra":0xae4930,
"Red Theatre":0x6e3637,
"Red Tolumnia Orchid":0xbe0119,
"Red Tomato":0xb1403a,
"Red Tone Ink":0x8b2e08,
"Red Tuna Fruit":0xb41b40,
"Red Velvet":0x783b38,
"Red Vine":0x5f383c,
"Red Violet":0x9e0168,
"Red Wattle Hog":0x765952,
"Red Willow":0x885a55,
"Red Wine":0x8c0034,
"Red Wine Vinegar":0x722f37,
"Red Wire":0xdb5947,
"Red Wrath":0xee1155,
"Red-Eye":0xdd1155,
"Red-Handed":0xdd2233,
"Red-Letter Day":0xcc0055,
"Red-Tailed-Hawk":0xa27547,
"Redalicious":0xbb2211,
"Redbox":0x94332f,
"Redbud":0xad5e65,
"Redcurrant":0x88455e,
"Reddened Earth":0x9c6e63,
"Reddest Red":0x9b4045,
"Reddish":0xc44240,
"Reddish Banana":0xffbb88,
"Reddish Black":0x433635,
"Reddish Brown":0x7f2b0a,
"Reddish Grey":0x997570,
"Reddish Orange":0xf8481c,
"Reddish Pink":0xfe2c54,
"Reddish Purple":0x910951,
"Reddish White":0xfff8d5,
"Reddy Brown":0x6e1005,
"Redend Point":0xae8e7e,
"Rediscover":0xc3cdc9,
"Redneck":0xf5d6d8,
"Redridge Brown":0x9d4e34,
"Redrock Canyon":0xa24d47,
"Redrum":0xff2200,
"Redstone":0xe46b71,
"Redtail":0xaf4544,
"Reduced Blue":0xd6dfec,
"Reduced Green":0xe7e9d8,
"Reduced Pink":0xf6e4e4,
"Reduced Red":0xefdedf,
"Reduced Sand":0xeee5da,
"Reduced Sky":0xd3eeec,
"Reduced Spearmint":0xdbe8df,
"Reduced Turquoise":0xdaece7,
"Reduced Yellow":0xf0ead7,
"Redwing":0x98010d,
"Redwood":0x5b342e,
"Redwood City":0xb45f56,
"Redwood Forest":0x916f5e,
"RedЯum":0xff0044,
"Reed":0xc3d3a8,
"Reed Bed":0xb0ad96,
"Reed Green":0xa1a14a,
"Reed Mace":0xcd5e3c,
"Reed Mace Brown":0x726250,
"Reed Yellow":0xdcc99e,
"Reeds":0xa0bca7,
"Reef":0x017371,
"Reef Blue":0x93bdcf,
"Reef Encounter":0x00968f,
"Reef Escape":0x0474ad,
"Reef Gold":0xa98d36,
"Reef Green":0xa5e1c4,
"Reef Refractions":0xd1ef9f,
"Reef Resort":0x274256,
"Reef Waters":0x6f9fa9,
"Refined Chianti":0x8c1b3c,
"Refined Green":0x384543,
"Refined Mint":0xf1f9ec,
"Refined Sand":0xc1b38c,
"Reflecting Pond":0x203e4a,
"Reflecting Pool":0xdcdfdc,
"Reflection":0xd3d5d3,
"Reflection Pool":0xcadbdf,
"Reform":0x8aaad6,
"Refresh":0xa1d4c8,
"Refreshed":0xcfe587,
"Refreshing Green":0x617a74,
"Refreshing Pool":0xb7e6e6,
"Refreshing Primer":0xd7fffe,
"Refreshing Tea":0xebdda6,
"Refrigerator Green":0xbadfcd,
"Refuge":0x607d84,
"Regal":0xdac2b3,
"Regal Azure":0x6a76af,
"Regal Blue":0x203f58,
"Regal Destiny":0x2e508a,
"Regal Gown":0x655777,
"Regal Orchid":0xa98baf,
"Regal Red":0x99484a,
"Regal Rose":0x9d7374,
"Regal View":0x749e8f,
"Regal Violet":0xa298a2,
"Regale Blue":0x7db5d3,
"Regalia":0x522d80,
"Regality":0x664480,
"Regatta":0x487ab7,
"Regatta Bay":0x2d5367,
"Regency Cream":0xe1bb87,
"Regency Rose":0xa78881,
"Regent Grey":0x798488,
"Regent St Blue":0xa0cdd9,
"Registra":0xc2bbbf,
"Registration Black":0x000200,
"Regula Barbara Blue":0x009999,
"Reign Over Me":0x76679e,
"Reikland Fleshshade":0xca6c4d,
"Reikland Fleshshade Gloss":0xcb7351,
"Reindeer":0xdac0ba,
"Reindeer Moss":0xbdf8a3,
"Rejuvenate":0xc4c7a5,
"Rejuvenation":0xa4a783,
"Relax":0xb9d2d3,
"Relaxation Green":0xa8d19e,
"Relaxed Blue":0x698a97,
"Relaxed Khaki":0xc8bba3,
"Relaxed Rhino":0xbbaaaa,
"Relaxing Blue":0x899daa,
"Relaxing Green":0xe0eadb,
"Relentless Olive":0x71713e,
"Reliable White":0xe8ded3,
"Relic":0x88789b,
"Relic Bronze":0x906a3a,
"Relief":0xbf2133,
"Relieved Red":0xe9dbdf,
"Reliquial Rose":0xff2288,
"Relish":0xb3cbaa,
"Remaining Embers":0x8a4c38,
"Rembrandt Ruby":0x974f49,
"Remembrance":0xca9e9c,
"Remington Rust":0xa25d4c,
"Remote Control":0x6d7a6a,
"Remy":0xf6deda,
"Renaissance":0x434257,
"Renaissance Rose":0x865560,
"Renanthera Orchid":0x820747,
"Rendezvous":0xabbed0,
"Renga Brick":0xb55233,
"Renkon Beige":0x989f7a,
"Rennie's Rose":0xb87f84,
"Reno Sand":0xb26e33,
"Renoir Bisque":0xdabe9f,
"Renwick Beige":0xc3b09d,
"Renwick Brown":0x504e47,
"Renwick Golden Oak":0x96724c,
"Renwick Heather":0x8b7d7b,
"Renwick Olive":0x97896a,
"Renwick Rose Beige":0xaf8871,
"Repose Gray":0xccc9c0,
"Reptile Green":0x24da91,
"Reptilian Green":0x009e82,
"Republican":0xde0100,
"Requiem":0x4e3f44,
"Requisite Gray":0xb9b2a9,
"Reseda":0xa1ad92,
"Reseda Green":0x75946b,
"Reservation":0x8c7544,
"Reserve":0xac8a98,
"Reserved Beige":0xe2e1d6,
"Reserved Blue":0xd2d8de,
"Reserved White":0xe0e0d9,
"Resolute Blue":0x85b0c4,
"Resolution Blue":0x002387,
"Resonant Blue":0x01a2c6,
"Resort Sunrise":0xf4d7c5,
"Resort Tan":0x907d66,
"Resort White":0xf4f1e4,
"Resounding Rose":0xcd8e89,
"Respite":0x97b4c3,
"Rest Assured":0x9bbfc9,
"Restful":0xbbbba4,
"Restful Brown":0x8c7e6f,
"Restful Rain":0xf1f2dd,
"Restful Retreat":0xb1c7c9,
"Restful White":0xeee8d7,
"Resting Place":0xbcc8be,
"Restless Sea":0x38515d,
"Restoration":0x939581,
"Restoration Ivory":0xe9e1ca,
"Restrained Gold":0xd2b084,
"Reticence":0xd9cdc3,
"Retina Soft Blue":0xb6c7e0,
"Retiring Blue":0xd5eae8,
"Retreat":0x7a8076,
"Retributor Armour Metal":0xc39e81,
"Retro":0x9bdc96,
"Retro Avocado":0x958d45,
"Retro Blue":0x2b62f4,
"Retro Mint":0x9fcdb1,
"Retro Nectarine":0xef7d16,
"Retro Orange":0xe85112,
"Retro Peach":0xe7c0ad,
"Retro Pink":0xb48286,
"Retro Vibe":0xcb9711,
"Revel Blue":0x4c6b8a,
"Revenant Brown":0xc59782,
"Revered":0xa78faf,
"Reverie Pink":0xf4e5e1,
"Reversed Grey":0x080808,
"Revival":0x5f81a4,
"Revival Mahogany":0x665043,
"Revival Red":0x7f4e47,
"Revival Rose":0xc09084,
"Reviving Green":0xe8e097,
"Revolver":0x37363f,
"Reynard":0xb46848,
"Rhapsody":0x9f86aa,
"Rhapsody In Blue":0x002244,
"Rhapsody Lilac":0xbabfdc,
"Rhapsody Rap":0x74676c,
"Rhind Papyrus":0x969565,
"Rhine Castle":0x5f5e5f,
"Rhine Falls":0xe3eadb,
"Rhine River Rose":0xab3560,
"Rhinestone":0x8e6c94,
"Rhino":0x3d4653,
"Rhinoceros":0x727a7c,
"Rhinoceros Beetle":0x440011,
"Rhinox Hide":0x493435,
"Rhode Island Red":0x9b5b55,
"Rhodes":0x89c0e6,
"Rhododendron":0x722b3f,
"Rhodonite Brown":0x4d4141,
"Rhubarb":0x77202f,
"Rhubarb Gin":0xd9a6c1,
"Rhubarb Leaf Green":0xbca872,
"Rhubarb Pie":0xd78187,
"Rhubarb Smoothie":0x8c474b,
"Rhumba Orange":0xcb7841,
"Rhynchites Nitens":0x383867,
"Rhys":0xbeceb4,
"Rhythm":0x767194,
"Rhythm & Blues":0x70767b,
"Rhythmic Blue":0xb8d5d7,
"Rialto":0x914d57,
"Ribbon Red":0xb92636,
"Rice Bowl":0xf1e7d5,
"Rice Cake":0xefecde,
"Rice Crackers":0xe0ccb6,
"Rice Curry":0xb2854a,
"Rice Fibre":0xe4d8ab,
"Rice Flower":0xeff5d1,
"Rice Grain":0xdbd0b9,
"Rice Paddy":0xdfd4b0,
"Rice Paper":0xfffcdb,
"Rice Pudding":0xfff0e3,
"Rice Wine":0xf5e7c8,
"Rich and Rare":0x977540,
"Rich Biscuit":0x948165,
"Rich Black":0x004040,
"Rich Blue":0x021bf9,
"Rich Bordeaux":0x514142,
"Rich Brilliant Lavender":0xf1a7fe,
"Rich Brocade":0x925850,
"Rich Brown":0x715e4f,
"Rich Carmine":0xd70041,
"Rich Cream":0xfaeac3,
"Rich Electric Blue":0x0892d0,
"Rich Gardenia":0xf57f4f,
"Rich Georgia Clay":0xde7a63,
"Rich Glow":0xffe8a0,
"Rich Gold":0xaa8833,
"Rich Green":0x218845,
"Rich Grey Turquoise":0x324943,
"Rich Honey":0xf9bc7d,
"Rich Ivory":0xfff0c4,
"Rich Lavender":0xa76bcf,
"Rich Lilac":0xb666d2,
"Rich Loam":0x583d37,
"Rich Mahogany":0x604944,
"Rich Maroon":0xb0306a,
"Rich Mocha":0x745342,
"Rich Oak":0xa7855a,
"Rich Olive":0x3e4740,
"Rich Pewter":0x6b7172,
"Rich Purple":0x720058,
"Rich Red":0xff1144,
"Rich Red Violet":0x7c3651,
"Rich Reward":0xb9a37f,
"Rich Taupe":0xb39c89,
"Rich Texture":0x645671,
"Rich Violet":0x50578b,
"Rich Walnut":0x7c5f4a,
"Richardson Brick":0x854c47,
"Rickrack":0xa6a660,
"Ricochet":0x817c74,
"Ride off into the Sunset":0xf3cf64,
"Ridge Light":0xb2c8dd,
"Ridge View":0xa3aab8,
"Ridgeback":0xef985c,
"Ridgecrest":0x9d8861,
"Riding Boots":0x734a35,
"Riding Star":0xa0a197,
"Riesling Grape":0xbfb065,
"Rifle Green":0x414833,
"Rigby Ridge":0xa0a082,
"Right as Rain":0xc0e1e4,
"Rikan Brown":0x534a32,
"Rikyū Brown":0x826b58,
"Rikyūnezumi Brown":0x656255,
"Rikyūshira Brown":0xb0927a,
"Rincon Cove":0xc7b39e,
"Ringlet":0xfbedbe,
"Rinse":0xd5d9dd,
"Rinsed-Out red":0xff7952,
"Rio Grande":0xb7c61a,
"Rio Red":0x8a2232,
"Rio Rust":0x926956,
"Rio Sky":0xcae1da,
"Rip Cord":0xdfab56,
"Rip Van Periwinkle":0x8fa4d2,
"Ripasso":0x774041,
"Ripe Berry":0x5c5666,
"Ripe Currant":0x8a3c3e,
"Ripe Eggplant":0x492d35,
"Ripe Fig":0x6a5254,
"Ripe Green":0x747a2c,
"Ripe Lemon":0xf4d81c,
"Ripe Malinka":0xf5576c,
"Ripe Mango":0xffc324,
"Ripe Melon":0xfebaad,
"Ripe Olive":0x44483d,
"Ripe Pear":0xe1e36e,
"Ripe Pineapple":0xffe07b,
"Ripe Plum":0x410056,
"Ripe Pumpkin":0xffaf37,
"Ripe Rhubarb":0x7e3947,
"Ripe Wheat":0xe3c494,
"Ripening Grape":0x6f3942,
"Ripple":0xd3dcdc,
"Rippled Rock":0xc4c5bc,
"Riptide":0x89d9c8,
"Rise and Shine":0xffe99e,
"Rise-N-Shine":0xffc632,
"Rising Ash":0x978888,
"Risotto":0xf8f5e9,
"Rita Repulsa":0x00aa55,
"Rita's Rouge":0xba7176,
"Rite of Spring":0xffeba9,
"Ritterlich Blue":0x293286,
"Ritual":0x767081,
"Ritual Experience":0x533844,
"Ritzy":0xd79c5f,
"River Bank":0x7e705e,
"River Blue":0x38afcd,
"River Clay":0xc7b5a9,
"River Forest":0x545b45,
"River Fountain":0x248591,
"River God":0x6c6c5f,
"River Mist":0xd6e1d4,
"River Mud":0xa08b71,
"River Pebble":0xa39c92,
"River Reed":0xdedbc4,
"River Road":0xae8d6b,
"River Rock":0xd8cdc4,
"River Rocks":0x7e645d,
"River Rouge":0xec9b9d,
"River Shark":0xdfdcd5,
"River Styx":0x161820,
"River Tour":0x848b99,
"River Valley":0x94a5b7,
"River Veil":0xd9e0de,
"Riverbed":0x556061,
"Riverdale":0xbec5ba,
"Rivergrass":0x84a27b,
"Rivers Edge":0xafd9d7,
"Riverside":0x4c6a92,
"Riverside Blue":0x6cb4c3,
"Riverway":0x5d7274,
"Riveter Rose":0xb7a9a2,
"Riviera":0x189fac,
"Riviera Beach":0xc0ae96,
"Riviera Blue":0x65b4d8,
"Riviera Clay":0xc9a88d,
"Riviera Paradise":0x009a9e,
"Riviera Retreat":0xd9c0a6,
"Riviera Rose":0xf7b1a6,
"Riviera Sand":0xdfc6a0,
"Riviera Sea":0x1b8188,
"Rivulet":0xd5dae1,
"Rix":0x605655,
"Road Less-Travelled":0x8b7b6e,
"Road Runner":0xcbc3bd,
"Roadside":0xada493,
"Roadster White":0xe1e0d7,
"Roadster Yellow":0xf3dea2,
"Roan Rouge":0x885157,
"Roanoke Taupe":0x8f837d,
"Roaring Twenties":0xb39c9e,
"Roast Coffee":0x704341,
"Roasted Almond":0xd2b49c,
"Roasted Black":0x655a5c,
"Roasted Cashew":0x918579,
"Roasted Coconut":0xab8c72,
"Roasted Hazelnut":0xaf967d,
"Roasted Kona":0x574038,
"Roasted Nuts":0x604d42,
"Roasted Pecan":0x93592b,
"Roasted Pepper":0x890a01,
"Roasted Pistachio":0xc9b27c,
"Roasted Seeds":0xe1a175,
"Roasted Sienna":0xea7e5d,
"Roasted Squash":0xe6a255,
"Rob Roy":0xddad56,
"Robeson Rose":0x654f4f,
"Robin's Egg":0x6dedfd,
"Robinhood":0x6e6a3b,
"Robo Master":0xadadad,
"Robot Grendizer Gold":0xeeee11,
"Robust Orange":0xc4633e,
"Rock":0x5a4d41,
"Rock Blue":0x93a2ba,
"Rock Bottom":0x484c49,
"Rock Candy":0xdee1df,
"Rock Cliffs":0xc0af92,
"Rock Crystal":0xcecbcb,
"Rock Garden":0x465448,
"Rock Slide":0xa1968c,
"Rock Spray":0x9d442d,
"Rock Star Pink":0xc58bba,
"Rock'n Oak":0x8b785c,
"Rock'n'Rose":0xfc8aaa,
"Rockabilly":0x6c7186,
"Rockabye Baby":0xf4e4e0,
"Rocket Fuel":0xfefbe5,
"Rocket Man":0xbebec3,
"Rocket Metallic":0x8a7f80,
"Rocket Science":0xff3311,
"Rockfall":0xaabbaa,
"Rockin Red":0xbc363c,
"Rocking Chair":0x721f37,
"Rocking Chair Red":0x90413d,
"Rockman Blue":0x31a2f2,
"Rockmelon Rind":0xd3e0b1,
"Rockpool":0x519ea1,
"Rockwall Vine":0x6d7e42,
"Rockweed":0x443735,
"Rockwood Jade":0xc8e0ba,
"Rocky Creek":0x3e4d50,
"Rocky Hill":0x567b8a,
"Rocky Mountain":0xa9867d,
"Rocky Mountain Red":0x76443e,
"Rocky Mountain Sky":0xb5bfbd,
"Rocky Ridge":0x918c86,
"Rocky River":0x5e706a,
"Rocky Road":0x5a3e36,
"Rococco Red":0xbb363f,
"Rococo Beige":0xdfd6c1,
"Rococo Gold":0x977447,
"Rodan Gold":0xfddc5c,
"Rodeo":0x7f5e46,
"Rodeo Dust":0xc7a384,
"Rodeo Red":0xa24b3a,
"Rodeo Roundup":0xa68e6d,
"Rodeo Tan":0xa78b74,
"Rodham":0xb2b26c,
"Roebuck":0xb09080,
"Rogan Josh":0x883311,
"Rogue":0x807a6c,
"Rogue Cowboy":0xba9e88,
"Rogue Pink":0xf8a4c0,
"Rohwurst":0x734a45,
"Rojo 0xide":0x8d4942,
"Rojo Dust":0xb57466,
"Rojo Marrón":0x4b3029,
"Rokō Brown":0x665343,
"Rokou Brown":0x8c7042,
"Rokushō Green":0x407a52,
"Roland-Garros":0xbb5522,
"Roller Coaster":0x8c8578,
"Roller Coaster Chariot":0x0078be,
"Roller Derby":0x8cffdb,
"Rolling Hills":0x7c7e6a,
"Rolling Pebble":0xa09482,
"Rolling Sea":0x5a6d77,
"Rolling Stone":0x6d7876,
"Rolling Waves":0xbfd1c9,
"Romaine":0xc0d2ad,
"Romaine Green":0xa38e00,
"Roman":0xd8625b,
"Roman Bath":0x8c97a3,
"Roman Brick":0xab7f5b,
"Roman Bronze Coin":0x514100,
"Roman Coffee":0x7d6757,
"Roman Coin":0xac8760,
"Roman Column":0xf6f0e2,
"Roman Empire Red":0xee1111,
"Roman Gold":0xd19b2f,
"Roman Mosaic":0xdad1ce,
"Roman Plaster":0xddd2bf,
"Roman Purple":0x524765,
"Roman Ruins":0xc0b5a0,
"Roman Silver":0x838996,
"Roman Snail":0xa49593,
"Roman Violet":0x4d517f,
"Roman Wall":0xb0ada0,
"Roman White":0xdeedeb,
"Romance":0xf4f0e6,
"Romanesque":0x7983a4,
"Romanesque Gold":0xd0af7a,
"Romantic":0xffc69e,
"Romantic Ballad":0xe0bedf,
"Romantic Cruise":0xe7e0ee,
"Romantic Isle":0x007c75,
"Romantic Moment":0x9076ae,
"Romantic Morn":0xfcd5cb,
"Romantic Morning":0xddbbdd,
"Romantic Night":0x96353a,
"Romantic Poetry":0xcac0ce,
"Romantic Rose":0xaa4488,
"Romantic Vampire":0x991166,
"Romeo":0xe3d2ce,
"Romeo O Romeo":0xa4233c,
"Romesco":0xf48101,
"Romp":0x983d48,
"Romulus":0xdfc1a8,
"Ronchi":0xeab852,
"Rondo of Blood":0xa60044,
"Roof Terracotta":0xa14743,
"Roof Tile Green":0x043132,
"Rooftop Garden":0x9ead92,
"Rooibos Tea":0xa23c26,
"Rookwood Amber":0xc08650,
"Rookwood Antique Gold":0xa58258,
"Rookwood Blue Green":0x738478,
"Rookwood Brown":0x7f614a,
"Rookwood Clay":0x9a7e64,
"Rookwood Dark Brown":0x5f4d43,
"Rookwood Dark Green":0x565c4a,
"Rookwood Dark Red":0x4b2929,
"Rookwood Jade":0x979f7f,
"Rookwood Medium Brown":0x6e5241,
"Rookwood Red":0x622f2d,
"Rookwood Sash Green":0x506a67,
"Rookwood Shutter Green":0x303b39,
"Rookwood Terra Cotta":0x975840,
"Rooster Comb":0x96463f,
"Root Beer":0x714a41,
"Root Beer Float":0xcfa46b,
"Root Brew":0x290e05,
"Root Brown":0x6b3226,
"Rope":0x8e593c,
"Roquefort Blue":0xaec6cf,
"Rosa":0xfe86a4,
"Rosa Bonito":0xefd9e1,
"Rosa Vieja":0xf0e3df,
"Rosaline Pearl":0xa38887,
"Rosarian":0xfaeadd,
"Rose":0xff007f,
"Rosé":0xf7746b,
"Rose Ashes":0xb5acab,
"Rose Aspect":0xf1c6ca,
"Rose Bisque":0xc6a499,
"Rose Bonbon":0xf9429e,
"Rose Branch":0x80565b,
"Rose Brocade":0x996c6e,
"Rose Brown":0xbc8f8f,
"Rose Bud":0xb65f9a,
"Rose Chintz":0xc77579,
"Rose Cloud":0xdbb0a2,
"Rose Colored":0xdcb6b5,
"Rose Colored Glasses":0xe5c4c0,
"Rose Cream":0xefe0de,
"Rose Daphne":0xff9ede,
"Rose Dawn":0xb38380,
"Rose de Mai":0xcb8e81,
"Rose Dragée":0xeecffe,
"Rose Dusk":0xe5a192,
"Rose Dust":0xcdb2a5,
"Rose Ebony":0x674846,
"Rose Embroidery":0xc59ea1,
"Rose Essence":0xf29b89,
"Rose Fantasy":0xf1e8ec,
"Rose Fog":0xe7bcb4,
"Rose Frost":0xffece9,
"Rose Fusion":0xf96653,
"Rose Garland":0x865a64,
"Rose Garnet":0x960145,
"Rose Glory":0xe585a5,
"Rose Glow":0xffdbeb,
"Rose Gold":0xb76e79,
"Rose Hip":0xfd0e35,
"Rose Hip Tonic":0xdbb9b6,
"Rose Linen":0xe8aea2,
"Rose Madder":0xe33636,
"Rose Mallow":0xf4aac7,
"Rose Marble":0xceb9c4,
"Rose Marquee":0xa76464,
"Rose Marquis":0xdd94a1,
"Rose Mauve":0xaf9690,
"Rose Meadow":0xc4989e,
"Rose Melody":0xecbfc9,
"Rose Mochi":0xffe9ed,
"Rose of Sharon":0xac512d,
"Rose Pearl":0xdfd4cc,
"Rose Petal":0xe6c1bb,
"Rose Pink":0xff66cc,
"Rose Pink Villa":0x7c383e,
"Rose Potpourri":0xc9a59f,
"Rose Pottery":0xd0a29e,
"Rose Quartz":0xf7cac1,
"Rose Red":0xc92351,
"Rose Reminder":0xf4c0c6,
"Rose Romantic":0xeed1cd,
"Rose Rush":0xdd2255,
"Rose Sachet":0xce858f,
"Rose Shadow":0xf9c2cd,
"Rose Silk":0xe7afa8,
"Rose Smoke":0xd3b4ad,
"Rose Sorbet":0xfbd3cd,
"Rose Souvenir":0xc290c5,
"Rose Stain":0xd3b6ba,
"Rose Sugar":0xfae6e5,
"Rose Tan":0xfae8e1,
"Rose Tattoo":0xe1a890,
"Rose Taupe":0x905d5d,
"Rose Tea":0xb48993,
"Rose Tonic":0xffdddd,
"Rose Turkish Delight":0xdb5079,
"Rose Vale":0xab4e5f,
"Rose Vapor":0xf2dbd6,
"Rose Violet":0xc0428a,
"Rose Water":0xf6dbd8,
"Rose White":0xfbeee8,
"Rose Wine":0x9d5c75,
"Rose Yogurt":0xd9bcb7,
"Roseate":0xf7e5db,
"Rosebay":0xcb9aad,
"Roseberry":0xf4a6a1,
"Rosebloom":0xe290b2,
"Rosebud":0xe0cdd1,
"Rosebud Cherry":0x8a2d52,
"Rosecco":0xeebbdd,
"Rosedust":0xcc8d84,
"Roseland":0x926566,
"Rosemary":0x405e5c,
"Rosemary Green":0x699b72,
"Rosemary Sprig":0x626a52,
"Rosemary White":0xdfe3db,
"Rosenkavalier":0xbc8a90,
"Roses are Red":0xaa3646,
"Rosetta":0xba8f7f,
"Rosette":0xce8e8b,
"Rosettee":0xd7a491,
"Rosewater":0xe2c8bf,
"Rosewood":0x65000b,
"Rosewood Apricot":0xd39ea2,
"Rosewood Brown":0x72371c,
"Rosey Afterglow":0xfac8ce,
"Rosie":0xffbbcc,
"Rosie Posie":0xefe4e9,
"Rosily":0xbe7583,
"Rosin":0x36362d,
"Rosso Corsa":0xd40000,
"Rosy":0xbe89a8,
"Rosy Cheeks":0xdc506e,
"Rosy Copper":0xcf8974,
"Rosy Highlight":0xf7d994,
"Rosy Lavender":0xd7c7d0,
"Rosy Maple Moth":0xfec9ed,
"Rosy Outlook":0xf5ab9e,
"Rosy Pink":0xf6688e,
"Rosy Queen":0xcf9384,
"Rosy Sandstone":0x735551,
"Rosy Skin":0xf7b978,
"Rosy Tan":0xc8aba7,
"Roti":0xb69642,
"Rotting Flesh":0x8aa775,
"Rotunda Gold":0xf5e0bf,
"Rotunda White":0xd7d1c6,
"Rouge":0xab1239,
"Rouge Charm":0x814d54,
"Rouge Like":0xa94064,
"Rouge Red":0xe24666,
"Rouge Sarde":0xee2233,
"Rough Ride":0x7a8687,
"Rough Stone":0x9ea2aa,
"Roulette":0x97635f,
"Rousseau Gold":0xead6af,
"Rousseau Green":0x175844,
"Roux":0x994400,
"Row House Tan":0xd2bb9d,
"Rowan":0xcb0162,
"Rowdy Orange":0xeaa007,
"Rowntree":0x8e8e6e,
"Roxy Brown":0x7a5546,
"Royal":0x0c1793,
"Royal Azure":0x0038a8,
"Royal Banner":0xc74767,
"Royal Battle":0x2f3844,
"Royal Blue":0x4169e1,
"Royal Breeze":0x275779,
"Royal Brown":0x523b35,
"Royal Consort":0x2e5686,
"Royal Coronation":0x3e3542,
"Royal Curtsy":0x282a4a,
"Royal Decree":0x403547,
"Royal Flycatcher Crest":0xee6600,
"Royal Fortune":0x747792,
"Royal Fuchsia":0xca2c92,
"Royal Gold":0xe1bc8a,
"Royal Heath":0xb54b73,
"Royal Hunter Blue":0x4411ee,
"Royal Hunter Green":0x3f5948,
"Royal Hyacinth":0x464b6a,
"Royal Indigo":0x4e4260,
"Royal Intrigue":0x687094,
"Royal Lavender":0x7851a9,
"Royal Lilac":0x774d8e,
"Royal Liqueur":0x784d40,
"Royal Mail Red":0xda202a,
"Royal Maroon":0x543938,
"Royal Mile":0xa1a0b7,
"Royal Milk Tea":0xf7cfb4,
"Royal Navy Blue":0x0066cc,
"Royal Night":0x2b3191,
"Royal Oakleaf":0x879473,
"Royal Oranje":0xff7722,
"Royal Orchard":0x5f6d59,
"Royal Palm":0x418d84,
"Royal Plum":0x654161,
"Royal Pretender":0xa063a1,
"Royal Proclamation":0xaaa0bc,
"Royal Purple":0x4b006e,
"Royal Purpleness":0x881177,
"Royal Raisin":0x806f72,
"Royal Red Flush":0x8e3c3f,
"Royal Robe":0x614a7b,
"Royal Rum":0xa54a4a,
"Royal Silk":0x4b3841,
"Royal Silver":0xe0dddd,
"Royal Star":0xfede4f,
"Royal Velvet":0x513e4d,
"Royal Vessel":0x4433ee,
"Royal Wedding":0xfbe3e3,
"Royal Yellow":0xfada50,
"Roycroft Adobe":0xa76251,
"Roycroft Bottle Green":0x324038,
"Roycroft Brass":0x7a6a51,
"Roycroft Bronze Green":0x575449,
"Roycroft Copper Red":0x7b3728,
"Roycroft Mist Gray":0xc2bdb1,
"Roycroft Pewter":0x616564,
"Roycroft Rose":0xc08f80,
"Roycroft Suede":0xa79473,
"Roycroft Vellum":0xe8d9bd,
"Rozowy Pink":0xf2a8b8,
"Rub Elbows":0x5f5547,
"Rubber":0x815b37,
"Rubber Band":0xce4676,
"Rubber Ducky":0xfacf58,
"Rubber Radish":0xff9999,
"Rubber Rose":0xffc5cb,
"Rubidium":0xc5b9b4,
"Rubine":0x6c383c,
"Rubine Red":0xd10056,
"Ruby":0xca0147,
"Ruby Dust":0xe0115f,
"Ruby Eye":0xd0a2a0,
"Ruby Grey":0x73525c,
"Ruby Lips":0x813e45,
"Ruby Red":0x9b111e,
"Ruby Ring":0xa03d41,
"Ruby Shade":0xa2566f,
"Ruby Slippers":0x9c2e33,
"Ruby Star":0xbb1122,
"Ruby Violet":0x5c384e,
"Ruby Wine":0x77333b,
"Rubylicious":0xdb1459,
"Rucksack Tan":0xedb508,
"Ruddy":0xff0028,
"Ruddy Brown":0xbb6528,
"Ruddy Oak":0xa5654e,
"Ruddy Pink":0xe18e96,
"Rudraksha Beads":0x894e45,
"Ruffled Clam":0xf9f2dc,
"Ruffled Iris":0x9fa3c0,
"Ruffles":0xfbbbae,
"Rufous":0xa81c07,
"Rugby Tan":0xc2a594,
"Rugged Brown":0x694336,
"Rugged Tan":0xb8a292,
"Ruggero Grey":0x484435,
"Ruined Smores":0x0f1012,
"Ruins of Civilization":0xcadece,
"Rule Breaker":0x774e55,
"Rum":0x716675,
"Rum Custard":0xe9cfaa,
"Rum Punch":0xaa423a,
"Rum Raisin":0x583432,
"Rum Riche":0x990044,
"Rum Spice":0xaa7971,
"Rum Swizzle":0xf1edd4,
"Rumba Orange":0xc77b42,
"Rumba Red":0x7c2439,
"Rumors":0x744245,
"Rundlet Peach":0xd3aa94,
"Runefang Steel":0xc4c4c7,
"Runelord Brass":0xb6a89a,
"Runic Mauve":0xcab2c1,
"Running Water":0x326193,
"Rural Eyes":0x99af73,
"Rural Green":0x8d844d,
"Rural Red":0xbb1144,
"Ruri Blue":0x1e50a2,
"Rurikon Blue":0x1b294b,
"Rush Hour":0x536770,
"Rushing River":0x5f7797,
"Rushing Stream":0x65c3d6,
"Rushmore Grey":0xb7b2a6,
"Ruskie":0x866c5e,
"Ruskin Blue":0x546b75,
"Ruskin Bronze":0x4d4d41,
"Ruskin Red":0x935242,
"Ruskin Room Green":0xaca17d,
"Russ Grey":0x547588,
"Russet":0x80461b,
"Russet Brown":0x743332,
"Russet Green":0xe3d9a0,
"Russet Leather":0x965849,
"Russet Orange":0xe47127,
"Russian Blue":0x9aaebb,
"Russian Green":0x679267,
"Russian Olive":0x726647,
"Russian Red":0x4d4244,
"Russian Toffee":0xd0c4af,
"Russian Uniform":0x5f6d36,
"Russian Violet":0x32174d,
"Rust":0xa83c09,
"Rust Brown":0x8b3103,
"Rust Coloured":0xa46454,
"Rust Effect":0xbb3344,
"Rust Magenta":0x966684,
"Rust Orange":0xc45508,
"Rust Red":0xaa2704,
"Rusted Crimson":0x60372e,
"Rusted Lock":0xaa4411,
"Rustic Adobe":0xd39a72,
"Rustic Brown":0x855141,
"Rustic Cabin":0x705536,
"Rustic City":0xba9a67,
"Rustic Cream":0xf6efe2,
"Rustic Hacienda":0x9c8e74,
"Rustic Pottery":0xdf745b,
"Rustic Ranch":0x8d794f,
"Rustic Red":0x3a181a,
"Rustic Rose":0xcbb6a4,
"Rustic Taupe":0xcdb9a2,
"Rustic Tobacco":0x6e5949,
"Rustique":0xf5bfb2,
"Rustling Leaves":0x6b6d4e,
"Rusty":0x96512a,
"Rusty Chainmail":0xc6494c,
"Rusty Coin":0x8d5f2c,
"Rusty Gate":0xaf6649,
"Rusty Heart":0xa04039,
"Rusty Nail":0xcc5522,
"Rusty Orange":0xcd5909,
"Rusty Pebble":0xe3dce0,
"Rusty Red":0xaf2f0d,
"Rusty Sand":0xedb384,
"Rusty Sword":0xa4493d,
"Rusty Tap":0x719da8,
"Rutabaga":0xecddbe,
"Rutherford":0x8d734f,
"Ruthless Empress":0x573894,
"Rye":0xd1ae7b,
"Rye Bread":0xcdbea1,
"Rye Brown":0x807465,
"Rye Dough Brown":0x807365,
"Ryegrass":0xbbb286,
"Ryn Flesh":0xf6ebe7,
"Ryoku-Ou-Shoku Yellow":0xdccb18,
"Ryu's Kimono":0xf3f1e1,
"Ryza Dust":0xec631a,
"S'mores":0xa87f5f,
"Sabal Palm":0x496a4e,
"Saber Tooth":0xd4b385,
"Saber-Toothed Tiger":0xe69656,
"Sabiasagi Blue":0x6a7f7a,
"Sabionando Grey":0x455859,
"Sabiseiji Grey":0x898a74,
"Sable":0x6e403c,
"Sablé":0xf6d8be,
"Sable Brown":0x946a52,
"Sable Cloaked":0xc4a7a1,
"Sablewood":0xecdfd6,
"Sabo Garden":0x978d59,
"Sabz Green":0xa5d610,
"Sachet Cushion":0xd4d8ed,
"Sachet Pink":0xf18aad,
"Sacramento State Green":0x00563f,
"Sacred Blue":0x97b9e0,
"Sacred Ground":0xb2865d,
"Sacred Sapling":0x7c8635,
"Sacred Spring":0xc7cbce,
"Sacred Turquoise":0x49b3a5,
"Sacred Vortex":0xa59c8d,
"Sacrifice":0x2a5774,
"Sacrifice Altar":0x850101,
"Sacro Bosco":0x229911,
"Saddle":0x5d4e46,
"Saddle Brown":0x8b4513,
"Saddle Soap":0x9f906e,
"Saddle Up":0xab927a,
"Saddlebag":0x8a534e,
"Safari":0xbaaa91,
"Safari Brown":0x976c60,
"Safari Chic":0xb7aa96,
"Safari Sun":0xb4875e,
"Safari Trail":0x8f7b51,
"Safari Vest":0xb2a68f,
"Safe Harbour":0x1e8ea1,
"Safe Haven":0x5588aa,
"Safety Orange":0xff6600,
"Safety Yellow":0xeed202,
"Safflower":0xfdae44,
"Safflower Bark":0xbb5548,
"Safflower Kite":0x9a493f,
"Safflower Purple":0xb44c97,
"Safflower Red":0xd9333f,
"Safflower Scarlet":0xe83929,
"Safflower Wisteria":0xcca6bf,
"Safflowerish Sky":0x8491c3,
"Saffron":0xf4c430,
"Saffron Blossom Mauve":0x9c8aab,
"Saffron Bread":0xe8e9cf,
"Saffron Crocus":0x584c77,
"Saffron Gold":0xf08f00,
"Saffron Mango":0xf9bf58,
"Saffron Robe":0xd49f4e,
"Saffron Soufflé":0xfeb209,
"Saffron Strands":0xd39952,
"Saffron Sunset":0xda9e35,
"Saffron Thread":0xffb301,
"Saffron Tint":0xf2ead6,
"Saffron Valley":0xa7843e,
"Saffron Yellow":0xd09b2c,
"Saga Blue":0x75a0b1,
"Sagat Purple":0x6a31ca,
"Sage":0x87ae73,
"Sage Advice":0x948b76,
"Sage Blossom Blue":0x4e78a9,
"Sage Brush":0xbfc1a2,
"Sage Garden":0x7fab70,
"Sage Green":0x887766,
"Sage Green Grey":0x69796a,
"Sage Green Light":0x73705e,
"Sage Grey":0x9ea49d,
"Sage Leaves":0x7b8b5d,
"Sage Splash":0xe4e5d2,
"Sage Splendor":0xc3c6a4,
"Sage Tint":0xdaded1,
"Sage Violet":0x413c7b,
"Sage Wisdom":0xafad96,
"Sagebrush Green":0x567572,
"Sagey":0xa2aa8c,
"Sago":0xd8cfc3,
"Sago Garden":0x94be7f,
"Saguaro":0x655f2d,
"Sahara":0xb79826,
"Sahara Dust":0xa8989b,
"Sahara Gravel":0xdfc08a,
"Sahara Light Red":0xf0e1db,
"Sahara Sand":0xf1e788,
"Sahara Shade":0xe2ab60,
"Sahara Splendor":0x9b7448,
"Sahara Sun":0xc67363,
"Sahara Wind":0xdfd4b7,
"Sail":0xa5ceec,
"Sail Away":0x55b4de,
"Sail Cloth":0xece5d7,
"Sail Cover":0x588fa0,
"Sail Grey":0xcabaa4,
"Sail into the Horizon":0xa3bbdc,
"Sail Maker":0x0e4d72,
"Sail On":0x4575ad,
"Sail to the Sea":0x99c3f0,
"Sailboat":0x314a72,
"Sailcloth":0xece0c4,
"Sailing Safari":0x3a5161,
"Sailor":0x445780,
"Sailor Blue":0x0e3a53,
"Sailor Boy":0xaebbd0,
"Sailor Moon Locks":0xffee00,
"Sailor's Bay":0x496f8e,
"Sailor's Coat":0x334b58,
"Sailor's Knot":0xb8a47a,
"Sainsbury":0x66b89c,
"Saint Seiya Gold":0xeeee00,
"Saira Red":0xff9bb7,
"Sakura":0xdfb1b6,
"Sakura Mochi":0xcea19f,
"Sakura Nezu":0xe8dfe4,
"Sakura Night":0x7b6c7c,
"Salad":0x8ba673,
"Saladin":0x7e8f69,
"Salal Leaves":0x637d74,
"Salamander":0x63775b,
"Salami":0x820000,
"Salami Slice":0xda655e,
"Salem":0x177b4d,
"Salem Black":0x45494d,
"Salem Blue":0x66a9d3,
"Salina Springs":0xcad2d4,
"Saline Water":0xc5e8e7,
"Salisbury Stone":0xddd8c6,
"Salmon":0xff796c,
"Salmon Beauty":0xfbc6b6,
"Salmon Buff":0xfeaa7b,
"Salmon Carpaccio":0xee867d,
"Salmon Cream":0xe9cfcf,
"Salmon Creek":0xfeddc5,
"Salmon Eggs":0xf7d560,
"Salmon Fresco":0xfbb1a2,
"Salmon Grey":0xe3b6aa,
"Salmon Mousse":0xfcd1c3,
"Salmon Nigiri":0xf9906f,
"Salmon Orange":0xff8c69,
"Salmon Pate":0xd5847e,
"Salmon Peach":0xfdc5b5,
"Salmon Pink":0xff91a4,
"Salmon Pink Red":0xe1958f,
"Salmon Poké Bowl":0xee7777,
"Salmon Rose":0xff8d94,
"Salmon Run":0xedaf9c,
"Salmon Salt":0xe7968b,
"Salmon Sand":0xd9aa8f,
"Salmon Sashimi":0xff7e79,
"Salmon Slice":0xf1ac8d,
"Salmon Smoke":0xd4bfbd,
"Salmon Tartare":0xff9baa,
"Salmon Tint":0xefccbf,
"Salmon Upstream":0xffa8a6,
"Salome":0xbbeddb,
"Salomie":0xffd67b,
"Salon Bleu":0x7d8697,
"Salon Rose":0xab7878,
"Salsa":0xaa182b,
"Salsa Diane":0xbb4f5c,
"Salsa Verde":0xcec754,
"Salsify Grass":0x2bb179,
"Salsify White":0xded8c4,
"Salt":0xefede6,
"Salt Blue":0x7d9c9d,
"Salt Box":0xf5e9d9,
"Salt Box Blue":0x648fa4,
"Salt Cellar":0xdee0d7,
"Salt Crystal":0xf0ede0,
"Salt Glaze":0xcfd4ce,
"Salt Island Green":0x757261,
"Salt Lake":0x74c6d3,
"Salt Mountain":0xd7fefe,
"Salt n Pepa":0xdcd9db,
"Salt Pebble":0xf9ecea,
"Salt Spray":0xa7c5ce,
"Salt Steppe":0xeeddbb,
"Salt Water":0x95bbd8,
"Salt Water Taffy":0xd1ab99,
"Saltbox Blue":0x65758a,
"Salted Caramel":0xebb367,
"Salted Caramel Popcorn":0xfdb251,
"Salted Pretzel":0x816b56,
"Saltpan":0xeef3e5,
"Saltwater":0xc2d0de,
"Salty Breeze":0xdde2d7,
"Salty Cracker":0xe2c681,
"Salty Dog":0x234058,
"Salty Ice":0xcce2f3,
"Salty Seeds":0xc1b993,
"Salty Tear":0xcfebed,
"Salty Tears":0xbacad4,
"Salty Thyme":0x96b403,
"Salty Vapour":0xcbdee3,
"Salute":0x282b34,
"Salvation":0x514e5c,
"Salvia":0xa8b59e,
"Salvia Divinorum":0x929752,
"Samantha's Room":0xf2d7e6,
"Samba":0xa2242f,
"Samba de Coco":0xf0e0d4,
"Sambuca":0x3b2e25,
"Sambucus":0x17182b,
"Samoan Sun":0xfbc85f,
"Samovar Silver":0xb8bebe,
"Samphire Green":0x4db560,
"San Antonio Sage":0xa69474,
"San Carlos Plaza":0xd9bb8e,
"San Felix":0x2c6e31,
"San Francisco Fog":0xc4c2bc,
"San Francisco Mauve":0x936a6d,
"San Gabriel Blue":0x2f6679,
"San Juan":0x445761,
"San Marino":0x4e6c9d,
"San Miguel Blue":0x527585,
"Sanctuary":0xd4c9a6,
"Sanctuary Spa":0x66b2e4,
"Sand":0xe2ca76,
"Sand Blast":0xdecbab,
"Sand Brown":0xcba560,
"Sand Castle":0xe5d9c6,
"Sand Crystal":0xffeeda,
"Sand Dagger":0xe6ddd2,
"Sand Dance":0xe0c8b9,
"Sand Diamond":0xfae8bc,
"Sand Dollar":0xdecdbe,
"Sand Dollar White":0xfae3c9,
"Sand Drift":0xe5e0d3,
"Sand Dune":0xe3d2c0,
"Sand Fossil":0xdecfb3,
"Sand Grain":0xe3e4d9,
"Sand Island":0xf4d1c2,
"Sand Motif":0xddc6a8,
"Sand Paper":0xccbb88,
"Sand Pearl":0xe7d4b6,
"Sand Pebble":0xb09d7f,
"Sand Puffs":0xe6e5d3,
"Sand Pyramid":0xddcc77,
"Sand Ripples":0xc1b7b0,
"Sand Shark":0x5a86ad,
"Sand Trail":0xd0c6a1,
"Sand Trap":0xbba595,
"Sand Verbena":0x9f90c1,
"Sand Yellow":0xfdee73,
"Sandal":0xa3876a,
"Sandalwood":0x615543,
"Sandalwood Beige":0xf2d1b1,
"Sandalwood Grey Blue":0x005160,
"Sandalwood Tan":0x907f68,
"Sandbank":0xe9d5ad,
"Sandbar":0xcbbfad,
"Sandblast":0xf5c9bf,
"Sandcastle":0xe5d7c4,
"Sanderling":0xc8ab96,
"Sandgrass Green":0x93917f,
"Sanding Sugar":0xefebde,
"Sandpaper":0xd7b1a5,
"Sandpiper":0xebdac8,
"Sandpiper Cove":0x717474,
"Sandpit":0x9e7c5e,
"Sandpoint":0xeacdb0,
"Sandrift":0xaf937d,
"Sands of Time":0xbca38b,
"Sandshell":0xd8ccbb,
"Sandstone":0xc9ae74,
"Sandstone Cliff":0xd2c9b7,
"Sandstone Grey":0x857266,
"Sandstone Grey Green":0x88928c,
"Sandstone Palette":0xd9ccb6,
"Sandstone Red Grey":0x886e70,
"Sandstorm":0xecd540,
"Sandwashed Driftwood":0x706859,
"Sandwashed Glassshard":0xdee8e3,
"Sandwisp":0xdecb81,
"Sandworm":0xfce883,
"Sandy":0xf1da7a,
"Sandy Ash":0xe4ded5,
"Sandy Bay":0xfad7b3,
"Sandy Beach":0xf9e2d0,
"Sandy Bluff":0xaca088,
"Sandy Clay":0xdbd0bd,
"Sandy Day":0xd7cfc1,
"Sandy Pail":0xd2c098,
"Sandy Ridge":0xa18e77,
"Sandy Shoes":0x847563,
"Sandy Shore":0xf2e9bb,
"Sandy Tan":0xfdd9b5,
"Sandy Taupe":0x967111,
"Sandy Toes":0xc7b8a4,
"Sang de Boeuf":0x771100,
"Sango Pink":0xf5b1aa,
"Sango Red":0xf8674f,
"Sangoire Red":0x881100,
"Sangria":0xb14566,
"Sanguinary":0xf01a4d,
"Sanguine Brown":0x6c3736,
"Sanskrit":0xe69332,
"Santa Fe":0xb16d52,
"Santa Fe Sunrise":0xcc9469,
"Santa Fe Sunset":0xa75a4c,
"Santa Fe Tan":0xd5ad85,
"Santana Soul":0x714636,
"Santas Grey":0x9fa0b1,
"Santiago Orange":0xe95f24,
"Santo":0xd6d2ce,
"Santolina Blooms":0xe3d0d5,
"Santorini":0x41b0d0,
"Santorini Blue":0x416d83,
"Sap Green":0x5c8b15,
"Sapless Green":0xbebdac,
"Sapling":0xe1d5a6,
"Sappanwood":0x9e3d3f,
"Sappanwood Incense":0xa24f46,
"Sappanwood Perfume":0xa86965,
"Sapphire":0x0f52ba,
"Sapphire Blue":0x0067bc,
"Sapphire Fog":0x99a8c9,
"Sapphire Glitter":0x0033cc,
"Sapphire Lace":0x235c8e,
"Sapphire Light Yellow":0xcdc7b4,
"Sapphire Pink":0x887084,
"Sapphire Shimmer Blue":0x5776af,
"Sapphire Siren":0x662288,
"Sapphire Sparkle":0x135e84,
"Sapphire Stone":0x41495d,
"Sapphireberry":0xc9e5ee,
"Sarah's Garden":0x00aac1,
"Saratoga":0x555b2c,
"Sarawak White Pepper":0xf4eeba,
"Sarcoline":0xffddaa,
"Sardinia Beaches":0x28a4cb,
"Sargasso Sea":0x35435a,
"Sari":0xe47c64,
"Sarsaparilla":0x5b4c44,
"Saruk Grey":0x817265,
"Sashay Sand":0xcfb4a8,
"Sasquatch Socks":0xff4681,
"Sassafras":0x54353b,
"Sassafras Tea":0xdbd8ca,
"Sassy":0xc18862,
"Sassy Grass":0x7a8c31,
"Sassy Green":0xbba86a,
"Sassy Pink":0xf6cefc,
"Sassy Yellow":0xf0c374,
"Satan":0xe63626,
"Satellite":0x9f8d89,
"Satin Black":0x4e5152,
"Satin Blush":0xffe4c6,
"Satin Chocolate":0x773344,
"Satin Cream White":0xfdf3d5,
"Satin Deep Black":0x1c1e21,
"Satin Flower":0xb48fbd,
"Satin Green":0xc7dfb8,
"Satin Latour":0xfad7b0,
"Satin Lime":0x33ee00,
"Satin Linen":0xe6e4d4,
"Satin Pink":0xfbe0dc,
"Satin Purse":0xfff8ee,
"Satin Ribbon":0xffd8dc,
"Satin Sheen Gold":0xcba135,
"Satin Soft Blue":0x9cadc7,
"Satin Soil":0x6b4836,
"Satin Souffle":0xefe0bc,
"Satin Weave":0xf3edd9,
"Satin White":0xcfd5db,
"Satire":0xc4c2cd,
"Sativa":0xb5bf50,
"Satoimo Brown":0x654321,
"Satsuma Imo Red":0x96466a,
"Sattle":0xaa6622,
"Saturated Sky":0x4b4cfc,
"Saturn":0xfae5bf,
"Saturn Grey":0xb8b19f,
"Saturnia":0xdddbce,
"Satyr Brown":0xbca17a,
"Saucisson":0x882c17,
"Saucy Gold":0xb6743b,
"Saudi Sand":0x9e958a,
"Sauna Steam":0xedebe1,
"Sausage Roll":0xebdfcd,
"Sausalito":0xf4e5c5,
"Sausalito Port":0x5d6f85,
"Sausalito Ridge":0x6a5d53,
"Sauteed Mushroom":0xab9378,
"Sauterne":0xc5a253,
"Sauvignon":0xf4eae4,
"Sauvignon Blanc":0xb18276,
"Savanna":0x874c44,
"Savannah":0xd1bd92,
"Savannah Grass":0xbabc72,
"Savannah Sun":0xffb989,
"Saveloy":0xaa2200,
"Savile Row":0xc0b7cf,
"Saving Light":0x550011,
"Savon de Provence":0xeed9b6,
"Savory Salmon":0xd19c97,
"Savoy":0x87b550,
"Savoy Blue":0x4b61d1,
"Sawdust":0xf6e9cf,
"Sawgrass":0xd1cfc0,
"Sawgrass Basket":0xc3b090,
"Sawgrass Cottage":0xd3cda2,
"Sawshark":0xaa7766,
"Sawtooth Aak":0xec956c,
"Saxon":0xabc1a0,
"Saxon Blue":0x435965,
"Saxony Blue":0x1f6680,
"Saxophone Gold":0xceaf81,
"Sayward Pine":0x383739,
"Sazerac":0xf5dec4,
"Scab Red":0x8b0000,
"Scallion":0x6b8e23,
"Scallop Shell":0xfbd8c9,
"Scalloped Oak":0xf2d1a0,
"Scalloped Potato":0xfce3cf,
"Scalloped Shell":0xf3e9e0,
"Scallywag":0xe5d5bd,
"Scaly Green":0x027275,
"Scampi":0x6f63a0,
"Scanda":0x6b8ca9,
"Scandal":0xadd9d1,
"Scandalous Rose":0xdfbdd0,
"Scandinavian Sky":0xc2d3d6,
"Scapa Flow":0x6b6a6c,
"Scarab":0x23312d,
"Scarabaeus Sacer":0x414040,
"Scarabœus Nobilis":0x7d8c55,
"Scarborough":0x809391,
"Scarlet":0xff2400,
"Scarlet Apple":0x922e4a,
"Scarlet Flame":0x993366,
"Scarlet Gum":0x4a2d57,
"Scarlet Ibis":0xf45520,
"Scarlet Past":0xa53b3d,
"Scarlet Red":0xb63e36,
"Scarlet Ribbons":0xa4334a,
"Scarlet Sage":0x9d202f,
"Scarlet Shade":0x7e2530,
"Scarpetta":0x8ca468,
"Scatman Blue":0x647983,
"Scattered Showers":0x7b8285,
"Scenario":0x81a79e,
"Scene Stealer":0xaf6d62,
"Scenic Path":0xcec5b4,
"Scented Clove":0x61524c,
"Scented Frill":0xcaaeb8,
"Scented Valentine":0xf3d9d6,
"Sceptre Blue":0x353542,
"Schabziger Yellow":0xeeeebb,
"Schauss Pink":0xff91af,
"Schiaparelli Pink":0xe84998,
"Schiava Blue":0x192961,
"Schindler Brown":0x8b714c,
"Schist":0x87876f,
"Schnipo":0xdd8855,
"Scholarship":0x586a7d,
"School Bus":0xffd800,
"School Ink":0x31373f,
"Schooner":0x8d8478,
"Sci-fi Petrol":0x006666,
"Sci-Fi Takeout":0x00604b,
"Science Blue":0x0076cc,
"Scintillating Violet":0x764663,
"Sconce":0xae935d,
"Sconce Gold":0x957340,
"Scoop of Dark Matter":0x110055,
"Scooter":0x308ea0,
"Scorched":0x351f19,
"Scorched Brown":0x4d0001,
"Scorched Earth":0x44403d,
"Scorched Metal":0x423d27,
"Scorpion":0x6a6466,
"Scorpion Grass Blue":0x99aac8,
"Scorpion Venom":0x97ea10,
"Scorpy Green":0x8eef15,
"Scorzonera Brown":0x544e03,
"Scotch Blue":0x000077,
"Scotch Bonnet":0xfe9f00,
"Scotch Lassie":0x649d85,
"Scotch Mist":0xeee7c8,
"Scotchtone":0xebccb9,
"Scotland Isle":0x87954f,
"Scotland Road":0x9baa9a,
"Scots Pine":0x5f653b,
"Scott Base":0x66a3c3,
"Scouring Rush":0x3b7960,
"Screamer Pink":0xab0040,
"Screamin' Green":0x66ff66,
"Screaming Bell Metal":0xc16f45,
"Screaming Magenta":0xcc00cc,
"Screaming Skull":0xf0f2d2,
"Screech Owl":0xeae4d8,
"Screed Grey":0x9a908a,
"Screen Gem":0x9d7798,
"Screen Glow":0x66eeaa,
"Screen Test":0x999eb0,
"Scribe":0x9fabb6,
"Script Ink":0x60616b,
"Script White":0xdbdddf,
"Scrofulous Brown":0xdba539,
"Scroll":0xefe0cb,
"Scroll of Wisdom":0xf3e5c0,
"Scrolled Parchment":0xe9ddc9,
"Scrub":0x3d4031,
"Scuba":0x6392b7,
"Scuba Blue":0x00abc0,
"Scud":0xacd7c8,
"Scuff Blue":0x0044ee,
"Sculptor Clay":0xccc3b4,
"Sculptural Silver":0xd1dad5,
"Scurf Green":0x02737a,
"Sè Lèi Orange":0xfc824a,
"Sea":0x3c9992,
"Sea Anemone":0xe8dad6,
"Sea Angel":0x98bfca,
"Sea Beast":0x62777e,
"Sea Bed":0x29848d,
"Sea Blithe":0x41545c,
"Sea Blue":0x006994,
"Sea Breeze":0xa4bfce,
"Sea Breeze Green":0xc9d9e7,
"Sea Buckthorn":0xffbf65,
"Sea Cabbage":0x519d76,
"Sea Caller":0x45868b,
"Sea Cap":0xe4f3df,
"Sea Capture":0x61bddc,
"Sea Cave":0x005986,
"Sea Challenge":0x2c585c,
"Sea Cliff":0xa5c7df,
"Sea Creature":0x00586d,
"Sea Crystal":0x608ba6,
"Sea Current":0x4c959d,
"Sea Deep":0x2d3c44,
"Sea Drifter":0x4b7794,
"Sea Drive":0xc2d2e0,
"Sea Elephant":0x77675c,
"Sea Fantasy":0x1a9597,
"Sea Fern":0x656d54,
"Sea Foam":0x87e0cf,
"Sea Foam Mist":0xcbdce2,
"Sea Fog":0xdfddd6,
"Sea Frost":0xd5dcdc,
"Sea Garden":0x568e88,
"Sea Glass":0xafc1bf,
"Sea Glass Teal":0xa0e5d9,
"Sea Goddess":0x216987,
"Sea Going":0x2a2e44,
"Sea Grape":0x3300aa,
"Sea Grass":0x67ad83,
"Sea Green":0x53fca1,
"Sea Haze Grey":0xcbd9d4,
"Sea Hunter":0x245878,
"Sea Ice":0xd7f2ed,
"Sea Kale":0x30a299,
"Sea Kelp":0x354a55,
"Sea Lavender":0xcfb1d8,
"Sea Lettuce":0x67a181,
"Sea Life":0x5dc6bf,
"Sea Lion":0x7f8793,
"Sea Loch":0x6e99d1,
"Sea Mariner":0x434a54,
"Sea Mark":0x92b6cf,
"Sea Mist":0xdbeee0,
"Sea Monster":0x658c7b,
"Sea Moss":0x254445,
"Sea Nettle":0xf47633,
"Sea Note":0x5482c2,
"Sea Nymph":0x8aaea4,
"Sea of Atlantis":0x2d535a,
"Sea of Tranquility":0x81d1da,
"Sea Paint":0x00507a,
"Sea Palm":0x72897e,
"Sea Pea":0x457973,
"Sea Pearl":0xe0e9e4,
"Sea Pine":0x4c6969,
"Sea Pink":0xdb817e,
"Sea Quest":0x3e7984,
"Sea Radish":0x799781,
"Sea Ridge":0x45a3cb,
"Sea Rover":0xa3d1e2,
"Sea Salt":0xf1e6de,
"Sea Serpent":0x4bc7cf,
"Sea Serpent's Tears":0x5511cc,
"Sea Sight":0x00789b,
"Sea Sparkle":0x469ba7,
"Sea Spray":0xd2ebea,
"Sea Sprite":0xb7ccc7,
"Sea Squash":0xbaa243,
"Sea Star":0x4d939a,
"Sea Swimmer":0x337f86,
"Sea Turtle":0x818a40,
"Sea Urchin":0x367d83,
"Sea Wind":0xaccad5,
"Sea Wonder":0x0f9bc0,
"Seaborne":0x7aa5c9,
"Seabrook":0x4b81af,
"Seabuckthorn Yellow Brown":0xcd7b00,
"Seachange":0x3e8896,
"Seacrest":0xbfd1b3,
"Seafair Green":0xb8f8d8,
"Seafoam Blue":0x78d1b6,
"Seafoam Green":0x99bb88,
"Seafoam Pearl":0xc2ecd8,
"Seafoam Spray":0xdaefce,
"Seaglass":0xd0e6de,
"Seagrass":0xbcc6a2,
"Seagrass Green":0x264e50,
"Seagull":0xe0ded8,
"Seagull Grey":0xd9d9d2,
"Seagull Wail":0xc7bda8,
"Seal Blue":0x475663,
"Seal Brown":0x321414,
"Seal Grey":0x8a9098,
"Seal Pup":0x65869b,
"Sealegs":0x6b8b8b,
"Sealskin":0x48423c,
"Sealskin Shadow":0xe9ece6,
"Seamount":0x15646d,
"Seance":0x69326e,
"Seaplane Grey":0x3a3f41,
"Seaport":0x005e7d,
"Seaport Steam":0xaecac8,
"Searching Blue":0x6c7f9a,
"Searchlight":0xeff0bf,
"Seared Earth":0x9a5633,
"Seared Grey":0x495157,
"Searing Gorge Brown":0x6b3b23,
"Seascape Blue":0xa6bad1,
"Seascape Green":0xb5e4e4,
"Seashell":0xfff5ee,
"Seashell Cove":0x104c77,
"Seashell Peach":0xfff6de,
"Seashell Pink":0xf7c8c2,
"Seashore Dreams":0xb5dcef,
"Seaside Sand":0xf2e9d7,
"Seaside Villa":0xe9d5c9,
"Season Finale":0xbea27b,
"Seasonal Beige":0xe6b99f,
"Seasoned Acorn":0x7f6640,
"Seasoned Apple Green":0x8db600,
"Seasoned Salt":0xcec2a1,
"Seattle Red":0x7d212a,
"Seawashed Glass":0xa9c095,
"Seaweed":0x18d17b,
"Seaweed Green":0x35ad6b,
"Seaweed Salad":0x7d7b55,
"Seaweed Tea":0x5d7759,
"Seaweed Wrap":0x4d473d,
"Seaworld":0x125459,
"Seaworthy":0x314d58,
"Sebright Chicken":0xbd5701,
"Secluded Canyon":0xc6876f,
"Secluded Green":0x6f6d56,
"Secluded Woods":0x495a52,
"Second Nature":0x585642,
"Second Pour":0x887ca4,
"Second Wind":0xdfece9,
"Secrecy":0x50759e,
"Secret Blush":0xe1d2d5,
"Secret Cove":0x68909d,
"Secret Crush":0xd7dfd6,
"Secret Garden":0x11aa66,
"Secret Glade":0xb5b88d,
"Secret Journal":0x7c6055,
"Secret Meadow":0x72754f,
"Secret of Mana":0x4166f5,
"Secret Passageway":0x6d695e,
"Secret Path":0x737054,
"Secret Safari":0xc6bb68,
"Secret Scent":0xe3d7dc,
"Secret Society":0x464e5a,
"Secret Story":0xff1493,
"Secure Blue":0x5389a1,
"Security":0xd6e1c2,
"Sedate Gray":0xd1cdbf,
"Sedge":0xb1a591,
"Sedge Green":0x707a68,
"Sedia":0xb0a67e,
"Sedona":0xe7e0cf,
"Sedona at Sunset":0xbf7c45,
"Sedona Pink":0xd6b8a7,
"Sedona Sage":0x686d6c,
"Sedona Shadow":0x665f70,
"Seduction":0xfbf2bf,
"Seductive Thorns":0xa2c748,
"Seed Pearl":0xe6dac4,
"Seedless Grape":0xd3c3d4,
"Seedling":0xc0cba1,
"Seeress":0xa99ba9,
"Sefid White":0xfff1f1,
"Seiheki Green":0x3a6960,
"Seiji Green":0x819c8b,
"Sekichiku Pink":0xe5abbe,
"Sekkasshoku Brown":0x683f36,
"Selago":0xe6dfe7,
"Selective Yellow":0xffba00,
"Self Powered":0x8c7591,
"Self-Destruct":0xc2b398,
"Seljuk Blue":0x4488ee,
"Sell Gold":0xd4ae5e,
"Sell Out":0x90a2b7,
"Semi Opal":0xab9649,
"Semi Sweet":0x6b5250,
"Semi Sweet Chocolate":0x6b4226,
"Semi-Precious":0x659b97,
"Semolina":0xceb899,
"Semolina Pudding":0xffe8c7,
"Sēn Lín Lǜ Forest":0x4ca973,
"Senate":0x4a515f,
"Sencha Brown":0x824b35,
"Seneca Rock":0x9a927f,
"Senior Moment":0xfdecc7,
"Sensai Brown":0x494a41,
"Sensaicha brown":0x3b3429,
"Sensaimidori Green":0x374231,
"Sensational Sand":0xbfa38d,
"Sensible Hue":0xead7b4,
"Sensitive Scorpion":0xcc2266,
"Sensitive Tint":0xcec9cc,
"Sensitivity":0xa1b0be,
"Sensual Climax":0xda3287,
"Sensual Fumes":0xcd68e2,
"Sensual Peach":0xffd2b6,
"Sensuous":0xb75e6b,
"Sensuous Gray":0x837d7f,
"Sentimental":0xe6d8d2,
"Sentimental Beige":0xe0d8c5,
"Sentimental Lady":0xc4d3dc,
"Sentimental Pink":0xf8eef4,
"Sentinel":0xd2e0d6,
"Sephiroth Grey":0x8c92ac,
"Sepia":0x704214,
"Sepia Black":0x2b0202,
"Sepia Brown":0x4b3526,
"Sepia Filter":0xcbb499,
"Sepia Rose":0xd4bab6,
"Sepia Skin":0x9f5c42,
"Sepia Tint":0x897560,
"Sepia Tone":0xb8a88a,
"Sepia Wash":0x995915,
"Sepia Yellow":0x8c7340,
"September Gold":0x8d7548,
"September Morn":0xede6b3,
"September Morning":0xffe9bb,
"September Song":0xd5d8c8,
"September Sun":0xfdd7a2,
"Sequesta":0xd4d158,
"Sequin":0xe1c28d,
"Sequoia":0x804839,
"Sequoia Dusk":0x795953,
"Sequoia Fog":0xc5bbaf,
"Sequoia Grove":0x935e4e,
"Sequoia Lake":0x506c6b,
"Sequoia Redwood":0x763f3d,
"Serape":0xd88b4d,
"Seraphim Sepia":0xd7824b,
"Seraphinite":0x616f65,
"Serbian Green":0x3e644f,
"Serena":0xcfd0c1,
"Serenade":0xfce9d7,
"Serendibite Black":0x4a4354,
"Serendipity":0xbde1d8,
"Serene":0xdce3e4,
"Serene Blue":0x1199bb,
"Serene Breeze":0xbdd9d0,
"Serene Journey":0xcfd8d1,
"Serene Peach":0xf5d3b7,
"Serene Scene":0xd2c880,
"Serene Sea":0x78a7c3,
"Serene Setting":0xc5d2d9,
"Serene Sky":0xc3e3eb,
"Serene Stream":0x819daa,
"Serene Thought":0xc5c0ac,
"Serenely":0xced7d5,
"Serengeti Dust":0xe7dbc9,
"Serengeti Grass":0xab9579,
"Serengeti Green":0x77cc88,
"Serengeti Sand":0xfce7d0,
"Sereni Teal":0x76baa8,
"Serenity":0x91a8d0,
"Serious Gray":0x7d848b,
"Serious Grey":0xcec9c7,
"Seriously Sand":0xdcccb4,
"Serpent":0x817f6d,
"Serpentine":0x9b8e54,
"Serpentine Green":0xa2b37a,
"Serpentine Shadow":0x003300,
"Serrano Pepper":0x556600,
"Seryi Grey":0x9ca9ad,
"Sesame":0xbaa38b,
"Sesame Crunch":0xc26a35,
"Sesame Seed":0xe1d9b8,
"Sesame Street Green":0x00a870,
"Settlement":0x7e7970,
"Settler":0x8b9cac,
"Seven Days of Rain":0xd3dae1,
"Seven Seas":0x4a5c6a,
"Seven Veils":0xe3b8bd,
"Severe Seal":0xeee7de,
"Seville Scarlet":0x955843,
"Shabby Chic":0xbb8a8e,
"Shabby Chic Pink":0xefddd6,
"Shade of Amber":0xff7e00,
"Shade of Bone Marrow":0x889988,
"Shade of Marigold":0xb88a3d,
"Shade of Mauve":0xae7181,
"Shade of Violet":0x8601af,
"Shade-Grown":0x4e5147,
"Shaded Fern":0x786947,
"Shaded Fuchsia":0x664348,
"Shaded Glen":0x8e824a,
"Shaded Hammock":0x859c9b,
"Shaded Spruce":0x00585e,
"Shaded Sun":0xf3eba5,
"Shades On":0x605f5f,
"Shadow":0x837050,
"Shadow Azalea Pink":0xe96a97,
"Shadow Blue":0x778ba5,
"Shadow Cliff":0x7a6f66,
"Shadow Dance":0x877d83,
"Shadow Effect":0x788788,
"Shadow Gargoyle":0x686767,
"Shadow Green":0x9ac0b6,
"Shadow Grey":0xbba5a0,
"Shadow Leaf":0x395648,
"Shadow Lime":0xcfe09d,
"Shadow Mountain":0x585858,
"Shadow of the Colossus":0xa3a2a1,
"Shadow Planet":0x221144,
"Shadow Purple":0x4e334e,
"Shadow Ridge":0x5b5343,
"Shadow Warrior":0x1a2421,
"Shadow White":0xeef1ea,
"Shadow Wood":0x5e534a,
"Shadow Woods":0x8a795d,
"Shadowdancer":0x111155,
"Shadowed Steel":0x4b4b4b,
"Shadows":0x6b6d6a,
"Shady":0xdbd6cb,
"Shady Blue":0x42808a,
"Shady Character":0x4c4b4c,
"Shady Glade":0x006e5b,
"Shady Green":0x635d4c,
"Shady Grey":0x849292,
"Shady Lady":0x9f9b9d,
"Shady Neon Blue":0x5555ff,
"Shady Oak":0x73694b,
"Shady Pink":0xc4a1af,
"Shady White":0xf0e9df,
"Shady Willow":0x939689,
"Shagbark Olive":0x645d41,
"Shaggy Barked":0xb3ab98,
"Shagreen":0xcbc99d,
"Shaker Blue":0x748c96,
"Shaker Grey":0x6c6556,
"Shaker Peg":0x886a3f,
"Shakespeare":0x609ab8,
"Shakker Red":0x7f4340,
"Shakshuka":0xaa3311,
"Shaku-Do Copper":0x752100,
"Shale":0x4a3f41,
"Shale Green":0x739072,
"Shale Grey":0x899da3,
"Shalimar":0xf8f6a8,
"Shallot Bulb":0x7b8d73,
"Shallot Leaf":0x505c3a,
"Shallow End":0xc5f5e8,
"Shallow Sea":0x9ab8c2,
"Shallow Shoal":0x9dd6d4,
"Shallow Shore":0xb0dec8,
"Shallow Water":0x8af1fe,
"Shallow Water Ground":0x8caeac,
"Shamanic Journey":0xcc855a,
"Shampoo":0xffcff1,
"Shamrock":0x009e60,
"Shamrock Field":0x358d52,
"Shamrock Green":0x4ea77d,
"Shān Hú Hóng Coral":0xfa9a85,
"Shandy":0xffe670,
"Shanghai Jade":0xaad9bb,
"Shanghai Peach":0xd79a91,
"Shanghai Silk":0xc8dfc3,
"Shangri La":0xecd4d2,
"Shani Purple":0x4c1050,
"Shank":0xa18b5d,
"Sharbah Fizz":0x9be3d7,
"Sharegaki Persimmon":0xffa26b,
"Shark":0xcadcde,
"Shark Bait":0xee6699,
"Shark Fin":0x969795,
"Shark Tooth":0xe4e1d3,
"Sharknado":0x35524a,
"Sharkskin":0x838487,
"Sharp Blue":0x2b3d54,
"Sharp Green":0xc6ec7a,
"Sharp Grey":0xc9cad1,
"Sharp Pebbles":0xdbd6d8,
"Sharp Yellow":0xecc043,
"Sharp-Rip Drill":0xeae1d6,
"Shasta Lake":0x355c74,
"Shattan Gold":0xbb5577,
"Shattell":0xb5a088,
"Shattered Ice":0xdaeee6,
"Shattered Porcelain":0xeee2e0,
"Shattered Sky":0xd0dde9,
"Shattered White":0xf1f1e5,
"Shaved Chocolate":0x543b35,
"Shaved Ice":0xa9b4ba,
"Shaving Cream":0xe1e5e5,
"Shawarma":0xdd9955,
"She Loves Pink":0xe39b96,
"Shea":0xf8f1eb,
"Shearwater Black":0x5b5b6c,
"Shebang":0x81876f,
"Sheen Green":0x8fd400,
"Sheepskin":0xdab58f,
"Sheepskin Gloves":0xad9e87,
"Sheer Apricot":0xf3c99d,
"Sheer Green":0xb0c69a,
"Sheer Lavender":0xefe2f2,
"Sheer Lilac":0xb793c0,
"Sheer Peach":0xfff7e7,
"Sheer Pink":0xf6e5db,
"Sheer Rosebud":0xffe8e5,
"Sheer Scarf":0xe3d6ca,
"Sheer Sunlight":0xfffedf,
"Sheet Blue":0x52616f,
"Sheet Metal":0x5e6063,
"Sheffield":0x638f7b,
"Sheffield Grey":0x6b7680,
"Sheikh Zayed White":0xe6efef,
"Shell":0xe1cfc6,
"Shell Brook":0xeee7e6,
"Shell Brown":0x56564b,
"Shell Coral":0xea9575,
"Shell Ginger":0xf9e4d6,
"Shell Haven":0xebdfc0,
"Shell Pink":0xf88180,
"Shell Tint":0xfdd7ca,
"Shell White":0xf0ebe0,
"Shelter":0xb8986c,
"Sheltered Bay":0x758f9a,
"Shēn Chéng Orange":0xc03f20,
"Shēn Hóng Red":0xbe0620,
"Shepherd's Warning":0xc06f68,
"Sheraton Sage":0x8f8666,
"Sherbet Fruit":0xf8c8bb,
"Sheriff":0xebcfaa,
"Sheringa Rose":0x735153,
"Sherpa Blue":0x00494e,
"Sherry Cream":0xf9e4db,
"Sherwood Forest":0x555a4c,
"Sherwood Green":0x1b4636,
"Shetland Lace":0xdfd0c0,
"Shì Zǐ Chéng Persimmon":0xe29f31,
"Shiffurple":0x9900aa,
"Shifting Sand":0xd8c0ad,
"Shiitake":0xa5988a,
"Shiitake Mushroom":0x736253,
"Shikon":0x2b2028,
"Shilo":0xe6b2a6,
"Shimmer":0x88c7e9,
"Shimmering Blue":0x82dbcc,
"Shimmering Blush":0xd98695,
"Shimmering Brook":0x64b3d3,
"Shimmering Champagne":0xf3debc,
"Shimmering Expanse Cyan":0x45e9fd,
"Shimmering Glade":0xa4943a,
"Shimmering Love":0xff88cc,
"Shimmering Pool":0xd2efe6,
"Shimmering Sea":0x2b526a,
"Shimmering Sky":0xdbd1e8,
"Shin Godzilla":0x9a373f,
"Shinbashi":0x59b9c6,
"Shinbashi Azure":0x006c7f,
"Shindig":0x00a990,
"Shine Baby Shine":0xa85e6e,
"Shiner":0x773ca7,
"Shingle Fawn":0x745937,
"Shining Armor":0x908b8e,
"Shining Gold":0xbad147,
"Shining Knight":0x989ea7,
"Shining Silver":0xc7c7c9,
"Shinkansen White":0xdacdcd,
"Shinshu":0x8f1d21,
"Shiny Armor":0xa1a9a8,
"Shiny Gold":0xae9f65,
"Shiny Kettle":0xcea190,
"Shiny Luster":0xdbdddb,
"Shiny Nickel":0xccd3d8,
"Shiny Rubber":0x3a363b,
"Shiny Shamrock":0x5fa778,
"Shiny Silk":0xf7ecca,
"Ship Cove":0x7988ab,
"Ship Grey":0x3e3a44,
"Ship Steering Wheel":0x62493b,
"Ship's Harbour":0x4f84af,
"Ship's Officer":0x2d3a49,
"Shipwreck":0x968772,
"Shipyard":0x4f6f85,
"Shiracha Brown":0xc48e69,
"Shiraz":0x842833,
"Shire":0x646b59,
"Shire Green":0x68e52f,
"Shiroi White":0xebf5f0,
"Shironeri Silk":0xfeddcb,
"Shirt Blue":0x6598af,
"Shisha Coal":0x3c3b3c,
"Shishi Pink":0xefab93,
"Shishito Pepper Green":0xbbf90f,
"Shiso Green":0x63a950,
"Shiva Blue":0x99dbfe,
"Shock Jockey":0xbb88aa,
"Shocking":0xe899be,
"Shocking Pink":0xfe02a2,
"Shockwave":0x72c8b8,
"Shoe Wax":0x2b2b2b,
"Shoelace":0xeae4d9,
"Shoelace Beige":0xf6ebd3,
"Shōji":0xded5c7,
"Shoji White":0xe6dfd3,
"Shojo's Blood":0xe2041b,
"Shōjōhi Red":0xdc3023,
"Shooting Star":0xecf0eb,
"Shopping Bag":0x5a4743,
"Shore Water":0x6797a2,
"Shoreland":0xead9cb,
"Shoreline Green":0x58c6ab,
"Shoreline Haze":0xd2cbbc,
"Short and Sweet":0xedd1d3,
"Short Phase":0xbbdfd5,
"Shortbread":0xf5e6d3,
"Shortbread Cookie":0xeaceb0,
"Shortcake":0xeedaac,
"Shortgrass Prairie":0x9e957c,
"Shot Over":0x4a5c69,
"Shot-Put":0x716b63,
"Shovel Knight":0x37c4fa,
"Show Business":0xdd835b,
"Show Stopper":0xa42e37,
"Shower":0x9fadb7,
"Showstopper":0x7f607f,
"Shrimp":0xe29a86,
"Shrimp Boat":0xf5be9d,
"Shrimp Boudin":0xdbbfa3,
"Shrimp Cocktail":0xf4a460,
"Shrimp Toast":0xf7c5a0,
"Shrine of Pleasures":0xcc3388,
"Shrinking Violet":0x5d84b1,
"Shrub Green":0x003636,
"Shrubbery":0xa9c08a,
"Shrubby Lichen":0xb5d1db,
"Shu Red":0xeb6101,
"Shǔi Cǎo Lǜ Green":0x40826d,
"Shui Jiao Dumpling":0xdccca3,
"Shukra Blue":0x2b64ad,
"Shuriken":0x333344,
"Shutter Blue":0x666e7f,
"Shutter Copper":0xbb6622,
"Shutter Grey":0x797f7d,
"Shutterbug":0xbba262,
"Shutters":0x6c705e,
"Shuttle Grey":0x61666b,
"Shy Beige":0xe2ded6,
"Shy Blunt":0xd3d8de,
"Shy Candela":0xd6dde6,
"Shy Cupid":0xf0d6ca,
"Shy Denim":0xd7dadd,
"Shy Girl":0xffd7cf,
"Shy Green":0xe5e8d9,
"Shy Guy Red":0xaa0055,
"Shy Mint":0xe0e4db,
"Shy Moment":0xaaaaff,
"Shy Pink":0xdfd9dc,
"Shy Smile":0xdcbbbe,
"Shy Violet":0xd6c7d6,
"Shylock":0x5ab9a4,
"Shyness":0xf3f3d9,
"Siam":0x686b50,
"Siam Gold":0x896f40,
"Siamese Green":0x9dac79,
"Siamese Kitten":0xefe1d5,
"Siberian Fur":0xeee2d5,
"Siberian Green":0x4e6157,
"Sicilia Bougainvillea":0xff44ff,
"Sicilian Villa":0xfcc792,
"Sicily Sea":0xc1c6ad,
"Sick Blue":0x502d86,
"Sick Green":0x9db92c,
"Sickly Green":0x94b21c,
"Sickly Yellow":0xd0e429,
"Sidecar":0xe9d9a9,
"Sidekick":0xbfc3ae,
"Sideshow":0xe2c591,
"Sidewalk Chalk Blue":0xdbe9ed,
"Sidewalk Chalk Pink":0xf7ccc4,
"Sidewalk Grey":0x7b8f99,
"Sienna":0xa9561e,
"Sienna Buff":0xcda589,
"Sienna Dust":0xdcc4ac,
"Sienna Ochre":0xde9f83,
"Sienna Red":0xb1635e,
"Sienna Yellow":0xf1d28c,
"Sierra":0x985c41,
"Sierra Foothills":0xa28a67,
"Sierra Madre":0xc2bcae,
"Sierra Redwood":0x924e3c,
"Sierra Sand":0xafa28f,
"Siesta":0xf0c3a7,
"Siesta Dreams":0xc9a480,
"Siesta Rose":0xec7878,
"Siesta Sands":0xf1e6e0,
"Siesta Tan":0xe9d8c8,
"Siesta White":0xcbdadb,
"Sightful":0x76a4a6,
"Sigmarite":0xcaad76,
"Sign of Spring":0xe3ede2,
"Sign of the Crown":0xfce299,
"Signal Green":0x33ff00,
"Signal Grey":0x838684,
"Signal Pink":0xb15384,
"Signal White":0xecece6,
"Signature Blue":0x455371,
"Silence":0xeaede5,
"Silence is Golden":0xc2a06d,
"Silent Breath":0xe9f1ec,
"Silent Breeze":0xc6eaec,
"Silent Delight":0xe5e7e8,
"Silent Film":0x9fa5a5,
"Silent Ivory":0xfef2c7,
"Silent Night":0x526771,
"Silent Ripple":0xabe3de,
"Silent Sage":0x729988,
"Silent Sands":0xa99582,
"Silent Sea":0x3a4a63,
"Silent Smoke":0xdbd7ce,
"Silent Storm":0xc3c7bd,
"Silent Tide":0x7c929a,
"Silent White":0xe5e7e4,
"Silentropae Cloud":0xccbbbb,
"Silhouette":0xcbcdc4,
"Silica Sand":0xede2e0,
"Silicate Green":0x88b2a9,
"Silicate Light Turquoise":0xcddad3,
"Siliceous Red":0x5a3d4a,
"Silicone Seduction":0xebe0ca,
"Silicone Serena":0xdcdccf,
"Silithus Brown":0xd57b65,
"Silk":0xbbada1,
"Silk Chiffon":0xccbfc7,
"Silk Crepe Grey":0x354e4b,
"Silk Crepe Mauve":0x6e7196,
"Silk Dessou":0xeee9dc,
"Silk Elegance":0xf6e8de,
"Silk Gown":0xfceedb,
"Silk Jewel":0x02517a,
"Silk Khimar":0x70939e,
"Silk Lilac":0x9188b5,
"Silk Lining":0xfcefe0,
"Silk Pillow":0xf3f0ea,
"Silk Ribbon":0xc86e8b,
"Silk Road":0x97976f,
"Silk Sails":0xf6eecd,
"Silk Sari":0x009283,
"Silk Sheets":0xefdddf,
"Silk Sox":0xa5b2c7,
"Silk Star":0xf5eec6,
"Silk Stone":0xcc9999,
"Silken Peacock":0x427584,
"Silken Pine":0x495d5a,
"Silken Raspberry":0xaa7d89,
"Silken Tofu":0xfef6d8,
"Silkie Chicken":0xfdefdb,
"Silkworm":0xeeeecc,
"Silky Bamboo":0xeae0cd,
"Silky Green":0xbdc2bb,
"Silky Mint":0xd7ecd9,
"Silky Pink":0xffddf4,
"Silky Tofu":0xfff5e4,
"Silky White":0xeeebe2,
"Silky Yogurt":0xf2f3cd,
"Silly Puddy":0xf4b0bb,
"Silt":0x8a7d72,
"Silt Green":0xa9bdb1,
"Silver":0xc0c0c0,
"Silver Ash":0xdddbd0,
"Silver Bells":0xb8b4b6,
"Silver Birch":0xd2cfc4,
"Silver Bird":0xfbf5f0,
"Silver Blue":0x8a9a9a,
"Silver Blueberry":0x5b7085,
"Silver Bullet":0xb6b5b8,
"Silver Chalice":0xacaea9,
"Silver Charm":0xadb0b4,
"Silver City":0xe2e4e9,
"Silver Cloud":0xbeb7b0,
"Silver Clouds":0xa6aaa2,
"Silver Creek":0xd9dad2,
"Silver Cross":0xcdc5c2,
"Silver Dagger":0xc1c1d1,
"Silver Dollar":0xbdb6ae,
"Silver Drop":0x9ab2a9,
"Silver Dust":0xe8e7e0,
"Silver Feather":0xedebe7,
"Silver Fern":0xe1ddbf,
"Silver Filigree":0x7f7c81,
"Silver Fir Blue":0x7196a2,
"Silver Fox":0xbdbcc4,
"Silver Grass":0xc6cec3,
"Silver Grass Traces":0xdfe4dc,
"Silver Gray":0xb8b2a2,
"Silver Green":0xd7d7c7,
"Silver Grey":0xa8a8a4,
"Silver Hill":0x6d747b,
"Silver Lake":0xdedddd,
"Silver Lake Blue":0x618bb9,
"Silver Laurel":0xd8dcc8,
"Silver Leaf":0x9db7a5,
"Silver Linden Grey":0x859382,
"Silver Lined":0xbbbfc3,
"Silver Lining":0xbdb6ab,
"Silver Lustre":0xa8a798,
"Silver Maple Green":0x71776e,
"Silver Marlin":0xc8c8c0,
"Silver Mauve":0xdbccd3,
"Silver Medal":0xd6d6d6,
"Silver Mine":0xbec2c1,
"Silver Mink":0x9f8d7c,
"Silver Moon":0xd9d7c9,
"Silver Peony":0xe7cfc7,
"Silver Pink":0xdcb1af,
"Silver Polish":0xc6c6c6,
"Silver Rose":0xd29ea6,
"Silver Rust":0xc9a0df,
"Silver Sage":0x938b78,
"Silver Sand":0xbebdb6,
"Silver Sands":0xdadedd,
"Silver Sateen":0xc7c6c0,
"Silver Sconce":0xa19fa5,
"Silver Screen":0xa6aeaa,
"Silver Service":0xb2aaaa,
"Silver Setting":0xd8dadb,
"Silver Shadow":0xd8dad8,
"Silver Skate":0x87a1b1,
"Silver Sky":0xeaece9,
"Silver Snippet":0x8e9090,
"Silver Spoon":0xd3d3d2,
"Silver Springs":0xb7bdc4,
"Silver Spruce":0xcadfdd,
"Silver Star":0x98a0b8,
"Silver Storm":0x8599a8,
"Silver Strand":0xb8c7ce,
"Silver Strand Beach":0xcacdca,
"Silver Strawberry":0xf2c1c0,
"Silver Surfer":0x7e7d88,
"Silver Sweetpea":0xc4c9e2,
"Silver Thistle Beige":0xe7d5c5,
"Silver Tinsel":0xb6b3a9,
"Silver Tipped Sage":0xbfc2bf,
"Silver Tradition":0xd9d9d3,
"Silver Tree":0x67be90,
"Silver Willow Green":0x637c5b,
"Silverado":0x6a6472,
"Silverado Ranch":0xa7a89b,
"Silverado Trail":0xb7bbc6,
"Silverbeet":0x5a6a43,
"Silverberry":0xbebbc9,
"Silverfish":0x8d95aa,
"Silvermist":0xb0b8b2,
"Silverpine":0x4e6866,
"Silverpine Cyan":0x8ae8ff,
"Silverplate":0xc2c0ba,
"Silverpointe":0xd1d2cb,
"Silverstone":0xb1b3b3,
"Silverton":0xbfd9ce,
"Silverware":0xb8b8bf,
"Silvery Moon":0xe6e5dc,
"Silvery Streak":0xd5dbd5,
"Simmered Seaweed":0x4c3d30,
"Simmering Ridge":0xcb9281,
"Simmering Smoke":0xa99f96,
"Simple Pink":0xf9a3aa,
"Simple Serenity":0xc8d9e5,
"Simple Silhouette":0x7a716e,
"Simple Stone":0xcdc7b7,
"Simple White":0xdfd9d2,
"Simplicity":0xced0db,
"Simplify Beige":0xd6c7b9,
"Simply Blue":0xadbbc9,
"Simply Delicious":0xffd2c1,
"Simply Elegant":0xcedde7,
"Simply Green":0x009b75,
"Simply Peachy":0xffc06c,
"Simply Posh":0x8cb9d4,
"Simply Sage":0xa7a996,
"Simply Sparkling":0xb0c5e0,
"Simply Taupe":0xad9f93,
"Simply Violet":0xa6a1d7,
"Simpson Surprise":0x82856d,
"Simpsons Yellow":0xffd90f,
"Sin City":0xcfa236,
"Sinatra":0x4675b7,
"Sinbad":0xa6d5d0,
"Sinful":0x645059,
"Singapore Orchid":0xa020f0,
"Singing Blue":0x0074a4,
"Singing in the Rain":0x8e9c98,
"Singing the Blues":0x2b4d68,
"Sinister":0x12110e,
"Sinister Minister":0x353331,
"Sinister Mood":0xa89c94,
"Siniy Blue":0x4c4dff,
"Sinkhole":0x49716d,
"Sinking Sand":0xd8b778,
"Sinner's City":0xfee5cb,
"Sinoper Red":0xbb1111,
"Sinopia":0xcb410b,
"Sip of Mint":0xdedfc9,
"Sip of Nut Milk":0xeae2df,
"Sir Edmund":0x20415d,
"Siren":0x69293b,
"Sirocco":0x68766e,
"Sis Kebab":0x884411,
"Sisal":0xc5baa0,
"Siskin Green":0xc8c76f,
"Siskin Sprout":0x7a942e,
"Site White":0xdcdedc,
"Sitter Red":0x3c2233,
"Sixteen Million Pink":0xfd02ff,
"Sixties Blue":0x0079a9,
"Siyâh Black":0x1c1b1a,
"Sizzling Hot":0xa36956,
"Sizzling Red":0xff3855,
"Sizzling Sunrise":0xffdb00,
"Sizzling Sunset":0xeb7e4d,
"Skarsnik Green":0x5f9370,
"Skavenblight Dinge":0x47413b,
"Skeleton":0xebdecc,
"Skeleton Bone":0xf4ebbc,
"Skeletor's Cape":0x773399,
"Skeptic":0x9db4aa,
"Ski Patrol":0xbb1237,
"Ski Slope":0xe1e5e3,
"Skilandis":0x41332f,
"Skimmed Milk White":0xfeffe3,
"Skin Tone":0xdecaae,
"Skink Blue":0x5cbfce,
"Skinny Dip":0xf9dbd2,
"Skinny Jeans":0x5588ff,
"Skipper":0x748796,
"Skipper Blue":0x484a72,
"Skipping Rocks":0xd1d0c9,
"Skipping Stone":0xd0cbb6,
"Skirret Green":0x51b73b,
"Skobeloff":0x007474,
"Skrag Brown":0xb04e0f,
"Skull":0xe3dac9,
"Skullcrusher Brass":0xf1c78e,
"Skullfire":0xf9f5da,
"Sky":0x76d6ff,
"Sky Babe":0x88c1d8,
"Sky Blue":0x9fb9e2,
"Sky Blue Pink":0xdcbfe1,
"Sky Bus":0x99c1d6,
"Sky Captain":0x262934,
"Sky Chase":0xa5cad1,
"Sky City":0xa0bdd9,
"Sky Cloud":0xaddee5,
"Sky Dancer":0x4499ff,
"Sky Eyes":0x8eaabd,
"Sky Fall":0x89c6df,
"Sky Glass":0xd1dcd8,
"Sky Grey":0xbcc8c6,
"Sky High":0xa7c2eb,
"Sky Light View":0xcadade,
"Sky Lodge":0x546977,
"Sky Magenta":0xcf71af,
"Sky of Magritte":0x0099ff,
"Sky of Ocean":0x82cde5,
"Sky Pilot":0xa2bad4,
"Sky Splash":0xc9d3d3,
"Sky Wanderer":0xb8dced,
"Sky Watch":0x8acfd6,
"Sky's the Limit":0xbbcee0,
"Skyan":0x66ccff,
"Skydiver":0x83acd3,
"Skydiving":0xc6d6d7,
"Skydome":0x38a3cc,
"Skylark":0xc1e4f0,
"Skylight":0xc8e0e0,
"Skyline":0x959eb7,
"Skyline Steel":0xb9c0c3,
"Skylla":0x1f7cc2,
"Skysail Blue":0x818db3,
"Skyscraper":0xd3dbe2,
"Skywalker":0xc1deea,
"Skyway":0xadbed3,
"Slaanesh Grey":0xdbd5e6,
"Slap Happy":0xc9cc4a,
"Slate":0x516572,
"Slate Black":0x4b3d33,
"Slate Blue":0x5b7c99,
"Slate Brown":0xa0987c,
"Slate Green":0x658d6d,
"Slate Grey":0x59656d,
"Slate Mauve":0x625c63,
"Slate Pebble":0xb4ada9,
"Slate Pink":0xb3586c,
"Slate Rock":0x868988,
"Slate Rose":0xb45865,
"Slate Stone":0xacb4ac,
"Slate Tile":0x606e74,
"Slate Tint":0x7a818d,
"Slate Violet":0x989192,
"Slate Wall":0x40535d,
"Sled":0x4c5055,
"Sleek White":0xfaf6e9,
"Sleep":0x4579ac,
"Sleep Baby Sleep":0xbed1e1,
"Sleeping Easy":0x98bddd,
"Sleeping Giant":0x786d5e,
"Sleepy Blue":0xbccbce,
"Sleepy Hollow":0xb7c9d1,
"Sleepy Owlet":0xb5a78d,
"Sleet":0x92949b,
"Slender Reed":0xdec29f,
"Slice of Heaven":0x0022ee,
"Slice of Watermelon":0xe1697c,
"Sliced Cucumber":0xcccfbf,
"Slices of Happy":0xede5bc,
"Slick Blue":0x73ccd8,
"Slick Green":0x615d4c,
"Slick Mud":0xa66e49,
"Sliding":0x97aeaf,
"Slight Mushroom":0xcfc9c5,
"Slightly Golden":0xcb904e,
"Slightly Peach":0xf1ddd8,
"Slightly Rose":0xe6cfce,
"Slightly Spritzig":0x92d2ed,
"Slightly Zen":0xdce4dd,
"Slime":0xa7c408,
"Slime Lime":0xb8ebc5,
"Slimer Green":0xaadd00,
"Slimy Green":0x7ded17,
"Slipper Satin":0xbfc1cb,
"Slippery Moss":0xbeba82,
"Slippery Salmon":0xf87e63,
"Slippery Shale":0x7b766c,
"Slippery Soap":0xefedd8,
"Slippery Stone":0x8d6a4a,
"Slippery Tub":0xd5f3ec,
"Slopes":0xd2b698,
"Slow Dance":0xdbdcc4,
"Slow Green":0xc6d5c9,
"Slow Perch":0xd5d4ce,
"Slubbed Silk":0xe1c2be,
"Sludge":0xca6b02,
"Slugger":0x42342b,
"Slumber":0x2d517c,
"Slumber Sloth":0xcdc5b5,
"Sly Fox":0x804741,
"Sly Shrimp":0xf8e2d9,
"Smallmouth Bass":0xac9a7e,
"Smalt":0x003399,
"Smalt Blue":0x496267,
"Smaragdine":0x4a9976,
"Smart White":0xf6f3ec,
"Smashed Grape":0x8775a1,
"Smashed Potatoes":0xe2d0b9,
"Smashed Pumpkin":0xff6d3a,
"Smashing Pumpkins":0xff5522,
"Smell of Garlic":0xd9ddcb,
"Smell of Lavender":0xdce0ea,
"Smell the Roses":0xbb7283,
"Smells of Fresh Bread":0xd7cecd,
"Smiley Face":0xffc962,
"Smitten":0xc84186,
"Smock Blue":0x3b646c,
"Smoke":0xbfc8c3,
"Smoke & Ash":0x939789,
"Smoke and Mirrors":0xd9e6e8,
"Smoke Blue":0x6688bb,
"Smoke Bush":0xcc7788,
"Smoke Bush Rose":0xad8177,
"Smoke Cloud":0xadb6b9,
"Smoke Dragon":0xccbbaa,
"Smoke Green":0xa8bba2,
"Smoke Grey":0xcebaa8,
"Smoke Pine":0x3e6257,
"Smoke Screen":0xaeaeae,
"Smoke Tree":0xbb5f34,
"Smoked Amethyst":0x5a4351,
"Smoked Black Coffee":0x3b2f2f,
"Smoked Claret":0x583a39,
"Smoked Flamingo":0x674244,
"Smoked Lavender":0xceb5b3,
"Smoked Mauve":0xa89c97,
"Smoked Mulberry":0x725f6c,
"Smoked Oak Brown":0x573f16,
"Smoked Oyster":0xd9d2cd,
"Smoked Paprika":0x6e362c,
"Smoked Pearl":0x656466,
"Smoked Purple":0x444251,
"Smoked Salmon":0xfa8072,
"Smoked Silver":0xddbbcc,
"Smoked Tan":0xaea494,
"Smoked Umber":0xd0c6bd,
"Smokehouse":0x716354,
"Smokescreen":0x5e5755,
"Smokestack":0xbeb2a5,
"Smokey Blue":0x647b84,
"Smokey Claret":0x88716d,
"Smokey Cream":0xe9dfd5,
"Smokey Lilac":0x9a9da2,
"Smokey Pink":0xcebdb4,
"Smokey Slate":0xa5b5ac,
"Smokey Tan":0x9f8c7c,
"Smokey Topaz":0xa57b5b,
"Smokey Wings":0xa7a5a3,
"Smokin Hot":0x954a3d,
"Smoking Mirror":0xa29587,
"Smoking Night Blue":0x43454c,
"Smoking Red":0x992200,
"Smoky":0x605d6b,
"Smoky Azurite":0x708d9e,
"Smoky Beige":0xb9a796,
"Smoky Black":0x100c08,
"Smoky Blue":0x7196a6,
"Smoky Day":0xa49e93,
"Smoky Emerald":0x4c726b,
"Smoky Forest":0x817d68,
"Smoky Grape":0x9b8fa6,
"Smoky Grey Green":0x939087,
"Smoky Mauve":0x998ba5,
"Smoky Mountain":0xafa8a9,
"Smoky Orchid":0xe1d9dc,
"Smoky Pink":0xbb8d88,
"Smoky Quartz":0x51484f,
"Smoky Salmon":0xe2b6a7,
"Smoky Slate":0xa1a18f,
"Smoky Sunrise":0xaa9793,
"Smoky Tone":0x9d9e9d,
"Smoky Topaz":0x7e7668,
"Smoky Trout":0x857d72,
"Smoky White":0xaeada3,
"Smoky Wings":0xb2aca9,
"Smoldering Copper":0xaa6e4b,
"Smooth As Corn Silk":0xf4e4b3,
"Smooth Beech":0xd3bb96,
"Smooth Coffee":0x5d4e4c,
"Smooth Satin":0xa2d5d3,
"Smooth Silk":0xf6ead2,
"Smooth Stone":0xbcb6b3,
"Smooth-Hound Shark":0x97b2b1,
"Smoothie Green":0x988e01,
"Smudged Lips":0xee4466,
"Snail Trail Silver":0xe9eeeb,
"Snake Eyes":0xe9cb4c,
"Snake Fruit":0xdb2217,
"Snake River":0x45698c,
"Snakebite":0xbb4444,
"Snakebite Leather":0xbaa208,
"Snakes in the Grass":0x889717,
"Snap Pea Green":0x8a8650,
"Snap-Shot":0x2b3e52,
"Snapdragon":0xfed777,
"Snappy Happy":0xeb8239,
"Snappy Violet":0xcc0088,
"Snarky Mint":0x9ae37d,
"Sneaky Sesame":0x896a46,
"Sneezy":0x9d7938,
"Snip of Parsley":0x718854,
"Snip of Tannin":0xdccebb,
"Snobby Shore":0xdd7733,
"Snoop":0x49556c,
"Snorkel Blue":0x034f84,
"Snorkel Sea":0x004f7d,
"Snorlax":0x222277,
"Snot":0xacbb0d,
"Snot Green":0x9dc100,
"Snow":0xfffafa,
"Snow Ballet":0xdef1e7,
"Snow Cloud":0xe5e9eb,
"Snow Crystal Green":0xe4f0e8,
"Snow Day":0xf7f5ed,
"Snow Drift":0xe3e3dc,
"Snow Fall":0xf3f2eb,
"Snow Flurry":0xeaf7c9,
"Snow Globe":0xf4f2e9,
"Snow Goose":0xc3d9cb,
"Snow Green":0xc8dac2,
"Snow Leopard":0xcfdfdb,
"Snow Pea":0x6ccc7b,
"Snow Peak":0xe0dcdb,
"Snow Plum":0xf4eaf0,
"Snow Shadow":0xd7e4ed,
"Snow Storm":0xeeedea,
"Snow Tiger":0xdadce0,
"Snow White":0xeeffee,
"Snow White Blush":0xf8afa9,
"Snowball Effect":0xd9e9e5,
"Snowbank":0xe8e9e9,
"Snowbelt":0xeef1ec,
"Snowberry":0xefeced,
"Snowboard":0x74a9b9,
"Snowbound":0xddebe3,
"Snowdrop":0xeeffcc,
"Snowdrop Explosion":0xe0efe1,
"Snowfall":0xe0deda,
"Snowfall White":0xeeede0,
"Snowflake":0xeff0f0,
"Snowglory":0xc8c8c4,
"Snowman":0xfefafb,
"Snowmelt":0xc9e6e9,
"Snowpink":0xf1c5c2,
"Snowshoe Hare":0xe7e3d6,
"Snowstorm Space Shuttle":0x001188,
"Snowy Evergreen":0xedf2e0,
"Snowy Mint":0xd6f0cd,
"Snowy Mount":0xf1eeeb,
"Snowy Pine":0xf0efe3,
"Snowy Shadow":0xd3dbec,
"Snowy Summit":0xc5d8e9,
"Snub":0xa5adbd,
"Snuff":0xe4d7e5,
"Snug Cottage":0xfff9e2,
"Snuggle Pie":0xa58f73,
"So Blue-Berry":0xd4d8e3,
"So Chic!":0xcecdc5,
"So Dainty":0xcdc0c9,
"So Merlot":0x84525a,
"So Much Fawn":0xf1e0cb,
"So Shy":0xdad5d6,
"So Sour":0x00ff11,
"So Sublime":0x8b847c,
"So-Sari":0x006f47,
"Soap":0xcec8ef,
"Soap Bubble":0xb2dcef,
"Soap Green":0xa0b28e,
"Soap Pink":0xe5bfca,
"Soapstone":0xece5da,
"Soar":0xddf0f0,
"Soaring Eagle":0x9badbe,
"Soaring Sky":0xb9e5e8,
"Soccer Turf":0x22bb00,
"Sociable":0xcf8c76,
"Social Butterfly":0xfaf2dc,
"Socialist":0x921a1c,
"Socialite":0x907676,
"Sockeye":0xe49780,
"Soda Pop":0xc3c67e,
"Sodalite Blue":0x253668,
"Sōdenkaracha Brown":0x9b533f,
"Sodium Silver":0xfffcee,
"Sofisticata":0x93806a,
"Soft Amber":0xcfbea5,
"Soft Amethyst":0xcfb7c9,
"Soft Apricot":0xe0b392,
"Soft Bark":0x897670,
"Soft Beige":0xb9b5af,
"Soft Blue":0x6488ea,
"Soft Blue Lavender":0x888cba,
"Soft Blue White":0xdae7e9,
"Soft Blush":0xe3bcbc,
"Soft Boiled":0xffb737,
"Soft Breeze":0xf6f0eb,
"Soft Bromeliad":0x99656c,
"Soft Bronze":0xa18666,
"Soft Buttercup":0xffedbe,
"Soft Candlelight":0xf7eacf,
"Soft Cashmere":0xefb6d8,
"Soft Celadon":0xbfcfc8,
"Soft Celery":0xc4cd87,
"Soft Chamois":0xdbb67a,
"Soft Charcoal":0x838298,
"Soft Cloud":0xd0e3ed,
"Soft Cocoa":0x987b71,
"Soft Coral":0xffeee0,
"Soft Cream":0xf5efd6,
"Soft Denim":0xb9c6ca,
"Soft Doeskin":0xe0cfb9,
"Soft Dove":0xc2bbb2,
"Soft Fawn":0xb59778,
"Soft Feather":0xefe4dc,
"Soft Fern":0xc7d368,
"Soft Fig":0x817714,
"Soft Focus":0xe2efdd,
"Soft Fresco":0xc0d5ca,
"Soft Froth":0xbdccb3,
"Soft Fur":0x7e7574,
"Soft Fuschia":0xd496bd,
"Soft Gossamer":0xfbeede,
"Soft Grass":0xc1dfc4,
"Soft Green":0x6fc276,
"Soft Greige":0xd7c3b5,
"Soft Heather":0xbea8b7,
"Soft Ice Rose":0xe7cfca,
"Soft Impact":0xb28ea8,
"Soft Impala":0xa28b7e,
"Soft Iris":0xe6e3eb,
"Soft Ivory":0xfbf1df,
"Soft Kind":0xd1d2be,
"Soft Lace":0xf5ede5,
"Soft Lavender":0xf6e5f6,
"Soft Leather":0xd9a077,
"Soft Lilac":0xe2d4df,
"Soft Lumen":0xbeddba,
"Soft Matte":0xdd99bb,
"Soft Metal":0xbab2b1,
"Soft Mint":0xe6f9f1,
"Soft Moonlight":0xefecd7,
"Soft Moss":0xcce1c7,
"Soft Muslin":0xf7eadf,
"Soft Olive":0x59604f,
"Soft Orange":0xeec0ab,
"Soft Orange Bloom":0xffdcd2,
"Soft Peach":0xeedfde,
"Soft Peach Mist":0xfff3f0,
"Soft Pearl":0xefe7db,
"Soft Petals":0xebf8ef,
"Soft Pink":0xfdb0c0,
"Soft Pumice":0x949ea2,
"Soft Purple":0xa66fb5,
"Soft Red":0x412533,
"Soft Sage":0xbcbcae,
"Soft Salmon":0xeaaaa2,
"Soft Satin":0xeec5ce,
"Soft Savvy":0x837e87,
"Soft Secret":0xd6d4ca,
"Soft Shoe":0xe8d5c6,
"Soft Sienna":0xd09f93,
"Soft Silver":0xf7f9e9,
"Soft Sky":0xb5b5cb,
"Soft Steel":0x404854,
"Soft Straw":0xf5d180,
"Soft Suede":0xd8cbad,
"Soft Summer Rain":0xa1d7ef,
"Soft Sunrise":0xf2e3d8,
"Soft Tone":0xc3b3b2,
"Soft Tone Ink":0x9d6016,
"Soft Touch":0x639b95,
"Soft Turquoise":0x74ced2,
"Soft Violet":0xe9e6e2,
"Soft Wheat":0xd9bd9c,
"Softened Green":0xbbbca7,
"Softer Tan":0xdacab2,
"Softly Softly":0xc9b7ce,
"Softsun":0xf3ca40,
"Software":0x7f8486,
"Sohi Orange":0xe0815e,
"Sohi Red":0xe35c38,
"Soho Red":0xab6953,
"Soil Of Avagddu":0x845c00,
"Sojourn Blue":0x416f8b,
"Solar":0xfbeab8,
"Solar Ash":0xcc6622,
"Solar Energy":0xf7da74,
"Solar Flare":0xe67c41,
"Solar Fusion":0xdc9f46,
"Solar Light":0xfaf0c9,
"Solar Power":0xf4bf3a,
"Solar Storm":0xffc16c,
"Solar Wind":0xfce9b9,
"Solaria":0xf5d68f,
"Solarium":0xe1ba36,
"Soldier Green":0x545a2c,
"Solé":0xf7dda1,
"Soleil":0xe9cb2e,
"Solemn Silence":0xd3d8d8,
"Solid Empire":0x635c59,
"Solid Gold":0xb7d24b,
"Solid Opal":0xeeeae2,
"Solid Pink":0xc78b95,
"Solid Snake":0xa1a58c,
"Solitaire":0xc6decf,
"Solitary Slate":0x80796d,
"Solitary State":0xc4c7c4,
"Solitary Tree":0x539b6a,
"Solitude":0xe9ecf1,
"Solo":0xcbd2d0,
"Solstice":0xbabdb8,
"Solution":0x77abab,
"Somali Brown":0x6c5751,
"Somber":0xcbb489,
"Somber Green":0x005c2b,
"Sombre Grey":0x555470,
"Sombrero":0xb39c8c,
"Sombrero Tan":0xcba391,
"Someday":0xefe4cc,
"Something Blue":0xb0d6e6,
"Sommelier":0x5d3736,
"Somnambulist":0x778899,
"Sonata":0xabc8d8,
"Sonata Blue":0x8a9eae,
"Song Bird":0x0078af,
"Song of Summer":0xfce7b5,
"Song Thrush":0xaf987f,
"Song Thrush Egg":0xf2e5e0,
"Songbird":0xa3d1eb,
"Sonia Rose":0xf3c8c2,
"Sonic Blue":0x17569b,
"Sonic Silver":0x757575,
"Sonoma Chardonnay":0xddcb91,
"Sonoma Sage":0x90a58a,
"Sonoma Sky":0xbfd1ca,
"Sonora Apricot":0xe0b493,
"Sonora Hills":0xbea77d,
"Sonora Rose":0xe8d2e3,
"Sonora Shade":0xc89672,
"Sonoran Desert":0xcfb8a1,
"Sonoran Sands":0xddd5c6,
"Sonorous Bells":0xfaf0cb,
"Soooo Bloody":0x550000,
"Soot":0x555e5f,
"Soothing Breeze":0xb3bec4,
"Soothing Pink":0xf2e7de,
"Soothing Sea":0xc3e9e4,
"Soothing Spring":0xbccbc4,
"Soothing White":0xe1e2e4,
"Soothsayer":0x8092bc,
"Sooty":0x141414,
"Sooty Willow Bamboo":0x4d4b3a,
"Sophisticated Lilac":0x956c87,
"Sophisticated Plum":0x5d5153,
"Sophisticated Teal":0x537175,
"Sophistication":0xbfb5a6,
"Sophomore":0x7d7170,
"Sora Blue":0xa0d8ef,
"Sora Sky":0x4d8fac,
"Sorbet Ice Mauve":0xa1a6d6,
"Sorbet Yellow":0xdac100,
"Sorbus":0xdd6b38,
"Sorcerer":0x3398ce,
"Sorrel Brown":0x9b6d51,
"Sorrel Felt":0xa49688,
"Sorrel Leaf":0x887e64,
"Sorrell Brown":0x9d7f61,
"Sorx Red":0xfc0156,
"Sotek Green":0x47788a,
"Soufflé":0xedd1a8,
"Soul Quenching":0x7e989d,
"Soul Search":0x377290,
"Soul Side":0xffaa55,
"Soul Train":0x58475e,
"Soulful":0x374357,
"Soulful Blue":0x757c91,
"Soulful Music":0x3b4457,
"Soulmate":0x85777b,
"Soulstone Blue":0x0047ab,
"Sounds of Nature":0xdfe5d7,
"Sour Apple":0xa0ac4f,
"Sour Apple Rings":0x33bb00,
"Sour Bubba":0x8b844e,
"Sour Candy":0x66b348,
"Sour Face":0xadc979,
"Sour Green":0xc1e613,
"Sour Green Cherry":0xc8ffb0,
"Sour Lemon":0xffeea5,
"Sour Patch Peach":0xf4d9c5,
"Sour Tarts":0xfee5c8,
"Sour Yellow":0xeeff04,
"Source Blue":0xcdeae5,
"Source Green":0x84b6a2,
"Sourdough":0xc9b59a,
"South Kingston":0x76614b,
"South Pacific":0x698694,
"South Peach":0xead2bb,
"South Peak":0xeadfd2,
"South Rim Trail":0xa6847b,
"South Shore Sun":0xffdc9e,
"Southern Barrens Mud":0xb98258,
"Southern Beauty":0xf7dddb,
"Southern Belle":0xa6d6c3,
"Southern Blue":0x365787,
"Southern Breeze":0xe4dfd1,
"Southern Evening":0x34657d,
"Southern Moss":0xbca66a,
"Southern Pine":0xacb4ab,
"Southern Platyfish":0xd0d34d,
"Southwest Stone":0xde9f85,
"Southwestern Clay":0xcc6758,
"Southwestern Sand":0xede0ce,
"Sovereign":0x4b4356,
"Sovereignty":0x304e63,
"Soy Milk":0xd5d2c7,
"Soya":0xfae3bc,
"Soya Bean":0x6f634b,
"Soybean":0xd2c29d,
"Soylent Green":0x578363,
"Spa":0xceece7,
"Spa Blue":0xd3dedf,
"Spa Dream":0x1993be,
"Spa Retreat":0xd4e4e6,
"Spa Sangria":0xd7c9a5,
"Space Angel":0x3b4271,
"Space Black":0x505150,
"Space Cadet":0x1d2951,
"Space Convoy":0x667788,
"Space Dust":0x002299,
"Space Exploration":0x001199,
"Space Explorer":0x114499,
"Space Grey":0x110022,
"Space Invader":0x139d08,
"Space Opera":0x5511dd,
"Space Shuttle":0x4b433b,
"Space Station":0x6c6d7a,
"Space Wolves Grey":0xdae6ef,
"Spacebox":0x5c6b6b,
"Spaceman":0x5f6882,
"Spacescape":0x222255,
"Spacious Grey":0x877d75,
"Spacious Plain":0x9a8557,
"Spacious Skies":0xd5eaf2,
"Spacious Sky":0xaeb5c7,
"Spade Black":0x424142,
"Spaghetti":0xfef69e,
"Spaghetti Carbonara":0xddddaa,
"Spaghetti Monster":0xeecc88,
"Spaghetti Strap Pink":0xfbaed2,
"Spalding Gray":0x8d7f75,
"Spandex Green":0x36b14e,
"Spangle":0xe5dbe5,
"Spanish Bistre":0x807532,
"Spanish Blue":0x0070b8,
"Spanish Carmine":0xd10047,
"Spanish Chestnut":0x7f5f52,
"Spanish Cream":0xfce5c0,
"Spanish Crimson":0xe51a4c,
"Spanish Galleon":0x817863,
"Spanish Gold":0xb09a4f,
"Spanish Green":0x7b8976,
"Spanish Grey":0x989898,
"Spanish Lace":0xfce8ca,
"Spanish Leather":0x8e6a3f,
"Spanish Mustang":0x684b40,
"Spanish Olive":0xa1a867,
"Spanish Orange":0xe86100,
"Spanish Peanut":0xc57556,
"Spanish Pink":0xf7bfbe,
"Spanish Plum":0x5c3357,
"Spanish Purple":0x66033c,
"Spanish Raisin":0x61504e,
"Spanish Red":0xe60026,
"Spanish Roast":0x111133,
"Spanish Sand":0xcab08e,
"Spanish Sky Blue":0x00fffe,
"Spanish Style":0x93765c,
"Spanish Villa":0xdfbaa9,
"Spanish Violet":0x4c2882,
"Spanish Viridian":0x007f5c,
"Spanish White":0xded1b7,
"Spanish Yellow":0xf6b511,
"Spare White":0xe4e4dd,
"Sparkle Glow":0xf5d2b5,
"Sparkler":0xffee99,
"Sparkling Apple":0x77b244,
"Sparkling Blueberry Lemonade":0xc15187,
"Sparkling Brook":0xdceee3,
"Sparkling Champagne":0xefcf98,
"Sparkling Cider":0xfffdeb,
"Sparkling Cove":0x2da4b6,
"Sparkling Emerald":0x1f6c53,
"Sparkling Frost":0xd2d5da,
"Sparkling Grape":0x773376,
"Sparkling Green":0x66ee00,
"Sparkling Lavender":0xeeccff,
"Sparkling Metal":0xc3c3c7,
"Sparkling Pink":0xf5cee6,
"Sparkling Purple":0xcc11ff,
"Sparkling Red":0xee3333,
"Sparkling River":0xd6edf1,
"Sparkling Silver":0xcbd0cd,
"Sparkling Spring":0xd9e3e0,
"Sparks In The Dark":0xff7711,
"Sparrow":0x69595c,
"Sparrow Grey Red":0x523e47,
"Sparrow’s Fire":0xff6622,
"Spartacus":0x76a4a7,
"Spartan Blue":0x7a8898,
"Spartan Crimson":0x9e1316,
"Spartan Stone":0xafa994,
"Spatial Spirit":0xc1edd3,
"Spatial White":0xdedddb,
"Spätzle Yellow":0xffee88,
"Speak To Me":0xffd9a6,
"Speakeasy":0x826a6c,
"Speaking of the Devil":0xa8415b,
"Spear Shaft":0x885500,
"Spearfish":0x5fb6bf,
"Spearmint":0x64bfa4,
"Spearmint Frosting":0x8dc2a8,
"Spearmint Ice":0xbfd3cb,
"Spearmint Stick":0xe8f0e2,
"Spearmint Water":0xb1eae8,
"Spearmints":0xbce3c9,
"Special Delivery":0xa5b2b7,
"Special Gray":0x7b787d,
"Special Ops":0x868b53,
"Species":0xdcd867,
"Speckled Easter Egg":0xd38798,
"Spectacular Purple":0xbb00ff,
"Spectra":0x375d4f,
"Spectra Green":0x009b8c,
"Spectra Yellow":0xf7b718,
"Spectral Green":0x008664,
"Spectrum Blue":0x3d3c7c,
"Speedboat":0x90bfd4,
"Speeding Ticket":0xf9f1d7,
"Speedwell":0x5a6272,
"Spell":0x5e4f50,
"Spell Caster":0x4a373e,
"Spelt Grain Brown":0xa38c6b,
"Spelunking":0x35465e,
"Sphagnales Moss":0xa5ad44,
"Sphagnum Moss":0x75693d,
"Sphere":0xf2e8cc,
"Sphinx":0xab9895,
"Spice":0x6c4f3f,
"Spice Bazaar":0x86613f,
"Spice Cake":0xb87243,
"Spice Cookie":0xf0ded3,
"Spice Delight":0xf3e9cf,
"Spice Garden":0xc9d6b4,
"Spice Girl":0xe1c2c1,
"Spice Is Nice":0xebd0a4,
"Spice Ivory":0xf4eedc,
"Spice of Life":0x86493f,
"Spice Route":0xb95b3f,
"Spiceberry":0x604941,
"Spiced Apple":0x783937,
"Spiced Beige":0xe9d2bb,
"Spiced Berry":0x85443f,
"Spiced Brandy":0xbb9683,
"Spiced Butternut":0xffd978,
"Spiced Carrot":0xa4624c,
"Spiced Cashews":0xd3b080,
"Spiced Cider":0x915b41,
"Spiced Cinnamon":0x805b48,
"Spiced Coral":0xd75c5d,
"Spiced Honey":0xa38061,
"Spiced Hot Chocolate":0x53433e,
"Spiced Latte":0x886c57,
"Spiced Mustard":0xb99563,
"Spiced Nectarine":0xffbb72,
"Spiced Nutmeg":0x927d6c,
"Spiced Orange":0xedc7b6,
"Spiced Plum":0x6d4773,
"Spiced Potpourri":0x905d5f,
"Spiced Pumpkin":0xd88d56,
"Spiced Red":0x8b4c3d,
"Spiced Rum":0xad8b6a,
"Spiced Tea":0xab6162,
"Spiced Up":0xb14b38,
"Spiced Vinegar":0xcdba99,
"Spiced Wine":0x664942,
"Spicy":0xff1111,
"Spicy Berry":0xcc3366,
"Spicy Cayenne":0x9b5b4f,
"Spicy Hue":0x994b35,
"Spicy Hummus":0xeebbaa,
"Spicy Mix":0x8b5f4d,
"Spicy Mustard":0x74640d,
"Spicy Orange":0xd73c26,
"Spicy Pink":0xff1cae,
"Spicy Red":0x97413e,
"Spicy Sweetcorn":0xf6ac00,
"Spicy Tomato":0xc75433,
"Spider Cotton":0xe2e8df,
"Spike":0x656271,
"Spiked Apricot":0xfdddb7,
"Spikey Red":0x600000,
"Spill the Beans":0x9b351b,
"Spilled Cappuccino":0xe4e1de,
"Spilt Milk":0xf4f4d1,
"Spinach Banana Smoothie":0xaaaa55,
"Spinach Dip":0xb1cdac,
"Spinach Green":0x909b4c,
"Spinach Soup":0x6e750e,
"Spinach White":0xe4e8da,
"Spindle":0xb3c4d8,
"Spindrift":0x73fcd6,
"Spinel Black":0x41435b,
"Spinel Grey":0x6a5662,
"Spinel Stone Black":0x272a3b,
"Spinel Violet":0x38283d,
"Spinnaker":0xa3e2dd,
"Spinning Blue":0x5b6a7c,
"Spinning Silk":0xf3ddbc,
"Spinning Wheel":0xf6edda,
"Spirit":0xb2bbc6,
"Spirit Dance":0x514b80,
"Spirit Mountain":0x6a8b98,
"Spirit Rock":0x5f534e,
"Spirit Warrior":0xd45341,
"Spirit Whisper":0xe3eebf,
"Spirited Away":0xfde7e3,
"Spirited Green":0xbddec7,
"Spirited Yellow":0xffdc83,
"Spiritstone Red":0xfd411e,
"Spiro Disco Ball":0x0fc0fc,
"Spirulina":0x5a665c,
"Spitsbergen Blue":0x6f757d,
"Splash":0xf1d79e,
"Splash Of Grenadine":0xf984e5,
"Splash of Honey":0xd8b98c,
"Splash Palace":0x5984b0,
"Splashing Wave":0x44ddff,
"Splashy":0x019196,
"Splatter":0xa9586c,
"Spleen Green":0xccee00,
"Splendiferous":0x806e7c,
"Splendor":0xf3dfcc,
"Splendor and Pride":0x5870a4,
"Splendor Gold":0xffb14e,
"Splinter":0xa3713f,
"Splish Splash":0x3194ce,
"Split Pea":0x9c9a40,
"Split Pea Soup":0xc8b165,
"Split Rail":0x8e6c51,
"Spoiled Egg":0xe8ff2a,
"Spoiled Rotten":0xb6bfe5,
"Sponge":0xa49775,
"Sponge Cake":0xfffe40,
"Spooky":0xd1d2bf,
"Spooky Ghost":0xd4d1d9,
"Spooky Graveyard":0x685e4f,
"Spooled White":0xf5eae3,
"Spoonful of Sugar":0xe7e9e3,
"Spores":0x7f8162,
"Sport Green":0x00a27d,
"Sport Yellow":0xefd678,
"Sporting Green":0x434c47,
"Sports Blue":0x399bb4,
"Sports Fan":0xe08119,
"Sports Field Green":0x4d8064,
"Sporty Blue":0x6a8aa4,
"Spotlight":0xfaeacd,
"Spotted Dove":0xbfbfbd,
"Spotted Snake Eel":0xb1d3e3,
"Spray":0x7ecddd,
"Spray Green":0xaea692,
"Spray of Mint":0xbdd0c3,
"Spreadsheet Green":0x007711,
"Sprig Muslin":0xd6c1c5,
"Sprig of Mint":0x8be0ba,
"Spring":0x00f900,
"Spring Blossom":0xe9edbd,
"Spring Bouquet":0x6dce87,
"Spring Boutique":0xd7b9cb,
"Spring Bud":0xa7fc00,
"Spring Burst":0xc9e0c8,
"Spring Buttercup":0xfff6c2,
"Spring Crocus":0xba69a1,
"Spring Day":0xdbd7b7,
"Spring Fever":0xe5e3bf,
"Spring Fields":0xb3cdac,
"Spring Fog":0xecf1ec,
"Spring Forest":0x67926f,
"Spring Forth":0x11bb22,
"Spring Frost":0x87ff2a,
"Spring Garden":0x558961,
"Spring Glow":0xd3e0b8,
"Spring Grass":0xd5cb7f,
"Spring Green":0x00ff7c,
"Spring Grey":0xc5c6b3,
"Spring Heat":0xfffddd,
"Spring Hill":0xc4cbb2,
"Spring Juniper":0x4a754a,
"Spring Kiss":0xe3efb2,
"Spring Leaves":0xa8c3aa,
"Spring Lilac":0xb1b3cb,
"Spring Lily":0xfcf4c8,
"Spring Lobster":0x640125,
"Spring Lobster Brown":0x6c2c2f,
"Spring Lobster Dye":0x7a4171,
"Spring Marsh":0xc0b05d,
"Spring Mist":0xd3e0de,
"Spring Morn":0xe5f0d5,
"Spring Moss":0xa99757,
"Spring Onion":0x596c3c,
"Spring Pink":0xdfbcc9,
"Spring Rain":0xa3bd9c,
"Spring Reflection":0xa1bfab,
"Spring Roll":0xc4a661,
"Spring Savor":0xcceecc,
"Spring Shoot":0xe2edc1,
"Spring Shower":0xabdcee,
"Spring Slumber Green":0xb8f8b8,
"Spring Song":0xfaccbf,
"Spring Sprig":0xa2c09b,
"Spring Sprout":0x86ba4a,
"Spring Storm":0xa9c6cb,
"Spring Stream":0x98beb2,
"Spring Sun":0xf1f1c6,
"Spring Thaw":0xd9dcdd,
"Spring Thyme":0xd8dcb3,
"Spring Valley":0xced7c5,
"Spring Walk":0xacb193,
"Spring Water Turquoise":0x7ab5ae,
"Spring Wheat":0xe0eed4,
"Spring White":0xecfcec,
"Spring Wisteria":0xcda4de,
"Spring Wood":0xe9e1d9,
"Spring Yellow":0xf2e47d,
"Springtide Green":0xc8cb8e,
"Springtime":0xe9e5b3,
"Springtime Bloom":0xdb88ac,
"Springtime Dew":0xffffef,
"Springtime Rain":0xebeef3,
"Springview Green":0x7ea15a,
"Sprinkle":0xebddea,
"Sprite Twist":0xb9dcc3,
"Spritzig":0x76c5e7,
"Sprout":0xb8ca9d,
"Sprout Green":0xcbd7d2,
"Spruce":0x0a5f38,
"Spruce Shade":0x91a49d,
"Spruce Stone":0x9fc09c,
"Spruce Tree Flower":0xb35e97,
"Spruce Woods":0x6e6a51,
"Spruce Yellow":0xbe8a4a,
"Spruced Up":0x9a7f28,
"Spumoni":0xbccfa4,
"Spun Cotton":0xf3ecdc,
"Spun Jute":0xf4e4cf,
"Spun Pearl":0xa2a1ac,
"Spun Sugar":0xfae2ed,
"Spun Wool":0xe3ded4,
"SQL Injection Purple":0x5e0092,
"Squant":0x666666,
"Squash":0xf2ab15,
"Squash Bisque":0xe7b17c,
"Squash Blossom":0xf8b438,
"Squeaky":0x6cc4da,
"Squeeze Toy Alien":0x11ee00,
"Squid Hat":0x6e2233,
"Squid Ink Powder":0x001133,
"Squid Pink":0xf5b4bd,
"Squid's Ink":0x4d4e5c,
"Squig Orange":0xaa4f44,
"Squirrel":0x8f7d6b,
"Squirrel's Nest":0x665e48,
"Squirt":0x95bcc5,
"Sriracha":0xf56961,
"St. Augustine":0xd0ddcc,
"St. Bart's":0x577c88,
"St. Nicholas Beard":0xeedddd,
"St. Patrick":0x2b8c4e,
"St. Patrick's Blue":0x23297a,
"St. Petersburg":0xdee8f3,
"St. Tropez":0x325482,
"Stability":0xc1d0b2,
"Stable Hay":0xf6e0be,
"Stack":0x858885,
"Stacked Limestone":0xd1b992,
"Stacked Stone":0x918676,
"Stadium Grass":0xd5f534,
"Stadium Lawn":0x9af764,
"Stag Beetle":0x603b41,
"Stage Gold":0x9e6928,
"Stage Mauve":0xb081aa,
"Stagecoach":0x7f5a44,
"Stained Glass":0x556682,
"Stainless Steel":0xb4bdc7,
"Stairway to Heaven":0x67716e,
"Stalactite Brown":0xd4c4a7,
"Stalk":0x7cb26e,
"Stamina":0xb0a8ad,
"Stamp Pad Green":0x2ea18c,
"Stamped Concrete":0xa0a09a,
"Stand Out":0x7f8596,
"Standby Led":0xff0066,
"Standing Ovation":0xbfb9bd,
"Standing Waters":0x005599,
"Standish Blue":0x85979a,
"Stanford Green":0x658f7c,
"Stanford Stone":0xbcab9c,
"Stanger Red":0xa40000,
"Stanley":0x9bc2b4,
"Star":0xffe500,
"Star Anise":0x5c5042,
"Star Bright":0xe8ddae,
"Star City":0x5796a1,
"Star Command Blue":0x007bb8,
"Star Dust":0xf9f3dd,
"Star Fruit Yellow Green":0xbeaa4a,
"Star Grass":0x75dbc1,
"Star Magic":0xe4d8d8,
"Star Map":0xdae2e9,
"Star Mist":0xb3c6ce,
"Star of Gold":0xebe3c7,
"Star of Life":0x057bc1,
"Star of Morning":0xebbbbe,
"Star Sapphire":0x386192,
"Star Shine":0xf8f6e3,
"Star Spangled":0x3a5779,
"Star White":0xefefe8,
"Star-Studded":0xf7ebac,
"Starboard":0x016c4f,
"Starbright":0xf5ecc9,
"Starbur":0x6cb037,
"Starburst":0xdce7e5,
"Stardew":0xa6b2b5,
"Stardust":0xddd3ae,
"Stardust Ballroom":0xdacfd4,
"Stardust Evening":0xb8bfdc,
"Starfish":0xe5bca5,
"Starfleet Blue":0x0096ff,
"Starflower Blue":0x4e9ab0,
"Starfox":0xf0e8d5,
"Starfruit":0xe4d183,
"Stargate":0xb7c4d3,
"Stargate Shimmer":0x7777ff,
"Stargazer":0x39505c,
"Stargazing":0x414549,
"Starglider":0xfaeede,
"Stark White":0xd2c6b6,
"Starless Night":0x3e4855,
"Starlet":0x854e51,
"Starlet Pink":0xedc2db,
"Starlight":0xbcc0cc,
"Starlight Blue":0xb5ced4,
"Starling's Egg":0xe8dfd8,
"Starlit Eve":0x384351,
"Starlit Night":0x3b476b,
"Starry Night":0x286492,
"Starry Sky Blue":0x4f5e7e,
"Starset":0x758ba4,
"Starship":0xe3dd39,
"Starship Tonic":0xcce7e8,
"Starship Trooper":0x229966,
"Starstruck":0x4664a5,
"Startling Orange":0xe56131,
"Stately Frills":0xc5bdc4,
"Stately Stems":0x577a6c,
"Stately White":0xfaf9ea,
"Static":0xd5d3c3,
"Statue of Liberty":0x376d64,
"Statued":0xd0bcb1,
"Statuesque":0xe0dfd9,
"Status Bronze":0xdc8a30,
"Stay in Lime":0x9fac5c,
"Steadfast":0x4a5777,
"Steady Brown":0x8a6b4d,
"Stealth Jet":0x4b4844,
"Steam":0xdddddd,
"Steam Bath":0xccd0da,
"Steam Chestnut":0xebe1a9,
"Steam Engine":0xb2b2ad,
"Steam White":0xe8e9e5,
"Steamboat Geyser":0xd2ccb4,
"Steamed Chai":0xe0d4bd,
"Steamed Chestnut":0xd3b17d,
"Steamed Milk":0xead8be,
"Steamed Salmon":0xee8888,
"Steamy Dumpling":0xeae9b4,
"Steamy Spring":0xb1cfc7,
"Steel":0x797979,
"Steel Armor":0x767275,
"Steel Blue":0x4682b4,
"Steel Blue Eyes":0x7d94c6,
"Steel Blue Grey":0x436175,
"Steel Grey":0x43464b,
"Steel Legion Drab":0x7a744d,
"Steel Light Blue":0x5599b6,
"Steel Me":0xddd5ce,
"Steel Pan Mallet":0x71a6a1,
"Steel Pink":0xcc33cc,
"Steel Teal":0x5f8a8b,
"Steel Wool":0x777777,
"Steely Gray":0x90979b,
"Steeple Grey":0x827e7c,
"Stegadon Scale Green":0x074863,
"Steiglitz Fog":0x415862,
"Stella":0xf5d056,
"Stella Dora":0xf9daa5,
"Stellar":0x46647e,
"Stellar Explorer":0x002222,
"Stellar Light":0xfff4dd,
"Stellar Mist":0xab9d9c,
"Stem Green":0xabdf8f,
"Stencil Blue":0xb4ceda,
"Steppe Green":0x7d7640,
"Stepping Stone":0xa4a7a4,
"Stepping Stones":0xb2a18c,
"Sterling":0xd1d4d1,
"Sterling Blue":0xa2b9c2,
"Sterling Shadow":0xe9ebde,
"Sterling Silver":0x9eafc2,
"Stetson":0x9e7a58,
"Steveareno Beige":0xc5b5a4,
"Sticks & Stones":0xbaa482,
"Sticky Black Tarmac":0x112111,
"Sticky Toffee":0xcc8149,
"Stieglitz Silver":0x8d8f8e,
"Stil De Grain Yellow":0xfadb5e,
"Stiletto":0x323235,
"Stiletto Love":0xb6453e,
"Still":0xadaf9c,
"Still Fuchsia":0xc154c0,
"Still Grey":0xaba9a0,
"Still Moment":0xcbc4b2,
"Still Morning":0xfff8e1,
"Still Water":0x4a5d5f,
"Stillwater":0x70a4b0,
"Stillwater Lake":0xc2d0df,
"Stilted Stalks":0xa29a6a,
"Stinging Nettle":0x495d39,
"Stinging Wasabi":0xaefd6c,
"Stingray Grey":0xb0aba3,
"Stinkhorn":0x2a545c,
"Stirland Battlemire":0xae5a2c,
"Stirland Mud":0x492b00,
"Stirring Orange":0xf6b064,
"Stizza":0x900910,
"Stock Horse":0x806852,
"Stockade Green":0x104f4a,
"Stocking White":0xe9e5d8,
"Stockleaf":0x647b72,
"Stoic White":0xe0e0ff,
"Stolen Kiss":0xefdcd3,
"Stomy Shower":0x0088b0,
"Stone":0xada587,
"Stone Blue":0x829ca5,
"Stone Bridge":0x52706c,
"Stone Brown":0xb79983,
"Stone Craft":0x7d867c,
"Stone Creek":0x8f9183,
"Stone Cypress Green":0x5f7d6c,
"Stone Fence":0x929c9c,
"Stone Fruit":0xf2a28c,
"Stone Golem":0xc2cbd2,
"Stone Green":0x658e67,
"Stone Grey":0x9f9484,
"Stone Guardians":0xcaba97,
"Stone Harbour":0xe8e0d8,
"Stone Hearth":0x636869,
"Stone Lion":0xb3a491,
"Stone Mason":0x7a7b75,
"Stone Mill":0xb6b7ad,
"Stone Path":0xe4efe5,
"Stone Pillar":0xefe5d4,
"Stone Pine":0x665c46,
"Stone Quarry":0xece4dc,
"Stone Silver":0x8ba8ae,
"Stone Terrace":0xa09484,
"Stone Violet":0x4d404f,
"Stone Walkway":0xb5b09e,
"Stone Wall":0xefe1d8,
"Stone Walls":0xafa791,
"Stone Wash":0xe5d4c0,
"Stone's Throw":0x605c58,
"Stonebread":0xddcea7,
"Stonebriar":0xcba97e,
"Stonecrop":0xa08f6f,
"Stonegate":0x99917e,
"Stonehenge Greige":0xa79d8d,
"Stonelake":0xbab1a3,
"Stonetalon Mountains":0x8d7a4d,
"Stonewall":0x807661,
"Stonewall Grey":0xc1c1c1,
"Stonewash":0x74809a,
"Stonewashed":0xddd7c5,
"Stonewashed Brown":0xdcccc0,
"Stonewashed Pink":0xf4eee4,
"Stonish Beige":0xccb49a,
"Stony Creek":0x948f82,
"Stony Field":0x615547,
"Stop":0xc33a36,
"Storksbill":0xe5e1dd,
"Storksbill White":0xf2f2e2,
"Storm":0x444400,
"Storm Blue":0x507b9c,
"Storm Break":0x938988,
"Storm Cloud":0x808283,
"Storm Dust":0x65645f,
"Storm Front":0x787376,
"Storm Green":0x113333,
"Storm Grey":0x717486,
"Storm Lightning":0xf9e69c,
"Storm Petrel":0x7f95a5,
"Storm Red":0xa28a88,
"Storm Warning":0x696863,
"Storm's Coming":0xcfc9bc,
"Stormeye":0xe7b57f,
"Stormfang":0x80a7c1,
"Stormhost Silver":0xbbc6c9,
"Storms Mountain":0x8d9390,
"Stormvermin Fur":0x5c5954,
"Stormy":0xb0bcc3,
"Stormy Bay":0x9aafaf,
"Stormy Grey":0x7d7b7c,
"Stormy Horizon":0x777799,
"Stormy Mauve":0x71738c,
"Stormy Oceans":0x70818e,
"Stormy Pink":0xe3b5ad,
"Stormy Ridge":0x507b9a,
"Stormy Sea":0x6e8082,
"Stormy Strait Green":0x0f9b8e,
"Stormy Strait Grey":0x6b8ba4,
"Stormy Sunrise":0xc8a2c8,
"Stormy Weather":0x58646d,
"Stout":0x0f0b0a,
"Stowaway":0x7b8393,
"Straightforward Green":0x52a550,
"Straken Green":0x628026,
"Stranglethorn Ochre":0xdbb060,
"Stratford Blue":0x528a9a,
"Stratford Sage":0x8c8670,
"Stratos":0x000741,
"Stratos Blue":0x3799c8,
"Stratosphere":0x9ec1cc,
"Stratus":0x8193aa,
"Stravinsky":0x996e74,
"Stravinsky Pink":0x77515a,
"Straw":0xe4d96f,
"Straw Basket":0xd9c69a,
"Straw Gold":0xfcf679,
"Straw Harvest":0xdbc8a2,
"Straw Hat":0xf0d5a8,
"Straw Hut":0xbdb268,
"Straw Yellow":0xf0d696,
"Strawberry":0xfb2943,
"Strawberry Blonde":0xffdadc,
"Strawberry Confection":0xf4bfc6,
"Strawberry Cough":0x990011,
"Strawberry Cream":0xf4c3c4,
"Strawberry Daiquiri":0xa23d50,
"Strawberry Dreams":0xff88aa,
"Strawberry Dust":0xfff0ea,
"Strawberry Frappe":0xffa2aa,
"Strawberry Freeze":0xc677a8,
"Strawberry Frosting":0xff6ffc,
"Strawberry Glaze":0xdab7be,
"Strawberry Ice":0xe78b90,
"Strawberry Jam":0x86423e,
"Strawberry Jubilee":0xc08591,
"Strawberry Milkshake Red":0xd47186,
"Strawberry Mousse":0xa5647e,
"Strawberry Pink":0xf57f8e,
"Strawberry Pop":0xee2255,
"Strawberry Rhubarb":0xb96364,
"Strawberry Rose":0xe29991,
"Strawberry Shortcake":0xfa8e99,
"Strawberry Smash":0xee0055,
"Strawberry Smoothie":0xe79ea6,
"Strawberry Soap":0xf7879a,
"Strawberry Spinach Red":0xfa4224,
"Strawberry Surprise":0xb9758d,
"Strawberry Whip":0xf9d7cd,
"Strawberry Wine":0xcb6a6b,
"Strawberry Yogurt":0xe9b3b4,
"Strawflower":0xddbdba,
"Stream":0x495e7b,
"Streetwise":0xd8e2df,
"Stretch Limo":0x2b2c30,
"Streusel Cake":0xd7aa60,
"Strike a Pose":0x5a4659,
"Strike It Rich":0xd7b55f,
"Strikemaster":0x946a81,
"Striking":0x00667b,
"Striking Purple":0x944e87,
"Striking Red":0xc03543,
"String":0xaa9f96,
"String Ball":0xf1e8d8,
"String Cheese":0xfbf1dd,
"String Deep":0x7f7860,
"String of Pearls":0xebe3d8,
"Stromboli":0x406356,
"Strong Blue":0x0c06f7,
"Strong Cerise":0x960056,
"Strong Envy":0x782e2c,
"Strong Iris":0x5e5f7e,
"Strong Mocha":0x6f372d,
"Strong Mustard":0xa88905,
"Strong Olive":0x646756,
"Strong Pink":0xff0789,
"Strong Sage":0x2b6460,
"Strong Strawberry":0x8a3e34,
"Strong Tone Wash":0x454129,
"Strong Winds":0xa3a59b,
"Stroopwafel":0xa86f48,
"Struck by Lightning":0xf0e1e8,
"Structural Blue":0x0e9bd1,
"Stucco":0xa58d7f,
"Stucco Tan":0xe8dece,
"Stucco Wall":0xf1b19d,
"Stucco White":0xe2d3b9,
"Studer Blue":0x005577,
"Studio":0x724aa1,
"Studio Beige":0xc1b2a1,
"Studio Blue Green":0x6d817b,
"Studio Clay":0xd9ccb8,
"Studio Cream":0xebdbaa,
"Studio Mauve":0xc6b9b8,
"Studio Taupe":0xa59789,
"Studio White":0xe8dcd5,
"Stuffed Olive":0xadac7c,
"Stuffing":0xbf9b84,
"Stump Green":0x5e5f4d,
"Stunning Gold":0xda9a5d,
"Stunning Sapphire":0x185887,
"Stunning Shade":0x676064,
"Sturdy Brown":0x9b856f,
"Sturgis Grey":0x57544d,
"Stylish":0xcec1a5,
"Su-Nezumi Grey":0x9fa0a0,
"Suave Grey":0xd1d8dd,
"Subaqueous":0x00576f,
"Subdue Red":0xccb8b3,
"Subdued Hue":0xc6b1ad,
"Subdued Sienna":0xcc896c,
"Sublime":0xecede0,
"Submarine":0x7a7778,
"Submarine Base":0x5566aa,
"Submarine Grey":0x4d585c,
"Submerged":0x4a7d82,
"Submersible":0x00576e,
"Subpoena":0xd8ccc6,
"Subterranean River":0x1f3b4d,
"Subtle Blue":0xd9e3e5,
"Subtle Green":0xb5cbbb,
"Subtle Night Sky":0x554b4f,
"Subtle Shadow":0xd8d8d0,
"Subtle Suede":0xd0bd94,
"Subtle Sunshine":0xe4d89a,
"Subtle Touch":0xdbdbd9,
"Subtle Turquoise":0x7a9693,
"Subtle Violet":0xb29e9e,
"Subway":0x87857c,
"Succinct Violet":0x513b6e,
"Succubus":0x990022,
"Succulent":0xdcdd65,
"Succulent Garden":0xbccbb2,
"Succulent Green":0x5e9b86,
"Succulent Leaves":0x658e64,
"Succulents":0x007744,
"Such Melodrama":0xc6c1c5,
"Sudan Brown":0xac6b29,
"Sudden Sapphire":0x6376a9,
"Suddenly Sapphire":0x1a5897,
"Suds":0xa6b4c5,
"Suede Beige":0xd9c7b9,
"Suede Grey":0x857f7a,
"Suede Indigo":0x585d6d,
"Suede Leather":0x896757,
"Suede Vest":0xd79043,
"Suffragette Yellow":0xecd0a1,
"Sugar Almond":0x935529,
"Sugar Beet":0x834253,
"Sugar Berry":0xe3d4cd,
"Sugar Cane":0xeeefdf,
"Sugar Cane Dahlia":0xf7c2bf,
"Sugar Chic":0xffccff,
"Sugar Coated Almond":0xbb6611,
"Sugar Cookie":0xf2e2a4,
"Sugar Coral":0xf56c73,
"Sugar Crystal":0xf8f4ff,
"Sugar Dust":0xf9ede3,
"Sugar Glaze":0xfff0e1,
"Sugar Glazed Cashew":0xcc9955,
"Sugar Grape":0x9437ff,
"Sugar Honey Cashew":0xddaa66,
"Sugar Maple":0x9c7647,
"Sugar Mint":0xc0e2c5,
"Sugar Pie":0xc7a77b,
"Sugar Pine":0x73776e,
"Sugar Plum":0x914e75,
"Sugar Pool":0xaed6d4,
"Sugar Poppy":0xe58281,
"Sugar Quill":0xebe5d7,
"Sugar Rush Peach Pepper":0xcfb599,
"Sugar Shack":0xeed5b6,
"Sugar Soap":0xefe8dc,
"Sugar Sweet":0xecc4dc,
"Sugar Swizzle":0xf3eee7,
"Sugar Tooth":0xd68f9f,
"Sugar Tree":0xa2999a,
"Sugar-Candied Peanuts":0x8b2e16,
"Sugared Almond":0xb49d7b,
"Sugared Peach":0xfddcc6,
"Sugared Pears":0xebd5b7,
"Sugarloaf Brown":0x554400,
"Sugarpills":0xffddff,
"Sugilite":0xa2999f,
"Suit Blue":0x2b3036,
"Suitable Brown":0x645a4b,
"Sulfur Pit":0xe5cc69,
"Sulfur Yellow":0xdbc058,
"Sulfuric Yellow":0xa79f5c,
"Sullen Gold":0xa58b34,
"Sullivan's Heart":0xf7c5d1,
"Sulphur":0xddb614,
"Sulphur Spring":0xd5d717,
"Sulphur Water":0xf2f3cf,
"Sulphur Yellow":0xccc050,
"Sultan Sand":0xe3c9be,
"Sultan's Silk":0x134558,
"Sultana":0x674668,
"Sultry Castle":0x948d84,
"Sultry Sea":0x506770,
"Sultry Smoke":0x73696f,
"Sultry Spell":0x716563,
"Sulu":0xc6ea80,
"Sumac dyed":0xe08a1e,
"Sumatra":0xf6e8cc,
"Sumatra Chicken":0x4f666a,
"Sumi Ink":0x595857,
"Sumire Violet":0x7058a3,
"Summer Air":0x3fafcf,
"Summer Beige":0xdbc2b9,
"Summer Birthday":0xbbd5ef,
"Summer Bliss":0xfcf1cf,
"Summer Bloom":0xd1beb4,
"Summer Blue":0x1880a1,
"Summer Blush":0xf6dfd6,
"Summer Breeze":0xd3e5db,
"Summer Citrus":0xf8822a,
"Summer Cloud":0xbbffee,
"Summer Clover":0xe5cfde,
"Summer Concrete":0x57595d,
"Summer Cosmos":0xfad1e0,
"Summer Crush":0xf2d6da,
"Summer Daffodil":0xffe078,
"Summer Day":0xeaaa62,
"Summer Dragonfly":0x83ada3,
"Summer Field":0xe2c278,
"Summer Fig":0xbe4b3b,
"Summer Forest Green":0x228b22,
"Summer Garden":0x7aac80,
"Summer Glow":0xeeaa44,
"Summer Green":0x8fb69c,
"Summer Harvest":0xffe69a,
"Summer Heat":0xaa5939,
"Summer Hill":0xc1a58d,
"Summer House":0xc8efe2,
"Summer Hue":0xffefc2,
"Summer in the City":0xcda168,
"Summer Jasmine":0xeeebd6,
"Summer Lake":0x0077a7,
"Summer Lily":0xf8d374,
"Summer Melon":0xead3ae,
"Summer Memory":0xdf856e,
"Summer Mist":0xcbeaee,
"Summer Moon":0xfdedcf,
"Summer Night":0x36576a,
"Summer Orange":0xffb653,
"Summer Pear":0xf5f0d1,
"Summer Rain":0xe1e8db,
"Summer Resort":0xf7efba,
"Summer Sandcastle":0xece4ce,
"Summer Sea":0x66a9b1,
"Summer Shade":0xd1d9d7,
"Summer Shower":0xe5ebe3,
"Summer Sky":0x38b0de,
"Summer Soft Blue":0x94d3d1,
"Summer Solstice":0xded1a3,
"Summer Storm":0xb0c5df,
"Summer Sun":0xffdc00,
"Summer Sunset":0xd88167,
"Summer Sunshine":0xf7e8c7,
"Summer Turquoise":0x008572,
"Summer Turquoise Blue":0x4b9cab,
"Summer Waters":0x215399,
"Summer Weasel":0xbb8e55,
"Summer White":0xf4e9d6,
"Summer's End":0xdc9367,
"Summer's Eve":0xa97069,
"Summer's Heat":0xf9e699,
"Summerday Blue":0x376698,
"Summertime":0xf2d178,
"Summertown":0x8cbc9e,
"Summerville Brown":0x997651,
"Summerwood":0xd4b28b,
"Summit":0x8bb6b8,
"Summit Gray":0x959491,
"Sumptuous Peach":0xe5b99b,
"Sun":0xef8e38,
"Sun Baked":0xd27f63,
"Sun Baked Earth":0xa36658,
"Sun Bleached Mint":0xe3efe1,
"Sun Bleached Ochre":0xe3ab7b,
"Sun Bleached Pink":0xfadadd,
"Sun City":0xfffed9,
"Sun Crete":0xff8c00,
"Sun Dance":0xc4aa4d,
"Sun Deck":0xf0dca0,
"Sun Dial":0xc79b36,
"Sun Drenched":0xffe7a3,
"Sun Dried":0xeabd5b,
"Sun Dried Tomato":0x752329,
"Sun Drops":0xeaaf11,
"Sun Dust":0xf6e0a4,
"Sun Glare":0xf1f4d1,
"Sun Glint":0xfaf3d9,
"Sun God":0xdfba5a,
"Sun Kiss":0xebd1bb,
"Sun Kissed":0xffeec2,
"Sun Orange":0xf48037,
"Sun Ray":0xffb219,
"Sun Salutation":0xe7c26f,
"Sun Shower":0xffde73,
"Sun Song":0xe9ad17,
"Sun Splashed":0xfbd795,
"Sun Surprise":0xfff2a0,
"Sun Touched":0xfad675,
"Sun Valley":0x698538,
"Sun Wukong's Crown":0xecc033,
"Sun Yellow":0xffdf22,
"Sun-Kissed Brick":0xb75e41,
"Sun's Glory":0xf6f2e5,
"Sun's Rage":0xa94e37,
"Suna White":0xdcd3b2,
"Sunbaked Adobe":0xab9a6e,
"Sunbeam":0xf5edb2,
"Sunbeam Yellow":0xf0d39d,
"Sunblast Yellow":0xfeff0f,
"Sunbleached":0xe5e0d7,
"Sunbound":0xf9d964,
"Sunburn":0xb37256,
"Sunburnt Cyclops":0xff404c,
"Sunburnt Toes":0xd79584,
"Sunburst":0xf6c289,
"Sunburst Yellow":0xffff99,
"Sundance":0xfac76c,
"Sunday Afternoon":0xf6c778,
"Sunday Best":0xfcc9c7,
"Sunday Drive":0xdcc9ae,
"Sunday Gloves":0xd7bad1,
"Sunday Niqab":0x3d4035,
"Sundaze":0xfae198,
"Sundew":0xe1cdae,
"Sundown":0xf5c99e,
"Sundress":0xebcf89,
"Sundried Tomato":0x692b2b,
"Sunezumi Brown":0x6e5f57,
"Sunflower":0xffc512,
"Sunflower Seed":0xffe3a9,
"Sunflower Yellow":0xffda03,
"Sunglo":0xc76155,
"Sunglow":0xffcc33,
"Sunglow Gecko":0xffcf48,
"Sunken Battleship":0x51574f,
"Sunken Gold":0xb29700,
"Sunken Pool":0xc8ddda,
"Sunken Ship":0x6b443d,
"Sunkissed Apricot":0xf2bda8,
"Sunkissed Peach":0xfed8bf,
"Sunkissed Yellow":0xffe9ba,
"Sunkist Coral":0xea6676,
"Sunlight":0xedd59e,
"Sunlit Allium":0x9787bb,
"Sunlit Kelp Green":0x7d7103,
"Sunlounge":0xda8433,
"Sunning Deck":0xe8d7b1,
"Sunny":0xf2f27a,
"Sunny Disposition":0xdba637,
"Sunny Festival":0xffc946,
"Sunny Gazebo":0xede1cc,
"Sunny Green":0xc5cd40,
"Sunny Honey":0xf8f0d8,
"Sunny Horizon":0xd0875a,
"Sunny Lime":0xdfef87,
"Sunny Mimosa":0xf5f5cc,
"Sunny Mood":0xf7c84a,
"Sunny Morning":0xf6d365,
"Sunny Pavement":0xd9d7d9,
"Sunny Side Up":0xffdc41,
"Sunny Summer":0xffc900,
"Sunny Summit":0xe3e9cf,
"Sunny Veranda":0xfedf94,
"Sunny Yellow":0xfff917,
"Sunnyside":0xf8d016,
"Sunporch":0xffd18c,
"Sunray":0xe3ab57,
"Sunray Venus":0xcfc5b6,
"Sunrise":0xf4bf77,
"Sunrise Glow":0xfef0c5,
"Sunrise Heat":0xcaa061,
"Sunrose Yellow":0xffdb67,
"Sunset":0xc0514a,
"Sunset Beige":0xd0a584,
"Sunset Cloud":0xbe916d,
"Sunset Cove":0xdcb397,
"Sunset Cruise":0xffbe94,
"Sunset Drive":0xeabba2,
"Sunset Gold":0xf7c46c,
"Sunset Horizon":0xba87aa,
"Sunset in Italy":0xf0c484,
"Sunset Meadow":0xa5a796,
"Sunset Orange":0xfd5e53,
"Sunset Papaya":0xfc7d64,
"Sunset Pink":0xfad6e5,
"Sunset Purple":0x6f456e,
"Sunset Red":0x7f5158,
"Sunset Riders":0xd70040,
"Sunset Serenade":0x594265,
"Sunset Strip":0xffbc00,
"Sunset Yellow":0xfa873d,
"Sunshade":0xfa9d49,
"Sunshine":0xfade85,
"Sunshine Surprise":0xfcb02f,
"Sunshine Yellow":0xfffd37,
"Sunshone Plum":0x886688,
"Sunstitch":0xfee2b2,
"Sunstone":0xc7887f,
"Suntan":0xd9b19f,
"Suntan Glow":0xbe8c74,
"Sunwashed Brick":0xe3c1b3,
"Suō":0x7e2639,
"Super Banana":0xfffe71,
"Super Black":0x221100,
"Super Gold":0xaa8822,
"Super Hero":0xca535b,
"Super Leaf Brown":0xba5e0f,
"Super Lemon":0xe4bf45,
"Super Pink":0xce6ba4,
"Super Rose Red":0xcb1028,
"Super Saiyan":0xffdd00,
"Super Sepia":0xffaa88,
"Super Silver":0xeeeeee,
"Superior Blue":0x3a5e73,
"Superior Bronze":0x786957,
"Superman Red":0xff1122,
"Supermint":0x00928c,
"Supernatural":0x313641,
"Supernova":0xfff8d9,
"Supernova Residues":0xd9ece9,
"Superstar":0xffcc11,
"Superstition":0x5b6e74,
"Superstitious":0xac91b5,
"Superwhite":0xe8eaea,
"Support Green":0x78a300,
"Supreme Green":0xcfddc7,
"Supreme Grey":0x86949f,
"Surati Pink":0xfc53fc,
"Surf":0xb8d4bb,
"Surf Crest":0xc3d6bd,
"Surf Green":0x427573,
"Surf Rider":0x0193c2,
"Surf Spray":0xb4c8c2,
"Surf the Web":0x203c7f,
"Surf Wash":0x87ceca,
"Surf'n'dive":0x374755,
"Surf's Surprise":0xc4d3e5,
"Surf's Up":0xc6e4eb,
"Surfboard Yellow":0xfcda89,
"Surfer":0x70b8ba,
"Surfer Girl":0xdb6484,
"Surfie Green":0x007b77,
"Surfin'":0x73c0d2,
"Surfside":0x9acad3,
"Surgeon Green":0x009f6b,
"Surprise":0xc9936f,
"Surprise Amber":0xefb57a,
"Surya Red":0x70191f,
"Sushi":0x7c9f2f,
"Sushi Rice":0xfff7df,
"Sussie":0x58bac2,
"Susu Green":0x887f7a,
"Susu-Take Bamboo":0x6f514c,
"Sutherland":0x859d95,
"Suva Grey":0x888387,
"Suzu Grey":0x9ea1a3,
"Suzume Brown":0xaa4f37,
"Suzumecha Brown":0x8c4736,
"Svelte":0xb8a3bb,
"Svelte Sage":0xb2ac96,
"Swagger":0x19b6b5,
"Swallow Blue":0x154962,
"Swallow-Tailed Moth":0xece9dd,
"Swamp":0x7f755f,
"Swamp Fox":0xb79d69,
"Swamp Green":0x748500,
"Swamp Monster":0x005511,
"Swamp Mosquito":0x252f2f,
"Swamp Moss":0x698339,
"Swamp Mud":0x857947,
"Swamp of Sorrows":0x36310d,
"Swamp Shrub":0x6d753b,
"Swampland":0x226633,
"Swan Dive":0xe5e4dd,
"Swan Lake":0xc5e5e2,
"Swan Sea":0xa6c1bf,
"Swan White":0xf7f1e2,
"Swan Wing":0xf5f2e6,
"Swanky Gray":0xb5b1b5,
"Swanndri":0x5f7963,
"Swans Down":0xdae6dd,
"Sweat Bee":0x1d4e8f,
"Sweater Weather":0xccccc5,
"Swedish Blue":0x007eb1,
"Swedish Clover":0x7b8867,
"Swedish Green":0x184d43,
"Swedish Yellow":0xfce081,
"Sweet & Sour":0xc9aa37,
"Sweet 60":0xf29eab,
"Sweet Almond":0xcc9977,
"Sweet Alyssum":0xe7c2de,
"Sweet Angel":0xf5c8bb,
"Sweet Angelica":0xe8d08e,
"Sweet Annie":0x9c946e,
"Sweet Apricot":0xfcc0a6,
"Sweet Aqua":0xa7e8d3,
"Sweet Ariel":0xe5eae3,
"Sweet as Honey":0xffe9ac,
"Sweet Baby Rose":0xc24f40,
"Sweet Bianca":0xeedadd,
"Sweet Blue":0xaebed2,
"Sweet Breeze":0xc8dae3,
"Sweet Brown":0xa83731,
"Sweet Butter":0xfffcd7,
"Sweet Buttermilk":0xfceedd,
"Sweet Carrot":0xcc764f,
"Sweet Cashew":0xddaa77,
"Sweet Chamomile":0xffe186,
"Sweet Cherry":0x9f4f4d,
"Sweet Cherry Red":0x84172c,
"Sweet Chrysanthemum":0xdd84a3,
"Sweet Corn":0xf9e176,
"Sweet Cream":0xf0eae7,
"Sweet Curry":0xe8a773,
"Sweet Desire":0xaa33ee,
"Sweet Dough":0xdbcbab,
"Sweet Dreams":0x9bc7ea,
"Sweet Earth":0xab9368,
"Sweet Emily":0xcbd1e1,
"Sweet Escape":0x8844ff,
"Sweet Flag":0x674196,
"Sweet Florence":0x8a9b76,
"Sweet Flower":0xe2e2ea,
"Sweet Frosting":0xfff8e4,
"Sweet Garden":0x5fd1ba,
"Sweet Gardenia":0xefe4da,
"Sweet Georgia Brown":0x8b715a,
"Sweet Grape":0x4b3b4f,
"Sweet Grass":0xb2b68a,
"Sweet Harbor":0xd9dde7,
"Sweet Honey":0xd4a55c,
"Sweet Illusion":0xe0e8ec,
"Sweet Jasmine":0xf9f4d4,
"Sweet Juliet":0xb8bfd2,
"Sweet Lavender":0x9a9bc1,
"Sweet Lilac":0xe8b5ce,
"Sweet Lychee":0x9b4040,
"Sweet Mandarin":0xd35e3a,
"Sweet Maple":0xddaf6c,
"Sweet Marzipan":0xecd5aa,
"Sweet Menthol":0xc2e4bc,
"Sweet Midori":0xa7c74f,
"Sweet Mint Pesto":0xbbee99,
"Sweet Mint Tea":0xd5e3d0,
"Sweet Molasses":0x4b423f,
"Sweet Murmur":0xecc5df,
"Sweet Mustard":0xd1b871,
"Sweet Nectar":0xfabdaf,
"Sweet Nothing":0xfae6e1,
"Sweet Nothings":0xbbdbd0,
"Sweet Orange":0xebccb3,
"Sweet Pastel":0xedc8b1,
"Sweet Pea":0xa3a969,
"Sweet Peach":0xe2bcb3,
"Sweet Petal":0xcbbad0,
"Sweet Pink":0xee918d,
"Sweet Potato":0xd87c3b,
"Sweet Potato Peel":0x917798,
"Sweet Rhapsody":0x93dad3,
"Sweet Romance":0xffc4dd,
"Sweet Roses":0xeae1dd,
"Sweet Sachet":0xffd8f0,
"Sweet Serenade":0xffc5d5,
"Sweet Sheba":0xf0b9a9,
"Sweet Sixteen":0xffc9d3,
"Sweet Slumber Pink":0xf8b8f8,
"Sweet Sparrow":0xa8946b,
"Sweet Spiceberry":0x7b453e,
"Sweet Spring":0xd1e8c2,
"Sweet Sue":0xd8aa86,
"Sweet Taffy":0xecbcd4,
"Sweet Tart":0xeaaea9,
"Sweet Tea":0xc18244,
"Sweet Tooth":0x5f6255,
"Sweet Truffle":0xf0dcd7,
"Sweet Vanilla":0xeeebe6,
"Sweet Violet":0x8c667a,
"Sweet Watermelon":0xfc5669,
"Sweet William":0x8892c1,
"Sweetheart":0xf3c3d8,
"Sweetie Pie":0xe1bbdb,
"Sweetly":0xffe5ef,
"Sweetness":0xf8dbc4,
"Sweety Pie":0xe7cee3,
"Swift":0x82aadc,
"Swimmer":0x0a91bf,
"Swimming":0xc2e5e5,
"Swimming Pool Green":0xa8cfc0,
"Swing Brown":0x947569,
"Swing Sage":0xc2c0a9,
"Swinging Vine":0x706842,
"Swirl":0xd7cec5,
"Swirling Smoke":0xcecac1,
"Swirling Water":0xe6e9e9,
"Swiss Brown":0x6e5f53,
"Swiss Chard":0xdd5e6d,
"Swiss Cheese":0xfff4b9,
"Swiss Chocolate":0x8c6150,
"Swiss Coffee":0xd5c3ad,
"Swiss Cream":0xecead9,
"Swiss Lilac":0x86608e,
"Swiss Plum":0x5946b2,
"Swollen Sky":0x67667c,
"Sword Steel":0xd6d2de,
"Sybarite Green":0x8bcbab,
"Sycamore":0x908d39,
"Sycamore Grove":0x6a8779,
"Sycamore Stand":0x959e8f,
"Sycamore Tan":0x9c8a79,
"Sycamore Tree":0x3f544f,
"Sycorax Bronze":0xcbb394,
"Sydney Harbour":0x97bbc8,
"Sylph":0xadaab1,
"Sylvan":0x979381,
"Sylvan Green":0xe7eacb,
"Sylvaneth Bark":0xac8262,
"Symbolic":0xb29ead,
"Symmetry":0x8fa0a7,
"Symphony Gold":0xc0a887,
"Symphony of Blue":0x89a0a6,
"Synallactida":0x331133,
"Synchronicity":0xc7d4ce,
"Syndicalist":0xf8c300,
"Syndicate Camouflage":0x918151,
"Synergy":0x48c2b0,
"Synthetic Mint":0x9ffeb0,
"Synthetic Pumpkin":0xff7538,
"Synthetic Spearmint":0x1ef876,
"Syrah":0x6a282c,
"Syrah Soil":0xa16717,
"Syrian Violet":0xdfcae4,
"Syrup":0xb18867,
"System Shock Blue":0x3a2efe,
"Szöllősi Grape":0x8020ff,
"T-Bird Turquoise":0x6fc1af,
"T-Rex Fossil":0x8e908d,
"Ta Prohm":0xc7c4a5,
"Tabasco":0xa02712,
"Tabbouleh Green":0x526525,
"Table Linen":0xf1e9dc,
"Table Pear Yellow":0xe5c279,
"Tabriz Teal":0x005553,
"Tacao":0xf6ae78,
"Tacha":0xd2b960,
"Taco":0xf3c7b3,
"Tactile":0xd3e7c7,
"Tadorna Teal":0x7ad7ad,
"Tadpole":0x7d7771,
"Taffeta Sheen":0x81825f,
"Taffeta Tint":0xf3e0eb,
"Taffy":0xc39b6a,
"Taffy Pink":0xfea6c8,
"Taffy Twist":0xaad0ba,
"Tagliatelle":0xf9f2d4,
"Tahini":0xddbb77,
"Tahiti Gold":0xdc722a,
"Tahitian Breeze":0xb8e9e4,
"Tahitian Sand":0xf5dcb4,
"Tahitian Sky":0xc9e9e7,
"Tahitian Tide":0x006b7e,
"Tahitian Treat":0x00686d,
"Tahoe Blue":0x94b8c1,
"Tahoe Snow":0xd7e1e5,
"Tahuna Sands":0xd8cc9b,
"Taiga":0x768078,
"Tail Lights":0xdd4411,
"Tailor's Buff":0xdfc2aa,
"Tailored Tan":0xbd9d7e,
"Tailwind":0xf5e8cf,
"Tainted Gold":0xead795,
"Taisha Brown":0xbb5520,
"Taisha Red":0x9f5233,
"Taiwan Blue Magpie":0x3377a2,
"Taiwan Gold":0xc7aa71,
"Taj":0x734a33,
"Taj Mahal":0xede9df,
"Take Five":0xb3c9d3,
"Take the Plunge":0xd8d4dd,
"Take-Out":0xe6ccb7,
"Talavera":0xa0928b,
"Talâyi Gold":0xe7b25d,
"Taliesin Blue":0x707e84,
"Talipot Palm":0x648149,
"Tall Poppy":0x853534,
"Tall Ships":0x0e81b9,
"Tall Waves":0x5c9bcc,
"Tallarn Flesh":0x947e74,
"Tallarn Sand":0xa79b5e,
"Tallow":0xa39977,
"Tamago Egg":0xfcd575,
"Tamago Orange":0xffa631,
"Tamahagane":0x3b3f40,
"Tamale":0xf0e4c6,
"Tamale Maize":0xf8e7b7,
"Tamanegi Peel":0xdeaa9b,
"Tamarama":0x11ddee,
"Tamarillo":0x752b2f,
"Tamarind":0x341515,
"Tamarind Fruit":0x75503b,
"Tamarind Tart":0x8e604b,
"Tambo Tank":0x7c7d57,
"Tamboon":0xbdc8af,
"Tambourine":0xf0edd6,
"Tambua Bay":0x658498,
"Tame Teal":0xc1e6df,
"Tame Thyme":0xc5c5ac,
"Tan":0xd1b26f,
"Tan 686A":0xa38d6d,
"Tan Brown":0xab7e4c,
"Tan Green":0xa9be70,
"Tàn Hēi Soot":0x323939,
"Tan Hide":0xfa9d5a,
"Tan Oak":0xc2aa87,
"Tan Plan":0xc19e78,
"Tan Temptation":0xf0bd9e,
"Tan Wagon":0xa3755d,
"Tan Whirl":0xf1d7ce,
"Tan Your Hide":0xb5905a,
"Tan-Gent":0xb69073,
"Tana":0xb8b5a1,
"Tanager":0xa43834,
"Tanager Turquoise":0x91dce8,
"Tanami Desert":0xd0b25c,
"Tanaris Beige":0xe9b581,
"Tanbark":0x896656,
"Tanbark Trail":0x766451,
"Tandayapa Cloud Forest":0x4a766e,
"Tandoori":0xbb5c4d,
"Tandoori Red":0xd25762,
"Tandoori Spice":0x9f4440,
"Tangara":0x97725f,
"Tangaroa":0x1e2f3c,
"Tangelo":0xf94d00,
"Tangelo Cream":0xf2e9de,
"Tangent":0xead3a2,
"Tangent Periwinkle":0x50507f,
"Tangerine":0xff9300,
"Tangerine Bliss":0xd86130,
"Tangerine Cream":0xffa089,
"Tangerine Dream":0xff8449,
"Tangerine Flake":0xe57f5b,
"Tangerine Skin":0xf28500,
"Tangerine Tango":0xff9e4b,
"Tangerine Yellow":0xfecd01,
"Tangier":0xa97164,
"Tangle":0x7c7c65,
"Tangled Twine":0xb19466,
"Tangled Vines":0xcac19a,
"Tanglewood":0xa58f85,
"Tango":0xd46f31,
"Tango Mango":0xf8c884,
"Tango Pink":0xe47f7a,
"Tango Red":0xac0e2e,
"Tangy":0xe3c382,
"Tangy Dill":0x9a9147,
"Tangy Green":0xbb9b52,
"Tangy Taffy":0xe7cac3,
"Tank":0x5c6141,
"Tank Grey":0x848481,
"Tank Yellow":0xefc93d,
"Tankard Grey":0x7d7463,
"Tanned Flesh":0xf7b45e,
"Tanned Leather":0xf2c108,
"Tanned Skin":0xf7cd08,
"Tanned Wood":0x8f6e4b,
"Tannin":0xa68a6d,
"Tanooki Suit Brown":0xae6c37,
"Tansy":0xc7c844,
"Tansy Green":0x95945c,
"Tantalizing Tan":0xf3dcd1,
"Tantalizing Teal":0x87dcce,
"Tantanmen Brown":0x857158,
"Tanzanian Gold":0xfcd215,
"Tanzanite":0x1478a7,
"Tanzanite Blue":0x114a6b,
"Taos Taupe":0xbfa77f,
"Taos Turquoise":0x2b8c8a,
"Tap Shoe":0x2a2b2d,
"Tapa":0x7c7c72,
"Tapenade":0x805d24,
"Tapering Light":0xf7f2dd,
"Tapestry":0xb37084,
"Tapestry Beige":0xb8ac9e,
"Tapestry Gold":0xb4966b,
"Tapestry Red":0xc06960,
"Tapestry Teal":0x4d7f86,
"Tapioca":0xdccdbc,
"Tara":0xdef1dd,
"Tara's Drapes":0x767a49,
"Tarawera":0x253c48,
"Tardis":0x105673,
"Tardis Blue":0x003b6f,
"Tareyton":0xa1cdbf,
"Tarmac":0x5a5348,
"Tarmac Green":0x477f4a,
"Tarnished Brass":0x7f6c24,
"Tarnished Silver":0x797b80,
"Tarnished Treasure":0xb9a47e,
"Tarnished Trumpet":0xd5b176,
"Tarpon Green":0xc1b55c,
"Tarragon":0xa4ae77,
"Tarragon Tease":0xb4ac84,
"Tarsier":0x825e61,
"Tart Apple":0xb6d27e,
"Tart Gelato":0xf6eec9,
"Tart Orange":0xfb4d46,
"Tartan Red":0xb1282a,
"Tartare":0xbf5b3c,
"Tartlet":0xfddcd9,
"Tartrazine":0xf7d917,
"Tarzan Green":0x919585,
"Tasman":0xbac0b3,
"Tasman Honey Yellow":0xe6c562,
"Tasmanian Sea":0x658a8a,
"Tassel":0xc6884a,
"Tassel Flower":0xf9c0ce,
"Tassel Taupe":0x9f9291,
"Taste of Berry":0xc8a3b8,
"Taste of Summer":0xf2ae73,
"Tasty Toffee":0x9b6d54,
"Tatami":0xdeccaf,
"Tatami Mat":0xaf9d83,
"Tatami Tan":0xba8c64,
"Tatarian Aster":0x976e9a,
"Tate Olive":0x988f63,
"Tattered Teddy":0xa2806f,
"Tattletail":0x80736a,
"Tatzelwurm Green":0x376d03,
"Tau Light Ochre":0xf7d60d,
"Tau Sept Ochre":0xa3813f,
"Taupe":0xb9a281,
"Taupe Grey":0x8b8589,
"Taupe Mist":0xe1d9d0,
"Taupe Night":0x705a56,
"Taupe of the Morning":0xdad2c6,
"Taupe Tapestry":0xc3a79a,
"Taupe Tease":0xe0d9cf,
"Taupe Tone":0xada090,
"Taupe White":0xc7c1bb,
"Tavern":0xb7a594,
"Tavern Creek":0x957046,
"Tavern Taupe":0x9e938f,
"Tawny Amber":0xd19776,
"Tawny Birch":0xae856c,
"Tawny Brown":0xab856f,
"Tawny Daylily":0xeee4d1,
"Tawny Mushroom":0xb39997,
"Tawny Olive":0xc4962c,
"Tawny Orange":0xd37f6f,
"Tawny Owl":0x978b71,
"Tawny Port":0x643a48,
"Tawny Tan":0xccb299,
"Tax Break":0x496569,
"Taxite":0x5c3937,
"Taylor":0x5f5879,
"Te Papa Green":0x2b4b40,
"Tea":0xbfb5a2,
"Tea Bag":0x726259,
"Tea Biscuit":0xf5ebe1,
"Tea Blossom Pink":0xb5a9ac,
"Tea Chest":0x605547,
"Tea Cookie":0xf4e1c0,
"Tea Green":0xd0f0c0,
"Tea Leaf":0x8f8667,
"Tea Leaf Brown":0xa59564,
"Tea Leaf Mouse":0x888e7e,
"Tea Light":0xf8e4c2,
"Tea Party":0xffd7d0,
"Tea Room":0xdcb5b0,
"Tea Rose":0xf883c2,
"Tea Time":0xd9bebc,
"Teaberry":0xdc3855,
"Teaberry Blossom":0xb44940,
"Teak":0xab8953,
"Teak Wood":0x624133,
"Teakwood":0x8d7e6d,
"Teakwood Brown":0x89756b,
"Teal":0x008080,
"Teal Bayou":0x57a1a0,
"Teal Blue":0x01889f,
"Teal Dark Blue":0x0f4d5c,
"Teal Dark Green":0x006d57,
"Teal Deer":0x99e6b3,
"Teal Essence":0x3da3ae,
"Teal Forest":0x405b5d,
"Teal Fury":0x1a6c76,
"Teal Green":0x25a36f,
"Teal Ice":0xd1efe9,
"Teal Me No Lies":0x0daca7,
"Teal Mosaic":0x406976,
"Teal Motif":0x006d73,
"Teal Stencil":0x627f7b,
"Teal Treat":0xd9f2e3,
"Teal Tree":0x94b9b4,
"Teal Trip":0x00a093,
"Teal Tune":0x02708c,
"Teal Waters":0x007765,
"Teal Wave":0x8b9ea1,
"Tealish":0x24bca8,
"Tealish Green":0x0cdc73,
"Team Spirit":0x416986,
"Teardrop":0xd1eaea,
"Tears of Joy":0xf0f1da,
"Teary Eyed":0xded2e8,
"Teasel Dipsacus":0xceaefa,
"Teasing Peach":0xf1e1d7,
"Teatime":0xbe9b79,
"Teatime Mauve":0xc8a89e,
"Tech Wave":0x4c7a9d,
"Techile":0x9fa1a1,
"Technical Blue":0x587c8d,
"Techno Blue":0x006b8b,
"Techno Gray":0xbfb9aa,
"Techno Green":0x69ac58,
"Techno Pink":0xdd95b4,
"Techno Turquoise":0x60bd8e,
"Teclis Blue":0xa3bae3,
"Teddy Bear":0x9d8164,
"Teddy's Taupe":0xbcac9f,
"Tee Off":0x68855a,
"Teen Queen":0xa67498,
"Teeny Bikini":0x326395,
"Teewurst":0xf2dbd7,
"Teldrassil Purple":0xad66d2,
"Telemagenta":0xaa22cc,
"Telopea":0x2d2541,
"Tempe Star":0x47626a,
"Temperamental Green":0x2b8725,
"Temperate Taupe":0xbfb1aa,
"Tempered Chocolate":0x772211,
"Tempered Grey":0xa1aeb1,
"Tempest":0x79839b,
"Template":0xa6c9e3,
"Temple Guard Blue":0x339a8d,
"Temple of Orange":0xee7755,
"Temple Tile":0xa9855d,
"Tempo":0x33abb2,
"Tempo Teal":0x018c94,
"Temptatious Tangerine":0xff7733,
"Tempting Taupe":0xccaa99,
"Temptress":0x3c2126,
"Tenacious Tentacles":0x98f6b0,
"Tender":0xf7e8d7,
"Tender Greens":0xc5cfb6,
"Tender Limerence":0xe0d4e0,
"Tender Peach":0xf8d5b8,
"Tender Shoot":0xe8eace,
"Tender Shoots":0xb5cc39,
"Tender Touch":0xd5c6d6,
"Tender Turquoise":0x82d9c5,
"Tender Twilight":0xb7cfe2,
"Tender Waves":0xbadbdf,
"Tender Yellow":0xededb7,
"Tenderness":0xc8dbce,
"Tendril":0x89a06b,
"Tenné":0xcd5700,
"Tennis Ball":0xdfff4f,
"Tennis Blue":0x7cb5c6,
"Tennis Court":0xc8450c,
"Tense Terracotta":0xa35732,
"Tent Green":0xa89f86,
"Tentacle Pink":0xffbacd,
"Tenzing":0x9ecfd9,
"Tequila":0xf4d0a4,
"Teri-Gaki Persimmon":0xeb6238,
"Terminator Chrome":0xdcdfe5,
"Terminatus Stone":0xbdb192,
"Termite Beige":0xddbb66,
"Terra Brun":0x5a382d,
"Terra Cotta Clay":0xd08f73,
"Terra Cotta Pot":0xd38d71,
"Terra Cotta Sun":0x9c675f,
"Terra Cotta Urn":0xb06f60,
"Terra Orange":0xcc7661,
"Terra Pin":0x534d42,
"Terra Rosa":0xbb6569,
"Terra Rose":0x9f6d66,
"Terra Sol":0xe8b57b,
"Terra Tone":0xb6706b,
"Terrace Brown":0x73544d,
"Terrace Taupe":0xb2ab9c,
"Terrace Teal":0x275b60,
"Terrace View":0xcad0bf,
"Terracotta":0xcb6843,
"Terracotta Chip":0xc47c5e,
"Terracotta Red Brown":0x976a66,
"Terracotta Sand":0xd6ba9b,
"Terrain":0x708157,
"Terran Khaki":0xa1965e,
"Terrarium":0x5f6d5c,
"Terrazzo Brown":0xa28873,
"Terrazzo Tan":0xbe8973,
"Terror from the Deep":0x1d4769,
"Testosterose":0xddaaff,
"Tête-à-Tête":0xd90166,
"Teton Blue":0x8d99a1,
"Teton Breeze":0xdfeae8,
"Tetrarose":0x8e6f73,
"Tetsu Black":0x2b3733,
"Tetsu Green":0x005243,
"Tetsu Iron":0x455765,
"Tetsu-Guro Black":0x281a14,
"Tetsu-Kon Blue":0x17184b,
"Tetsuonando Black":0x2b3736,
"Texan Angel":0xe2ddd1,
"Texas":0xece67e,
"Texas Boots":0x8b6947,
"Texas Heatwave":0xa54e37,
"Texas Hills":0xc9926e,
"Texas Longhorn":0xe08d3c,
"Texas Ranger Brown":0xa0522d,
"Texas Rose":0xf1d2c9,
"Texas Sage":0xb9a77c,
"Texas Sunset":0xfc9625,
"Texas Sweet Tea":0x794840,
"Tezcatlipōca Blue":0x5500ee,
"Thai Basil":0x7a7f3f,
"Thai Chili":0xce0001,
"Thai Curry":0xab6819,
"Thai Hot":0xfe1c06,
"Thai Ice Tea":0xe0a878,
"Thai Mango":0xe77200,
"Thai Spice":0xbb4455,
"Thai Teak":0x624435,
"Thai Teal":0x2e8689,
"Thai Temple":0xe7c630,
"Thallium Flame":0x58f898,
"Thamar Black":0x181818,
"Thames Dusk":0x62676a,
"Thanksgiving":0xb56e4a,
"That's Atomic":0xb0b08e,
"That's My Lime":0xdcd290,
"Thatch":0xb1948f,
"Thatch Brown":0x867057,
"Thatch Green":0x544e31,
"Thatched Cottage":0xd6c7a6,
"Thatched Roof":0xefe0c6,
"Thawed Out":0xe1eeec,
"The Blarney Stone":0xab9f89,
"The Bluff":0xffc8c2,
"The Boulevard":0xd0a492,
"The Broadway":0x145775,
"The Ego Has Landed":0xa75455,
"The End":0x2a2a2a,
"The Fang":0x585673,
"The Fang Grey":0x436174,
"The Fifth Sun":0xf0e22c,
"The Golden State":0xe9d2af,
"The Goods":0xaaa651,
"The Killing Joke":0xb0bf1a,
"The Oregon Blue":0x448ee4,
"The Rainbow Fish":0x4466ee,
"The Real Teal":0x007883,
"The Sickener":0xdb7093,
"The Speed of Light":0xf6f4ef,
"The Vast of Night":0x110066,
"The White in my Eye":0xf1eee5,
"Theatre Blue":0x21467a,
"Theatre District Lights":0xeef4db,
"Theatre Dress":0x274242,
"Theatre Gold":0xa76924,
"Theatre Powder Rose":0xe2d4d4,
"Themeda Japonica":0xe2b13c,
"Therapeutic Toucan":0xee7711,
"There Is Light":0x002288,
"There's No Place Like Home":0xad9569,
"Thermal":0x3f5052,
"Thermal Aqua":0x9ccebe,
"Thermal Spring":0x589489,
"Thermocline":0x8fadbd,
"Thermos":0xd2bb95,
"They call it Mellow":0xfbe4b3,
"Thick Fog":0xdcd3ce,
"Thicket":0x69865b,
"Thimble Red":0xa05d8b,
"Thimbleberry":0xe34b50,
"Thimbleberry Leaf":0xafa97d,
"Thin Air":0xc6fcff,
"Thin Cloud":0xd4dcda,
"Thin Heights":0xcae0df,
"Thin Ice":0xd9dcdb,
"Think Pink":0xe5a5c1,
"Thirsty Thursday":0x726e9b,
"Thistle":0xd8bfd8,
"Thistle Down":0x9499bb,
"Thistle Green":0xcccaa8,
"Thistle Grey":0xc0b6a8,
"Thistle Mauve":0x834d7c,
"Thistleblossom Soft Blue":0x8ab3bf,
"Thor's Thunder":0x915a7f,
"Thorn Crown":0xb5a197,
"Thorny Branch":0x4c4a41,
"Thought":0xd8cdc8,
"Thousand Herb":0x317589,
"Thousand Needles Sand":0xffd9bb,
"Thousand Sons Blue":0x02d8e9,
"Thousand Years Green":0x316745,
"Thraka Green Wash":0x4f6446,
"Threaded Loom":0xcec2aa,
"Thredbo":0x73c4d7,
"Three Ring Circus":0xfddbb6,
"Thresher Shark":0x93cce7,
"Threshold Taupe":0xac9a8a,
"Throat":0x281f3f,
"Thrush":0x936b4f,
"Thrush Egg":0xa4b6a7,
"Thulian Pink":0xdf6fa1,
"Thulite Rose":0xddc2ba,
"Thumper":0xbdada4,
"Thundelarra":0xe88a76,
"Thunder":0x4d4d4b,
"Thunder & Lightning":0xf9f5db,
"Thunder Bay":0xcbd9d7,
"Thunder Chi":0xaac4d4,
"Thunder Gray":0x57534c,
"Thunder Mountain Longhorn Pepper":0xce1b1f,
"Thunderbird":0x923830,
"Thunderbolt":0x7c8783,
"Thunderbolt Blue":0x454c56,
"Thundercat":0x8a99a3,
"Thundercloud":0x698589,
"Thunderhawk Blue":0x417074,
"Thunderous":0x6d6c62,
"Thunderstorm":0x9098a1,
"Thunderstorm Blue":0x004f63,
"Thunderstruck":0x5f5755,
"Thurman":0x7f7b60,
"Thy Flesh Consumed":0x98514a,
"Thyme":0x50574c,
"Thyme and Salt":0x629a31,
"Thyme Green":0x737b6c,
"Tia Maria":0x97422d,
"Tiamo":0x9bb2aa,
"Tiān Lán Sky":0x5db3ff,
"Tiāntāi Mountain Green":0x566b38,
"Tiara":0xb9c3be,
"Tiara Jewel":0xeae0e8,
"Tiara Pink":0xdaa6cf,
"Tiber":0x184343,
"Tibetan Cloak":0x6a6264,
"Tibetan Jasmine":0xf6f3e1,
"Tibetan Orange":0xae5848,
"Tibetan Plateau":0x88ffdd,
"Tibetan Red":0x782a39,
"Tibetan Silk":0x9c8a52,
"Tibetan Sky":0xdbeaed,
"Tibetan Stone":0x82c2c7,
"Tibetan Temple":0x814d50,
"Tibetan Turquoise":0x0084a6,
"Tibetan Yellow":0xfedf00,
"Ticino Blue":0x268bcc,
"Tickle Me Pink":0xfc89ac,
"Tickled Crow":0xb6baa4,
"Tickled Pink":0xefa7bf,
"Tidal":0xf0f590,
"Tidal Foam":0xbfb9a3,
"Tidal Green":0xcdca98,
"Tidal Mist":0xe5e9e1,
"Tidal Pool":0x005e59,
"Tidal Thicket":0x8b866b,
"Tidal Wave":0x355978,
"Tide":0xbeb4ab,
"Tide Pools":0xc6d8d0,
"Tidepool":0x0a6f69,
"Tides of Darkness":0x002400,
"Tidewater":0xc2e3dd,
"Tiě Hēi Metal":0x343450,
"Tierra Del Fuego Sea Green":0xc2ddd3,
"Tiffany Amber":0xb58141,
"Tiffany Blue":0x7bf2da,
"Tiffany Light":0xfde4b4,
"Tiffany Rose":0xd2a694,
"Tiger":0xbe9c67,
"Tiger Cat":0xcda035,
"Tiger Claw":0xe1daca,
"Tiger Cub":0xdeae46,
"Tiger King":0xdd9922,
"Tiger Moth":0xf8f2dd,
"Tiger Moth Orange":0xdd6611,
"Tiger of Mysore":0xff8855,
"Tiger Stripe":0xbf6f39,
"Tiger Tail":0xfee9c4,
"Tiger Yellow":0xffde7e,
"Tiger's Eye":0x977c61,
"Tigereye":0xbb7748,
"Tigerlily":0xe2583e,
"Tijolo":0xaa5500,
"Tiki Hut":0x8a6e45,
"Tiki Monster":0x8fbc8f,
"Tiki Straw":0xb9a37e,
"Tiki Torch":0xbb9e3f,
"Tile Blue":0x008491,
"Tile Green":0x7a958e,
"Tile Red":0xc76b4a,
"Tilla Kari Mosque":0x00cccc,
"Tillandsia Purple":0x563474,
"Tilled Earth":0x80624e,
"Tilled Soil":0x6b4d35,
"Tilted Pinball":0xee5522,
"Tilted Red":0x991122,
"Timber Beam":0xa0855c,
"Timber Brown":0x605652,
"Timber Green":0x324336,
"Timber Town":0x908d85,
"Timber Wolf":0x8d8070,
"Timber Wolf White":0xd9d6cf,
"Time Capsule":0xa59888,
"Time Out":0xfadeb8,
"Time Travel":0xb3c4d5,
"Time Warp":0x9397a3,
"Timeless":0xb1d8db,
"Timeless Beauty":0xb6273e,
"Timeless Copper":0x976d59,
"Timeless Day":0xece9e8,
"Timeless Lilac":0xafb2c4,
"Timeless Ruby":0x9a4149,
"Timeless Taupe":0x908379,
"Times Square Screens":0x20c073,
"Timid Beige":0xe5e0dd,
"Timid Blue":0xd9e0ee,
"Timid Cloud":0xdcdde5,
"Timid Green":0xe1e2d6,
"Timid Lime":0xe4e0da,
"Timid Purple":0xdfdfea,
"Timid Sea":0x66a9b0,
"Timid Sheep":0xe4e0dd,
"Tin":0x919191,
"Tin Bitz":0x48452b,
"Tin Foil":0xacb0b0,
"Tin Lizzie":0x928a98,
"Tin Man":0xa4a298,
"Tin Pink":0xa3898a,
"Tin Soldier":0xbebebe,
"Tinge Of Mauve":0xd4c3cc,
"Tingle":0xe6541b,
"Tinker Light":0xfbedb8,
"Tinny Tin":0x4b492d,
"Tinsel":0xc3964d,
"Tinsmith":0xdce0dc,
"Tint of Earth":0xce9480,
"Tint of Green":0xdae9dc,
"Tint of Rose":0xffcbc9,
"Tint of Turquoise":0x41bfb5,
"Tinted Ice":0xcff6f4,
"Tinted Iris":0xc4b7d8,
"Tinted Mint":0xe3e7c4,
"Tinted Rosewood":0xe1c8d1,
"Tiny Bubbles":0x0088ab,
"Tiny Calf":0xe0bfa5,
"Tiny Fawn":0xc08b6d,
"Tiny Ghost Town":0xd4cfcc,
"Tiny Mr Frosty":0xb8d3e4,
"Tiny Pink":0xffd6c7,
"Tiny Ribbons":0xb98faf,
"Tip of the Iceberg":0xbbe4ea,
"Tip Toes":0xd8c2cd,
"Tiramisu":0x634235,
"Tiramisu Cream":0xd3bda4,
"Tirisfal Lime":0x75de2f,
"Tirol":0x9e915c,
"Titan White":0xddd6e1,
"Titanite Yellow":0xad8f0f,
"Titanium":0x807d7f,
"Titanium Blue":0x5b798e,
"Titanium Grey":0x545b62,
"Titanium Yellow":0xeee600,
"Titian Red":0xbd5620,
"Titmouse Grey":0xb8b2be,
"Tizzy":0xf9f3df,
"Tlāloc Blue":0x316f82,
"Toad":0x748d70,
"Toad King":0x3d6c54,
"Toadstool":0xb8282f,
"Toadstool Dot":0xd7e7da,
"Toadstool Soup":0x988088,
"Toast":0x9f715f,
"Toast and Butter":0xd2ad84,
"Toasted":0xb59274,
"Toasted Almond":0xdacfba,
"Toasted Bagel":0x986b4d,
"Toasted Barley":0xe7ddcb,
"Toasted Cashew":0xe2d0b8,
"Toasted Chestnut":0xa7775b,
"Toasted Coconut":0xe9c2a1,
"Toasted Grain":0xc5a986,
"Toasted Marshmallow":0xefe0d4,
"Toasted Nut":0xc08768,
"Toasted Nutmeg":0xa47365,
"Toasted Oatmeal":0xefdecc,
"Toasted Pecan":0x765143,
"Toasted Pine Nut":0xdcc6a6,
"Toasted Sesame":0xaf9a73,
"Toasted Truffle":0xaa3344,
"Toasted Walnut":0x746a5a,
"Toasted Wheat":0xc9af96,
"Toasty":0x957258,
"Toasty Grey":0xd1ccc0,
"Tobacco Brown":0x6d5843,
"Tobacco Leaf":0x8c724f,
"Tobago":0x44362d,
"Tobermory":0xd39898,
"Tobernite":0x077a7d,
"Tobey Rattan":0xad785c,
"Tobi Brown":0x4c221b,
"Tobiko Orange":0xe45c10,
"Toffee":0x755139,
"Toffee Bar":0x947255,
"Toffee Crunch":0x995e39,
"Toffee Fingers":0x968678,
"Toffee Tan":0xc8a883,
"Toffee Tart":0xc08950,
"Tofino Belue":0x03719c,
"Tofu":0xe8e3d9,
"Toile Blue":0x94bee1,
"Toile Red":0x8b534e,
"Toki Brown":0xb88884,
"Tokiwa Green":0x007b43,
"Tokyo Underground":0xecf3d8,
"Tol Barad Green":0x6c5846,
"Tol Barad Grey":0x4e4851,
"Toledo":0x3e2631,
"Toledo Cuoio":0xdecbb1,
"Tom Thumb":0x4f6348,
"Tomatillo Peel":0xcad3c1,
"Tomatillo Salsa":0xbbb085,
"Tomato":0xef4026,
"Tomato Baby":0xe10d18,
"Tomato Bisque":0xd15915,
"Tomato Concassé":0xf6561c,
"Tomato Cream":0xc57644,
"Tomato Frog":0xff4444,
"Tomato Puree":0xc53346,
"Tomato Red":0xec2d01,
"Tomato Sauce":0xb21807,
"Tomato Slices":0xa2423d,
"Tomb Blue":0x0099cc,
"Tombstone Grey":0xcec5b6,
"Tōmorokoshi Corn":0xfaa945,
"Tomorokoshi Yellow":0xeec362,
"Tomorrow's Coral":0xffc5a3,
"Tōnatiuh Red":0xd14155,
"Tongue":0xd1908e,
"Tonic":0xdeddaa,
"Tonicha":0x975437,
"Tony Taupe":0xb1a290,
"Tonys Pink":0xe79e88,
"Too Blue":0x3d6695,
"Too Dark Tonight":0x0011bb,
"Tōō Gold":0xffb61e,
"Tool Blue":0x637985,
"Tool Green":0x7f7711,
"Toolbox":0x746cc0,
"Tootie Fruity":0xf9dbe2,
"Top Hat Tan":0xc1a393,
"Top Shelf":0x82889c,
"Top Tomato":0xd04838,
"Topaz":0xd08344,
"Topaz Green":0xc5ddd0,
"Topaz Mountain":0x92653f,
"Topaz Yellow":0xeb975e,
"Topiary":0x8e9655,
"Topiary Garden":0x6f7c00,
"Topiary Tint":0xbbc9b2,
"Topinambur Root":0xaa5c71,
"Topsail":0xdae2e0,
"Toque White":0xe7e2da,
"Torch Light":0xf69a54,
"Torch Red":0xfd0d35,
"Torchlight":0xffc985,
"Torea Bay":0x353d75,
"Toreador":0xb61032,
"Tornado":0xd1d3cf,
"Tornado Cloud":0x5e5b60,
"Tornado Season":0x4d7179,
"Tornado Wind":0x60635f,
"Toronja":0xffdecd,
"Torrefacto Roast":0x220044,
"Torrey Pine":0x55784f,
"Torrid Turquoise":0x00938b,
"Tort":0x5e8e91,
"Tortilla":0xefdba7,
"Tortoise Shell":0x754734,
"Tortuga":0x84816f,
"Tory Blue":0x374e88,
"Tosca":0x744042,
"Toscana":0x9f846b,
"Tostada":0xe3c19c,
"Total Eclipse":0x2c313d,
"Total Recall":0xf6ead8,
"Totally Black":0x3f4041,
"Totally Cool":0x909853,
"Totally Tan":0xcca683,
"Totally Toffee":0xdd9977,
"Totem Pole":0x991b07,
"Toucan":0xf09650,
"Touch of Blue":0xc2d7e9,
"Touch of Blush":0xf6ded5,
"Touch of Class":0x8e6f6e,
"Touch of Glamor":0xdd8844,
"Touch Of Green":0xdbe9d5,
"Touch of Grey":0xd1cfca,
"Touch of Lime":0xe1e5d7,
"Touch of Mint":0xf8fff8,
"Touch of Sand":0xd5c7ba,
"Touch of Sun":0xfaf7e9,
"Touch of Tan":0xeed9d1,
"Touch of Topaz":0xf7e4d0,
"Touch of Turquoise":0xa1d4cf,
"Touch Of White Green":0xecefe3,
"Touchable":0xecdfd8,
"Touched by the Sea":0xc3e4e8,
"Touching White":0xf4e1d7,
"Toupe":0xc7ac7d,
"Tourmaline":0x86a1a9,
"Tourmaline Mauve":0xbda3a5,
"Tourmaline Turquoise":0x4f9e96,
"Tourmaline Water Blue":0x99d3df,
"Tournament Field":0x54836b,
"Tower Bridge":0x7ba0a0,
"Tower Grey":0x9caca5,
"Tower Tan":0xd5b59b,
"Towering Cliffs":0x897565,
"Townhall Tan":0xc3aa8c,
"Townhouse Tan":0xc19859,
"Townhouse Taupe":0xbbb09b,
"Toxic Boyfriend":0xccff11,
"Toxic Essence":0xcceebb,
"Toxic Frog":0x98fb98,
"Toxic Green":0x61de2a,
"Toxic Latte":0xe1f8e7,
"Toxic Orange":0xff6037,
"Toxic Sludge":0x00bb33,
"Toy Blue":0x00889f,
"Toy Camouflage":0x117700,
"Toy Mauve":0x776ea2,
"Toy Submarine Blue":0x005280,
"Toy Tank Green":0x6d6f4f,
"Track and Field":0xdd1111,
"Track Green":0x849e88,
"Tractor Beam":0x00bffe,
"Tractor Green":0x1c6a51,
"Tractor Red":0xfd0f35,
"Trade Secret":0x6a7978,
"Trade Winds":0xe6e3d6,
"Tradewind":0x6dafa7,
"Tradewinds":0x7e8692,
"Trading Post":0xbb8d3b,
"Traditional":0x776255,
"Traditional Blue":0x1f648d,
"Traditional Grey":0xc7c7c1,
"Traditional Leather":0x6f4f3e,
"Traditional Rose":0xbe013c,
"Traditional Royal Blue":0x0504aa,
"Traditional Tan":0xd6d2c0,
"Traffic Green":0x55ff22,
"Traffic Light Green":0x8c9900,
"Traffic Red":0xff1c1c,
"Traffic White":0xf1f0ea,
"Traffic Yellow":0xfedc39,
"Trail Dust":0xd0c4ac,
"Trail Print":0x6b6662,
"Trail Sand":0xbfaa97,
"Trailblazer":0xc0b28e,
"Trailing Vine":0xcfd5a7,
"Trance":0x8f97a5,
"Tranquil":0xddede9,
"Tranquil Aqua":0x7c9aa0,
"Tranquil Bay":0x74b8de,
"Tranquil Eve":0xece7f2,
"Tranquil Green":0xa4af9e,
"Tranquil Peach":0xfce2d7,
"Tranquil Pond":0x768294,
"Tranquil Pool":0x88ddff,
"Tranquil Retreat":0xdbd2cf,
"Tranquil Sea":0xd2d2df,
"Tranquil Seashore":0x629091,
"Tranquil Taupe":0xb0a596,
"Tranquil Teal":0x8ac7bb,
"Tranquili Teal":0x6c9da9,
"Tranquility":0x8e9b96,
"Trans Tasman":0x307d67,
"Transcend":0xc3ac98,
"Transcendence":0xf8f4d8,
"Transformer":0xa5acb7,
"Transfusion":0xea1833,
"Translucent Silk":0xffe9e1,
"Translucent Vision":0xe5efd7,
"Translucent White":0xe4e3e9,
"Transparent Beige":0xf4ecc2,
"Transparent Blue":0xddddff,
"Transparent Green":0xddffdd,
"Transparent Mauve":0xb4a6bf,
"Transparent Orange":0xffaa66,
"Transparent Pink":0xffddee,
"Transparent White":0xcbdccb,
"Transparent Yellow":0xffeeaa,
"Transporter Green":0x004f54,
"Trapped Darkness":0x0e1d32,
"Trapper Green":0x005239,
"Travertine":0xe2ddc7,
"Travertine Path":0xb5ab8f,
"Treacherous Blizzard":0xddf5e7,
"Treacle":0x885d2d,
"Treacle Fudge":0xde9832,
"Treasure Casket":0x9b7856,
"Treasure Chamber":0x998866,
"Treasure Chest":0x726854,
"Treasure Island":0x47493b,
"Treasure Isle":0x609d91,
"Treasure Map":0x658faa,
"Treasure Seeker":0x3f363d,
"Treasures":0xba8b36,
"Tree Bark":0x715e58,
"Tree Bark Brown":0x665b4e,
"Tree Bark Green":0x304b4a,
"Tree Branch":0x8a7362,
"Tree Fern":0x7fb489,
"Tree Frog":0x9fb32e,
"Tree Frog Green":0x7ca14e,
"Tree Green":0x2a7e19,
"Tree House":0x3b2820,
"Tree Hugger":0x79774a,
"Tree Lined":0x8ea597,
"Tree Moss":0xdcdbca,
"Tree of Life":0x595d45,
"Tree Palm":0x7faa4b,
"Tree Peony":0xa4345d,
"Tree Poppy":0xe2813b,
"Tree Pose":0xbdc7bc,
"Tree Python":0x22cc00,
"Tree Sap":0xcc7711,
"Tree Shade":0x476a30,
"Tree Swing":0x726144,
"Treeless":0xd1b7a7,
"Treemoss":0x615746,
"Treetop":0x91b6ac,
"Trefoil":0x47562f,
"Trek Tan":0xd1ae9a,
"Trekking Blue":0x4e606d,
"Trekking Green":0x355048,
"Trellis":0xeaefe5,
"Trellis Vine":0x5d7f74,
"Trellised Ivy":0x9aa097,
"Trendy Green":0x7e8424,
"Trendy Pink":0x805d80,
"Tres Naturale":0xdcc7ad,
"Trevi Fountain":0xc2dfe2,
"Tri-Tip":0xf2d1c4,
"Triamble":0x94a089,
"Triassic":0x67422d,
"Tribal":0x807943,
"Tribal Drum":0x514843,
"Tribal Pottery":0xa78876,
"Tribeca":0xa4918d,
"Tribecca Corner":0x33373b,
"Trick or Treat":0xeab38a,
"Tricorn Black":0x2f2f30,
"Tricot Lilac White":0xdcd3e3,
"Tricycle Taupe":0xb09994,
"Tried & True Blue":0x494f62,
"Triforce Shine":0xf5f5da,
"Triforce Yellow":0xf0f00f,
"Trim":0x756d44,
"Trinidad":0xc54f33,
"Trinidad Moruga Scorpion":0xd0343d,
"Trinity Islands":0xb9b79b,
"Trinket":0xd69835,
"Trinket Box":0x7e633f,
"Trinket Gold":0xa7885f,
"Tripoli White":0xe5e3e5,
"Trippy Velvet":0xcc00ee,
"Trisha's Eyes":0x8eb9c4,
"Tristesse":0x0c0c1f,
"Trite White":0xf4f0e3,
"Trixter":0x705676,
"Trojan Horse Brown":0x775020,
"Troll Green":0x014e2e,
"Troll Slayer Orange":0xf4a34c,
"Trolley Grey":0x818181,
"Trooper":0x697a7e,
"Tropez Blue":0x73b7c2,
"Tropic Canary":0xbcc23c,
"Tropic Tide":0x6cc1bb,
"Tropical Blooms":0xd7967e,
"Tropical Blue":0xaec9eb,
"Tropical Breeze":0xebedee,
"Tropical Cascade":0x8ca8a0,
"Tropical Dream":0xd9eae5,
"Tropical Fog":0xcbcab6,
"Tropical Forest":0x024a43,
"Tropical Forest Green":0x228b21,
"Tropical Freeze":0x99ddcc,
"Tropical Fruit":0xfdd3a7,
"Tropical Green":0x17806d,
"Tropical Heat":0xc2343c,
"Tropical Hibiscus":0x9c6071,
"Tropical Holiday":0x8fcdc7,
"Tropical Kelp":0x009d7d,
"Tropical Lagoon":0x1e98ae,
"Tropical Light":0x9cd572,
"Tropical Moss":0xd2c478,
"Tropical Night Blue":0x2a2e4c,
"Tropical Orchid":0xa0828a,
"Tropical Peach":0xffc4b2,
"Tropical Pool":0xbfdeef,
"Tropical Rain":0x447777,
"Tropical Rainforest":0x00755e,
"Tropical Sea":0x03a598,
"Tropical Siesta":0xddc073,
"Tropical Skies":0x155d66,
"Tropical Smoothie":0xc5556d,
"Tropical Splash":0x70cbce,
"Tropical Tale":0xe0deb8,
"Tropical Tan":0xcbb391,
"Tropical Teal":0x008794,
"Tropical Tide":0x5ecaae,
"Tropical Trail":0x89d1b5,
"Tropical Tree":0x20aea7,
"Tropical Turquoise":0x04cdff,
"Tropical Twist":0x837946,
"Tropical Violet":0xcda5df,
"Tropical Waterfall":0xbee7e2,
"Tropical Waters":0x007c7e,
"Tropical Wood":0xba8f68,
"Tropical Wood Brown":0x603b2a,
"Tropicana":0x447700,
"Tropics":0x009b8e,
"Trough Shell":0x726d40,
"Trough Shell Brown":0x918754,
"Trouser Blue":0x00666d,
"Trout":0x4c5356,
"True Blonde":0xdcc49b,
"True Blue":0x010fcc,
"True Copper":0x8b5643,
"True Crimson":0xa22042,
"True Green":0x089404,
"True Khaki":0xb8ae98,
"True Lavender":0x7e89c8,
"True Love":0xe27e8a,
"True Navy":0x3f5277,
"True Purple":0x65318e,
"True Red":0xbf1932,
"True Romance":0x4d456a,
"True Taupewood":0xa8a095,
"True To You":0xcdd3a3,
"True V":0x8e72c7,
"True Walnut":0x967a67,
"Truepenny":0xb46c42,
"Truesky Gloxym":0x99bbff,
"Truly Olive":0x777250,
"Truly Taupe":0xac9e97,
"Trump Tan":0xfaa76c,
"Trumpet":0x867e85,
"Trumpet Flower":0xe49977,
"Trumpet Teal":0x5a7d7a,
"Trumpeter":0x907baa,
"Trunks Hair":0x9b5fc0,
"Trusted Purple":0x6600cc,
"Trustee":0x527498,
"Trusty Tan":0xb59f8f,
"Truth":0x344989,
"Tsar":0x8b7f7b,
"Tsarina":0xd1b4c6,
"Tsunami":0x869baf,
"Tsurubami Green":0x9ba88d,
"Tǔ Hēi Black":0x574d35,
"Tuatara":0x454642,
"Tuberose":0xfffaec,
"Tucson Teal":0x00858b,
"Tudor Ice":0xc1cecf,
"Tudor Tan":0xb68960,
"Tuffet":0xa59788,
"Tuft":0xcbc2ad,
"Tuft Bush":0xf9d3be,
"Tufts Blue":0x417dc1,
"Tuğçe Silver":0xccddee,
"Tuk Tuk":0x573b2a,
"Tulip":0xff878d,
"Tulip Petals":0xfbf4da,
"Tulip Poplar Purple":0x531938,
"Tulip Red":0xb8516a,
"Tulip Soft Blue":0xc3c4d6,
"Tulip Tree":0xe3ac3d,
"Tulip White":0xf1e5d1,
"Tulipan Violet":0x966993,
"Tulipwood":0x805466,
"Tulle Grey":0x8d9098,
"Tulle Soft Blue":0xd9e7e5,
"Tulle White":0xfbede5,
"Tumbleweed":0xdeaa88,
"Tumblin' Tumbleweed":0xcdbb9c,
"Tumbling Tumbleweed":0xcebf9c,
"Tuna":0x46494e,
"Tuna Sashimi":0xcf6275,
"Tundora":0x585452,
"Tundra Frost":0xe1e1db,
"Tungsten":0xb5ac9f,
"Tunisian Stone":0xffddb5,
"Tupelo Honey":0xc0a04d,
"Tupelo Tree":0x9c9152,
"Turbinado Sugar":0xf9bb59,
"Turbo":0xf5cc23,
"Turbulence":0x4e545b,
"Turbulent Sea":0x536a79,
"Turf":0x5f4f42,
"Turf Green":0x6f8c69,
"Turf Master":0x009922,
"Turkish Aqua":0x006169,
"Turkish Bath":0xbb937b,
"Turkish Blue":0x007fae,
"Turkish Boy":0x0e9ca5,
"Turkish Coffee":0x483f39,
"Turkish Jade":0x2b888d,
"Turkish Rose":0xa56e75,
"Turkish Sea":0x195190,
"Turkish Stone":0x2f7a92,
"Turkish Teal":0x72cac1,
"Turkish Tile":0x00698b,
"Turkish Tower":0xd9d9d1,
"Turkish Turquoise":0x77dde7,
"Turkscap":0xf3d8be,
"Turmeric":0xae9041,
"Turmeric Brown":0xc18116,
"Turmeric Red":0xca7a40,
"Turmeric Root":0xfeae0d,
"Turmeric Tea":0xd88e2d,
"Turned Leaf":0x8d7448,
"Turner's Light":0x93bcbb,
"Turner's Yellow":0xe6c26f,
"Turning Leaf":0xced9c3,
"Turning Oakleaf":0xede1a8,
"Turquesa":0x448899,
"Turquish":0x01a192,
"Turquoise":0x06c2ac,
"Turquoise Blue":0x00ffef,
"Turquoise Chalk":0x6fe7db,
"Turquoise Cyan":0x0e7c61,
"Turquoise Green":0x04f489,
"Turquoise Grey":0xb4cecf,
"Turquoise Panic":0x30d5c8,
"Turquoise Pearl":0x89f5e3,
"Turquoise Sea":0x6cdae7,
"Turquoise Surf":0x00c5cd,
"Turquoise Topaz":0x13bbaf,
"Turquoise Tower":0xa8e3cc,
"Turquoise White":0xcfe9dc,
"Turtle":0x523f31,
"Turtle Bay":0x84897f,
"Turtle Chalk":0xced8c1,
"Turtle Creek":0x65926d,
"Turtle Dove":0xe3e1cf,
"Turtle Green":0x75b84f,
"Turtle Lake":0x73b7a5,
"Turtle Moss":0x939717,
"Turtle Skin":0x363e1d,
"Turtle Trail":0xb6b5a0,
"Turtledove":0xded7c8,
"Tuscan":0xfbd5a6,
"Tuscan Bread":0xe7d2ad,
"Tuscan Brown":0x6f4c37,
"Tuscan Clay":0xaa5e5a,
"Tuscan Herbs":0x658362,
"Tuscan Image":0xdc938c,
"Tuscan Mosaic":0xa08d71,
"Tuscan Olive":0x5d583e,
"Tuscan Red":0x7c4848,
"Tuscan Russet":0x723d3b,
"Tuscan Soil":0xa67b5b,
"Tuscan Sun":0xffd84d,
"Tuscan Sunset":0xbb7c3f,
"Tuscan Wall":0xfcc492,
"Tuscana Blue":0x008893,
"Tuscany":0xbe9785,
"Tuscany Hillside":0x7e875f,
"Tusche Blue":0x0082ad,
"Tusi Grey":0x9996b3,
"Tusk":0xe3e5b1,
"Tuskgor Fur":0x883636,
"Tussock":0xbf914b,
"Tutti Frutti":0xbc587b,
"Tutu":0xf8e4e3,
"Tutuji Pink":0xe95295,
"Tweed":0x937b56,
"Tweety":0xffef00,
"Twenty Carat":0xffbe4c,
"Twig Basket":0x77623a,
"Twilight":0x4e518b,
"Twilight Blue":0x0a437a,
"Twilight Blush":0xb59a9c,
"Twilight Chimes":0x3f5363,
"Twilight Dusk":0x606079,
"Twilight Forest":0x54574f,
"Twilight Gray":0xc8bfb5,
"Twilight Grey":0xd1d6d6,
"Twilight Lavender":0x8a496b,
"Twilight Light":0xdac0cd,
"Twilight Mauve":0x8b6f70,
"Twilight Pearl":0xbfbcd2,
"Twilight Purple":0x66648b,
"Twilight Stroll":0x71898d,
"Twilight Taupe":0xa79994,
"Twilight Twinkle":0x7b85c6,
"Twilight Twist":0xe5e6d7,
"Twill":0xa79b82,
"Twin Cities":0xa4c7c8,
"Twinberry":0x684344,
"Twine":0xc19156,
"Twinkle":0xadc6d3,
"Twinkle Blue":0xd0d7df,
"Twinkle Little Star":0xfce79a,
"Twinkle Toes":0xe2d39b,
"Twinkle Twinkle":0xfcf0c5,
"Twinkled Pink":0xe9dbe4,
"Twinkling Lights":0xfffac1,
"Twinkly Pinkily":0xcf4796,
"Twist of Lime":0x4e632c,
"Twisted Blue":0x76c4d1,
"Twisted Tail":0x9a845e,
"Twisted Time":0x7f6c6e,
"Twisted Vine":0x655f50,
"Two Harbours":0xbed3e1,
"Typhus Corrosion":0x463d2b,
"Tyrant Skull":0xcdc586,
"Tyrian":0x4e4d59,
"Tyrian Purple":0x66023c,
"Tyrol":0xb3cdbf,
"Tyrolite Blue-Green":0x00a499,
"Tyson Taupe":0x736458,
"Tzatziki Green":0xddeecc,
"UA Blue":0x0033aa,
"UA Red":0xd9004c,
"Ube":0x8878c3,
"Über Umber":0x7b5838,
"UCLA Blue":0x536895,
"UCLA Gold":0xffb300,
"Ufo":0x989fa3,
"UFO Defense Green":0x88aa11,
"UFO Green":0x3cd070,
"Uguisu Brown":0x645530,
"Uguisu Green":0x928c36,
"Ukon Saffron":0xfabf14,
"Uldum Beige":0xfcc680,
"Ulthuan Grey":0xc7e0d9,
"Ultimate Gray":0xa9a8a9,
"Ultimate Orange":0xff4200,
"Ultimate Pink":0xff55ff,
"Ultra Green":0x7eba4d,
"Ultra Indigo":0x4433ff,
"Ultra Pink":0xf06fff,
"Ultra Pure White":0xf8f8f3,
"Ultra Red":0xfc6c85,
"Ultra Violet":0x7366bd,
"Ultra Violet Lentz":0xaa22aa,
"Ultraberry":0x770088,
"Ultramarine":0x1805db,
"Ultramarine Blue":0x657abb,
"Ultramarine Green":0x006b54,
"Ultramarine Highlight":0x2e328f,
"Ultramarine Shadow":0x090045,
"Ultramarine Violet":0x1d2a58,
"Ultramint":0xb6ccb6,
"Ultraviolet Berl":0xbb44cc,
"Ultraviolet Cryner":0xbb44bb,
"Ultraviolet Nusp":0xbb44aa,
"Ultraviolet Onsible":0xbb44dd,
"Uluru Red":0x921d0f,
"Ulva Lactuca Green":0x90ee90,
"Umber":0xb26400,
"Umber Brown":0x613936,
"Umber Rust":0x765138,
"Umber Shade Wash":0x4e4d2f,
"Umber Style":0xece7dd,
"Umbra":0x211e1f,
"Umbra Sand":0x87706b,
"Umbral Umber":0x520200,
"Umbrella Green":0xa2af70,
"Umemurasaki Purple":0x8f4155,
"Umenezumi Plum":0x97645a,
"Umezome Pink":0xfa9258,
"Unakite":0x75a14f,
"Unbleached":0xfbfaf5,
"Unbleached Calico":0xf5d8bb,
"Unbleached Silk":0xffddca,
"Unburdened Pink":0xfbe7e6,
"Uncertain Gray":0xa9b0b1,
"Uncharted":0x19565e,
"Underbrush":0xbe9e48,
"Undercool":0x7fc3e1,
"Underground":0x665a51,
"Underground Civilization":0x524b4c,
"Underground Gardens":0x87968b,
"Underhive Ash":0xb2ac88,
"Underpass Shrine":0xcc4422,
"Undersea":0x90b1ae,
"Underseas":0x7c8e87,
"Understated":0xd4c9bb,
"Undertow":0x779999,
"Underwater":0xcfeee8,
"Underwater Falling":0x0022bb,
"Underwater Fern":0x06d078,
"Underwater Flare":0xe78ea5,
"Underwater Moonlight":0x4488aa,
"Underworld":0x1e231c,
"Undine":0x89c1ba,
"Unexplained":0x69667c,
"Unfading Dusk":0xe7d8de,
"Unfired Clay":0x986960,
"Unforgettably Gold":0xae8245,
"Unfussy Beige":0xd6c8c0,
"Ungor Flesh":0xd6a766,
"Unicorn Dust":0xff2f92,
"Unicorn Silver":0xe8e8e8,
"Uniform":0xa7b7ca,
"Uniform Brown":0x6e5d3e,
"Uniform Green":0x4c4623,
"Uniform Green Grey":0x5f7b7e,
"Uniform Grey":0xa8a8a8,
"Unimaginable":0x8c7eb9,
"Uninhibited":0xb5d1c7,
"Union Springs":0x9c9680,
"Union Station":0xc7c5ba,
"Unique Gray":0xcbc9c9,
"United Nations Blue":0x5b92e5,
"Unity":0x264d8e,
"Universal Green":0x006b38,
"Universal Khaki":0xb8a992,
"University of California Gold":0xb78727,
"University of Tennessee Orange":0xf77f00,
"Unloaded Texture Purple":0xc154c1,
"Unmarked Trail":0xd2cab7,
"Unmatched Beauty":0xb12d35,
"Unmellow Yellow":0xfefe66,
"Unplugged":0x4b4840,
"Unpredictable Hue":0x7b746b,
"Unreal Teal":0x5c6e70,
"Unripe Strawberry":0xf78fa7,
"Untamed Orange":0xde5730,
"Untamed Red":0xdd0022,
"Unusual Gray":0xa3a7a0,
"Unwind":0xf2f8ed,
"UP Forest Green":0x014431,
"Up in Smoke":0x6e706d,
"UP Maroon":0x7b1113,
"Up North":0x6f9587,
"Upbeat":0xf1d9a5,
"Upper Crust":0xa3758b,
"Upper East Side":0x8d6051,
"Uproar Red":0xee1100,
"Upscale":0xa8adc2,
"Upsdell Red":0xae2029,
"Upsed Tomato":0xb52923,
"Upstream Salmon":0xf99a7a,
"Uptown Girl":0xa791a8,
"Uptown Taupe":0xf1e4d7,
"Upward":0xbdc9d2,
"Urahayanagi Green":0xbcb58c,
"Uran Mica":0x93b778,
"Uranus":0xace5ee,
"Urban Bird":0xddd4c5,
"Urban Charm":0xaea28c,
"Urban Chic":0x464e4d,
"Urban Exploration":0x89776e,
"Urban Garden":0x7c7466,
"Urban Green":0x005042,
"Urban Grey":0xcacacc,
"Urban Jungle":0xa4947e,
"Urban Legend":0x67585f,
"Urban Mist":0xd3dbd9,
"Urban Pigeon":0x9dacb7,
"Urban Putty":0xb0b1a9,
"Urban Raincoat":0xbdcbca,
"Urban Safari":0x978b6e,
"Urban Taupe":0xc9bdb6,
"Urban Vibes":0x8899aa,
"Urbane Bronze":0x54504a,
"Urbanite":0x4d5659,
"Uri Yellow":0xffd72e,
"Urnebes Beige":0xffecc2,
"Urobilin":0xe1ad21,
"US Air Force Blue":0x00308f,
"US Field Drab":0x716140,
"USAFA Blue":0x004f98,
"USC Cardinal":0x990010,
"USC Gold":0xffcc00,
"Used Oil":0x231712,
"Useful Gray":0xcfcabd,
"Ushabti Bone":0xbbbb7f,
"USMC Green":0x373d31,
"Usu Koubai Blossom":0xe597b2,
"Usu Pink":0xa87ca0,
"Usuao Blue":0x8c9c76,
"Usubeni Red":0xf2666c,
"Usugaki Persimmon":0xfca474,
"Usukō":0xfea464,
"Usumoegi Green":0x8db255,
"Utah Crimson":0xd3003f,
"Utah Sky":0xaed1e8,
"Utaupeia":0xa58f7b,
"Utepils":0xfafad2,
"Utterly Beige":0xb5a597,
"UV Light":0x0098c8,
"Va Va Bloom":0xefd5cf,
"Va Va Voom":0xe3b34c,
"Vacation Island":0xd1d991,
"Vacherin Cheese":0xfde882,
"Vagabond":0xaa8877,
"Vaguely Mauve":0xd1c5c4,
"Vaguely Violet":0xdbe1ef,
"Valencia":0xd4574e,
"Valentine":0xa53a4e,
"Valentine Heart":0xba789e,
"Valentine Lava":0xba0728,
"Valentine Red":0x9b233b,
"Valentine's Day":0xa63864,
"Valentino":0xb64476,
"Valentino Nero":0x382c38,
"Valerian":0x9f7a93,
"Valerie":0xfde6e7,
"Valhalla":0x2a2b41,
"Valhallan Blizzard":0xf2ede7,
"Valiant Poppy":0xbc322c,
"Valiant Violet":0x3e4371,
"Valkyrie":0xeecc22,
"Vallarta Blue":0x30658e,
"Valley Flower":0xffdd9d,
"Valley Hills":0x848a83,
"Valley Mist":0xc9d5cb,
"Valley of Fire":0xff8a4a,
"Valley of Glaciers":0x2d7e96,
"Valley Vineyards":0x8a763d,
"Valleyview":0xc2ccac,
"Valonia":0x79c9d1,
"Valor":0xa3bcdb,
"Vampire Bite":0xc40233,
"Vampire Fangs":0xcc2255,
"Vampire Fiction":0x9b0f11,
"Vampire Love Story":0xdd0077,
"Vampire Red":0xdd4132,
"Vampire State Building":0xcc1100,
"Vampiric Bloodlust":0xcc0066,
"Vampiric Shadow":0xbfb6aa,
"Van Cleef":0x523936,
"Van de Cane":0xfaf7eb,
"Van Dyke Brown":0x664228,
"Van Gogh Blue":0xabddf1,
"Van Gogh Green":0x65ce95,
"Van Gogh Olives":0x759465,
"Vanadyl Blue":0x00a3e0,
"Vandermint":0xabdee4,
"Vandyck Brown":0x7b5349,
"Vanilla":0xf3e5ab,
"Vanilla Bean Brown":0x362c1d,
"Vanilla Blush":0xfcede4,
"Vanilla Cream":0xf4d8c6,
"Vanilla Custard":0xf3e0be,
"Vanilla Delight":0xf5e8d5,
"Vanilla Doe":0xd1bea8,
"Vanilla Flower":0xe9dfcf,
"Vanilla Frost":0xfde9c5,
"Vanilla Ice":0xfdf2d1,
"Vanilla Ice Cream":0xffe6b3,
"Vanilla Ice Smoke":0xc9dae2,
"Vanilla Love":0xe6e0cc,
"Vanilla Milkshake":0xf1ece2,
"Vanilla Mocha":0xebdbc8,
"Vanilla Paste":0xf3e7d3,
"Vanilla Powder":0xfaf3dd,
"Vanilla Pudding":0xf7e26b,
"Vanilla Quake":0xcbc8c2,
"Vanilla Seed":0xccb69b,
"Vanilla Shake":0xfffbf0,
"Vanilla Tan":0xf1e9dd,
"Vanilla Wafer":0xf3ead2,
"Vanilla White":0xf6eee5,
"Vanillin":0xf2e3ca,
"Vanishing":0x331155,
"Vanishing Blue":0xcfdfef,
"Vanishing Night":0x990088,
"Vanishing Point":0xddeedd,
"Vanity":0x5692b2,
"Vanity Pink":0xe6ccdd,
"Vantablack":0x000100,
"Vape Smoke":0xe8e8d7,
"Vapor":0xf0ffff,
"Vapor Blue":0xbebdbd,
"Vapor Trail":0xf5eedf,
"Vaporous Grey":0xdfddd7,
"Vaporwave":0xff66ee,
"Vaporwave Pool":0x99eebb,
"Vaquero Boots":0x855f43,
"Varden":0xfdefd3,
"Variegated Frond":0x747d5a,
"Varnished Ivory":0xe6dccc,
"Vast":0xc9bdb8,
"Vast Desert":0xc2b197,
"Vast Escape":0xd2c595,
"Vast Sky":0xa9c9d7,
"Vega Violet":0xaa55ff,
"Vegan":0x22bb88,
"Vegan Green":0x006c47,
"Vegan Mastermind":0x22bb55,
"Vegan Villain":0xaa9911,
"Vegas Gold":0xc5b358,
"Vegeta Blue":0x26538d,
"Vegetable Garden":0x8b8c40,
"Vegetarian":0x22aa00,
"Vegetarian Veteran":0x78945a,
"Vegetarian Vulture":0xcccc99,
"Vegetation":0x5ccd97,
"Vehicle Body Grey":0x4c433d,
"Veil of Dusk":0xdad8c9,
"Veiled Chameleon":0x80b690,
"Veiled Delight":0xb2b0bd,
"Veiled Rose":0xf8cdc9,
"Veiled Spotlight":0xcfd5d7,
"Veiled Violet":0xb19bb0,
"Velddrif":0xa17d61,
"Vellum Parchment":0xefe4d9,
"Velour":0xbaa7bf,
"Veltliner White":0xd7d8c3,
"Velum Smoke":0xd6ceb9,
"Velvet":0x750851,
"Velvet Beige":0xd0c5b1,
"Velvet Black":0x241f20,
"Velvet Blush":0xe3d5d8,
"Velvet Cake":0x9d253d,
"Velvet Cape":0x623941,
"Velvet Clover":0x656d63,
"Velvet Cosmos":0x441144,
"Velvet Crest":0x9291bc,
"Velvet Cupcake":0xaa0066,
"Velvet Curtain":0x7e85a3,
"Velvet Dawn":0xbdb0bc,
"Velvet Ears":0xc5adb4,
"Velvet Evening":0x33505e,
"Velvet Green":0x2f5d50,
"Velvet Green Grey":0x737866,
"Velvet Grey":0xacaab3,
"Velvet Leaf":0x96c193,
"Velvet Magic":0xbb1155,
"Velvet Mauve":0x692b57,
"Velvet Morning":0x60688d,
"Velvet Robe":0x939dcc,
"Velvet Rope":0x36526a,
"Velvet Rose":0x7e374c,
"Velvet Scarf":0xe3dfec,
"Velvet Sky":0xc5d3dd,
"Velvet Slipper":0x846c76,
"Velvet Touch":0x523544,
"Velvet Umber":0x6b605a,
"Velvet Violet":0x43354f,
"Velvet Wine":0x9a435d,
"Velveteen Crush":0x936064,
"Velvety Chestnut":0xa2877d,
"Velvety Merlot":0x794143,
"Venetian":0x928083,
"Venetian Glass":0x9cb08a,
"Venetian Gold":0xb39142,
"Venetian Lace":0xf7edda,
"Venetian Mask":0xe7ceb6,
"Venetian Nights":0x7755ff,
"Venetian Pearl":0xd2ead5,
"Venetian Pink":0xbb8e84,
"Venetian Red":0xc80815,
"Venetian Rose":0xefc6e1,
"Venetian Wall":0x949486,
"Venetian Yellow":0xf6e3a1,
"Venice Blue":0x2c5778,
"Venice Square":0xe6c591,
"Venom":0xa9a52a,
"Venom Dart":0x01ff01,
"Venom Wyrm":0x607038,
"Venomous Green":0x66ff22,
"Venous Blood Red":0x3f3033,
"Ventilated":0xcde6e8,
"Venture Violet":0x7381b3,
"Venus":0xeed053,
"Venus Deathtrap":0xfed8b1,
"Venus Deva":0x8f7974,
"Venus Flower":0x9ea6cf,
"Venus Flytrap":0x94b44c,
"Venus Mist":0x5f606e,
"Venus Pink":0xf0e5e5,
"Venus Slipper Orchid":0xdf73ff,
"Venus Teal":0x85a4a2,
"Venusian":0x71384c,
"Veranda":0x61a9a5,
"Veranda Blue":0x66b6b0,
"Veranda Charm":0x9eb1af,
"Veranda Gold":0xaf9968,
"Veranda Green":0x8e977e,
"Veranda Hills":0xccb994,
"Veranda Iris":0x9da4be,
"Verbena":0xf1dfdf,
"Verdant":0x847e35,
"Verdant Fields":0x5ad33e,
"Verdant Forest":0x28615d,
"Verdant Green":0x12674a,
"Verdant Views":0x75794a,
"Verde":0x7fb383,
"Verde Garrafa":0x355e3b,
"Verde Marrón":0x877459,
"Verde Pastel":0xedf5e7,
"Verde Tortuga":0xa7ad8d,
"Verde Tropa":0x758000,
"Verdigreen":0x81a595,
"Verdigris":0x43b3ae,
"Verdigris Coloured":0x62be77,
"Verdigris Foncé":0x62603e,
"Verdigris Green":0x61ac86,
"Verdigris Roundhead":0x558367,
"Verditer":0x00bbaa,
"Verditer Blue":0x55aabb,
"Verdun Green":0x48531a,
"Veri Berri":0x937496,
"Veritably Verdant":0x00844b,
"Vermeer Blue":0x2b7caf,
"Vermicelle":0xdabe82,
"Vermicelles":0xbb835f,
"Vermicelli":0xd1b791,
"Vermilion":0xf4320c,
"Vermilion Bird":0xf24433,
"Vermilion Cinnabar":0xe34244,
"Vermilion Green":0x474230,
"Vermilion Red":0xb5493a,
"Vermillion":0xda3b1f,
"Vermillion Orange":0xf9633b,
"Vermillion Seabass":0x973a36,
"Vermin Brown":0x8f7303,
"Verminal":0x55cc11,
"Verminlord Hide":0xa16954,
"Vermont Cream":0xf8f5e8,
"Vermont Slate":0x48535a,
"Verona Beach":0xe9d3ba,
"Veronese Peach":0xecbfa8,
"Veronica":0xa020ff,
"Vers de Terre":0xacdfad,
"Versailles Rose":0xc4b0ad,
"Versatile Gray":0xc1b6ab,
"Verse Green":0x18880d,
"Vert Pierre":0x4a615c,
"Vertigo Cherry":0x990055,
"Verve":0xfcedd8,
"Verve Violet":0x944f80,
"Very Berry":0xb73275,
"Very Coffee":0x664411,
"Very Grape":0x927288,
"Very Light Blue":0xd5ffff,
"Very Navy":0x3a4859,
"Very Pale Blue":0xd6fffe,
"Vespa Yellow":0xf3d19f,
"Vesper":0x0011cc,
"Vesper Violet":0x99a0b2,
"Vessel":0xcdc8bf,
"Vestige":0x937899,
"Vesuvian Green":0x879860,
"Vesuvian Violet":0xa28a9f,
"Vesuvius":0xa85533,
"Vetiver":0x807d6f,
"Viaduct":0xc1bbb0,
"Viameter":0xd9d140,
"Vibrant":0xffd44d,
"Vibrant Amber":0xd1902e,
"Vibrant Blue":0x0339f8,
"Vibrant Green":0x0add08,
"Vibrant Honey":0xffbd31,
"Vibrant Hue":0x544563,
"Vibrant Orange":0xff7420,
"Vibrant Orchid":0x804b81,
"Vibrant Purple":0xad03de,
"Vibrant Red":0xc24c6a,
"Vibrant Soft Blue":0x88d6dc,
"Vibrant Velvet":0xbb0088,
"Vibrant Vine":0x4b373a,
"Vibrant Vision":0x6c6068,
"Vibrant White":0xeaedeb,
"Vibrant Yellow":0xffda29,
"VIC 20 Blue":0xc7ffff,
"VIC 20 Creme":0xffffb2,
"VIC 20 Green":0x94e089,
"VIC 20 Pink":0xea9ff6,
"VIC 20 Sky":0x87d6dd,
"Vicarious Violet":0x5f4d50,
"Vice City":0xee00dd,
"Vicious Violet":0x8f509d,
"Victoria":0x564985,
"Victoria Blue":0x08589d,
"Victoria Green":0x006a4d,
"Victoria Peak":0x007755,
"Victoria Red":0x6a3c3a,
"Victorian":0x988f97,
"Victorian Cottage":0xd4c5ca,
"Victorian Crown":0xc38b36,
"Victorian Gold":0xa2783b,
"Victorian Greenhouse":0x00b191,
"Victorian Iris":0x6d657e,
"Victorian Lace":0xefe1cd,
"Victorian Mauve":0xb68b88,
"Victorian Peacock":0x104a65,
"Victorian Pearl":0xf1e3d8,
"Victorian Pewter":0x828388,
"Victorian Plum":0x8e6278,
"Victorian Rouge":0xd28085,
"Victorian Valentine":0xae6aa1,
"Victorian Violet":0xb079a7,
"Victoriana":0xd6b2ad,
"Victory Blue":0x3a405a,
"Victory Lake":0x92abd8,
"Vida Loca":0x549019,
"Vidalia":0xa1ddd4,
"Vienna Dawn":0xf7efef,
"Vienna Lace":0xe9d9d4,
"Vienna Roast":0x330022,
"Vienna Sausage":0xfed1bd,
"Viennese":0x8c8185,
"Viennese Blue":0x4278af,
"Vietnamese Lantern":0xeec172,
"Vigilant":0x81796f,
"Vigorous Violet":0x645681,
"Viking":0x4db1c8,
"Viking Castle":0x757266,
"Viking Diva":0xcabae0,
"Vile Green":0x8fcdb0,
"Villa White":0xefeae1,
"Village Crier":0xab9769,
"Village Green":0x7e867c,
"Village Square":0x7b6f60,
"Villandry":0x728f66,
"Vin Cuit":0xb47463,
"Vin Rouge":0x955264,
"Vinaigrette":0xefdaae,
"Vinalhaven":0xacb3ae,
"Vinca":0x5778a7,
"Vincotto":0x483743,
"Vindaloo":0xae7579,
"Vine Leaf":0x4d5f4f,
"Vine Leaf Green":0x6e5e2c,
"Vineyard":0x819e84,
"Vineyard Autumn":0xee4455,
"Vineyard Green":0x5f7355,
"Vineyard Wine":0x58363d,
"Vinho do Porto":0xb31a38,
"Vining Ivy":0x4b7378,
"Vino Tinto":0x4c1c24,
"Vintage":0x847592,
"Vintage Beige":0xdfe1cc,
"Vintage Blue":0x87b8b5,
"Vintage Charm":0xc7b0a7,
"Vintage Copper":0x9d5f46,
"Vintage Coral":0xd68c76,
"Vintage Ephemera":0xd8ceb9,
"Vintage Gold":0xb79e78,
"Vintage Grape":0x6f636d,
"Vintage Indigo":0x4a556b,
"Vintage Khaki":0x9a9186,
"Vintage Lace":0xf1e7d2,
"Vintage Linen":0xe3dcca,
"Vintage Mauve":0xbaafac,
"Vintage Merlot":0x763d4b,
"Vintage Orange":0xffb05f,
"Vintage Plum":0x675d62,
"Vintage Porcelain":0xf2edec,
"Vintage Pottery":0xa66c47,
"Vintage Red":0x9e3641,
"Vintage Ribbon":0x9097b4,
"Vintage Taupe":0xcdbfb9,
"Vintage Tea Rose":0xcbb0a8,
"Vintage Teal":0x669699,
"Vintage Velvet":0x485169,
"Vintage Vessel":0x94b2a6,
"Vintage Vibe":0x888f4f,
"Vintage Victorian":0xe59dac,
"Vintage Violet":0x634f62,
"Vintage White":0xf4efe4,
"Vintage Wine":0x65344e,
"Vintner":0x68546a,
"Viola":0x966ebd,
"Viola Black":0x2f2a41,
"Viola Grey":0x8c6897,
"Viola Ice Grey":0xc6c8d0,
"Viola Sororia":0xb9a5bd,
"Violaceous":0xbf8fc4,
"Violaceous Greti":0x881188,
"Violent Violet":0x7f00ff,
"Violet":0x9a0eea,
"Violet Aura":0x838ba4,
"Violet Beauty":0xbab3cb,
"Violet Black":0x49434a,
"Violet Blue":0x510ac9,
"Violet Bouquet":0xb9b1c8,
"Violet Clues":0xefecef,
"Violet Crush":0xd8d3e6,
"Violet Dawn":0xa89b9c,
"Violet Echo":0xdfdee5,
"Violet Eclipse":0xa387ac,
"Violet Eggplant":0x991199,
"Violet Essence":0xe6e5e6,
"Violet Evening":0x65677a,
"Violet Extract":0xdee2ec,
"Violet Fields":0xb8a4c8,
"Violet Frog":0x926eae,
"Violet Gems":0xc4c0e9,
"Violet Glow":0x4422ee,
"Violet Haze":0x675b72,
"Violet Heaven":0xcdb7fa,
"Violet Hickey":0x330099,
"Violet Hush":0xe5e2e7,
"Violet Ice":0xc2acb1,
"Violet Indigo":0x3e285c,
"Violet Ink":0x9400d3,
"Violet Intense":0x4d4456,
"Violet Kiss":0xf0a0d1,
"Violet Majesty":0x644982,
"Violet Mist":0xdaccde,
"Violet Mix":0xaca8cd,
"Violet Orchid":0xca7988,
"Violet Persuasion":0x927b97,
"Violet Pink":0xfb5ffc,
"Violet Poison":0x8601bf,
"Violet Posy":0x60394d,
"Violet Powder":0xc7ccd8,
"Violet Purple":0x3a2f52,
"Violet Quartz":0x8b4963,
"Violet Red":0xa50055,
"Violet Scent Soft Blue":0xbcc6df,
"Violet Shadow":0x4d4860,
"Violet Storm":0x5c619d,
"Violet Sweet Pea":0xc7c5dc,
"Violet Tulip":0x9e91c3,
"Violet Tulle":0xc193c0,
"Violet Vapor":0xe5dae1,
"Violet Velvet":0xb19cd9,
"Violet Verbena":0x898ca3,
"Violet Vibes":0x898098,
"Violet Vignette":0xd8e0ea,
"Violet Vision":0xb7bdd1,
"Violet Vista":0xb09f9e,
"Violet Vixen":0x883377,
"Violet Vogue":0xe9e1e8,
"Violet Water":0xd2d6e6,
"Violet Webcap":0x833e82,
"Violet Whimsey":0xdad6df,
"Violet White":0xe2e3e9,
"Violeta Silvestre":0xaca7cb,
"Violets Are Blue":0x7487c6,
"Violin Brown":0x674403,
"Virgin Olive Oil":0xe2dcab,
"Virgin Peach":0xecbdb0,
"Virginia Blue":0xb7c3d7,
"Viric Green":0x99cc00,
"Viridian":0x1e9167,
"Viridian Green":0xbcd7d4,
"Viridine Green":0xc8e0ab,
"Viridis":0x00846b,
"Virtual Boy":0xfe0215,
"Virtual Forest":0x8aa56e,
"Virtual Pink":0xc6174e,
"Virtual Taupe":0x8a7a6a,
"Virtual Violet":0x66537f,
"Virtuoso":0x5d5558,
"Virtuous":0x9f7ba9,
"Virtuous Violet":0xb7b0bf,
"Vis Vis":0xf9e496,
"Vision":0xd2cce5,
"Vision of Light":0xdfd3cb,
"Vision Quest":0x9b94c2,
"Visiona Red":0x83477d,
"Visionary":0xf6e0a9,
"Vista Blue":0x97d5b3,
"Vista White":0xe3dfd9,
"Vital Green":0x138859,
"Vital Yellow":0xede0c5,
"Vitalize":0x2aaa45,
"Vitamin C":0xff9900,
"Viva Gold":0xe3ac72,
"Viva La Bleu":0x97bee2,
"Viva Las Vegas":0xb39953,
"Vivacious":0xa32857,
"Vivacious Pink":0xdc89a8,
"Vivacious Violet":0x804665,
"Vivaldi Red":0xef3939,
"Vivid Amber":0xcc9900,
"Vivid Auburn":0x922724,
"Vivid Blue":0x152eff,
"Vivid Burgundy":0x9f1d35,
"Vivid Cerise":0xda1d81,
"Vivid Cerulean":0x00aaee,
"Vivid Crimson":0xcc0033,
"Vivid Green":0x2fef10,
"Vivid Imagination":0x5c9f59,
"Vivid Lime Green":0xa6d608,
"Vivid Malachite":0x00cc33,
"Vivid Mulberry":0xb80ce3,
"Vivid Orange":0xff5f00,
"Vivid Orange Peel":0xffa102,
"Vivid Orchid":0xcc00ff,
"Vivid Purple":0x9900fa,
"Vivid Raspberry":0xff006c,
"Vivid Red":0xf70d1a,
"Vivid Red Tangelo":0xdf6124,
"Vivid Sky Blue":0x00ccff,
"Vivid Tangelo":0xf07427,
"Vivid Tangerine":0xff9980,
"Vivid Vermilion":0xe56024,
"Vivid Viola":0x993c7c,
"Vivid Violet":0x9f00ff,
"Vivid Vision":0x5e4b62,
"Vivid Yellow":0xffe302,
"Vixen":0x573d37,
"Vizcaya":0x7b9e98,
"Vizcaya Palm":0x47644b,
"Vodka":0xbfc0ee,
"Void":0x050d25,
"Voila!":0xaf8ba8,
"Volcanic":0xa55749,
"Volcanic Ash":0x6f7678,
"Volcanic Blast":0xe15835,
"Volcanic Brick":0x72453a,
"Volcanic Glass":0x615c60,
"Volcanic Island":0x605244,
"Volcanic Rock":0x6b6965,
"Volcanic Sand":0x404048,
"Volcanic Stone Green":0x45433b,
"Volcano":0x4e2728,
"Voldemort":0x2d135f,
"Volt":0xceff00,
"Voltage":0x3b4956,
"Voluptuous Violet":0x7711dd,
"Volute":0x445a5e,
"Voodoo":0x443240,
"Voxatron Purple":0x83769c,
"Voyage":0x719ca4,
"Voyager":0x4d5062,
"Voysey Grey":0x9a937f,
"Vulcan":0x36383c,
"Vulcan Burgundy":0x5f3e42,
"Vulcan Mud":0x897f79,
"Waaagh! Flesh":0x1f5429,
"Wabi-Sabi":0xc8c8b5,
"Waddles Pink":0xeeaacc,
"Wafer":0xd4bbb1,
"Waffle Cone":0xe2c779,
"Wafting Grey":0xcdbdba,
"Wageningen Green":0x34b233,
"Wagon Wheel":0xc2b79e,
"Wahoo":0x272d4e,
"Waikawa Grey":0x5b6e91,
"Waikiki":0x218ba0,
"Wailing Woods":0x004411,
"Wainscot Green":0x9c9d85,
"Waiouru":0x4c4e31,
"Waiporoporo Purple":0x654bc9,
"Waiting":0x9d9d9d,
"Wakame Green":0x00656e,
"Wakatake Green":0x6b9362,
"Wake Me Up":0xf6d559,
"Wakefield":0x295468,
"Walden Pond":0x789bb6,
"Walk in the Park":0x88bb11,
"Walk in the Woods":0x3bb08f,
"Walk Me Home":0x496568,
"Walker Lake":0x3d87bb,
"Wall Green":0xabae86,
"Wall Street":0x656d73,
"Walled Garden":0x11cc44,
"Walleye":0x9b5953,
"Wallflower":0xa0848a,
"Wallflower White":0xe4e3e6,
"Wallis":0xc6bdbf,
"Walls of Santorini":0xe9edf1,
"Walnut":0x773f1a,
"Walnut Grove":0x5c5644,
"Walnut Hull":0x5d5242,
"Walnut Oil":0xeecb88,
"Walnut Shell":0xaa8344,
"Walnut Shell Brown":0xa68b6e,
"Walrus":0x999b9b,
"Wan Blue":0xcbdcdf,
"Wan White":0xe4e2dc,
"Wanderer":0x5e5648,
"Wandering River":0x73a4c6,
"Wandering Road":0x876d5e,
"Wandering Willow":0xa6a897,
"Wanderlust":0x426267,
"War God":0x643530,
"Warlock Red":0xb50038,
"Warlord":0xba0033,
"Warm and Toasty":0xcbb68f,
"Warm Apricot":0xffb865,
"Warm Ash":0xcfc9c7,
"Warm Asphalt":0x9c9395,
"Warm Biscuits":0xe3cdac,
"Warm Black":0x004242,
"Warm Blue":0x4b57db,
"Warm Bread":0xf9e6d3,
"Warm Brown":0x964e02,
"Warm Brownie":0x604840,
"Warm Buttercream":0xe6d5ba,
"Warm Butterscotch":0xd0b082,
"Warm Cider":0xbf6a52,
"Warm Cocoon":0xf9d09c,
"Warm Cognac":0xa88168,
"Warm Comfort":0xb38a82,
"Warm Croissant":0xe4ceb5,
"Warm Earth":0x927558,
"Warm Embrace":0x93817e,
"Warm Fuzzies":0xf6e2ce,
"Warm Glow":0xf1cf8a,
"Warm Granite":0xa49e97,
"Warm Grey":0x978a84,
"Warm Grey Flannel":0xaca49a,
"Warm Haze":0x736967,
"Warm Hearth":0xbe9677,
"Warm Leather":0xc89f59,
"Warm Light":0xfff9d8,
"Warm Mahogany":0x6d4741,
"Warm Muffin":0xe1be8b,
"Warm Neutral":0xc1b19d,
"Warm Nutmeg":0x8f6a50,
"Warm Oats":0xd8cfba,
"Warm Olive":0xc7b63c,
"Warm Onyx":0x4c4845,
"Warm Pewter":0xb4ada6,
"Warm Pink":0xfb5581,
"Warm Port":0x513938,
"Warm Pumpernickel":0x5c4e44,
"Warm Purple":0x952e8f,
"Warm Sand":0xc5ae91,
"Warm Shell":0xddc9b1,
"Warm Spice":0x987744,
"Warm Spring":0x4286bc,
"Warm Stone":0xa79a8a,
"Warm Sun":0xfaf6db,
"Warm Taupe":0xaf9483,
"Warm Terra Cotta":0xc1775e,
"Warm Turbulence":0xf3f5dc,
"Warm Up":0x9e6654,
"Warm Wassail":0xa66e68,
"Warm Waters":0x7ebbc2,
"Warm Welcome":0xea9073,
"Warm Wetlands":0x8d894a,
"Warm White":0xefebd8,
"Warm Winter":0xd4ede3,
"Warm Woolen":0xd0b55a,
"Warmed Wine":0x5c3839,
"Warming Peach":0xe4b9a2,
"Warmstone":0xe6d7cc,
"Warmth":0x9f552d,
"Warp Drive":0xeaf2f1,
"Warpfiend Grey":0x6b6a74,
"Warplock Bronze":0x515131,
"Warplock Bronze Metal":0x927d7b,
"Warpstone Glow":0x168340,
"Warrant":0xb8966e,
"Warren Tavern":0x6b654e,
"Warrior":0x7d685b,
"Wasabi":0xafd77f,
"Wasabi Green":0xa9ad74,
"Wasabi Nori":0x333300,
"Wasabi Nuts":0x849137,
"Wasabi Paste":0xcae277,
"Wasabi Peanut":0xb4c79c,
"Wasabi Powder":0xbdb38f,
"Wasabi Zing":0xd2cca0,
"Wash Me":0xfafbfd,
"Washed Black":0x1f262a,
"Washed Blue":0x94d1df,
"Washed Denim":0x819dbe,
"Washed Dollar":0xe1e3d7,
"Washed Green":0xccd1c8,
"Washed in Light":0xfae8c8,
"Washed Khaki":0xcac2af,
"Washed Olive":0xc5c0a3,
"Washed Out Green":0xbcf5a6,
"Washed-Out Crimson":0xffb3a7,
"Washing Powder Soft Blue":0xc3d8e4,
"Washing Powder White":0xc2dce3,
"Wasteland":0x9c8855,
"Wasurenagusa Blue":0x89c3eb,
"Watchet":0x8fbabc,
"Water":0xd4f1f9,
"Water Baby":0x5ab5cb,
"Water Baptism":0xcfdfdd,
"Water Blue":0x0e87cc,
"Water Carrier":0x4999a1,
"Water Chestnut":0xede4cf,
"Water Chi":0x355873,
"Water Cooler":0x75a7ad,
"Water Droplet":0xe1e5dc,
"Water Fern":0x75b790,
"Water Flow":0x7ac6d9,
"Water Glitter":0x76afb6,
"Water Green":0x81b89a,
"Water Hyacinth":0xa0a3d2,
"Water Iris":0xe2e3eb,
"Water Leaf":0xb6ecde,
"Water Lily":0xdde3d5,
"Water Lily White":0xe6d6c4,
"Water Mist":0xc7d8e3,
"Water Music":0x6fb0be,
"Water Ouzel":0x4f5156,
"Water Park":0x54af9c,
"Water Persimmon":0xb56c60,
"Water Raceway":0x0083c8,
"Water Reed":0xb0ab80,
"Water Scrub":0x949381,
"Water Slide":0xa2cdd2,
"Water Spirit":0x65a5d5,
"Water Sports":0x44bbcc,
"Water Sprout":0xe5eecc,
"Water Squirt":0xd8ebea,
"Water Surface":0xa9bdb8,
"Water Tower":0x958f88,
"Water Wash":0xacc7e5,
"Water Welt":0x3994af,
"Water Wheel":0xa28566,
"Water Wonder":0x80d4d0,
"Watercolour Blue":0x084d58,
"Watercolour Green":0x96b47e,
"Watercolour White":0xdbe5db,
"Watercourse":0x006e4e,
"Watercress":0x6e9377,
"Watercress Pesto":0xc7c7a1,
"Watercress Spice":0x748c69,
"Waterfall":0x3ab0a2,
"Waterfall Mist":0xe4eeea,
"Waterhen Back":0x2f3f53,
"Waterline Blue":0x436bad,
"Waterloo":0x7b7c94,
"Watermark":0xdee9df,
"Watermelon":0xfd4659,
"Watermelon Candy":0xfd5b78,
"Watermelon Juice":0xf05c85,
"Watermelon Milk":0xdfcfca,
"Watermelon Pink":0xc77690,
"Watermelon Punch":0xe08880,
"Watermelon Red":0xbf4147,
"Watermelon Slice":0xe77b68,
"Watermelonade":0xeb4652,
"Watermill Wood":0xd3cccd,
"Waterpark":0xc9e3e5,
"Waterscape":0xdcece7,
"Watershed":0xb0cec2,
"Waterslide":0xd2f3eb,
"Waterspout":0xa4f4f9,
"Waterway":0x7eb7bf,
"Waterwings":0xafebde,
"Waterworld":0x00718a,
"Watery":0xaebdbb,
"Watery Sea":0x88bfe7,
"Watson Lake":0x74aeba,
"Wattle":0xd6ca3d,
"Watusi":0xf2cdbb,
"Wave":0xa5ced5,
"Wave Crest":0xdce9ea,
"Wave Jumper":0x6c919f,
"Wave of Grain":0xa0764a,
"Wave Splash":0xcbe4e7,
"Wave Top":0xafd9d3,
"Wavecrest":0xd6e1e4,
"Wavelet":0x7dc4cd,
"Waves of Grain":0xc7aa7c,
"Waves Queen":0xd2eaea,
"Wax":0xddbb33,
"Wax Crayon Blue":0x00a4a6,
"Wax Flower":0xeeb39e,
"Wax Green":0xd8db8b,
"Wax Poetic":0xf1e6cc,
"Wax Sculpture":0xe2d5bd,
"Wax Way":0xd3b667,
"Wax Wing":0xf6ecd6,
"Wax Yellow":0xede9ad,
"Waxen Moon":0xb38241,
"Waxy Corn":0xf8b500,
"Way Beyond the Blue":0x1188cc,
"Waystone Green":0x00c000,
"Wayward Willow":0xd9dcd1,
"Wayward Wind":0xdedfe2,
"Waywatcher Green":0x99cc04,
"Waza Bear":0x5e5a59,
"Wazdakka Red":0xb21b00,
"We Peep":0xfdd7d8,
"Weak Blue":0xcfe2ef,
"Weak Green":0xe1f2df,
"Weak Mauve":0xeadee4,
"Weak Mint":0xe0f0e5,
"Weak Orange":0xfaede3,
"Weak Pink":0xecdee5,
"Weak Yellow":0xf1f5db,
"Weapon Bronze":0xb47b27,
"Weather Board":0x9f947d,
"Weathered Bamboo":0x593a27,
"Weathered Blue":0xd2e2f2,
"Weathered Brown":0x59504c,
"Weathered Coral":0xead0a9,
"Weathered Fossil":0x988a72,
"Weathered Hide":0xd5c6c2,
"Weathered Leather":0x90614a,
"Weathered Mint":0xe4f5e1,
"Weathered Moss":0xbabbb3,
"Weathered Pebble":0x7b9093,
"Weathered Pink":0xeadfe8,
"Weathered Plastic":0xf9f4d9,
"Weathered Saddle":0xb5745c,
"Weathered Sandstone":0xdfc0a6,
"Weathered Shingle":0x937f68,
"Weathered Stone":0xc4c4c4,
"Weathered White":0xe6e3d9,
"Weathered Wicker":0x97774d,
"Weathered Wood":0xb19c86,
"Weathervane":0x2c201a,
"Weaver's Spool":0xbfb18a,
"Weaver's Tool":0x9d7f62,
"Web Gray":0x616669,
"Webcap Brown":0x8f684b,
"Wedded Bliss":0xedeadc,
"Wedding Cake":0xeee2c9,
"Wedding Cake White":0xe7e8e1,
"Wedding Dress":0xfefee7,
"Wedding Flowers":0xbcb6cb,
"Wedding in White":0xfffee5,
"Wedding Pink":0xf6dfd8,
"Wedge of Lime":0xe1eca5,
"Wedgewood":0x4c6b88,
"Weekend Gardener":0x9fe4aa,
"Weekend Retreat":0xe9c2ad,
"Weeping Willow":0xb3b17b,
"Weeping Wisteria":0xd7ddec,
"Wèi Lán Azure":0x5a06ef,
"Weird Green":0x3ae57f,
"Weissbier":0xb3833b,
"Weisswurst White":0xe4e1d6,
"Welcome Home":0xc09c6a,
"Welcome Walkway":0xd4c6a7,
"Welcome White":0xf3e3ca,
"Welcoming Wasp":0xeeaa00,
"Welded Iron":0x6f6f6d,
"Weldon Blue":0x7c98ab,
"Well Blue":0x00888b,
"Well Read":0x8e3537,
"Well-Bred Brown":0x564537,
"Wellington":0x4f6364,
"Wells Grey":0xb9b5a4,
"Welsh Onion":0x22bb66,
"Wenge":0x645452,
"Wenge Black":0x3e2a2c,
"Wentworth":0x345362,
"West Coast":0x5c512f,
"West Side":0xe5823a,
"Westar":0xd4cfc5,
"Westcar Papyrus":0xa49d70,
"Westchester Gray":0x797978,
"Western Red":0x9b6959,
"Western Reserve":0x8d876d,
"Western Sky":0xfadca7,
"Western Sunrise":0xdaa36f,
"Westfall Yellow":0xfcd450,
"Westhaven":0x2a4442,
"Westhighland White":0xf3eee3,
"Westminster":0x9c7c5b,
"Wet Adobe":0xa3623b,
"Wet Aloeswood":0x5a6457,
"Wet Ash":0xb2beb5,
"Wet Asphalt":0x989cab,
"Wet Cement":0x89877f,
"Wet Clay":0xa49690,
"Wet Concrete":0x353838,
"Wet Coral":0xd1584c,
"Wet Crow's Wing":0x000b00,
"Wet Latex":0x001144,
"Wet Leaf":0xb9a023,
"Wet Pottery Clay":0xe0816f,
"Wet River Rock":0x897870,
"Wet Sand":0xae8f60,
"Wet Sandstone":0x786d5f,
"Wet Suit":0x50493c,
"Wet Weather":0x929090,
"Wethersfield Moss":0x859488,
"Wetland Stone":0xa49f80,
"Wetlands Swamp":0x372418,
"Wewak":0xf1919a,
"Whale Bone":0xe5e7e5,
"Whale Grey":0x59676b,
"Whale Shark":0x607c8e,
"Whale Skin":0x505a92,
"Whale Watching":0xa5a495,
"Whale's Mouth":0xc7d3d5,
"Whale's Tale":0x115a82,
"Whaling Waters":0x2e7176,
"Wharf View":0x65737e,
"What Inheritance?":0xe8d7bc,
"What We Do in the Shadows":0x441122,
"What's Left":0xfff4e8,
"Wheat":0xfbdd7e,
"Wheat Beer":0xbf923b,
"Wheat Bread":0xdfbb7e,
"Wheat Flour White":0xddd6ca,
"Wheat Grass":0xc7c088,
"Wheat Penny":0x976b53,
"Wheat Seed":0xe3d1c8,
"Wheat Sheaf":0xdfd4c4,
"Wheat Tortilla":0xa49a79,
"Wheatacre":0xad935b,
"Wheaten White":0xfbebbb,
"Wheatfield":0xdfd7bd,
"Wheatmeal":0x9e8451,
"When Blue Met Red":0x584165,
"When Red Met Blue":0x564375,
"Where Buffalo Roam":0xc19851,
"Whero Red":0xdd262b,
"Whetstone Brown":0x9f6f55,
"Whimsical White":0xece4e2,
"Whimsy":0xed9987,
"Whimsy Blue":0xb0dced,
"Whipcord":0xa09176,
"Whiplash":0xc74547,
"Whipped Citron":0xf0edd2,
"Whipped Cream":0xf2f0e7,
"Whipped Mint":0xc7ddd6,
"Whipped Violet":0xa1a8d5,
"Whippet":0xcec1b5,
"Whipping Cream":0xfaf5e7,
"Whirligig":0xe6cdca,
"Whirligig Geyser":0xdfd4c0,
"Whirlpool":0xa5d8cd,
"Whirlpool Green":0xa7d0c5,
"Whirlwind":0xe2d5d3,
"Whiskers":0xf6f1e2,
"Whiskey":0xd29062,
"Whiskey and Wine":0x49463f,
"Whiskey Barrel":0x85705f,
"Whiskey Sour":0xd4915d,
"Whisky":0xc2877b,
"Whisky Barrel":0x96745b,
"Whisky Cola":0x772233,
"Whisky Sour":0xeeaa33,
"Whisper":0xefe6e6,
"Whisper Blue":0xe5e8f2,
"Whisper Green":0xe0e6d7,
"Whisper Grey":0xe9e5da,
"Whisper of Grass":0xcbede5,
"Whisper of Rose":0xcda2ac,
"Whisper Pink":0xdacbbe,
"Whisper Ridge":0xc9c3b5,
"Whisper White":0xede6db,
"Whisper Yellow":0xffe5b9,
"Whispered Secret":0x3f4855,
"Whispering Blue":0xc9dcdc,
"Whispering Grasslands":0xac9d64,
"Whispering Oaks":0x536151,
"Whispering Peach":0xfedcc3,
"Whispering Pine":0xc8cab5,
"Whispering Rain":0xececda,
"Whispering Waterfall":0xe3e6db,
"Whispering Willow":0x919c81,
"Whispering Winds":0xb7c3bf,
"Whistler Rose":0xc49e8f,
"White":0xffffff,
"White Acorn":0xd7a98c,
"White Alyssum":0xefebe7,
"White Asparagus":0xeceabe,
"White Bass":0xe8efec,
"White Beach":0xf5efe5,
"White Bean Hummus":0xe8d0b2,
"White Beet":0xebdfdd,
"White Blaze":0xe3e7e1,
"White Blossom":0xf4ecdb,
"White Blue":0xcdd6db,
"White Blush":0xfbecd8,
"White Box":0xbfd0cb,
"White Bud":0xe3e0e8,
"White Bullet":0xdfdfda,
"White Cabbage":0xb0b49b,
"White Canvas":0xfaece1,
"White Castle":0xdbd5d1,
"White Chalk":0xf6f4f1,
"White Cherry":0xe7dbdd,
"White Chocolate":0xf0e3c7,
"White City":0xd6d0cc,
"White Clay":0xe8e1d3,
"White Cliffs":0xe8e3c9,
"White Coffee":0xe6e0d4,
"White Convolvulus":0xf4f2f4,
"White Crest":0xf9f8ef,
"White Currant":0xf9ebc5,
"White Desert":0xfdfaf1,
"White Dogwood":0xefeae6,
"White Duck":0xcecaba,
"White Edgar":0xededed,
"White Elephant":0xdedee5,
"White Fence":0xf2e9d3,
"White Fever":0xfbf4e8,
"White Flag":0xc8c2c0,
"White Flour":0xf5ede0,
"White Fur":0xf1efe7,
"White Geranium":0xf1f1e1,
"White Glaze":0xddeeee,
"White Gloss":0xffeeee,
"White Glove":0xf0efed,
"White Granite":0xc8d1c4,
"White Grapefruit":0xfcf0de,
"White Grapes":0xbbcc99,
"White Green":0xd6e9ca,
"White Hamburg Grapes":0xe2e6d7,
"White Heat":0xfdf9ef,
"White Heron":0xe7e1d7,
"White Hot Chocolate":0xead8bb,
"White Hyacinth":0xf3e5d1,
"White Hydrangea":0xf9f6dd,
"White Ice":0xd7eee4,
"White Iris":0xdfe2e7,
"White Jade":0xd4dbb2,
"White Jasmine":0xf7f4df,
"White Kitten":0xdfdfdb,
"White Lake":0xe2e7e7,
"White Lavender":0xe1e2eb,
"White Lie":0xdededc,
"White Lightning":0xf9f3db,
"White Lilac":0xe7e5e8,
"White Lily":0xfaf0db,
"White Linen":0xeee7dd,
"White Luxury":0xf7f0e5,
"White Meadow":0xf2e6df,
"White Mecca":0xecf3e1,
"White Metal":0xd1d1cf,
"White Mink":0xefeee9,
"White Mint":0xe0e7da,
"White Mocha":0xe7dccc,
"White Moderne":0xebeae2,
"White Mountain":0xf6eddb,
"White Mouse":0xb9a193,
"White Nectar":0xf8f6d8,
"White Oak":0xce9f6f,
"White Opal":0xe7e2dd,
"White Owl":0xf5f3f5,
"White Peach":0xf9e6da,
"White Pearl":0xede1d1,
"White Pepper":0xb6a893,
"White Picket Fence":0xf0efeb,
"White Pointer":0xdad6cc,
"White Porcelain":0xf8fbf8,
"White Primer":0xc3bdab,
"White Pudding":0xf6e8df,
"White Rabbit":0xf8eee7,
"White Radish":0xe2e8cf,
"White Raisin":0xe5c28b,
"White Rock":0xd4cfb4,
"White Russian":0xf0e0dc,
"White Sage":0xd2d4c3,
"White Sail":0xebebe7,
"White Sand":0xf5ebd8,
"White Sapphire":0xe4eeeb,
"White Scar":0x8c9fa1,
"White Sea":0xd7e5ea,
"White Sesame":0xe4dbce,
"White Shadow":0xd1d3e0,
"White Shoulders":0xf1f0ec,
"White Smoke":0xf5f5f5,
"White Solid":0xf4f5fa,
"White Spruce":0x9fbdad,
"White Sulfur":0xf1faea,
"White Swan":0xe4d7c5,
"White Tiger":0xc5b8a8,
"White Truffle":0xefdbcd,
"White Ultramarine":0x83ccd2,
"White Veil":0xf7f1e3,
"White Vienna":0xc5dcb3,
"White Whale":0xedeeef,
"White Willow":0xecf4dd,
"White Wool":0xf2efde,
"White Zin":0xf8eee3,
"White-Red":0xf3e8ea,
"Whitecap Foam":0xdee3de,
"Whitecap Grey":0xe0d5c6,
"Whitened Sage":0xdee0d2,
"Whitest White":0xf8f9f5,
"Whitetail":0xf4eee5,
"Whitewash":0xfefffc,
"Whitewash Oak":0xcac9c0,
"Whitewashed Fence":0xfaf2e3,
"Whitewater Bay":0xbac4ad,
"Whitney Oaks":0xb2a188,
"Who-Dun-It":0x8b7181,
"Whole Nine Yards":0x03c03c,
"Whole Wheat":0xa48b73,
"Wholemeal Cookie":0xaaa662,
"Whomp Grey":0xbec1cf,
"Wicked Green":0x9bca47,
"Wicker Basket":0x847567,
"Wickerware":0xfce4af,
"Wickerwork":0xc19e80,
"Wickford Bay":0x4f6c8f,
"Wide Sky":0x416faf,
"Widowmaker":0x99aaff,
"Wiener Dog":0x874e3c,
"Wiener Schnitzel":0xee9900,
"Wiggle":0xc9c844,
"Wild Apple":0xfef9d7,
"Wild Aster":0x92316f,
"Wild Axolotl":0x63775a,
"Wild Bamboo":0xeac37e,
"Wild Beet Leaf":0x6b8372,
"Wild Berry":0x7e3a3c,
"Wild Bill Brown":0x795745,
"Wild Blue Yonder":0x7a89b8,
"Wild Boar":0x553322,
"Wild Boysenberry":0x5a4747,
"Wild Brown":0x47241a,
"Wild Caribbean Green":0x1cd3a2,
"Wild Cattail":0x916d5d,
"Wild Chestnut":0xbc5d58,
"Wild Chocolate":0x665134,
"Wild Clary":0x93a3c1,
"Wild Cranberry":0x6e3c42,
"Wild Currant":0x7c3239,
"Wild Dove":0x8b8c89,
"Wild Elderberry":0x545989,
"Wild Forest":0x38914a,
"Wild Geranium":0x986a79,
"Wild Ginger":0x7c4c53,
"Wild Ginseng":0x80805d,
"Wild Grapes":0x5e496c,
"Wild Grass":0x998643,
"Wild Hemp":0x9d7b74,
"Wild Honey":0xeecc00,
"Wild Horse":0x634a40,
"Wild Horses":0x8d6747,
"Wild Iris":0x2f2f4a,
"Wild Lilac":0xbeb8cd,
"Wild Lime":0xc3d363,
"Wild Manzanita":0x684944,
"Wild Maple":0xffe2c7,
"Wild Mulberry":0xa96388,
"Wild Mushroom":0x84704b,
"Wild Mustang":0x695649,
"Wild Nude":0xbeae8a,
"Wild Oats":0xecdbc3,
"Wild Orchid":0xd979a2,
"Wild Orchid Blue":0xb4b6da,
"Wild Pansy":0x6373b4,
"Wild Party":0xb97a77,
"Wild Phlox":0x9ea5c3,
"Wild Pigeon":0x767c6b,
"Wild Plum":0x83455d,
"Wild Poppy":0xb85b57,
"Wild Porcini":0xd6c0aa,
"Wild Primrose":0xebdd99,
"Wild Raisin":0x614746,
"Wild Rice":0xd5bfb4,
"Wild Rider Red":0xdc143c,
"Wild Rose":0xce8498,
"Wild Rye":0xb5a38c,
"Wild Sage":0x7e877d,
"Wild Sand":0xe7e4de,
"Wild Seaweed":0x8a6f45,
"Wild Stallion":0x7c5644,
"Wild Strawberry":0xff3399,
"Wild Thing":0x654243,
"Wild Thistle":0x9e9fb6,
"Wild Thyme":0x7e9c6f,
"Wild Truffle":0x463f3c,
"Wild Watermelon":0xfc6d84,
"Wild West":0x7e5c52,
"Wild Wheat":0xe0e1d1,
"Wild Wilderness":0x91857c,
"Wild Willow":0xbeca60,
"Wild Wisteria":0x686b93,
"Wildcat Grey":0xf5eec0,
"Wilderness":0x8f886c,
"Wilderness Grey":0xc2baa8,
"Wildfire":0xff8833,
"Wildflower":0x927d9b,
"Wildflower Bouquet":0xffb3b1,
"Wildflower Honey":0xc69c5d,
"Wildflower Prairie":0xcccfe2,
"Wildness Mint":0x5d9865,
"Wildwood":0xcdb99b,
"Wilhelminian Pink":0xaa83a4,
"Will":0x179fa6,
"Will O the Wisp":0xd7d8dd,
"William":0x53736f,
"Williams Pear Yellow":0xddc765,
"Willow":0x9a8b4f,
"Willow Blue":0x293648,
"Willow Bough":0x59754d,
"Willow Brook":0xdfe6cf,
"Willow Dyed":0x93b881,
"Willow Green":0xc3cabf,
"Willow Grey":0x817b69,
"Willow Grove":0x69755c,
"Willow Hedge":0x84c299,
"Willow Herb":0xe6dab6,
"Willow Leaf":0xa1a46d,
"Willow Sooty Bamboo":0x5b6356,
"Willow Springs":0xe7e6e0,
"Willow Tree":0x9e8f66,
"Willow Tree Mouse":0xc8d5bb,
"Willow Wood":0x58504d,
"Willow-Flower Yellow":0xf0d29d,
"Willowherb":0x8e4483,
"Willowleaf":0x85877b,
"Willowside":0xf3f2e8,
"Willpower Orange":0xfd5800,
"Wilmington Tan":0xbd9872,
"Wilted Brown":0xab4c3d,
"Wilted Leaf":0xeedac9,
"Wimbledon":0x626d5b,
"Wind Blown":0xdde3e7,
"Wind Blue":0xb1c9df,
"Wind Cave":0x686c7b,
"Wind Chill":0xeff3f0,
"Wind Chimes":0xcac5c2,
"Wind Force":0xd5e2ee,
"Wind Fresh White":0xd0d8cf,
"Wind of Change":0xc8deea,
"Wind Rose":0xe8babd,
"Wind Speed":0xbfd6d9,
"Wind Star":0x6875b7,
"Wind Tunnel":0xc7dfe6,
"Wind Weaver":0xc5d1d8,
"Windchill":0xd5d8d7,
"Windfall":0x84a7ce,
"Windflower":0xbc9ca2,
"Windfresh White":0xded8cf,
"Windgate Hill":0x5b584c,
"Windham Cream":0xf5e6c9,
"Winding Path":0xc6bba2,
"Windjammer":0x62a5df,
"Windmill":0xf5ece7,
"Windmill Park":0xa79b83,
"Windmill Wings":0xf0f1ec,
"Window Box":0xbcafbb,
"Window Grey":0x989ea1,
"Window Pane":0xe4ecdf,
"Windows 95 Desktop":0x018281,
"Windows Blue":0x3778bf,
"Windrift Beige":0xcebcae,
"Windrock":0x5e6c62,
"Windrush":0xdbd3c6,
"Winds Breath":0xe0e1da,
"Windsong":0xf4e4af,
"Windsor":0x462c77,
"Windsor Brown":0xa75502,
"Windsor Greige":0xc4b49c,
"Windsor Haze":0xa697a7,
"Windsor Moss":0x545c4a,
"Windsor Purple":0xc9afd0,
"Windsor Tan":0xcabba1,
"Windsor Toffee":0xccb490,
"Windsor Way":0x9fc9e4,
"Windsor Wine":0x582b36,
"Windstorm":0x6d98c4,
"Windsurf":0x91aab8,
"Windsurf Blue":0x718bae,
"Windsurfer":0xd7e2de,
"Windswept":0xd1f1f5,
"Windswept Beach":0xe3e4e5,
"Windswept Canyon":0xdba480,
"Windswept Leaves":0xb7926b,
"Windwood Spring":0xc2e5e0,
"Windy Blue":0xaabac6,
"Windy City":0x88a3c2,
"Windy Day":0x8cb0cb,
"Windy Meadow":0xb0a676,
"Windy Pine":0x3d604a,
"Windy Seas":0x667f8b,
"Windy Sky":0xe8ebe7,
"Wine":0x80013f,
"Wine Barrel":0xaa5522,
"Wine Bottle":0xd3d6c4,
"Wine Bottle Green":0x254636,
"Wine Brown":0x5f3e3e,
"Wine Cellar":0x70403d,
"Wine Cork":0x866d4c,
"Wine Country":0x602234,
"Wine Crush":0x96837d,
"Wine Dregs":0x673145,
"Wine Frost":0xe5d8e1,
"Wine Goblet":0x643b46,
"Wine Grape":0x941751,
"Wine Gummy Red":0x67334c,
"Wine Leaf":0x355e4b,
"Wine Not":0x864c58,
"Wine Red":0x7b0323,
"Wine Stain":0x69444f,
"Wine Stroll":0x8f7191,
"Wine Tasting":0x492a34,
"Wine Tour":0x653b66,
"Wine Yellow":0xd7c485,
"Wineberry":0x663366,
"Wineshade":0x433748,
"Wing Commander":0x0065ac,
"Wing Man":0x5a6868,
"Winged Victory":0xebe4e2,
"Wingsuit Wind":0xbad5d4,
"Wink":0x7792af,
"Wink Pink":0xede3e7,
"Winner's Circle":0x365771,
"Winning Red":0x894144,
"Winning Ticket":0x636653,
"Winsome Beige":0xe0cfc2,
"Winsome Grey":0xe7e9e4,
"Winsome Hue":0xa7d8e1,
"Winsome Orchid":0xd4b9cb,
"Winsome Rose":0xc28ba1,
"Winter Amethyst":0xb0a6c2,
"Winter Balsam":0x314747,
"Winter Blizzard":0xb8c8d3,
"Winter Bloom":0x47243b,
"Winter Breath":0xdeeced,
"Winter Chill":0x8eced8,
"Winter Chime":0x83c7df,
"Winter Coat":0x45494c,
"Winter Cocoa":0xbaaaa7,
"Winter Could Grey":0x6e7a7c,
"Winter Day":0xe3e7e9,
"Winter Dusk":0xb8b8cb,
"Winter Duvet":0xffffe0,
"Winter Escape":0xb4e5ec,
"Winter Evening":0x476476,
"Winter Fresh":0xd6eedd,
"Winter Frost":0xe4decd,
"Winter Garden":0xdcc89d,
"Winter Glaze":0xeaebe0,
"Winter Harbor":0x5e737d,
"Winter Haven":0xe1e6eb,
"Winter Haze":0xcec9c1,
"Winter Hazel":0xd0c383,
"Winter Hedge":0x798772,
"Winter Ice":0xdbdfe9,
"Winter in Paris":0x6e878b,
"Winter Lake":0x698b9c,
"Winter Lite":0xefe0c9,
"Winter Meadow":0xb7fffa,
"Winter Mist":0xe7fbec,
"Winter Mood":0xd1c295,
"Winter Morn":0xd9d9d6,
"Winter Morning Mist":0xa7b3b5,
"Winter Moss":0x5b5a41,
"Winter Nap":0xa99f97,
"Winter Oak":0x63594b,
"Winter Oasis":0xf2faed,
"Winter Orchid":0xe7e3e7,
"Winter Palace":0x41638a,
"Winter Park":0x95928d,
"Winter Pea Green":0x8e9549,
"Winter Peach":0xebd9d0,
"Winter Pear":0xb0b487,
"Winter Pear Beige":0xc7a55f,
"Winter Poinsettia":0xae3c3d,
"Winter Rye":0xaaa99d,
"Winter Sage":0xaa9d80,
"Winter Savanna":0xdac7ba,
"Winter Sea":0x303e55,
"Winter Shamrock":0xe3efdd,
"Winter Sky":0xa9c0cb,
"Winter Solstice":0x49545c,
"Winter Squash":0xacb99f,
"Winter Storm":0x4b7079,
"Winter Sunset":0xca6636,
"Winter Surf":0x7fb9ae,
"Winter Twig":0x948a7a,
"Winter Veil":0xe0e7e0,
"Winter Walk":0xd8d5cc,
"Winter Waves":0x21424d,
"Winter Way":0x3e474c,
"Winter Wedding":0xf1e4dc,
"Winter Wheat":0xdfc09f,
"Winter White":0xf5ecd2,
"Winter Willow Green":0xc1d8ac,
"Winter Wizard":0xa0e6ff,
"Winter's Breath":0xd4dddd,
"Winter's Day":0xdef7fe,
"Wintergreen":0x20f986,
"Wintergreen Dream":0x56887d,
"Wintergreen Mint":0xc6e5ca,
"Wintergreen Shadow":0x4f9e81,
"Wintermint":0x94d2bf,
"Winterspring Lilac":0xb5afff,
"Wintertime Mauve":0x786daa,
"Wintessa":0x8ba494,
"Winthrop Peach":0xfde6d6,
"Wiped Out":0x8b7180,
"Wipeout":0x3e8094,
"Wire Wool":0x676662,
"Wisdom":0xe2e3d8,
"Wise Owl":0xcdbba5,
"Wish":0xb6bcdf,
"Wish Upon a Star":0x447f8a,
"Wishard":0x53786a,
"Wishful Blue":0xd8dde6,
"Wishful Green":0xc8e2cc,
"Wishful Thinking":0xfcdadf,
"Wishful White":0xf4f1e8,
"Wishing Star":0x604f5a,
"Wishing Troll":0x9a834b,
"Wishing Well":0xd0d1c1,
"Wishy-Washy Beige":0xebdedb,
"Wishy-Washy Blue":0xc6e0e1,
"Wishy-Washy Brown":0xd1c2c2,
"Wishy-Washy Green":0xdfeae1,
"Wishy-Washy Lichen":0xdeede4,
"Wishy-Washy Lilies":0xf5dfe7,
"Wishy-Washy Lime":0xeef5db,
"Wishy-Washy Mauve":0xeddde4,
"Wishy-Washy Mint":0xdde2d9,
"Wishy-Washy Pink":0xf0dee7,
"Wishy-Washy Red":0xe1dadd,
"Wishy-Washy Yellow":0xe9e9d5,
"Wisley Pink":0xf2a599,
"Wisp":0xa9badd,
"Wisp of Mauve":0xd9c7be,
"Wisp of Smoke":0xe5e7e9,
"Wisp Pink":0xf9e8e2,
"Wispy Mauve":0xc6aeaa,
"Wispy Mint":0xbcc7a4,
"Wispy Pink":0xf3ebea,
"Wispy White":0xffc196,
"Wisteria":0xa87dc2,
"Wisteria Blue":0x84a2d4,
"Wisteria Fragrance":0xbbbcde,
"Wisteria Light Soft Blue":0xa6a8c5,
"Wisteria Powder":0xe6c8ff,
"Wisteria Purple":0x875f9a,
"Wisteria Trellis":0xb2adbf,
"Wisteria Yellow":0xf7c114,
"Wisteria-Wise":0xb2a7cc,
"Wistful":0xa29ecd,
"Wistful Beige":0xeaddd7,
"Wistful Mauve":0x946c74,
"Wistman's Wood":0xaa9966,
"Witch Hazel":0xfbf073,
"Witch Hazel Leaf":0x8e8976,
"Witch Soup":0x692746,
"Witch Wart":0x113300,
"Witch Wood":0x7c4a33,
"Witchcraft":0x474c50,
"Witches Cauldron":0x35343f,
"With A Twist":0xd1d1bb,
"With the Grain":0xbca380,
"Withered Rose":0xa26666,
"Witness":0x90c0c9,
"Witty Green":0xb1d99d,
"Wizard":0x4d5b88,
"Wizard Blue":0x0073cf,
"Wizard Grey":0x525e68,
"Wizard Time":0x6d4660,
"Wizard White":0xdff1fd,
"Wizard's Brew":0xa090b8,
"Wizard's Potion":0x5d6098,
"Wizard's Spell":0x584b4e,
"Woad Blue":0x597fb9,
"Woad Indigo":0x6c9898,
"Woad Purple":0x584769,
"Wobbegong Brown":0xc19a6b,
"Wolf Lichen":0xa8ff04,
"Wolf's Bane":0x3d343f,
"Wolf's Fur":0x5c5451,
"Wolfram":0x7d8574,
"Wolverine":0x91989d,
"Wonder Land":0x92adb2,
"Wonder Lust":0xef8e9f,
"Wonder Violet":0xa085a6,
"Wonder Wine":0x635d63,
"Wonder Wish":0xa97898,
"Wonder Woods":0xabcb7b,
"Wondrous Blue":0xb8cddd,
"Wonton Dumpling":0xd0a46d,
"Wood Acres":0x645a56,
"Wood Ash":0xd7cab0,
"Wood Avens":0xfbeeac,
"Wood Bark":0x302621,
"Wood Brown":0x554545,
"Wood Charcoal":0x464646,
"Wood Chi":0x90835e,
"Wood Garlic":0x7a7229,
"Wood Green":0xa78c59,
"Wood Lake":0xa08475,
"Wood Nymph":0xeba0a7,
"Wood Pigeon":0xaabbcc,
"Wood Stain Brown":0x796a4e,
"Wood Thrush":0xa47d43,
"Wood Violet":0x75406a,
"Wood-Black Red":0x584043,
"Wood's Creek":0x61633f,
"Woodbine":0x7b7f32,
"Woodbridge":0x847451,
"Woodbridge Trail":0xb3987d,
"Woodburn":0x463629,
"Woodchuck":0x8e746c,
"Woodcraft":0x8f847a,
"Wooded Acre":0xb59b7e,
"Wooden Cabin":0x765a3f,
"Wooden Nutmeg":0x745c51,
"Wooden Peg":0xa89983,
"Wooden Swing":0xa58563,
"Woodgrain":0x996633,
"Woodland":0x626746,
"Woodland Brown":0x5f4737,
"Woodland Grass":0x004400,
"Woodland Moss":0x5c645c,
"Woodland Nymph":0x69804b,
"Woodland Sage":0xa4a393,
"Woodland Walk":0x8b8d63,
"Woodlawn Green":0x405b50,
"Woodrose":0xae8c8e,
"Woodruff Green":0x8b9916,
"Woodrush":0x45402b,
"Woodsmoke":0x2b3230,
"Woodstock Rose":0xe9cab6,
"Woodsy Brown":0x3d271d,
"Woodward Park":0x755f4a,
"Wooed":0x40446c,
"Woohringa":0x5f655a,
"Wool Skein":0xd9cfba,
"Wool Turquoise":0x005152,
"Wool Tweed":0x917747,
"Wool Violet":0x5e5587,
"Wool White":0xf9ede4,
"Wool-Milk Pig":0xdbbdaa,
"Woolen Mittens":0xb59f55,
"Woolen Vest":0xb0a582,
"Woolly Beige":0xe7d5c9,
"Woolly Mammoth":0xbb9c7c,
"Wooly Thyme":0x907e63,
"Wooster Smoke":0xa5a192,
"Worcestershire Sauce":0x572b26,
"Work Blue":0x004d67,
"Workout Green":0xbfe6d2,
"Workout Routine":0xffd789,
"Workshop Blue":0x02667b,
"World Peace":0x005477,
"Worldly Gray":0xcec6bf,
"Wormwood Green":0x9fae9e,
"Worn Denim":0x4282c6,
"Worn Jade Tiles":0xd4ded4,
"Worn Khaki":0xa69c81,
"Worn Olive":0x6f6c0a,
"Worn Silver":0xc9c0bb,
"Worn Wood":0xe8dbd3,
"Worn Wooden":0x634333,
"Woven Basket":0x8e7b58,
"Woven Gold":0xdcb639,
"Woven Navajo":0xcead8e,
"Woven Reed":0xdddcbf,
"Woven Straw":0xc1ac8b,
"Woven Wicker":0xb99974,
"Wrack White":0xecead0,
"Wreath":0x76856a,
"Wren":0x4a4139,
"Wright Brown":0x71635e,
"Writer's Parchment":0xe9d6bd,
"Writing Paper":0xf1e6cf,
"Wrought Iron":0x999e98,
"Wrought Iron Gate":0x474749,
"Wu-Tang Gold":0xf8d106,
"Wulfenite":0xce7639,
"Wyvern Green":0x86a96f,
"Xâkestari White":0xfef2dc,
"Xanadu":0x738678,
"Xanthe Yellow":0xffee55,
"Xanthous":0xf1b42f,
"Xavier Blue":0x6ab4e0,
"Xena":0x847e54,
"Xenon Blue":0xb7c0d7,
"Xereus Purple":0x7d0061,
"Xiān Hóng Red":0xe60626,
"Xiàng Yá Bái Ivory":0xece6d1,
"Xiao Long Bao Dumpling":0xbcb7b0,
"Xìng Huáng Yellow":0xfce166,
"Xīpe Totēc Red":0xcc1166,
"Xmas Candy":0x990020,
"Xoxo":0xf08497,
"XV-88":0x72491e,
"Y7K Blue":0x1560fb,
"Yacht Blue":0x679bb3,
"Yacht Club":0x566062,
"Yacht Club Blue":0x485783,
"Yacht Harbor":0x7c9dae,
"Yahoo":0xfabba9,
"Yale Blue":0x0f4d92,
"Yam":0xd0893f,
"Yamabuki Gold":0xffa400,
"Yamabukicha Gold":0xcb7e1f,
"Yān Hūi Smoke":0xa8c3bc,
"Yanagicha":0x9c8a4d,
"Yanagizome Green":0x8c9e5e,
"Yáng Chéng Orange":0xf1a141,
"Yang Mist":0xede8dd,
"Yankee Doodle":0x4d5a6b,
"Yankees Blue":0x1c2841,
"Yardbird":0x9e826a,
"Yarmouth Oyster":0xdccfb6,
"Yarrow":0xd8ad39,
"Yawl":0x547497,
"Yearling":0xad896a,
"Yearning":0x061088,
"Yell Yellow":0xffffbf,
"Yellow":0xffff00,
"Yellow Acorn":0xb68d4c,
"Yellow Avarice":0xf5f5d9,
"Yellow Beam":0xf9eed0,
"Yellow Beige":0xe3c08d,
"Yellow Bell Pepper":0xffdd33,
"Yellow Bird":0xf1cd7b,
"Yellow Blitz":0xfdf4bb,
"Yellow Bombinate":0xfaf3cf,
"Yellow Bonnet":0xf9f6e8,
"Yellow Brick Road":0xeac853,
"Yellow Brown":0xae8b0c,
"Yellow Buzzing":0xeedd11,
"Yellow Canary":0xffeaac,
"Yellow Cattleya":0xfff44f,
"Yellow Chalk":0xf5f9ad,
"Yellow Coneflower":0xedb856,
"Yellow Corn":0xffde88,
"Yellow Cream":0xefdc75,
"Yellow Currant":0xf7c66b,
"Yellow Diamond":0xf6f1d7,
"Yellow Dragon":0xf8e47e,
"Yellow Emulsion":0xf0f0d9,
"Yellow Endive":0xd2cc81,
"Yellow Flash":0xffca00,
"Yellow Geranium":0xffe1a0,
"Yellow Gold":0xbe8400,
"Yellow Green":0xc8fd3d,
"Yellow Green Shade":0xc5e384,
"Yellow Groove":0xf7b930,
"Yellow Iris":0xeee78e,
"Yellow Jacket":0xffcc3a,
"Yellow Jasmine":0xeee8aa,
"Yellow Jasper":0xdaa436,
"Yellow Jubilee":0xffd379,
"Yellow Lupine":0xccaa4d,
"Yellow Maize":0xc0a85a,
"Yellow Mana":0xfdfcbf,
"Yellow Mandarin":0xd28034,
"Yellow Mask":0xf6d255,
"Yellow Metal":0x73633e,
"Yellow Nile":0x95804a,
"Yellow Ocher":0xc39143,
"Yellow Ochre":0xcb9d06,
"Yellow Orange":0xfcb001,
"Yellow Page":0xeadcc6,
"Yellow Pear":0xece99b,
"Yellow Phosphenes":0xe4e4cb,
"Yellow Polka Dot":0xfcb867,
"Yellow Powder":0xfcfd74,
"Yellow Rose":0xfff000,
"Yellow Salmonberry":0xfff47c,
"Yellow Sand":0xa28744,
"Yellow Sea":0xf49f35,
"Yellow Shimmer":0xf8e2ca,
"Yellow Shout":0xd19932,
"Yellow Stagshorn":0xfada5e,
"Yellow Submarine":0xffff14,
"Yellow Summer":0xf9b500,
"Yellow Sunshine":0xfff601,
"Yellow Tail":0xfff29d,
"Yellow Tan":0xffe36e,
"Yellow Tang":0xffd300,
"Yellow Trumpet":0xf9d988,
"Yellow Umbrella":0xcdbb63,
"Yellow Urn Orchid":0xfffdd0,
"Yellow Varnish":0xeab565,
"Yellow Warbler":0xffba6f,
"Yellow Warning":0xc69035,
"Yellow Wax Pepper":0xede5b7,
"Yellow Yarn":0xfef6be,
"Yellow-Bellied":0xffee33,
"Yellow-Green Grosbeak":0xc8cd37,
"Yellow-Rumped Warbler":0xeebb77,
"Yellowed Bone":0xf6f1c4,
"Yellowish":0xfaee66,
"Yellowish Brown":0x9b7a01,
"Yellowish Green":0xb0dd16,
"Yellowish Grey":0xedeeda,
"Yellowish Orange":0xffab0f,
"Yellowish Tan":0xfcfc81,
"Yellowish White":0xe9f1d0,
"Yellowstone":0xceb736,
"Yellowstone Park":0xe4d6ba,
"Yellowy Green":0xbff128,
"Yeti Footprint":0xc7d7e0,
"Yín Bái Silver":0xe0e1e2,
"Yin Hūi Silver":0x848999,
"Yin Mist":0x3b3c3c,
"Yín Sè Silver":0xb1c4cb,
"Yíng Guāng Sè Green":0x05ffa6,
"Yíng Guāng Sè Pink":0xff69af,
"Yíng Guāng Sè Purple":0x632de9,
"YInMn Blue":0x2e5090,
"Yippie Ya Yellow":0xf9f59f,
"Yippie Yellow":0xffff84,
"Yoga Daze":0xe3e4d2,
"Yogi":0x8a8c66,
"Yogurt":0xffecc3,
"Yolanda":0xa291ba,
"Yolande":0xd5a585,
"Yolk":0xeec701,
"Yolk Yellow":0xe2b051,
"York Bisque":0xf3d9c7,
"York Pink":0xd7837f,
"York Plum":0xd3bfe5,
"York River Green":0x67706d,
"Yorkshire Brown":0x735c53,
"Yorkshire Cloud":0xbac3cc,
"Yoshi":0x55aa00,
"You're Blushing":0xe2caaf,
"Young Apricot":0xfcd8b5,
"Young At Heart":0xd5a1a9,
"Young Bamboo":0x68be8d,
"Young Bud":0x86af38,
"Young Colt":0x938c83,
"Young Cornflower":0xbbffff,
"Young Crab":0xf6a09d,
"Young Fawn":0xc3b4b3,
"Young Fern":0x71bc78,
"Young Gecko":0xaac0ad,
"Young Grass":0xc3d825,
"Young Green":0x97d499,
"Young Green Onion":0xaacf53,
"Young Greens":0xd8e698,
"Young Leaf":0xb0c86f,
"Young Leaves":0xb9d08b,
"Young Mahogany":0xca3435,
"Young Night":0x232323,
"Young Peach":0xf2e1d2,
"Young Plum":0xacc729,
"Young Prince":0xb28ebc,
"Young Purple":0xbc64a4,
"Young Redwood":0xab4e52,
"Young Salmon":0xffb6b4,
"Young Tangerine":0xffa474,
"Young Turk":0xc9afa9,
"Young Wheat":0xe1e3a9,
"Your Majesty":0x61496e,
"Your Pink":0xffc5bb,
"Your Shadow":0x787e93,
"Youth":0xe2c9c8,
"Youthful Coral":0xee8073,
"Yreka!":0xa7b3b7,
"Yriel Yellow":0xffdb58,
"Yù Shí Bái White":0xc0e2e1,
"Yucatan":0xe9af78,
"Yucatan White Habanero":0xf2efe0,
"Yucca":0x75978f,
"Yucca Cream":0xa1d7c9,
"Yucca White":0xf2ead5,
"Yuè Guāng Lán Blue":0x2138ab,
"Yuè Guāng Lán Moonlight":0x5959ab,
"Yukon Gold":0x826a21,
"Yule Tree":0x66b032,
"Yuma":0xc7b882,
"Yuma Gold":0xffd678,
"Yuma Sand":0xcfc5ae,
"Yuzu Jam":0xfdd200,
"Yuzu Soy":0x112200,
"Yves Klein Blue":0x00008b,
"Zaffre":0x0014a8,
"Zahri Pink":0xec6d71,
"Zambezi":0x6b5a5a,
"Zambia":0xff990e,
"Zamesi Desert":0xdda026,
"Zanah":0xb2c6b1,
"Zanci":0xd38977,
"Zandri Dust":0xa39a61,
"Zangief's Chest":0x823c3d,
"Zany Pink":0xe47486,
"Zanzibar":0x7e6765,
"Zǎo Hóng Maroon":0xc1264c,
"Zappy Zebra":0xf1f3f3,
"Zard Yellow":0xfde634,
"Zatar Leaf":0x60a448,
"Zebra Finch":0xcec6bb,
"Zebra Grass":0x9da286,
"Zeftron":0x0090ad,
"Zelyony Green":0x016612,
"Zen":0xcfd9de,
"Zen Blue":0x9fa9be,
"Zen Essence":0xc6bfa7,
"Zen Garden":0xd1dac0,
"Zen Retreat":0x5b5d5c,
"Zenith":0x497a9f,
"Zenith Heights":0xa6c8c7,
"Zephyr":0xc89fa5,
"Zephyr Blue":0xd3d9d1,
"Zephyr Green":0x7cb083,
"Zero Degrees":0xddd9c4,
"Zero Gravity":0x332233,
"Zest":0xc6723b,
"Zesty Apple":0x92a360,
"Zeus":0x3b3c38,
"Zeus Palace":0x3c343d,
"Zeus Purple":0x660077,
"Zeus Temple":0x6c94cd,
"Zheleznogorsk Yellow":0xfef200,
"Zhēn Zhū Bái Pearl":0xf8f8f9,
"Zhohltyi Yellow":0xe4c500,
"Zhū Hóng Vermillion":0xcb464a,
"Zǐ Lúo Lán Sè Violet":0x9f0fef,
"Zǐ Sè Purple":0xc94cbe,
"Zia Olive":0x082903,
"Ziggurat":0x81a6aa,
"Zima Blue":0x16b8f3,
"Zimidar":0x6a5287,
"Zin Cluster":0x463b3a,
"Zinc":0x92898a,
"Zinc Blend":0xa3907e,
"Zinc Dust":0x5b5c5a,
"Zinc Grey":0x655b55,
"Zinc Luster":0x8c8373,
"Zinfandel":0x5c2935,
"Zinfandel Red":0x5a3844,
"Zing":0xfbc17b,
"Zingiber":0xdac01a,
"Zinnia":0xffa010,
"Zinnia Gold":0xffd781,
"Zinnwaldite":0xebc2af,
"Zinnwaldite Brown":0x2c1608,
"Zircon":0xdee3e3,
"Zircon Blue":0x00849d,
"Zircon Grey":0x807473,
"Zircon Ice":0xd0e4e5,
"Zitronenzucker":0xf4f3cd,
"Zodiac Constellation":0xee8844,
"Zombie":0x595a5c,
"Zomp":0x39a78e,
"Zōng Hóng Red":0xca6641,
"Zoom":0x7b6c74,
"Zorba":0xa29589,
"Zucchini":0x17462e,
"Zucchini Cream":0x97a98b,
"Zucchini Flower":0xe8a64e,
"Zucchini Noodles":0xc8d07f,
"Zumthor":0xcdd5d5,
"Zunda Green":0x6bc026,
"Zuni":0x008996,
"Zürich Blue":0x248bcc,
"Zürich White":0xe6e1d9,

}
def color(color):
    return str("0x"+"%03x" % colors.get(color))